/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(ub){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function sb(tb){var r=tb.a;var s=r.buffer;r.grow=qb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=tb.abort;var M=NaN;var N=Infinity;var O=tb.b;var P=tb.c;var Q=tb.d;var R=tb.e;var S=tb.f;var T=tb.g;var U=tb.h;var V=tb.i;var W=tb.j;var X=tb.k;var Y=tb.l;var Z=tb.m;var _=tb.n;var $=tb.o;var aa=tb.p;var ba=tb.q;var ca=tb.r;var da=tb.s;var ea=tb.t;var fa=tb.u;var ga=tb.v;var ha=tb.w;var ia=tb.x;var ja=tb.y;var ka=tb.z;var la=tb.A;var ma=tb.B;var na=tb.C;var oa=tb.D;var pa=tb.E;var qa=tb.F;var ra=tb.G;var sa=tb.H;var ta=tb.I;var ua=tb.J;var va=tb.K;var wa=tb.L;var xa=tb.M;var ya=tb.N;var za=tb.O;var Aa=tb.P;var Ba=tb.Q;var Ca=tb.R;var Da=tb.S;var Ea=tb.T;var Fa=tb.U;var Ga=tb.V;var Ha=tb.W;var Ia=tb.X;var Ja=tb.Y;var Ka=tb.Z;var La=tb._;var Ma=tb.$;var Na=tb.aa;var Oa=tb.ba;var Pa=tb.ca;var Qa=tb.da;var Ra=tb.ea;var Sa=tb.fa;var Ta=tb.ga;var Ua=tb.ha;var Va=tb.ia;var Wa=tb.ja;var Xa=tb.ka;var Ya=tb.la;var Za=tb.ma;var _a=tb.na;var $a=tb.oa;var ab=tb.pa;var bb=tb.qa;var cb=tb.ra;var db=tb.sa;var eb=tb.ta;var fb=tb.ua;var gb=5709392;var hb=0;var ib=0;var jb=0;
// EMSCRIPTEN_START_FUNCS
function Gt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=C(0),ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=C(0),Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=C(0),Ua=0;fa=gb-48|0;gb=fa;Aa=fa+40|0;v[Aa>>2]=55324;v[Aa>>2]=55224;d=dL(fa+32|0);e=dL(fa+24|0);f=v[d+4>>2];v[fa+16>>2]=v[d>>2];v[fa+20>>2]=f;f=v[e+4>>2];v[fa+8>>2]=v[e>>2];v[fa+12>>2]=f;ua=b;Ca=c;b=0;Y=gb-128|0;gb=Y;N=a;Da=a+24604|0;c=Da;a:{if(!v[c+16>>2]){break a}a=v[c+20>>2];if(a>>>0>4|!(1<<a&22)){break a}a=v[c+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){c=Y+112|0;UO(c,6290,10340,200,45);e=gb-160|0;gb=e;v[e+88>>2]=0;b=fu(e+88|0);v[22708]=0;f=Q(2,e+120|0,14842)|0;a=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{if((a|0)!=1){v[22708]=0;U(6,e+104|0,1,14484);a=v[22708];v[22708]=0;if((a|0)==1){break h}v[22708]=0;U(3,e+136|0,f|0,e+104|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;ha(33,b|0,c|0,1,10893,e+136|0);a=v[22708];v[22708]=0;if((a|0)==1){break f}vb(e+136|0);vb(e+104|0);vb(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(e+136|0)}vb(e+104|0)}vb(f)}S(b|0);L()}gb=e+160|0}a=v[N+480208>>2];i:{if(!ua|a&512){break i}Ka=N+8204|0;La=N+1074332|0;Ma=N+397452|0;Na=N+397448|0;Oa=N+393352|0;Pa=N+397456|0;ma=N+12|0;Ea=N+1298260|0;Qa=N+1074376|0;i=v[N+1074380>>2];while(1){j:{if(i){break j}ga=N;b=a|512;k:{if(a&256){break k}i=0;p=gb-48|0;gb=p;R=gb-32|0;gb=R;s=N;d=s;a=d+1074392|0;b=v[a>>2]+1|0;v[a>>2]=b;l:{m:{j=d+1074376|0;n:{if(uk(j)>>>0>b>>>0){break n}k=d+1074312|0;c=d+1074992|0;f=d+1298224|0;h=d+1074424|0;o=d+484344|0;m=d+484360|0;n=d+1074448|0;l=d+480210|0;while(1){Rz(R+24|0,d,j,(v[d+480208>>2]&524288)>>>19|0);o:{p:{q:{r:{if(!(w[d+480208|0]&32)){b=x[n>>1];a=d;s:{if(tc(Sb(m))>>>0>b>>>0){b=x[sc(Sb(m),x[n>>1])>>1];break s}b=65535}u[a+1074446>>1]=b;t:{if(Te(o)>>>0<=(b&65535)>>>0){break t}if(ii(_b(o,x[d+1074446>>1]))){break t}u[d+1074446>>1]=65534}if(x[d+1074446>>1]>=Te(o)>>>0){while(1){u:{v:{w:{x:{if(x[d+1074446>>1]!=65535){a=x[n>>1];if(tc(Sb(m))>>>0>a>>>0){break x}}b=x[Sb(m)+28>>1];if(b){break v}a=x[n>>1];if(tc(Sb(m))>>>0<a>>>0){break w}a=x[n>>1];if(!a){break w}while(1){b=a;a=b-1|0;if(!a){break w}if(x[sc(Sb(m),a)>>1]!=65535){continue}break}break v}a=x[n>>1]+1|0;u[n>>1]=a;break u}b=0}u[d+1074448>>1]=b;v[d+480208>>2]=v[d+480208>>2]&-524289;y:{if(tc(Sb(m))>>>0<=(b&65535)>>>0){break y}while(1){if(x[sc(Sb(m),x[n>>1])>>1]!=65534){break y}a=x[n>>1]+1|0;u[n>>1]=a;if(tc(Sb(m))>>>0>(a&65535)>>>0){continue}break}}a=x[n>>1];if(tc(Sb(m))>>>0<=a>>>0){break r}if(!No(Sb(m),x[n>>1])){break r}a=x[n>>1]}b=d;z:{if(tc(Sb(m))>>>0>(a&65535)>>>0){a=x[sc(Sb(m),x[n>>1])>>1];break z}a=65535}u[b+1074446>>1]=a;A:{if(Te(o)>>>0<=(a&65535)>>>0){break A}if(ii(_b(o,x[d+1074446>>1]))){break A}u[d+1074446>>1]=65534}if(x[d+1074446>>1]>=Te(o)>>>0){continue}break}}u[d+1074450>>1]=x[d+1074448>>1]}if(!me(o,x[d+1074446>>1])){break m}if(y[d+1074424>>2]>=y[_b(o,x[d+1074446>>1])+12>>2]){v[h>>2]=0}if(v[d+480208>>2]&32?v[d+480272>>2]!=-1:0){break o}if(!Au(f,x[n>>1],v[h>>2],Iq(R+16|0,c),w[R+24|0])){break o}a=v[d+480272>>2];if(a){if((a|0)>=1){v[d+480272>>2]=a-1}Io(f,1);Au(f,x[n>>1],v[h>>2],Iq(R+16|0,c),w[R+24|0]);break o}if(!(w[l|0]&64)){break r}if(nR(f,n,h,1)){break p}v[d+1074448>>2]=0;v[d+1074424>>2]=0;v[d+1074428>>2]=0;if(w[m+16|0]<(Qi(m)-1|0)){break q}Ri(m,0)}Io(f,1);break m}Ri(m,w[m+16|0]+1&255);Io(f,1)}a=0;while(1){_m((d+B(a,872)|0)+1074992|0,7,d,a&65535,134217728);a=a+1|0;if((a|0)!=256){continue}break}KO(d);v[d+1074416>>2]=v[d+480196>>2];v[d+1074420>>2]=v[d+480204>>2];v[d+1074456>>2]=v[d+480200>>2];u[d+1074450>>1]=x[d+1074448>>1];v[d+1074428>>2]=v[d+1074424>>2];b=f;e=tc(Sb(m));a=x[d+1074448>>1];if(e>>>0>a>>>0){Ra=d,Sa=x[sc(Sb(m),x[d+1074448>>1])>>1],u[Ra+1074446>>1]=Sa;a=x[d+1074448>>1]}Au(b,a&65535,v[d+1074424>>2],Iq(R+16|0,c),w[R+24|0]);if(!me(o,x[d+1074446>>1])){break m}}Qz(d,j,(v[d+480208>>2]&32)>>>5|0);b=Xc(_b(o,x[d+1074446>>1]),v[d+1074424>>2],0);a=x[d+480188>>1];if(a){g=(d+B(a,872)|0)+1074992|0;a=c;while(1){e=R+16|0;Db(e,k,82);B:{if(!Cb(e)|w[a+805|0]!=1){break B}e=w[b+3|0];if((e|0)!=3?(e|0)!=2:0){break B}Ra=a,Sa=_g(d,w[a+800|0],u[a+772>>1],v[a+704>>2]),v[Ra+700>>2]=Sa}e=R+16|0;Db(e,k,91);C:{if(!Cb(e)){break C}if(ce(b)){break C}if(!ce(a+788|0)|w[a+791|0]!=19){break C}e=w[a+793|0];if((e&240)!=208|y[d+1074416>>2]>(e&15)>>>0){break C}Ra=a,Sa=_g(d,w[a+788|0],u[a+772>>1],0),v[Ra+700>>2]=Sa}e=R+16|0;Db(e,k,92);D:{if(!Cb(e)){break D}e=R+8|0;Db(e,k,5);if(Cb(e)|v[d+1074416>>2]!=1|w[a+791|0]!=17){break D}v[d+1074420>>2]=B(w[a+793|0],1e4)}e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+788|0]=e;t[a+789|0]=e>>>8;t[a+790|0]=e>>>16;t[a+791|0]=e>>>24;e=w[b+4|0]|w[b+5|0]<<8;t[a+792|0]=e;t[a+793|0]=e>>>8;e=v[a+676>>2];v[a+20>>2]=v[a+672>>2];v[a+24>>2]=e;v[a+88>>2]=v[a+88>>2]&-393217;e=R+16|0;Db(e,k,21);if(!Cb(e)){t[a+831|0]=0}v[a+860>>2]=0;t[a+805|0]=0;b=b+6|0;a=a+872|0;if((g|0)!=(a|0)){continue}break}}a=d;b=a+1074412|0;E:{F:{e=a+484344|0;if(am(e,x[a+1074446>>1])){if(KP(_b(e,x[a+1074446>>1]))){break F}}v[a+1074408>>2]=v[a+480216>>2];a=v[a+480220>>2];break E}Ra=a+1074408|0,Sa=v[_b(e,x[a+1074446>>1])+16>>2],v[Ra>>2]=Sa;a=v[_b(e,x[a+1074446>>1])+20>>2]}v[b>>2]=a;if(!w[R+24|0]){break n}a=v[d+1074416>>2]+1|0;v[d+1074392>>2]=a;if(uk(j)>>>0<=a>>>0){continue}break}}if(!v[d+1074416>>2]){v[d+1074416>>2]=1}b=v[d+480208>>2];a=d;G:{H:{if(v[d+1074392>>2]){v[d+480208>>2]=b&-4097;if(v[d+480180>>2]&1048580|(w[d+480210|0]&32?0:v[d+480180>>2]==1)){break G}if(y[d+1074392>>2]>=uk(j)>>>0|y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)){break G}b=v[d+480208>>2];break H}b=b&-528385}v[a+480208>>2]=b|4096}K=0;E=gb-16|0;gb=E;u[d+1074444>>1]=65535;a=d+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;r=d+480208|0;$=d+1074376|0;if(x[d+480188>>1]){V=d+1075809|0;aa=d+1298260|0;I=d+1074312|0;T=d+480210|0;while(1){A=d+B(K,872)|0;o=A+1075785|0;q=w[o|0];k=A+1075783|0;b=w[k|0];j=A+1075784|0;l=w[j|0];H=A+1075782|0;e=w[H|0];_=A+1075781|0;f=w[_|0];h=v[d+1074392>>2];g=v[d+1074400>>2];c=v[d+1074416>>2];ba=A+1075780|0;a=tu(ba);W=A+1075843|0;t[W|0]=v[d+480208>>2]>>>12&1|w[W|0]&254;m=(h>>>0)%(c+g>>>0)|0;g=w[ba|0];if((g|0)==252){h=w[_|0];g=Hq(ba);c=Eo(ba);I:{if(!h|h-251>>>0<5){break I}h=v[(d+B(h,160)|0)+906140>>2];if(!h){break I}kb[v[v[h>>2]+44>>2]](h,g,C(C(c>>>0)/C(999)))}g=w[ba|0]}J:{if(b&255|z[A+1075852>>2]==C(0)?(g&255)!=251:0){break J}h=v[r>>2]&4096;K:{if(!h){c=w[A+1075862|0];break K}c=w[_|0];t[A+1075862|0]=c}if(!c|c-251>>>0<5){break J}n=(d+B(c,160)|0)+906140|0;if(!v[n>>2]){break J}L:{if(!h){g=x[A+1075860>>1];break L}g=pu(w[H|0],w[j|0]);u[A+1075860>>1]=g;da=C(C(pu(w[k|0],w[o|0])>>>0)/C(999));z[A+1075856>>2]=da;c=v[n>>2];Ra=A+1075852|0,Ta=C(C(da-C(kb[v[v[c>>2]+48>>2]](c,g)))/C(uk($)>>>0)),z[Ra>>2]=Ta}j=v[d+1074392>>2];c=uk($);h=v[n>>2];c=(c|0)==(j+1|0);kb[v[v[h>>2]+(c?44:104)>>2]](h,g,z[(c?A+1075856|0:A+1075852|0)>>2]);g=w[ba|0]}k=A+1074992|0;M:{N:{O:{P:{Q:{if(!EP(g&255)){if(w[r+1|0]&16){break P}c=f;break Q}b=gb-16|0;gb=b;u[b+12>>1]=0;v[b+8>>2]=0;bj(b+8|0);a=x[b+12>>1];t[k+792|0]=a;t[k+793|0]=a>>>8;a=v[b+8>>2];t[k+788|0]=a;t[k+789|0]=a>>>8;t[k+790|0]=a>>>16;t[k+791|0]=a>>>24;gb=b+16|0;c=0;e=0;l=0;b=0;q=0;a=0;j=0;h=0;n=0;f=0;o=0;g=0;if(w[r+1|0]&16){break N}}xP(d,k);f=c;break O}if(!f){f=0;break O}v[A+1075752>>2]=0}o=0;c=b&255;R:{S:{T:{if(c-19>>>0>=2){if((c|0)!=33){break T}b=E+8|0;Db(b,I,30);o=q>>>4|0;qA(d,K&65535,o+(q&15)|0,Cb(b));b=33;break S}U:{if(!(!(v[d+480180>>2]&16777250)|q)){q=w[A+1075825|0];break U}t[A+1075825|0]=q}c=q&240;if((c|0)==208){g=q&15;if(!g){if(v[d+480180>>2]&16777248){j=b;h=l;o=1;break R}c=a;j=b;h=l;n=e;g=q;if(v[d+480180>>2]!=2){break N}break M}V:{if(g>>>0<v[d+1074400>>2]+v[d+1074416>>2]>>>0){break V}c=E+8|0;Db(c,I,14);if(!Cb(c)){break V}if(!f){break M}t[A+1075795|0]=f;break M}j=b;h=l;o=g;break R}if(!(w[r+1|0]&16)|(c|0)!=224|(v[d+1074396>>2]?v[d+480180>>2]&16777250:0)){break T}c=q&15;if(c?0:v[d+480180>>2]&2){break T}v[d+1074396>>2]=c+1}}j=b;h=l}c=a;n=e;g=q}J=j&255;e=v[d+480180>>2]==16&(J|0)==19&(g&240)==208;X=e?0:o;W:{if(!X|w[ba|0]!=255|w[H|0]!=2){break W}a=E+8|0;Db(a,I,74);if(!Cb(a)){break W}t[H|0]=0}l=v[d+1074392>>2];a=E+8|0;Db(a,I,72);X:{if(Cb(a)){F=0;if(X>>>0>=y[d+1074416>>2]){break X}}b=E+8|0;Db(b,I,88);F=(m|0)==(X|0)|(l|0)==(X|0);if(!(!Cb(b)|!X)){break X}F=(l|0)==(X|0)}a=E+8|0;Db(a,I,44);if(Cb(a)){t[W|0]=w[W|0]&254|(m|0)==(X|0)}G=g&15;b=e?G|144:g;a=E+8|0;Db(a,I,66);c=(!X|Cb(a)^-1)&c;Y:{Z:{if(!(v[d+1074392>>2]|(!(w[T|0]&32)|!f))){v[A+1075652>>2]=0;if(F){break Z}if(!Ni(k)){break Y}t[A+1075795|0]=f;if(x[d+480190>>1]<f>>>0){break Y}a=d+B(f,104)|0;v[A+1075680>>2]=x[a+484410>>1];u[A+1075764>>1]=t[a+484417|0];break Y}if(!F){break Y}}g=w[ba|0];if(f){t[A+1075795|0]=f}_:{$:{if(!we(g)){break $}a=E+8|0;Db(a,I,67);if(!Cb(a)){break $}a=u[A+1075762>>1];aa:{if(!f|c){break aa}e=aA(d,g,f);if(!e){break aa}a=t[Tl(d,e)+36|0]}g=(a+g|0)-12>>>0>119?0:g;break _}if(!(v[d+480180>>2]&25165856)|!x[d+480192>>1]){break _}a=g;if(a){a=we(a)}else{a=1}if(!a){break _}a=f;ba:{if(!a){a=w[A+1075796|0];if(!a){break ba}}if(v[(d+(a<<2)|0)+900380>>2]?x[d+480192>>1]>=a>>>0:0){break _}g=0}f=0}if(!((J|0)!=25|b)){a=E+8|0;Db(a,I,55);a=Cb(a);f=a?0:f;g=a?0:g}a=E+8|0;Db(a,I,65);o=(f|0)!=0;l=!g;e=Cb(a);q=1;ca:{if(v[d+480180>>2]&16777248){break ca}a=E+8|0;Db(a,I,107);if(Cb(a)){break ca}Db(E,I,85);q=0;if(!Cb(E)){break ca}if(Ni(k)){break ca}q=1;a=v[A+1075096>>2];if(!a){break ca}q=Md(a)^1}m=l&o;o=e&o;da:{ea:{fa:{ga:{ha:{ia:{if(!(v[d+480180>>2]&1048580)){break ia}ja:{if((g|0)!=255){break ja}if((J|0)!=13?(n&255)==1|f:1){a=E+8|0;Db(a,I,55);if(Cb(a)){break ja}}a=v[A+1075648>>2];if(t[a+60|0]&1?a:0){break ja}v[A+1075680>>2]=0;f=A+1075080|0;v[f>>2]=v[f>>2]|2097152;ka:{if(!(v[d+480208>>2]&4096)){break ka}a=E+8|0;Db(a,I,86);if(!Cb(a)){break ka}v[f>>2]=v[f>>2]|4096}f=0;g=0;e=0;a=0;l=0;m=1;if(o){break ea}break da}a=E+8|0;Db(a,I,59);if(!Cb(a)|v[r>>2]&4096){break ia}la:{if(!g){g=w[A+1075789|0]-w[A+1075762|0]|0;break la}if(g>>>0>250){q=0;o=1;g=0;break la}ma:{if(f){break ma}a=E+8|0;Db(a,I,98);if(!Cb(a)){break ma}f=0;break la}q=1;o=1}e=g;c=0;break ha}e=0;l=0;if(!m){break ga}}a=E+8|0;Db(a,I,65);if(!Cb(a)){break fa}g=e;l=1}a=g;e=l;m=1;if(o){break ea}break da}g=e;e=1;m=o}na:{oa:{if(!x[d+480192>>1]){if(x[d+480190>>1]<f>>>0){break na}a=(d+B(f,104)|0)+484380|0;break oa}a=v[A+1075096>>2];if(!a){break na}}pa:{if(u[a+34>>1]<0){break pa}if(v[d+480180>>2]==2){if(!Md(a)){break pa}}v[A+1075680>>2]=x[a+30>>1]}if(!m){break na}So(k,x[a+28>>1],d)}a=g;l=e}e=E+8|0;Db(e,I,71);if(!(!Cb(e)|!f)){t[A+1075831|0]=32}qa:{if(!x[d+480192>>1]){break qa}e=E+8|0;Db(e,I,100);if(!Cb(e)|!f){break qa}if(we(a&255)){break qa}e=v[r>>2];ra:{if(c){if(e&8){break ra}break qa}if(!(e&4)){break qa}}Lm(k);v[A+1075688>>2]=65536;e=A+1075080|0;v[e>>2]=v[e>>2]|2097152}if(l){e=E+8|0;Db(e,I,11);sa:{if(!(Ra=Cb(e),Sa=1,Ua=v[d+480180>>2]!=268435456,Ua?Ra:Sa)){break sa}e=E+8|0;Db(e,I,87);g=0;if(Cb(e)){g=Ni(k)^1}ta:{if(x[d+480192>>1]){if(x[d+480192>>1]<f>>>0){break sa}if(v[A+1075648>>2]!=v[(d+(f<<2)|0)+900380>>2]|g){break ta}break sa}if((v[A+1075096>>2]!=((d+B(f,104)|0)+484380|0)|g)!=1){break sa}}a=w[A+1075789|0]}ua:{if(!x[d+480192>>1]|!(v[d+480180>>2]&1048588)){break ua}Lm(k);t[A+1075810|0]=0;v[A+1075748>>2]=0;v[A+1075688>>2]=65536;g=A+1075080|0;v[g>>2]=v[g>>2]&-2101249|2097152;e=E+8|0;Db(e,I,86);if(!Cb(e)){break ua}v[g>>2]=v[g>>2]&-2049}f=q?f:0}q=a&255;va:{if(q>>>0<251){break va}e=E+8|0;Db(e,I,50);wa:{if(!Cb(e)|!f){break wa}e=aA(d,w[A+1075791|0],f);if(!e){break wa}e=d+B(e,104)|0;if(u[e+484414>>1]<0){break wa}v[A+1075680>>2]=x[e+484410>>1]}e=E+8|0;Db(e,I,100);if(Ra=Cb(e),Sa=0,Ua=v[r>>2]&4,Ua?Ra:Sa){break va}f=0}xa:{if(!we(q)){break xa}t[A+1075794|0]=a;t[A+1075791|0]=a;if(!c){AP(d,K&65535,f,q,0)}e=A+1075776|0;a=u[e>>1];if(a){v[A+1075684>>2]=(a&32767)-1;if((a|0)<=-1){a=A+1075080|0;v[a>>2]=v[a>>2]|256}u[e>>1]=0}e=A+1075787|0;a=w[e|0];if(a){t[A+1075830|0]=a-1;t[e|0]=0}e=A+1075788|0;a=w[e|0];if(!a){break xa}t[A+1075829|0]=a-1;t[e|0]=0}ya:{za:{Aa:{Ba:{Ca:{if(f){g=A+1075096|0;e=v[g>>2];Do(d,k,f,c,1,1);a=v[g>>2];Da:{if(!a|!(w[a+35|0]&2)){break Da}if(!Dd(aa)){break Da}Du(v[aa>>2],K&65535,v[g>>2]+68|0)}Ea:{Fa:{if(v[d+480180>>2]==1){if(!c){break Fa}a=E+8|0;Db(a,I,85);if(!Cb(a)){break Fa}break Ea}a=E+8|0;Db(a,I,50);if(!Cb(a)){break Fa}if(!we(q)){break Ea}}t[A+1075795|0]=0}a=E+8|0;Db(a,I,42);if(Cb(a)){if(!we(q)|(e|0)==v[g>>2]){break Ba}break Ca}if(!(!(v[d+480180>>2]&16777248)|(e|0)==v[g>>2])){a=0;if(we(q)){break Aa}}a=E+8|0;Db(a,I,107);Ga:{if(!Cb(a)|(e|0)==v[g>>2]){break Ga}Ha:{if(!c){if(we(q)){break Ha}}a=A+1075068|0;if(y[a>>2]>=y[k+4>>2]){break Ga}v[a>>2]=0;break Ba}c=0}a=E+8|0;Db(a,I,85);if(!Cb(a)){break Ba}if(!Ni(k)){break Ca}break Ba}if(!q){a=c;break ya}e=0;m=A+1075795|0;Ia:{if(!w[m|0]){break Ia}if(!we(q)){break Ia}Do(d,k,w[m|0],c,!(v[A+1075096>>2]?1:v[A+1075648>>2]),!(v[d+480180>>2]&1048580));t[m|0]=0;e=1}a=c;break za}v[k>>2]=0;v[k+4>>2]=0}a=c}e=0;if(!q){break ya}}g=A+1075096|0;c=v[g>>2];Ja:{if(!c|!(w[c+35|0]&2)){break Ja}if(!Dd(aa)){break Ja}if(!e){if(BP(v[aa>>2],K&65535)){break Ja}}Du(v[aa>>2],K&65535,v[g>>2]+68|0)}e=K&65535;qu(d,k,q,a,!(v[d+480180>>2]&1048580),0,e);if(!(!a|(!(v[d+480180>>2]&1048580)|!f))){c=A+1075080|0;v[c>>2]=v[c>>2]|2097152;Lm(k);t[A+1075810|0]=0;v[A+1075748>>2]=0}if(!(v[A+1075080>>2]&512)){break ya}if(!Dd(aa)){break ya}Ka:{switch(q-253|0){case 0:c=E+8|0;Db(c,I,99);if(Cb(c)){break ya}break;case 1:case 2:break Ka;default:break ya}}c=E+8|0;Db(c,I,110);if(Cb(c)){WA(v[aa>>2],e,0,1,0)}vk(v[aa>>2],e)}La:{Ma:{switch((n&255)-1|0){case 0:h=h>>>0<64?h:64;v[A+1075680>>2]=h<<2;c=A+1075080|0;v[c>>2]=v[c>>2]|2097152;break La;case 1:break Ma;default:break La}}Nm(d,k,h,6)}if(x[d+480192>>1]){iO(d,K&65535)}c=a}a=E+8|0;Db(a,I,77);if(Ra=Cb(a),Sa=0,Ua=v[(d+(K<<5)|0)+480280>>2]&1024,Ua?Ra:Sa){break M}f=v[d+1074392>>2];a=E+8|0;Db(a,I,75);e=f>>>0>=X>>>0;Na:{Oa:{Pa:{Qa:{if(!Cb(a)|!X){break Qa}a=v[d+1074392>>2];if(!a){break Pa}e=1;if((a|0)!=(X|0)){break Qa}e=!w[_|0]&(n&255)!=11}f=n&255;if(!e|f>>>0<3){break Pa}if((f|0)==11){f=E+8|0;yA(f,d,ba,X);a=w[Ve(f)|0];zo(d,k,x[f>>1]);if(a){break Oa}n=11;break Pa}a=E+8|0;Db(a,I,62);Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{if(!(!Cb(a)|h)){h=0;n=0;Ya:{switch(f-8|0){case 0:break Xa;case 1:break Ya;default:break Pa}}if(w[r+1|0]&16){break Pa}v[A+1075684>>2]=0;break Pa}a=E+8|0;Db(a,I,41);Za:{if(Cb(a)){break Za}if(h){t[A+1075826|0]=h;break Za}h=w[A+1075826|0]}_a:{switch(f-3|0){case 0:case 1:$a:{ab:{if(h){break ab}a=E+8|0;Db(a,I,41);if(!Cb(a)){break ab}h=w[A+1075826|0];if(h){break $a}h=0;break Pa}t[A+1075826|0]=h}Co(d,k,((f|0)==3?h<<4:h)&255);break Pa;case 2:if((X|0)!=v[d+1074392>>2]){a=E+8|0;Db(a,I,41);n=5;if(Cb(a)){break Pa}}a=E+8|0;Db(a,I,41);Gq(d,k,h,Cb(a));n=5;break Pa;case 3:if((X|0)!=v[d+1074392>>2]){a=E+8|0;Db(a,I,41);n=6;if(Cb(a)){break Pa}}a=E+8|0;Db(a,I,41);Fq(d,k,h,Cb(a));n=6;break Pa;case 11:break Ra;case 12:break Sa;case 10:break Ta;case 9:break Ua;case 7:break Va;case 6:break Wa;case 5:break Xa;case 4:break _a;default:break Pa}}a=E+8|0;Db(a,I,53);if(Cb(a)){t[A+1075815|0]=h&15;n=7;break Pa}Hl(k,h<<4);n=7;break Pa}Hl(k,h);n=8;break Pa}a=E+8|0;Db(a,I,62);pA(d,k,h,Cb(a)^1);n=9;break Pa}a=E+8|0;Db(a,I,62);pA(d,k,h<<4&240,Cb(a)^1);n=10;break Pa}n=12;a=E+8|0;Db(a,I,12);wP(d,K&65535,h<<2&252,Cb(a));break Pa}a=E+8|0;Db(a,I,12);vP(d,K&65535,h<<2&252,Cb(a));n=13;break Pa}n=15;if(!F){break Pa}a=A+1075096|0;if(!v[a>>2]|h>>>0>9){break Pa}bb:{if(!h){f=v[A+1075656>>2];break bb}f=v[yf(v[a>>2]+68|0,h-1|0)>>2];v[A+1075656>>2]=f}Mm(d,k,f);break Pa}n=14;if(h>>>0>1){break Pa}t[W|0]=w[W|0]&251|!h<<2}f=b;cb:{db:{eb:{fb:{switch(J-1|0){case 12:if(!(w[r+1|0]&16)){break Oa}a=d+B(K,872)|0;v[a+1075680>>2]=b>>>0<64?b<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Oa;case 1:if(!b){f=0;if(v[d+480180>>2]&1){break Na}}wP(d,K&65535,b,0);break Oa;case 2:if(!b){f=0;if(v[d+480180>>2]&1){break Na}}vP(d,K&65535,b,0);break Oa;case 10:if(!b){f=0;if(v[d+480180>>2]==1){break Na}}Co(d,k,b);break Oa;case 3:zo(d,k,b);break Oa;case 5:if(v[d+480180>>2]==1?b:1){Co(d,k,b)}zo(d,k,0);break Oa;case 4:Hl(k,b);break Oa;case 6:if(v[d+480180>>2]==1?b:1){Co(d,k,b)}Hl(k,0);break Oa;case 15:if(!(w[r+1|0]&16)){break Oa}break cb;case 16:a=E+8|0;Db(a,I,5);if(Cb(a)){if(!(w[r+1|0]&16)){break Oa}if(b){break cb}break Oa}f=Om(d,x[d+1074446>>1],v[d+1074424>>2],K&65535,0);gb:{if(!(v[d+480180>>2]&16777250)){break gb}if(f){t[(d+B(K,872)|0)+1075827|0]=f;break gb}f=w[(d+B(K,872)|0)+1075827|0]}v[E+8>>2]=B(f,1e4);qc(E+8|0,B(v[v[d+8>>2]+24>>2],1e4));l=gb-16|0;gb=l;b=v[E+8>>2];v[l+8>>2]=b;a=d;g=v[a+8>>2];hb:{if(b>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){b=v[a+480208>>2];Db(l,a+1074312|0,92);if((Cb(l)|0)==((b&4096)>>>12|0)){break hb}v[l>>2]=B(v[g+24>>2],1e4);b=a+1074420|0;a=l+8|0;Ra=b,Sa=v[(yn(l,a)?l:a)>>2],v[Ra>>2]=Sa;break hb}if(w[a+480209|0]&16){break hb}e=a+1074420|0;c=(b>>>0)/1e4|0;b=B(c&15,1e4);v[e>>2]=v[e>>2]+((c&240)==16?b:0-b|0);c=v[g+20>>2];b=v[g+24>>2];Db(l,a+1074312|0,8);Fp(e,B(c,1e4),Cb(l)?255e4:B(b,1e4))}gb=l+16|0;break Na;case 9:if(!F|(v[d+480180>>2]==4?c:0)){break Oa}JP(d,k,K&65535,$);break Oa;case 43:if(!F){break Oa}a=oqa(v[(d+B(K,872)|0)+1075068>>2],0,b,0);f=jb;c=f>>>8|0;Mm(d,k,Qc((f&255)<<24|a>>>8,c));break Oa;case 0:if(v[d+1074392>>2]){break Oa}a=d+B(K,872)|0;ib:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break ib}a=v[a+1075648>>2];if(a){if(Ij(a)){break ib}}a=E+8|0;Db(a,I,13);if(Cb(a)){break ib}if(v[d+480180>>2]&16777248){break Oa}}if(!b){f=0;if(v[d+480180>>2]&5){break Na}t[(d+B(K,872)|0)+1075797|0]=1;break Na}a=d+B(K,872)|0;t[a+1075798|0]=b;t[a+1075797|0]=1;break Oa;case 14:if(v[d+480180>>2]&1048580){b=b&240?b:w[(d+B(K,872)|0)+1075799|0]&240|b;if(!(b&15)){b=w[(d+B(K,872)|0)+1075799|0]&15|b}b=b|256}f=b;a=E+8|0;Db(a,I,23);if(Cb(a)){a=d;c=K&65535;if(f){t[(d+B(K,872)|0)+1075799|0]=f;b=f}else{b=w[(d+B(K,872)|0)+1075799|0]}oA(a,c,b&255,(n&255)==15?h+1|0:0);break Na}jb:{if(f){t[(d+B(K,872)|0)+1075799|0]=f;break jb}f=w[(d+B(K,872)|0)+1075799|0]}oA(d,K&65535,f,(n&255)==15?h+1|0:0);break Na;case 17:if(!(w[r+1|0]&16)){break Oa}a=E+8|0;Db(a,I,22);kb:{lb:{if(Cb(a)){if(!b){b=0;break lb}if(w[r|0]&4){break lb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;break lb}a=E+8|0;Db(a,I,71);if(!Cb(a)){break kb}}a=(d+B(K,872)|0)+1075831|0;t[a|0]=w[a|0]|128}a=d+B(K,872)|0;t[a+1075797|0]=18;if(!b){f=0;break Na}t[a+1075832|0]=b;break Oa;case 22:if(!(w[r+1|0]&16)){break Oa}f=b<<!(v[d+480180>>2]&59593760);if(f>>>0<=128){v[d+1074456>>2]=f<<1;break Na}if(v[d+480180>>2]&16777250){break Na}v[d+1074456>>2]=256;break Na;case 23:a=E+8|0;Db(a,I,9);if(Cb(a)){uP(d,b,(d+B(K,872)|0)+1075809|0);break Oa}uP(d,b,V);break Oa;case 8:if(!(w[r+1|0]&16)){break Oa}Nm(d,k,b,8);break Oa;case 28:pA(d,k,b,1);break Oa;case 7:MP(k,b);break Oa;case 25:NP(d,k,b);break Oa;case 18:c=d;f=d+1074376|0;l=K&65535;e=B(l,872);g=(f+e|0)+616|0;a=b;h=b&15;mb:{nb:{switch(b>>>4|0){case 0:if(!x[c+480188>>1]){break mb}e=(a&1)<<14;f=0;while(1){a=(c+B(f,872)|0)+1075080|0;v[a>>2]=(e|v[a>>2]&-16385)^16384;f=f+1|0;if(f>>>0<x[c+480188>>1]){continue}break};break mb;case 1:if(!(v[c+480180>>2]&1048580?1:h)){break mb}mP(c,g,h);break mb;case 2:if(!(v[c+480180>>2]&1048580?1:h)){break mb}lP(c,g,h);break mb;case 3:a=(c+e|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((h|0)!=0)<<20;break mb;case 4:t[(c+e|0)+1075814|0]=a&7;break mb;case 5:if(!(w[c+480209|0]&16)){break mb}if(v[c+480180>>2]&69206025){e=c+B(l,872)|0;f=e+1075764|0;u[f>>1]=h<<28>>24;a=e+1075692|0;if(!v[a>>2]){break mb}if(!ce(e+1075780|0)){break mb}e=a;a=c+B(l,872)|0;Ra=e,Sa=_g(c,w[a+1075789|0],u[f>>1],v[a+1075696>>2]),v[Ra>>2]=Sa;break mb}f=v[c+480180>>2];e=ce((c+B(l,872)|0)+1075780|0);if((f|0)==16){if(!e){break mb}f=c+B(l,872)|0;a=v[f+1075096>>2];if(!a){break mb}t[a+37|0]=h;u[f+1075764>>1]=h;a=f+1075692|0;if(!v[a>>2]){break mb}f=a;a=c+B(l,872)|0;Ra=f,Sa=_g(c,w[a+1075789|0],h,v[a+1075696>>2]),v[Ra>>2]=Sa;break mb}if(!e){break mb}e=c+B(l,872)|0;f=(a<<4^-128)<<24>>24;u[e+1075764>>1]=f;a=e+1075692|0;if(!v[a>>2]){break mb}Ra=a,Sa=_g(c,w[e+1075789|0],f,v[e+1075696>>2]),v[Ra>>2]=Sa;break mb;case 6:if(!(w[c+480209|0]&16)){break mb}ru(c,f,g,h);break mb;case 7:t[(c+e|0)+1075817|0]=a&7;break mb;case 8:if(!(w[c+480209|0]&16)){break mb}Nm(c,g,h,4);break mb;case 9:oA(c,l,h,0);break mb;case 10:if(!(v[c+480180>>2]&1048580?1:h)){break mb}Gq(c,g,h,0);break mb;case 11:if(!(v[c+480180>>2]&1048580?1:h)){break mb}Fq(c,g,h,0);break mb;case 12:qA(c,l,h,0);break mb;case 15:break nb;default:break mb}}if(v[c+480180>>2]==1){t[(c+B(l,872)|0)+1075838|0]=h;if(!(w[c+480209|0]&16)){break mb}xP(c,g);break mb}t[(c+B(l,872)|0)+1075836|0]=h}break Oa;case 19:e=E+8|0;Db(e,I,78);a=d;c=K&65535;f=b;ob:{if(!Cb(e)){break ob}f=b;if(b){break ob}f=w[(d+B(K,872)|0)+1075798|0]}tP(a,c,f);break Na;case 24:a=E+8|0;Db(a,I,55);if(Cb(a)){if(v[d+1074392>>2]!=(b|0)){break Oa}a=v[(d+B(K,872)|0)+1075648>>2];if(t[a+60|0]&1?a:0){break db}if(!(!(w[H|0]?1:w[_|0])|b)){a=(d+B(K,872)|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break db}a=d+B(K,872)|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break db}if(w[r+1|0]&16){break db}break Oa;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Oa}if(!(1<<a&880)){if(!a){break eb}if((a|0)!=1){break Oa}sP(d,k,b&15);break Oa}a=E+8|0;Db(a,I,58);if(Cb(a)){break Oa}tP(d,K&65535,b);break Oa;case 34:case 35:if(!((j&255)!=36?w[r+1|0]&16:1)){break Oa}c=K&65535;HP(d,c,$,(j&255)==36);a=mu(d,c);if(!a){break Oa}kb[v[v[a>>2]+80>>2]](a,x[k+774>>1]>>>2^8192,c);break Oa;case 20:if(!(w[r+1|0]&16)|b>>>0>64){break Oa}a=d+B(K,872)|0;v[a+1075740>>2]=b;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Oa;case 21:f=d;a=k;l=b;pb:{if(b){t[a+816|0]=l;break pb}l=w[a+816|0]}h=l&255;c=a;g=l&240;j=l&15;qb:{rb:{if(!(!g|(j|0)!=15)){if(!(w[f+480209|0]&16)){break qb}e=h>>>4|0;break rb}e=v[f+480208>>2]&4096;if(!(!j|(g|0)!=240)){if(!e){break qb}e=0-j|0;break rb}if(e){break qb}if(j){e=0-j|0;if(!(v[f+480180>>2]&25690144)|!g){break rb}break qb}if((l&255)>>>0<16){break qb}e=h>>>4|0}Ra=c,Sa=Mb(e+v[a+748>>2]|0,0,64),v[Ra+748>>2]=Sa}break Oa;case 26:LP(k,b);break Oa;case 29:if(!(w[r+1|0]&16)){break Oa}c=d+B(K,872)|0;v[c+1075716>>2]=b;a=E+8|0;Db(a,I,60);if(Ra=0,Sa=Cb(a),Ua=w[c+1075722|0]&4,Ua?Ra:Sa){break Oa}a=d+B(K,872)|0;v[a+1075732>>2]=b;v[a+1075724>>2]=b;break Oa;case 11:xA(d,$,K&65535);break Oa;case 13:a=wA(d,$,K&65535,b);if((a|0)==-1){break Oa}v[d+1074436>>2]=a;if(!(w[d+480208|0]&32)){break Oa}u[d+1074444>>1]=x[d+1074448>>1];break Oa;case 37:case 38:case 39:case 40:c=k;a=j&255;l=(a|0)==38|(a|0)==40;g=(j&254)==40;a=d;if(w[a+480209|0]&16){j=w[c+848|0];e=f&240;if(e){j=e|j&15;t[c+848|0]=j}f=f&15;if(f){j=f|j&-16;t[c+848|0]=j}t[c+849|0]=(j&240)>>>4}sb:{tb:{if(v[a+480180>>2]==32768){j=w[c+848|0];if(w[a+480209|0]&16|(j&240)==16){break tb}break sb}if(w[a+480209|0]&16){break sb}f=w[c+849|0]-1|0;t[c+849|0]=f;if(f&255){break sb}j=w[c+848|0]}t[c+849|0]=(j&240)>>>4;f=j&15;f=l?f:0-f|0;ub:{if(Kj(c)){v[c+852>>2]=v[c+852>>2]+B(f,v[v[v[c+656>>2]+44>>2]+36>>2]);break ub}Ra=c,Sa=_g(a,lu(a,v[c+700>>2],0,v[c+704>>2])+f|0,0,v[c+704>>2]),v[Ra+700>>2]=Sa}if(!g){break sb}v[c>>2]=0;v[c+4>>2]=0}break Oa;case 41:uA(k,b);break Oa;case 42:break fb;default:break Na}}if(v[d+1074392>>2]|G>>>0>1|b>>>0>47){break Oa}a=(b&240)==16;f=a?0:K;e=(a?x[d+480188>>1]-1|0:K)&65535;if((f&65535)>>>0>e>>>0){break Oa}g=((G|0)==1)<<26;while(1){c=f&65535;a=(d+(c<<5)|0)+480280|0;v[a>>2]=g|v[a>>2]&-67108865;a=(d+B(c,872)|0)+1075080|0;v[a>>2]=g|v[a>>2]&-67108865;f=f+1|0;if(e>>>0>=(f&65535)>>>0){continue}break}break Oa}rP(d,k,b&15);break Oa}Bo(d,k);break Oa}OP(d,$,b)}f=b}a=E+8|0;Db(a,I,78);if(!(!Cb(a)|!f)){a=f&255;t[k+840|0]=a;t[k+812|0]=a;t[k+811|0]=a;t[k+809|0]=a;t[k+807|0]=a;t[k+806|0]=a;t[k+826|0]=a>>>4;t[k+827|0]=a<<2&60}a=w[_|0];if(!a){break M}t[A+1075796|0]=a}K=K+1|0;if(K>>>0<x[d+480188>>1]){continue}break}}vb:{if(!(w[r+1|0]&16)){break vb}if(!GP(d,$,1)){break vb}v[r>>2]=v[r>>2]|524288}gb=E+16|0;a=1;break l}a=0}gb=R+32|0;wb:{if(!a|!v[s+1074420>>2]){break wb}a=FO(s,s+1074376|0);v[s+1074380>>2]=a;v[s+1074404>>2]=a;b=Fd(x[s+480188>>1],1,31);W=s+1074332|0;xb:{if(w[W+34|0]){a=v[s+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}l=((B(v[s+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+38416|0]|0;break xb}l=v[s+480228>>2]}u[s+480212>>1]=0;$=s+1298260|0;X=s+1074312|0;J=s+480210|0;V=s+480209|0;n=0;while(1){r=s+B(n,872)|0;R=r+1075080|0;yb:{if(!(v[R>>2]&4096)|(v[r+1075016>>2]|(v[r+1075012>>2]|v[r+1075688>>2]))){break yb}a=p+16|0;Db(a,X,64);if(Cb(a)){break yb}v[r+1075068>>2]=0;a=r+1075084|0;v[a>>2]=0;v[a+4>>2]=0}c=x[s+480188>>1];b=v[R>>2];zb:{if(v[r+1075068>>2]|c>>>0>n>>>0?b&1024:1){if(c>>>0>n>>>0){pO(s,n&65535)}u[r+1075834>>1]=0;break zb}f=0;q=r+1075712|0;v[q>>2]=0;aa=r+1075672|0;v[aa>>2]=0;_=r+1075e3|0;a=_;v[a>>2]=0;v[a+4>>2]=0;v[r+1075092>>2]=0;v[p+44>>2]=1065353216;u[p+42>>1]=0;T=r+1075648|0;H=v[T>>2];v[p+36>>2]=0;i=0;ba=r+1075692|0;i=v[ba>>2]?v[r+1075068>>2]!=0:i;a=r+1074992|0;Ab:{Bb:{Cb:{if(c>>>0<=n>>>0){break Cb}if(w[(s+(n<<5)|0)+480288|0]){break Bb}if(!H){break Cb}f=w[H+34|0]!=0}if((f|i)!=1){break Ab}}v[p+8>>2]=v[r+1075680>>2];v[p+32>>2]=v[r+1075744>>2];f=p+16|0;Db(f,X,28);c=a;b=p+8|0;g=Cb(f)?p+32|0:b;d=gb-16|0;gb=d;f=d+8|0;e=s+1074312|0;Db(f,e,28);Db:{if(Cb(f)){v[g>>2]=v[g>>2]+u[c+776>>1];Rd(g,0,64);break Db}f=d+8|0;Db(f,e,1);f=Cb(f);e=u[c+776>>1];if(f){v[g>>2]=e+v[g>>2];Rd(g,0,256);break Db}v[c+688>>2]=e+v[c+688>>2];Rd(c+688|0,0,256);v[g>>2]=v[c+688>>2];u[c+776>>1]=0}gb=d+16|0;d=gb-16|0;gb=d;e=d+8|0;f=s+1074312|0;Db(e,f,28);Eb:{Fb:{if(!Cb(e)){Db(d,f,1);if(!Cb(d)){break Fb}}v[c+684>>2]=v[c+692>>2]+u[c+778>>1];Rd(c+684|0,0,256);break Eb}v[c+692>>2]=v[c+692>>2]+u[c+778>>1];Rd(c+692|0,0,256);u[c+778>>1]=0;v[c+684>>2]=v[c+692>>2]}gb=d+16|0;c=b;j=gb-16|0;gb=j;d=s;Gb:{if(!(w[a+90|0]&4)|(v[d+480208>>2]&2101248)==2101248){break Gb}e=a;Hb:{if(v[c>>2]<=0){f=j+8|0;Db(f,d+1074312|0,21);if(!Cb(f)){break Hb}}o=5;if(!(v[d+480180>>2]&5)){f=j+8|0;Db(f,d+1074312|0,21);o=Cb(f)?5:6}g=Pz(d,w[e+825|0],w[e+820|0]);Ib:{if((w[e+825|0]&3)!=1){break Ib}f=j+8|0;Db(f,d+1074312|0,89);if(!Cb(f)){break Ib}g=w[e+819|0];h=w[e+820|0];f=h<<2&124;f=(!(w[e+90|0]&2)|w[d+480209|0]&16?g:w[e+823|0]+g|0)&32?f^127:f;g=h&32?0-f|0:f}f=c;if(v[d+480180>>2]!=131072){c=v[c>>2]+((B(w[e+827|0],g)|0)/(1<<o)|0)|0}else{c=v[c>>2];c=((B(w[e+827|0],B(c,64-g|0))|0)/-8192|0)+c|0}v[f>>2]=c}if(!(v[d+480180>>2]&16777248)|w[d+480208|0]&4?w[d+480209|0]&16:0){break Gb}c=j+8|0;Db(c,d+1074312|0,21);d=Cb(c);f=w[e+826|0];c=w[e+820|0];t[e+820|0]=(d?f<<2:c)+(d?c:f)}gb=j+16|0;f=n&65535;m=f;e=b;k=gb-16|0;gb=k;c=k+8|0;d=s;g=d+1074312|0;Db(c,g,71);Jb:{if(Cb(c)){c=(d+B(m,872)|0)+1075831|0;h=t[c|0];if((h|0)>-1){break Jb}if(!(w[d+480209|0]&16|w[(d+B(m,872)|0)+1075797|0]!=18)){g=h&-33;t[c|0]=g;Kb:{Lb:{if((g|0)!=-64){g=h&223;if((g|0)!=128){break Lb}h=w[(d+B(m,872)|0)+1075832|0]>>>4|-64;break Kb}h=w[(d+B(m,872)|0)+1075832|0]&15|-128;break Kb}h=g-1|0}t[c|0]=h;c=(d+B(m,872)|0)+1075080|0;v[c>>2]=v[c>>2]|2097152}if((h&224)!=128){break Jb}v[e>>2]=0;break Jb}if(w[(d+B(m,872)|0)+1075797|0]!=18){break Jb}c=k+8|0;Db(c,g,22);Mb:{if(Cb(c)){g=d+B(m,872)|0;c=g+1075831|0;j=w[c|0];h=j<<24>>24;if(!((h|0)>-1|!v[g+1075068>>2])){Nb:{Ob:{if((j|0)!=192){if((j|0)!=128){break Ob}h=w[(d+B(m,872)|0)+1075832|0]>>>4|-64;break Nb}h=w[(d+B(m,872)|0)+1075832|0]&15|-128;break Nb}h=h-1|0}t[c|0]=h}if((h&192)!=128){break Mb}v[e>>2]=0;break Mb}c=w[(d+B(m,872)|0)+1075832|0];o=c>>>4|0;ea=o+(c&15)|0;if(!(w[d+480208|0]&4?0:v[d+480180>>2]&16777248)){ea=ea+2|0;o=o+1|0}g=(d+B(m,872)|0)+1075831|0;h=w[g|0];if(!(v[d+480180>>2]&4)){c=(h&255)>>>0<ea>>>0?h:0;if((c&255)>>>0>=o>>>0){v[e>>2]=0}t[g|0]=c+1;break Mb}Pb:{if(w[d+480209|0]&16){h=h&255?h-1|0:0;break Pb}t[g|0]=h+1}if(((h&255)>>>0)%(ea>>>0)>>>0<o>>>0){break Mb}v[e>>2]=0}c=(d+B(m,872)|0)+1075080|0;v[c>>2]=v[c>>2]|2097152}c=d+B(m,872)|0;Qb:{if(w[c+1075797|0]!=18){break Qb}g=c+1075648|0;c=v[g>>2];if(!c|!w[c+34|0]|w[c+15|0]&2){break Qb}c=d+B(m,872)|0;if(v[c+1075080>>2]&134218752){break Qb}j=c+1075791|0;if(!we(w[j|0])){break Qb}h=v[g>>2];o=v[(d+B(w[h+34|0],160)|0)+906140>>2];if(!o){break Qb}g=kb[v[v[o>>2]+100>>2]](o,w[j|0],m)|0;c=v[e>>2];if(!(!g|c)){kb[v[v[o>>2]+92>>2]](o,h,w[j|0]+255|0,0,m);break Qb}if(g|!c){break Qb}kb[v[v[o>>2]+92>>2]](o,h,w[j|0],x[(d+B(m,872)|0)+1075680>>1],m)}gb=k+16|0;Rd(b,0,256);v[p+8>>2]=v[p+8>>2]<<6;Rb:{if(H){b=p+16|0;Db(b,X,31);if(Cb(b)){au(s,a)}g=p+8|0;m=g;G=gb-16|0;gb=G;Sb:{if(!Oz(s,a,0)){break Sb}c=a;F=v[a+656>>2];b=G+8|0;o=d+1074312|0;Db(b,o,31);Tb:{if(Cb(b)){b=v[c+724>>2];if(b){break Tb}break Sb}b=v[c+724>>2]}e=G+8|0;Db(e,o,31);h=F+48|0;d=b-Cb(e)|0;b=Vq(h,d,256,64);e=w[F+65|0];Ub:{if((e|0)==255){break Ub}k=u[c+728>>1];if((k|0)==-1){break Ub}j=w[Lb(h,e)+2|0];e=x[Lb(h,w[F+65|0])>>1];c=G+8|0;Db(c,o,94);h=j<<2;b=(d|0)==(e|0)?h:b;if(Cb(c)){b=k+(b-h<<1)|0;break Ub}if(!j){b=0;break Ub}b=(B(b,k)|0)/(h|0)|0}Ra=m,Sa=(B(v[m>>2],Mb(b,0,512))|0)/256|0,v[Ra>>2]=Sa}gb=G+16|0;oO(a,g);h=gb-16|0;gb=h;b=s;Vb:{if(!Oz(b,a,1)){break Vb}c=a;g=v[a+656>>2];e=h+8|0;d=b+1074312|0;Db(e,d,31);Wb:{if(Cb(e)){b=v[c+732>>2];if(b){break Wb}break Vb}b=v[c+732>>2]}e=h+8|0;Db(e,d,31);d=Vq(g+68|0,b-Cb(e)|0,64,64)-32|0;b=v[c+684>>2];Ra=c,Sa=Mb(((B(d,(b|0)>127?256-b|0:b)|0)/32|0)+b|0,0,256),v[Ra+684>>2]=Sa}gb=h+16|0;d=v[a+656>>2];e=t[d+26|0];Xb:{if(!e){break Xb}b=a;c=w[b+797|0];if(!c){break Xb}Ra=b,Sa=Mb(v[b+684>>2]+((B(e,c+(w[d+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Ra+684>>2]=Sa}break Rb}if(!(w[R+1|0]&16)){break Rb}v[r+1075688>>2]=0;v[p+8>>2]=0}Yb:{if(w[r+1075843|0]&4){v[p+8>>2]=0;break Yb}c=v[p+8>>2];if(!c){break Yb}if(w[R+3|0]&8){v[aa>>2]=0;break Yb}if(w[W+33|0]){b=B(v[p+32>>2],v[r+1075740>>2]);d=b;e=b>>31;b=c<<8;Ra=aa,Sa=Ac(pqa(oqa(d,e,b,b>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;break Yb}b=B(v[p+32>>2],v[r+1075740>>2]);d=b;e=b>>31;b=B(c,v[s+1074456>>2]);Ra=aa,Sa=Ac(pqa(oqa(d,e,b,b>>31),jb,1048576,0),jb),v[Ra>>2]=Sa}v[q>>2]=v[p+8>>2];Zb:{_b:{if(v[s+480180>>2]==2|v[ba>>2]>=v[s+480260>>2]){break _b}if(sk(s)){break _b}v[ba>>2]=v[s+480260>>2];break Zb}if(v[ba>>2]<v[s+480264>>2]){break Zb}b=p+16|0;Db(b,X,113);if(!Cb(b)){break Zb}v[ba>>2]=v[s+480264>>2]}b=p+16|0;Db(b,X,73);if(Cb(b)){Mb(v[ba>>2],1,31999)}b=v[ba>>2];v[p+36>>2]=b;$b:{if((v[R>>2]&1572864)!=1572864){break $b}if(w[J|0]&32){if(!tu(r+1075780|0)|w[V|0]&16){break $b}b=v[p+36>>2]}c=r+1075704|0;ac:{if(v[c>>2]==(b|0)){b=v[r+1075708>>2];break ac}v[c>>2]=b;d=b;c=r+1075764|0;b=r+1075696|0;b=_g(s,lu(s,d,u[c>>1],v[b>>2]),u[c>>1],v[b>>2]);v[r+1075708>>2]=b}v[p+36>>2]=b}m=gb-16|0;gb=m;e=s;d=f;k=e+B(d,872)|0;g=v[k+1075648>>2];bc:{if(!g){break bc}b=w[g+34|0];if(!b|w[g+15|0]&2|(!v[(e+B(b,160)|0)+906140>>2]|v[(e+B(d,872)|0)+1075080>>2]&134218752)){break bc}f=e+B(d,872)|0;h=f+1075783|0;j=w[h|0];c=0;b=f+1075791|0;if(we(w[b|0])){c=w[lc(g+108|0,w[b|0]-1|0)|0]}o=f+1075780|0;cc:{dc:{if((j|0)==1){g=0;ec:{fc:{switch((y[e+1074392>>2]%3|0)-1|0){case 0:g=w[(e+B(d,872)|0)+1075798|0]>>>4|0;break ec;case 1:break fc;default:break ec}}g=w[(e+B(d,872)|0)+1075798|0]&15}b=e+B(d,872)|0;t[b+1075793|0]=c;if(w[b+1075792|0]==(c+g|0)){break cc}if(!(w[e+480209|0]&16)){break dc}if(!ce(o)){break dc}break cc}g=0;if(w[o|0]|!w[(e+B(d,872)|0)+1075792|0]){break cc}}b=e+B(d,872)|0;Km(e,d,w[b+1075793|0]+g|0,x[b+1075680>>1])}b=(e+B(d,872)|0)+1075792|0;f=w[b|0];gc:{if(!f){if(!(w[e+480209|0]&16)|(j|0)!=1){break gc}if(ce(o)){break gc}f=c;if(!we(c)){break gc}}Km(e,d,(f&255)+255|0,0)}t[b|0]=w[h|0]==1?w[(e+B(d,872)|0)+1075793|0]+g|0:0}hc:{if(w[k+1075797|0]!=1){break hc}if(Kj(k+1074992|0)){c=0;ic:{jc:{switch((y[e+1074392>>2]%3|0)-1|0){case 0:c=w[(e+B(d,872)|0)+1075798|0]>>>4|0;break ic;case 1:break jc;default:break ic}}c=w[(e+B(d,872)|0)+1075798|0]&15}u[p+42>>1]=c;b=(e+B(d,872)|0)+1075843|0;t[b|0]=w[b|0]|48;break hc}if(!(!(w[e+480209|0]&16)|v[e+480180>>2]!=1048576)){c=e+B(d,872)|0;b=_g(e,w[c+1075789|0],u[c+1075764>>1],v[c+1075696>>2]);v[p+36>>2]=b;v[c+1075692>>2]=b}b=m+8|0;h=e+1074312|0;Db(b,h,13);if(Cb(b)){c=w[(e+B(d,872)|0)+1075798|0];if(!c){break hc}b=65536;kc:{switch(((y[e+1074392>>2]%(v[e+1074400>>2]+v[e+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:c=c<<4;case 0:b=v[((c&240)<<2)+43584>>2];break;default:break kc}}e=sk(e);c=v[p+36>>2];g=c;c=c>>31;f=p;if(e){b=oqa(g,c,b,b>>31)+32768|0;c=jb;c=pqa(b,b>>>0<32768?c+1|0:c,65536,0)}else{d=c<<16|g>>>16;e=(b|0)/2|0;c=g<<16;g=e+c|0;k=d+(e>>31)|0;c=pqa(g,c>>>0>g>>>0?k+1|0:k,b,b>>31)}b=jb;Ra=f,Sa=Ac(c,b),v[Ra+36>>2]=Sa;break hc}b=m+8|0;Db(b,h,51);if(Cb(b)){if(w[e+480209|0]&16){break hc}lc:{mc:{b=v[e+1074416>>2];b=b-(y[e+1074392>>2]%(b>>>0)|0)|0;if((b|0)>16){break mc}if((b|0)==16){break hc}g=0;nc:{switch((b|0)%3|0){case 0:break hc;case 2:break mc;case 1:break nc;default:break lc}}g=w[(e+B(d,872)|0)+1075798|0]>>>4|0;break lc}g=w[(e+B(d,872)|0)+1075798|0]&15}c=e+B(d,872)|0;b=c+1075764|0;f=c+1075696|0;c=lu(e,v[p+36>>2],u[b>>1],v[f>>2])+g|0;b=_g(e,c,u[b>>1],v[f>>2]);v[p+36>>2]=b;if(c>>>0<109){break hc}v[m+8>>2]=b;Ra=m,Sa=_g(e,109,0,v[f>>2]),v[Ra+4>>2]=Sa;Ra=p,Sa=v[Mc(m+8|0,m+4|0)>>2],v[Ra+36>>2]=Sa;break hc}c=v[e+1074392>>2];if(v[e+480180>>2]!=1){g=w[(e+B(d,872)|0)+1075789|0]}else{b=e+B(d,872)|0;g=lu(e,v[p+36>>2],u[b+1075764>>1],v[b+1075696>>2])}oc:{pc:{switch((((v[e+480180>>2]&67633152?c+2|0:c)>>>0)%3|0)-1|0){case 0:g=(w[(e+B(d,872)|0)+1075798|0]>>>4|0)+g|0;break oc;case 1:break pc;default:break oc}}g=(w[(e+B(d,872)|0)+1075798|0]&15)+g|0}if(!(v[e+480180>>2]&67633408|w[(e+B(d,872)|0)+1075789|0]!=(g&255))){b=m+8|0;Db(b,h,82);if(!Cb(b)){break hc}}j=p;b=e;c=b;if(w[b+480210|0]&32){f=g&255;if((f|0)==85){v[p+36>>2]=2147483647;break hc}g=f>>>0>85?g-37|0:g}b=e+B(d,872)|0;Ra=j,Sa=_g(c,g&255,u[b+1075764>>1],v[b+1075696>>2]),v[Ra+36>>2]=Sa;if(v[e+480180>>2]&71827712){v[b+1075692>>2]=v[p+36>>2];break hc}b=m+8|0;Db(b,h,82);if(!Cb(b)){break hc}t[(e+B(d,872)|0)+1075792|0]=g}gb=m+16|0;if(!(!(w[J|0]&33)|v[p+36>>2]==2147483647)){qc:{if(v[s+480180>>2]==2){b=452;c=3424;break qc}c=B(x[r+1075764>>1]>>>4&15,24);b=x[c+39318>>1]>>>1|0;b=b>>>0>452?b:452;c=x[c+39296>>1]<<1}Rd(p+36|0,b,c);Rd(ba,b,c)}Tz(s,a);b=v[R>>2]}rc:{if(!(b&256)|w[V|0]&64){break rc}b=p+16|0;Db(b,X,37);if(!Cb(b)){break rc}v[r+1075676>>2]=128}m=n&65535;pO(s,m);sc:{if(!i){break sc}b=nO(s,a,p+36|0);if((b|0)<0|!(w[R+1|0]&2)){break sc}if(!Dd($)){break sc}Qq(v[$>>2],m,b>>>2&255,1)}tc:{if(w[r+1075782|0]!=8){break tc}uc:{vc:{b=w[r+1075783|0];switch(b-5|0){case 1:break tc;case 0:case 2:break uc;default:break vc}}if((b|0)!=26){break tc}}if(v[s+480180>>2]==4){if(w[V|0]&16){break tc}b=r+1075811|0;t[b|0]=w[b|0]+w[r+1075815|0];break tc}if(!(v[s+480180>>2]&16777248)){break tc}Hl(a,w[r+1075784|0]);mO(s,m,p+36|0,p+44|0)}mO(s,m,p+36|0,p+44|0);wc:{if(!i){break wc}v[p+32>>2]=0;c=s;d=p+36|0;k=gb-16|0;gb=k;F=v[a+104>>2];xc:{if(!F|!w[F+40|0]){break xc}g=a;f=Kj(a);j=sk(c);b=k+8|0;Db(b,c+1074312|0,21);i=j?44608:43584;e=j?43584:44608;if(!(f|!Cb(b)|v[c+480180>>2]==1048576)){if(!w[F+41|0]){break xc}h=w[g+818|0];v[k+4>>2]=v[g+756>>2]+w[F+39|0];ck(k+4|0,w[F+40|0]<<8);b=v[k+4>>2];v[g+756>>2]=b;f=(b|0)/256|0;v[k+4>>2]=f;t[g+818|0]=w[g+818|0]+w[F+41|0];yc:{zc:{switch(w[F+38|0]-1|0){case 3:b=kO(Ao(c))+-64|0;f=v[k+4>>2];break yc;case 2:b=64-(h+1>>>1|0)|0;break yc;case 1:b=(h+1>>>1|0)+-64|0;break yc;case 0:b=(h>>>1^-1)&64;break yc;default:break zc}}b=t[h+39888|0]}ck(d,8388607);h=v[d>>2]<<8;v[d>>2]=h;f=B(b,f);b=(f|0)/64|0;c=b>>31;g=c^b+c;b=g>>>2|0;c=d;Ac:{if((f|0)<=-64){b=v[(b<<2)+i>>2];f=Ac(pqa(oqa(b,b>>31,h,h>>31),jb,65536,0),jb);b=v[d>>2];e=f-b|0;f=g&3;i=e;if(!f){break Ac}f=v[(f<<2)+(j?43520:43456)>>2];f=Ac(pqa(oqa(f,f>>31,b,b>>31),jb,65536,0),jb)+e|0;b=v[d>>2];i=f-b|0;break Ac}b=v[e+(b<<2)>>2];f=Ac(pqa(oqa(b,b>>31,h,h>>31),jb,65536,0),jb);b=v[d>>2];e=f-b|0;f=g&3;i=e;if(!f){break Ac}f=v[(f<<2)+(j?43456:43520)>>2];f=Ac(pqa(oqa(f,f>>31,b,b>>31),jb,65536,0),jb)+e|0;b=v[d>>2];i=f-b|0}v[c>>2]=(b+i|0)/256;v[p+32>>2]=i&255;break xc}Bc:{if(!(w[F+39|0]|v[c+480180>>2]&16777248)){v[g+756>>2]=w[F+40|0]<<8;break Bc}Cc:{Dc:{if(v[c+480180>>2]&16777248){ea=w[F+39|0]<<1;o=v[g+756>>2];b=g+756|0;break Dc}if(w[g+89|0]&8){break Cc}o=((w[F+40|0]<<8&65280)>>>0)/w[F+39|0]|0;ea=v[g+756>>2];b=g+756|0}v[b>>2]=o+ea}ck(g+756|0,w[F+40|0]<<8)}b=w[g+818|0]+w[F+41|0]|0;t[g+818|0]=b;b=b<<24>>24;Ec:{Fc:{switch(w[F+38|0]-1|0){case 3:t[g+818|0]=b+1;j=t[(b&63)+39824|0];break Ec;case 2:j=(64-(b>>>1|0)&127)+-64|0;break Ec;case 1:j=((b>>>1|0)- -64&127)+-64|0;break Ec;case 0:j=(b|0)>-1?-64:64;break Ec;default:break Fc}}b=w[g+818|0];j=0-t[b+39888|0]|0;if(v[c+480180>>2]!=1048576){break Ec}j=(64-t[(b+-64&255)+39888|0]|0)/2<<16>>16}b=j;h=B(b,v[g+756>>2]);o=(h|0)/256|0;if(f){z[p+44>>2]=z[p+44>>2]+C(C(C(C(w[F+40|0])*C(.05000000074505806))*C(b|0))*C(.000244140625));t[g+851|0]=w[g+851|0]|32;break xc}if(v[c+480180>>2]!=4){Gc:{if((h|0)<=-256){o=0-o|0;b=0-h>>>16|0;f=(b<<2)+i|0;break Gc}i=e;b=(h|0)/65536|0;f=e+(b<<2)|0}c=v[d>>2];e=v[((b<<2)+i|0)+4>>2];b=v[f>>2];b=((B(e-b|0,(o|0)/4&63)|0)/64|0)+b|0;b=Ac(pqa(oqa(c,c>>31,b,b>>31),jb,256,0),jb);v[d>>2]=b;v[p+32>>2]=b&255;v[d>>2]=v[d>>2]/256;break xc}v[d>>2]=v[d>>2]+((h|0)/16384|0)}gb=k+16|0;if(v[p+36>>2]<=v[s+480260>>2]){b=p+16|0;Db(b,X,81);if(Cb(b)){v[r+1075068>>2]=0}v[p+36>>2]=v[s+480260>>2]}Hc:{if(!Kj(a)){break Hc}c=r+1075843|0;b=w[c|0];if(!(v[s+1074392>>2]|!(b&16)?b&32:1)){break Hc}IS(a,z[p+44>>2],u[p+42>>1],s);b=w[c|0];t[c|0]=(b&32?-33:-17)&b}b=p+16|0;Sz(b,s,a,v[p+36>>2],v[p+32>>2]);i=wb(b);d=oqa(v[b>>2],v[b+4>>2],v[s+480240>>2],0);c=jb;f=pqa(d,c,65536,0);e=jb;g=f;f=d+65535|0;c=f>>>0<65535?c+1|0:c;f=!c&f>>>0<131071;c=f?1:g;v[b>>2]=c;d=b;b=f?0:e;v[d+4>>2]=b;v[_>>2]=c;v[_+4>>2]=b;if((v[R>>2]&134219264)!=512){break wc}if(!Dd($)){break wc}b=p+8|0;Db(b,X,99);if(Ra=Cb(b)|!(w[R+1|0]&16),Sa=1,Ua=v[s+480180>>2]!=2,Ua?Ra:Sa){Ic:{if(w[R+1|0]&8?v[s+480180>>2]==2:0){break Ic}b=oqa(v[i>>2],0,261625,0)+66904|0;G=jb;e=Qc(rqa(b,b>>>0<66904?G+1|0:G,133808,0),jb);c=v[R>>2];b=1;Jc:{if(c&2048){break Jc}b=0;if(!(c&4096)){break Jc}b=!v[r+1075688>>2]}c=p+8|0;Db(c,X,110);if(Ra=Cb(c),Sa=0,Ua=b,Ua?Ra:Sa){break Ic}f=v[$>>2];c=p+8|0;Db(c,X,95);WA(f,m,e,b,Cb(c))}f=v[$>>2];b=oqa(B(v[r+1075744>>2],B(v[r+1075740>>2],v[q>>2])),0,63,0)+33554432|0;c=jb;c=b>>>0<33554432?c+1|0:c;Qq(f,m,Qc((c&67108863)<<6|b>>>26,c>>>26|0)&255,0);b=r+1075676|0;c=b;e=v[b>>2];i=0;d=v[$>>2];f=Nl(d,m);Kc:{if((f|0)==255){break Kc}if(wk(d)){break Kc}b=lc(XA(d+314|0,f),10);d=v[d>>2];f=Eu(f)|192;b=w[b|0]&-49;b=(e|0)<171?b|16:b;b=((e|0)>84?b|32:b)&255;Yh(d,f,b);i=(b>>>5&1)+(b<<27>>31)|0}v[c>>2]=(i<<7)+128}Lc:{b=v[T>>2];if(!b|(w[b+60|0]&7)!=1){break Lc}b=b+48|0;if(cd(b)){break Lc}c=v[lO(a,0)>>2];b=uo(b);if(c>>>0<x[b>>1]|w[b+2|0]){break Lc}Pi(v[$>>2],m,1);b=p+8|0;Db(b,X,109);c=Cb(b);b=v[R>>2];v[R>>2]=(c?b:b&-4609)|4096;v[r+1075688>>2]=0;break wc}b=p+8|0;Db(b,X,99);if(!Cb(b)|!(w[R+1|0]&16)|v[r+1075688>>2]){break wc}Pi(v[$>>2],m,1);v[R>>2]=v[R>>2]&-513}Mc:{if(!H){break Mc}b=p+16|0;Db(b,X,31);if(Cb(b)){break Mc}au(s,a)}b=v[R>>2];c=b&-65537;h=r+1075012|0;g=r+1075016|0;v[R>>2]=v[h>>2]|(v[g>>2]|v[aa>>2])?(c|b<<7&65536)^65536:c;e=r+1075664|0;v[e>>2]=0;v[e+4>>2]=0;k=r+1075834|0;b=w[k|0];c=b-4|0;t[k|0]=b>>>0<c>>>0?0:c;j=r+1075835|0;b=w[j|0];c=b-4|0;t[j|0]=b>>>0<c>>>0?0:c;Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{c=r+1075096|0;b=v[c>>2];Tc:{if(!b){break Tc}if(!Md(b)|!v[r+1075068>>2]){break Tc}if(Ni(a)){break Sc}}f=r+1075008|0;v[f>>2]=0;break Rc}f=r+1075008|0;b=v[v[c>>2]+20>>2];v[f>>2]=b;if(b){break Qc}}if(!tk(a)|w[R+1|0]&24){break Pc}}d=v[aa>>2];i=v[r+1075676>>2];b=(B(d,256-i|0)|0)/16384|0;c=b>>>0<127?b:127;b=t[k|0];if((b|0)<=-1){t[k|0]=c;m=c}else{m=b}b=c>>>1|0;if((m&255)>>>0<b>>>0){t[k|0]=b}b=(B(d,i)|0)/16384|0;c=b>>>0<127?b:127;i=c>>>1|0;d=i;b=t[j|0];if((b|0)<=-1){t[j|0]=c;b=c}if((b&255)>>>0<d>>>0){break Oc}break Nc}if(w[k|0]>=129){t[k|0]=0}i=0;if(w[j|0]<129){break Nc}}t[j|0]=i}Uc:{Vc:{if(v[f>>2]){f=r+1075668|0;Wc:{if(y[s+24624>>2]>=2){v[p+16>>2]=v[r+1075676>>2];Rd(p+16|0,0,256);g=B(l,v[aa>>2])>>>(w[W+34|0]?7:8)|0;c=f;Xc:{Yc:{Zc:{switch(w[W+32|0]){case 0:if(!(w[s+24616|0]&16)){break Yc}case 1:b=v[p+16>>2];if((b|0)<=127){v[e>>2]=g>>>1;b=(B(b,g)|0)/256|0;break Xc}v[e>>2]=(B(g,256-b|0)|0)/256;b=g>>>1|0;break Xc;case 3:break Zc;default:break Yc}}ck(p+16|0,255);b=e;i=v[p+16>>2];if((i|0)<1){d=65536}else{d=x[(0-i<<1)+46144>>1]}v[b>>2]=B(d,g)>>>16;b=B(g,x[(i<<1)+45632>>1])>>>16|0;break Xc}b=v[p+16>>2];v[e>>2]=(B(g,256-b|0)|0)/256;b=(B(b,g)|0)/256|0}v[c>>2]=b;break Wc}b=B(l,v[aa>>2])>>>8|0;v[e>>2]=b;v[f>>2]=b}i=r+1075786|0;d=i;_c:{$c:{b=v[T>>2];if(!b){break $c}if(!up(w[b+14|0])){break $c}c=w[v[T>>2]+14|0];break _c}if(up(w[s+480268|0])){c=w[s+480268|0];break _c}b=w[s+24648|0];c=w[J|0]&128?v[s+24668>>2]?-1:b:b}t[d|0]=c;g=v[R>>2];b=v[_>>2];d=v[_+4>>2];if(!(g&131072|((b|0)!=0|(d|0)!=1)|(v[r+1075748>>2]|(c&255)==255))){t[i|0]=0}c=1<<v[W+28>>2];v[e>>2]=v[e>>2]/(c|0);c=v[f>>2]/(c|0)|0;v[f>>2]=c;if(!(!(g&256)|v[s+24624>>2]!=2)){v[f>>2]=0-c}if(g&128){v[_>>2]=0-b;v[_+4>>2]=0-(((b|0)!=0)+d|0)}d=s;j=0;g=gb-16|0;gb=g;c=a;v[a+28>>2]=0;v[a+32>>2]=0;e=a;ad:{bd:{f=v[a+88>>2];if(!(f&65536)){a=v[c+676>>2];b=v[c+672>>2];break bd}b=v[c+20>>2];h=v[c+672>>2];cd:{if((b|0)!=(h|0)){a=v[c+24>>2];i=v[c+676>>2];break cd}a=v[c+24>>2];i=v[c+676>>2];if((a|0)==(i|0)){break bd}}k=d+24604|0;f=g;i=(b|0)<(h|0)|(a|0)<(i|0);dd:{if(i){a=LS(k);break dd}a=KS(k)}v[f+12>>2]=a;Db(g,d+1074312|0,4);if(!(!Cb(g)|!(v[d+480180>>2]&4))){a=v[d+24620>>2];a=oqa(a,a>>31,5,0)+500|0;k=jb;a=Ac(pqa(a,a>>>0<500?k+1|0:k,1e3,0),jb)}f=v[c+656>>2];ed:{if(!f){b=a;break ed}b=a;if(!i){break ed}f=x[f+12>>1];if(f){b=(B(f,v[d+24620>>2])>>>0)/1e5|0}j=(f|0)!=0}h=b?b:1;f=v[c+676>>2];m=v[c+24>>2];o=f-m<<12;i=v[c+672>>2];k=v[c+20>>2];b=i-k<<12;if(!(w[c+90|0]&32|(!(f|i)|(!(k|m)|j)))){v[g+12>>2]=v[d+1074380>>2];Rd(g+12|0,a,2048);i=v[c+672>>2];h=v[g+12>>2];f=v[c+676>>2]}j=(o|0)/(h|0)|0;v[c+32>>2]=j;d=(b|0)/(h|0)|0;v[c+28>>2]=d;a=((B(h,j)|0)/-4096|0)+f|0;v[c+24>>2]=a;b=((B(d,h)|0)/-4096|0)+i|0;v[c+20>>2]=b;if(d|j){v[c+100>>2]=h;f=v[c+88>>2];break ad}v[c+24>>2]=f;v[c+20>>2]=i;a=f;b=i;f=v[c+88>>2]&-65537;break ad}v[c+24>>2]=a;v[c+20>>2]=b;f=f&-65537}v[e+88>>2]=f&-2097153;v[c+40>>2]=a<<12;v[c+36>>2]=b<<12;gb=g+16|0;if(!(w[R+1|0]&2)){break Vc}break Uc}v[h>>2]=0;v[g>>2]=0;v[r+1075068>>2]=0;if(v[r+1075088>>2]){break Vc}if(!v[r+1075084>>2]){break Uc}}a=x[s+480212>>1];u[s+480212>>1]=a+1;u[(s+(a<<1)|0)+1074478>>1]=n}v[r+1075660>>2]=v[R>>2]}n=n+1|0;if((n|0)!=256){continue}break}i=1;if(y[s+24608>>2]>x[s+480212>>1]){break wb}h=s+1074478|0;j=h;b=h+(v[s+24608>>2]<<1)|0;d=h+(x[s+480212>>1]<<1)|0;l=gb-16|0;gb=l;v[l+8>>2]=s;g=l+8|0;e=g;a=b-h|0;if((a|0)>=3){c=a>>1;f=(c-2|0)/2|0;while(1){Lz(h,e,c,h+(f<<1)|0);a=(f|0)>0;f=f-1|0;if(a){continue}break}}if((b|0)!=(d|0)){c=b-j>>1;a=b;while(1){if(vq(g,x[a>>1],x[j>>1])){Mz(a,j);Lz(j,g,c,j)}a=a+2|0;if((d|0)!=(a|0)){continue}break}}a=b-j|0;if((a|0)>=3){a=a>>>1|0;while(1){b=b-2|0;Mz(j,b);c=a-1|0;Lz(j,g,c,j);f=(a|0)>2;a=c;if(f){continue}break}}gb=l+16|0}gb=p+48|0;if(i){a=v[N+480208>>2];break j}b=v[N+480208>>2]|512;if(w[N+1298380|0]){break k}a=0;b=N;c=v[b+24620>>2]/10|0;i=Ac(c,c>>31);fd:{if(!i){break fd}d=i>>>0<1048576?i:1048576;v[b+1074380>>2]=d;f=x[b+480212>>1];if(!f){break fd}e=b+1074376|0;while(1){g=e+B(x[(e+(a<<1)|0)+102>>1],872)|0;b=g+1288|0;v[b>>2]=0;v[b+4>>2]=0;v[g+716>>2]=d;c=v[g+640>>2]<<12;v[g+656>>2]=c;b=v[g+636>>2]<<12;v[g+652>>2]=b;v[g+704>>2]=v[g+704>>2]|65536;v[g+644>>2]=(0-b|0)/(d|0);v[g+648>>2]=(0-c|0)/(d|0);a=a+1|0;if((f|0)!=(a|0)){continue}break}}a=v[N+480208>>2];b=a|256;if(i){break k}b=a|512}a=b;v[ga+480208>>2]=a}if(a&512){Ra=N+1074392|0,Sa=uk(Qa),v[Ra>>2]=Sa;break i}v[Y+112>>2]=512;a=v[N+1074380>>2];v[Y+108>>2]=3;v[Y+120>>2]=ua;v[Y+116>>2]=a;v[Y+104>>2]=Y+112;a=v[Y+108>>2];v[Y+48>>2]=v[Y+104>>2];v[Y+52>>2]=a;s=RX(Y+48|0);if(v[N+24632>>2]){c=N;b=Aa;i=0;l=gb-48|0;gb=l;a=s;d=a<<2;while(1){v[l+32>>2]=0;f=(c+(i<<11)|0)+16396|0;g=f;f=(d+g|0)-g>>2;if((f|0)>=1){while(1){v[g>>2]=v[l+32>>2];g=g+4|0;e=(f|0)>1;f=f-1|0;if(e){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}i=0;while(1){v[(l+32|0)+(i<<2)>>2]=(c+(i<<11)|0)+16396;i=i+1|0;if((i|0)!=4){continue}break}f=mg(l+16|0,l+32|0,v[c+24632>>2],a);c=v[v[b>>2]+8>>2];v[l+8>>2]=v[f+8>>2];a=v[f+4>>2];v[l>>2]=v[f>>2];v[l+4>>2]=a;kb[c|0](b,l);gb=l+48|0}if(w[fa+12|0]){a=0;while(1){v[(Y+112|0)+(a<<2)>>2]=((a<<11)+N|0)+16396;a=a+1|0;if((a|0)!=4){continue}break}c=v[fa+8>>2];f=mg(Y+88|0,Y+112|0,v[N+24632>>2],s);b=v[v[c>>2]+8>>2];v[Y+40>>2]=v[f+8>>2];a=v[f+4>>2];v[Y+32>>2]=v[f>>2];v[Y+36>>2]=a;kb[b|0](c,Y+32|0)}H=N;wa=0;e=gb-112|0;gb=e;i=s;if(i){V=H+12|0;T=H+24592|0;F=H+24588|0;To(V,i,T,F);if(y[H+24624>>2]>=3){To(H+8204|0,i,H+24600|0,H+24596|0)}u[e+30>>1]=0;a=e+8|0;Ba=H+1074312|0;Db(a,Ba,33);a=Cb(a);if(x[H+480212>>1]){A=a?2:1;E=H+24648|0;M=H+24596|0;I=H+24600|0;K=H+8204|0;n=H+397452|0;p=H+397448|0;q=H+393352|0;J=H+397456|0;Fa=H+1074376|0;while(1){k=Fa+(wa<<1)|0;b=B(x[k+102>>1],872);l=b+Fa|0;la=l;gd:{hd:{if(v[l+632>>2]){break hd}a=b+H|0;if(v[a+1075088>>2]){break hd}if(!v[a+1075084>>2]){break gd}}m=b+H|0;a=w[m+1075786|0]+1|0;if((a&255)>>>0<=5){h=v[(a<<24>>24<<2)+34080>>2]}else{h=0}g=M;ca=m+1075080|0;j=v[ca>>2];id:{if(!(!(j&16777216)&w[H+24612|0]>>>5)){a=V;b=T;c=j;f=F;if(!(c&8388608)){break id}}a=q;b=p;d=n;f=i;c=J;if(!w[c+12|0]){To(a,f,b,d)}t[c+12|0]=1;c=v[ca>>2];f=n}c=c>>>8&y[H+24624>>2]>2;ea=c?g:f;na=c?I:b;f=c?K:a;oa=Jm(H,x[k+102>>1],2,1);jd:{if((!oa|0)==(oa>>>0<251|0)){break jd}b=v[(H+B(oa,160)|0)+906140>>2];if(!b){break jd}a=v[b+24>>2];if(!a){break jd}ea=b+36|0;na=b+40|0;if(!(t[b+28|0]&1)){To(a,i,na,ea);v[b+28>>2]=v[b+28>>2]|1}f=a}l=l+616|0;if(w[m+1075843|0]&4){MS(l,f,i);a=m+1075084|0;v[na>>2]=v[na>>2]+v[a>>2];v[ea>>2]=v[ea>>2]+v[m+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break gd}o=0;ga=e+8|0;a=ga;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=l;if(v[a+16>>2]){iF(ga,a);d=v[a+12>>2];b=d;c=v[a+8>>2];a=b>>31;g=c+a|0;G=b+a|0;a=a^(a>>>0>g>>>0?G+1|0:G);v[ga+12>>2]=a>>>0>8191?2:16384/(a+1>>>0)|0}r=j>>>12&8|(j>>>5&2|(h|j&1));Ga=m+1075795|0;R=m+1075778|0;X=m+1075688|0;$=m+1075024|0;aa=m+1075020|0;ba=m+1075668|0;_=m+1075664|0;ia=m+1075e3|0;pa=m+1075088|0;qa=m+1075084|0;Ha=m+1075016|0;ra=m+1075012|0;xa=m+1075096|0;va=m+1075076|0;ja=m+1075068|0;ya=m+1075072|0;sa=m+1075092|0;a=i;while(1){kd:{b=v[sa>>2];za=b?a>>>0>b>>>0?b:a:a;v[e+68>>2]=za;G=v[ya>>2];W=v[ca>>2];k=v[ia+4>>2];d=v[ia>>2];v[e+56>>2]=d;v[e+60>>2]=k;ld:{md:{if(!za|!(d|k)){break md}ka=v[ja>>2];if(!ka){break md}b=v[e+8>>2];if(!b){break md}v[la+632>>2]=b;b=v[l+4>>2];j=b;nd:{od:{g=v[l>>2];m=G&W<<30>>31;c=b;pd:{if((m|0)>(b|0)){if((k|0)<-1?1:(k|0)<=-1){b=e;v[b+104>>2]=0;c=m;v[b+108>>2]=c<<1;g=Pg(b+104|0,l);b=jb;j=b;v[l>>2]=g;v[l+4>>2]=b;if(!(b>>>0<c+v[ja>>2]>>>1>>>0?(b|0)>=(c|0):0)){b=l;g=0;v[b>>2]=g;v[b+4>>2]=c;j=c}h=0-d|0;v[e+56>>2]=h;b=0-(((d|0)!=0)+k|0)|0;v[e+60>>2]=b;v[ia>>2]=h;v[ia+4>>2]=b;c=v[ca>>2];qd:{if(c&4){Z=c&-129;v[ca>>2]=Z;break qd}Z=c|128;v[ca>>2]=Z;c=v[ja>>2]-1|0;j=c;v[l>>2]=g;v[l+4>>2]=c;v[ia>>2]=d;v[ia+4>>2]=k}if(!(Z&2)){break md}if(j>>>0<y[ja>>2]){break nd}break md}if((j|0)>-1){break pd}b=0;j=b;v[l>>2]=g;v[l+4>>2]=b;break pd}if(c>>>0>=ka>>>0){break od}}h=d;b=k;break nd}if(!(W&2)){break md}if(W&4){rd:{if((k|0)<0?1:(k|0)<=0?d>>>0<1:0){h=d;b=k;break rd}h=0-d|0;v[e+56>>2]=h;b=0-(((d|0)!=0)+k|0)|0;v[e+60>>2]=b;v[ia>>2]=h;v[ia+4>>2]=b}v[ca>>2]=W|128;d=c;c=1-((g|0)!=0)|0;g=0-g|0;k=(ka<<1)-(d+c|0)|0;c=k;j=c;d=l;v[d>>2]=g;v[d+4>>2]=c;if(c>>>0<ka>>>0?c>>>0>G>>>0:0){break nd}v[e+104>>2]=A;c=ka-v[Fb(ja,e+104|0)>>2]|0;g=v[l>>2];j=c;v[l>>2]=g;v[d+4>>2]=c;break nd}sd:{if((k|0)>-1){h=d;b=k;break sd}h=0-d|0;v[e+56>>2]=h;b=0-(((d|0)!=0)+k|0)|0;v[e+60>>2]=b;v[ia>>2]=h;v[ia+4>>2]=b}d=e;v[d+104>>2]=0;v[d+108>>2]=m-ka;Ub(l,d+104|0);v[ca>>2]=v[ca>>2]|8192;g=v[l>>2];j=v[l+4>>2]}v[e+48>>2]=g;c=j;v[e+52>>2]=c;td:{ud:{Z=c;if((c|0)<(m|0)){c=0;if((j|0)<0|(b|0)<0){break td}break ud}if((j|0)>0?1:(j|0)>=0){break ud}c=0;break td}c=0;if(Z>>>0>=y[ja>>2]){break td}v[e+44>>2]=za;qc(e+68|0,v[e+20>>2]);Ra=e,Sa=Bw(e+56|0,v[e+68>>2]-1|0),v[Ra+32>>2]=Sa;v[e+36>>2]=jb;c=b>>31;W=c;k=c+h|0;h=c;b=c+b|0;G=k;d=c>>>0>k>>>0?b+1|0:b;k=v[ya>>2];ta=k+16|0;c=v[e+36>>2]+v[e+52>>2]|0;b=v[e+48>>2];ka=b+v[e+32>>2]|0;b=b>>>0>ka>>>0?c+1|0:c;k=k>>>0>Z>>>0;if(Z>>>0<ta>>>0?k:1){v[ca>>2]=v[ca>>2]&-8193}W=G^W;G=d^h;c=b;vd:{wd:{xd:{if(!v[e+12>>2]){b=v[e+60>>2];break xd}d=v[e+16>>2];if(d>>>0<=Z>>>0){h=e;b=v[e+60>>2];yd:{if((b|0)<-1?1:(b|0)<=-1){v[e+96>>2]=g;v[e+100>>2]=j;c=e;v[c+104>>2]=0;v[c+108>>2]=d;Ra=c,Sa=Pg(c+96|0,c+104|0),v[Ra+80>>2]=Sa;v[c+84>>2]=jb;v[c+72>>2]=1;v[c+76>>2]=0;Ra=c,Sa=Pg(c+80|0,c+72|0),v[Ra+88>>2]=Sa;v[c+92>>2]=jb;b=Hn(c+88|0,W,G);break yd}d=v[va>>2];v[e+104>>2]=g;v[e+108>>2]=j;b=e;v[b+96>>2]=0;v[b+100>>2]=d;Ra=b,Sa=Pg(b+96|0,b+104|0),v[Ra+80>>2]=Sa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Ra=b,Sa=Pg(b+80|0,b+72|0),v[Ra+88>>2]=Sa;v[b+92>>2]=jb;b=Hn(b+88|0,W,G)}v[h+44>>2]=b+1;v[la+632>>2]=v[e+12>>2];break vd}if(!(!(w[ca+1|0]&32)|k|Z>>>0>=ta>>>0)){v[e+104>>2]=g;v[e+108>>2]=j;b=e;v[b+96>>2]=0;v[b+100>>2]=m+16;Ra=b,Sa=Pg(b+96|0,b+104|0),v[Ra+80>>2]=Sa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Ra=b,Sa=Pg(b+80|0,b+72|0),v[Ra+88>>2]=Sa;v[b+92>>2]=jb;Ra=b,Sa=Hn(b+88|0,W,G)+1|0,v[Ra+44>>2]=Sa;Ra=la,Sa=v[b+12>>2]+B(v[va>>2]-m|0,jj(v[xa>>2]))|0,v[Ra+632>>2]=Sa;break vd}b=v[e+60>>2];if((b|0)<0?1:(b|0)<=0?y[e+56>>2]<1:0){break xd}if(za>>>0<2|c>>>0<d>>>0){break wd}v[e+104>>2]=g;v[e+108>>2]=j;b=e;v[b+96>>2]=0;v[b+100>>2]=d;Ra=b,Sa=Pg(b+96|0,b+104|0),v[Ra+80>>2]=Sa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Ra=b,Sa=Pg(b+80|0,b+72|0),v[Ra+88>>2]=Sa;v[b+92>>2]=jb;Ra=b,Sa=Hn(b+88|0,W,G)+1|0,v[Ra+44>>2]=Sa;break vd}if((b|0)>-1){break wd}if((c|0)>=(m|0)){break vd}v[e+96>>2]=g;v[e+100>>2]=j;b=e;v[b+104>>2]=0;v[b+108>>2]=m;Ra=b,Sa=Pg(b+96|0,b+104|0),v[Ra+80>>2]=Sa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Ra=b,Sa=Pg(b+80|0,b+72|0),v[Ra+88>>2]=Sa;v[b+92>>2]=jb;Ra=b,Sa=Hn(b+88|0,W,G)+1|0,v[Ra+44>>2]=Sa;break vd}b=c;c=v[ja>>2];if((b|0)<(c|0)){break vd}v[e+104>>2]=g;v[e+108>>2]=j;b=e;v[b+96>>2]=0;v[b+100>>2]=c;Ra=b,Sa=Pg(b+96|0,b+104|0),v[Ra+80>>2]=Sa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Ra=b,Sa=Pg(b+80|0,b+72|0),v[Ra+88>>2]=Sa;v[b+92>>2]=jb;Ra=b,Sa=Hn(b+88|0,W,G)+1|0,v[Ra+44>>2]=Sa}Fp(e+44|0,1,v[e+68>>2]);c=v[e+44>>2]}if((c|0)>0){break ld}}v[la+632>>2]=0;v[ja>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[sa>>2]=0;MS(l,f,a);v[na>>2]=v[na>>2]+v[qa>>2];v[ea>>2]=v[ea>>2]+v[pa>>2];v[pa>>2]=0;v[qa>>2]=0;v[ca>>2]=v[ca>>2]&-129;Z=x[e+30>>1];break kd}zd:{Ad:{Z=x[e+30>>1];if(Z>>>0<y[H+24608>>2]){o=4;if(v[sa>>2]){break Ad}o=0;if(v[Ha>>2]|v[ra>>2]){break Ad}}Ra=e,Sa=oqa(v[ia>>2],v[ia+4>>2],c,c>>31),v[Ra+104>>2]=Sa;v[e+108>>2]=jb;Ub(l,e+104|0);o=0;v[pa>>2]=0;v[qa>>2]=0;b=(c<<3)+f|0;break zd}b=(c<<3)+f|0;g=b-8|0;v[qa>>2]=0-v[g>>2];d=b-4|0;v[pa>>2]=0-v[d>>2];kb[v[((o|r)<<2)+33696>>2]](l,E,f,c);v[qa>>2]=v[qa>>2]+v[g>>2];v[pa>>2]=v[pa>>2]+v[d>>2];o=1}f=b;b=v[sa>>2];Bd:{if(!b){break Bd}if(b>>>0<=c>>>0){v[sa>>2]=0;v[ra>>2]=v[_>>2];v[Ha>>2]=v[ba>>2];v[aa>>2]=0;v[$>>2]=0;if(v[X>>2]|!(w[ca+1|0]&16)){break Bd}v[ja>>2]=0;v[la+632>>2]=0;break Bd}v[sa>>2]=b-c}g=0;b=0;d=v[l+4>>2];b=d>>>0>=y[va>>2]?(w[ca|0]&2)>>>1|0:b;j=d;d=v[ja>>2];g=j>>>0<d>>>0|(!d|w[ca|0]&2)?g:!x[R>>1];a=a-c|0;c=e+104|0;Db(c,Ba,85);Cd:{Dd:{Ed:{Fd:{if(!Cb(c)){break Fd}c=w[Ga|0];if(!c|c>>>0>x[H+480190>>1]){break Fd}j=!(b|g);g=H+B(w[Ga|0],104)|0;d=g+484380|0;c=v[xa>>2];if(j|(d|0)==(c|0)){break Ed}v[xa>>2]=d;v[la+632>>2]=v[g+484400>>2];b=x[g+484414>>1];v[ca>>2]=b|v[ca>>2]&-768;c=v[g+484388>>2];v[ja>>2]=c&b<<30>>31;b=v[g+484384>>2];v[ya>>2]=b;v[va>>2]=c;v[l+4>>2]=b;iF(ga,l);if(!v[la+632>>2]){break kd}if((a|0)>0){continue}break kd}if(b){break Dd}break Cd}if(!b|(c|0)!=(d|0)){break Cd}}b=e+104|0;Db(b,Ba,83);if(!Cb(b)|v[ya>>2]){break Cd}v[l>>2]=v[l>>2];v[l+4>>2]=0;b=v[v[xa>>2]+8>>2];v[ja>>2]=b;v[va>>2]=b}if((a|0)>0){continue}}break}v[la+632>>2]=v[e+8>>2];u[e+30>>1]=o+Z;if(!o|!oa|oa>>>0>250){break gd}a=v[(H+B(oa,160)|0)+906140>>2];if(!a){break gd}kb[v[v[a>>2]+148>>2]](a)}wa=wa+1|0;if(wa>>>0<x[H+480212>>1]){continue}break}}Ra=H,Sa=x[Le(H+480214|0,e+30|0)>>1],u[Ra+480214>>1]=Sa}gb=e+112|0;if(Dd(Ea)){a=ma;b=(B(v[N+480232>>2],v[N+480236>>2])>>>0)/48|0;T=gb-16|0;gb=T;n=v[Ea>>2];Gd:{if(!w[n+530|0]){break Gd}b=oqa(b,0,6169,0);f=jb;c=f>>>16|0;F=Qc((f&65535)<<16|b>>>16,c);if(!i){break Gd}while(1){j=v[n>>2];h=v[j>>2];c=v[j+4>>2];if((h|0)<=(c|0)){d=j+14|0;e=j+12|0;while(1){v[j+8>>2]=v[j+12>>2];l=j;f=e;c=d;h=0;G=0;q=0;g=gb-16|0;gb=g;while(1){J=l+B(q,44)|0;Hd:{if(!w[J+56|0]){u[g+12>>1]=0;u[g+14>>1]=0;break Hd}b=v[J+32>>2];k=x[b+3840>>1];if(k&3){b=(x[J+36>>1]>>>7&7)>>>(w[b+3844|0]^1)>>>(k&1)|0;b=(k&4?0-b|0:b)&65535}else{b=0}V=b<<x[J+38>>1];ga=g;k=v[J+52>>2];Id:{if(k){k=x[k+32>>1];o=x[J+48>>1];M=kg(v[J+16>>2],v[J+40>>2],V<<16>>16,0,u[J+46>>1]);p=v[J+40>>2];m=v[J+20>>2];if(!k){if(!o){o=V<<16>>16;k=kg(m,p,o,M,0);k=kg(v[J+24>>2],v[J+40>>2],o,k,0);k=kg(v[J+28>>2],v[J+40>>2],o,k,0);break Id}o=V<<16>>16;k=kg(m,p,o,0,0);k=kg(v[J+24>>2],v[J+40>>2],o,k,0);k=kg(v[J+28>>2],v[J+40>>2],o,k,0)+M|0;break Id}if(!o){b=m;m=V<<16>>16;o=kg(b,p,m,M,0);k=kg(v[J+24>>2],v[J+40>>2],m,0,0);k=kg(v[J+28>>2],v[J+40>>2],m,k,0)+o|0;break Id}o=V<<16>>16;k=kg(m,p,o,0,0);k=(kg(v[J+24>>2],v[J+40>>2],o,k,0)+M|0)+kg(v[J+28>>2],v[J+40>>2],o,0,0)|0;break Id}k=x[J+48>>1];M=V<<16>>16;p=kg(v[J+16>>2],v[J+40>>2],M,0,u[J+46>>1]);m=v[J+40>>2];o=v[J+20>>2];if(!k){k=kg(o,m,M,p,0);break Id}k=kg(o,m,M,0,0)+p|0}u[ga+14>>1]=w[J+57|0]?k:0;u[g+12>>1]=w[J+58|0]?k:0}h=u[g+12>>1]+h|0;G=u[g+14>>1]+G|0;q=q+1|0;if((q|0)!=18){continue}break}b=(G|0)<32767?G:32767;u[f>>1]=(b|0)>-32768?b:-32768;b=(h|0)<32767?h:32767;u[c>>1]=(b|0)>-32768?b:-32768;u[l+3832>>1]=x[l+3832>>1]+1;b=(x[l+3834>>1]+1>>>0)%13440|0;u[l+3834>>1]=b;b=b>>>0<6720?b:13440-b|0;u[l+3836>>1]=b>>>8;if(!w[l+3843|0]){u[l+3836>>1]=b>>>10}b=x[l+3838>>1]+1|0;u[l+3838>>1]=b;if((b&65535)>>>0>=1024){u[l+3838>>1]=0;u[l+3840>>1]=x[l+3840>>1]+1&7}gb=g+16|0;h=v[j>>2];c=v[j+4>>2]-h|0;v[j+4>>2]=c;if((c|0)>=(h|0)){continue}break}}b=h-c|0;u[T+14>>1]=(B(u[j+12>>1],c)+B(b,u[j+8>>1])|0)/(h|0);u[T+12>>1]=(B(u[j+14>>1],c)+B(b,u[j+10>>1])|0)/(h|0);v[j+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(F,u[T+14>>1]);v[a+4>>2]=v[a+4>>2]+B(F,u[T+12>>1]);a=a+8|0;i=i-1|0;if(i){continue}break}}gb=T+16|0}c=ma;a=Oa;m=Na;k=Ma;d=s;l=Pa;Jd:{if(!w[l+12|0]){if(!v[l+16>>2]){break Jd}To(a,d,m,k)}h=v[l>>2];g=v[l+80>>2];b=B(h,g)>>>4|0;b=b>>>0<32767?b:32767;u[l+98>>1]=b;u[l+96>>1]=b;e=v[l+49948>>2];b=B(e,h)>>>4|0;b=b>>>0<65536?b:65536;f=b+127>>>3|0;u[l+49946>>1]=f;b=b+255>>>4|0;u[l+49944>>1]=b;u[l+49942>>1]=b;u[l+49940>>1]=f;i=c;f=a;b=(e|0)<(g|0)?g:e;e=(b|0)<32768?b:32768;b=36-h>>>1|0;b=b>>>0>8?b:8;j=16-(B(e,(b|0)<16?16-b|0:0)>>15)|0;e=0;b=d;if(b){while(1){h=e<<3;g=h+i|0;v[g>>2]=v[g>>2]+B(j,v[f+h>>2]>>4);h=h|4;g=h+i|0;v[g>>2]=v[g>>2]+B(j,v[f+h>>2]>>4);e=e+1|0;if((b|0)!=(e|0)){continue}break}}f=l+68|0;i=a;e=0;b=l;g=v[b+40>>2];o=v[b+36>>2];if(d){j=u[b+84>>1];while(1){n=(e<<3)+i|0;h=v[n>>2]>>12;o=(B(j,h-o|0)>>15)+h|0;v[n>>2]=o;h=v[n+4>>2]>>12;g=(B(j,h-g|0)>>15)+h|0;v[n+4>>2]=g;e=e+1|0;if((d|0)!=(e|0)){continue}break}}v[b+40>>2]=g;v[b+36>>2]=o;Kd:{if(!d){g=v[f>>2];break Kd}h=l+49892|0;e=d;b=f;j=v[b>>2]-1|0;g=x[b+22>>1];W=u[b+26>>1];T=u[b+18>>1];o=v[b+4>>2];n=x[b+20>>1];H=u[b+24>>1];F=u[b+16>>1];J=b+32928|0;while(1){p=Mb(v[i>>2],-32768,32767);q=Mb(v[i+4>>2],-32768,32767);n=Mb((n<<16>>16)-p|0,-32768,32767);g=Mb((g<<16>>16)-q|0,-32768,32767);n=Uc(Mb((B(n,F)|0)/65536<<1,-32768,32767)+p|0);g=Uc(Mb((B(g,T)|0)/65536<<1,-32768,32767)+q|0);q=J+(o<<2)|0;G=u[q+2>>1];M=u[q>>1];V=Uc(((B(M,H)|0)/-65536|0)+n|0);o=o+1&127;q=J+(o<<2)|0;p=Uc(((B(G,W)|0)/-65536|0)+g|0);u[q+2>>1]=p;u[q>>1]=V;j=j+1&8191;q=b+(j<<2)|0;Ra=q,Sa=Uc(M+((B(H,V)|0)/65536|0)|0),u[Ra+160>>1]=Sa;Ra=q,Sa=Uc(G+((B(p,W)|0)/65536|0)|0),u[Ra+162>>1]=Sa;i=i+8|0;e=e-1|0;if(e){continue}break}u[b+22>>1]=g;u[b+20>>1]=n;v[b+4>>2]=o;i=v[l+76>>2];E=l+33508|0;b=a;e=d;while(1){j=i&4095;Z=E+(j<<2)|0;g=b;j=4096-j|0;V=i-v[l+49892>>2]&4095;i=4096-V|0;i=i>>>0>j>>>0?j:i;i=e>>>0>i>>>0?i:e;p=i>>>0<64?i:64;q=p;n=0;H=gb-32|0;gb=H;i=f;j=v[f>>2];while(1){v[H+(n<<2)>>2]=j+(v[(i+(n<<4)|0)+32>>2]^-1);n=n+1|0;if((n|0)!=7){continue}break}j=u[i+28>>1]/8|0;if(q){G=j<<16>>16;while(1){j=0;o=0;n=0;while(1){M=H+(n<<2)|0;F=v[M>>2]+1&8191;v[M>>2]=F;ga=o;o=i+(F<<2)|0;F=u[o+160>>1];T=i+(n<<4)|0;M=u[o+162>>1];o=(ga+B(F,u[T+44>>1])|0)+B(M,u[T+46>>1])|0;j=(B(F,u[T+40>>1])+j|0)+B(M,u[T+42>>1])|0;n=n+1|0;if((n|0)!=4){continue}break}ea=0;n=4;T=Uc((j|0)/32768|0);F=Uc((o|0)/32768|0);j=0;while(1){o=H+(n<<2)|0;M=v[o>>2]+1&8191;v[o>>2]=M;ga=j;j=i+(M<<2)|0;M=u[j+160>>1];J=i+(n<<4)|0;o=u[j+162>>1];j=(ga+B(M,u[J+44>>1])|0)+B(o,u[J+46>>1])|0;ea=(B(M,u[J+40>>1])+ea|0)+B(o,u[J+42>>1])|0;n=n+1|0;if((n|0)!=7){continue}break}o=Uc(T+((ea|0)/32768|0)|0);u[Z>>1]=o;v[g>>2]=B(o,G);j=Uc(F+((j|0)/32768|0)|0);u[Z+2>>1]=j;v[g+4>>2]=B(j,G);g=g+8|0;Z=Z+4|0;q=q-1|0;if(q){continue}break}}gb=H+32|0;Z=E+(V<<2)|0;g=b;i=h;j=v[h+4>>2];o=j&2047;n=p;if(p){ra=i+8256|0;ta=i- -64|0;ka=i+24640|0;A=i+16448|0;while(1){I=u[(ra+((j+754&2047)<<2)|0)+2>>1];K=u[ra+((j+1206&2047)<<2)>>1];r=u[(ta+((j+1602&2047)<<2)|0)+2>>1];R=u[ta+((j+1750&2047)<<2)>>1];q=ka+((j+22&2047)<<2)|0;X=u[q+2>>1];$=u[q>>1];q=ka+((j+502&2047)<<2)|0;aa=u[q+2>>1];ba=u[Z>>1];_=u[Z+2>>1];W=u[q>>1];H=Mb(u[i+32>>1]-W|0,-32768,32767);J=u[i+24>>1];G=Mb(u[i+34>>1]-aa|0,-32768,32767);V=u[i+26>>1];T=Mb(u[i+36>>1]-$|0,-32768,32767);F=u[i+28>>1];M=Mb(u[i+38>>1]-X|0,-32768,32767);q=u[i+30>>1];Ra=i,Sa=Uc(Mb((B(H,J)|0)/65536<<1,-32768,32767)+W|0),u[Ra+32>>1]=Sa;Ra=i,Sa=Uc(Mb((B(G,V)|0)/65536<<1,-32768,32767)+aa|0),u[Ra+34>>1]=Sa;Ra=i,Sa=Uc(Mb((B(F,T)|0)/65536<<1,-32768,32767)+$|0),u[Ra+36>>1]=Sa;Ra=i,Sa=Uc(Mb((B(q,M)|0)/65536<<1,-32768,32767)+X|0),u[Ra+38>>1]=Sa;M=Mb((B(u[i+32>>1],u[i+16>>1])|0)/32768|0,-32768,32767);q=Mb((B(u[i+38>>1],u[i+22>>1])|0)/32768|0,-32768,32767);V=Mb(M+((ba|0)/4<<16>>16)|0,-32768,32767);T=Mb(q+((_|0)/4<<16>>16)|0,-32768,32767);F=Mb(V+((B(R,u[i+8>>1])|0)/-65536|0)|0,-32768,32767);_=o<<2;M=_+ta|0;q=Mb(T+((B(r,u[i+10>>1])|0)/-65536|0)|0,-32768,32767);u[M+2>>1]=q;u[M>>1]=F;F=Mb(R+((B(F,u[i+8>>1])|0)/65536|0)|0,-32768,32767);M=A+_|0;q=Mb(r+((B(q,u[i+10>>1])|0)/65536|0)|0,-32768,32767);u[M+2>>1]=q;u[M>>1]=F;V=Mb(F+V|0,-32768,32767);T=Mb(q+T|0,-32768,32767);q=A+((j+426&2047)<<2)|0;F=u[q+2>>1];M=u[q>>1];j=A+((j+682&2047)<<2)|0;q=u[j+2>>1];j=u[j>>1];H=Mb((B(q,u[i+42>>1])+B(j,u[i+40>>1])|0)/32768|0,-32768,32767);W=Mb((B(F,u[i+46>>1])+B(M,u[i+44>>1])|0)/32768|0,-32768,32767);J=Mb(Mb(j+V|0,-32768,32767)-H|0,-32768,32767);G=Mb(Mb(q+T|0,-32768,32767)-W|0,-32768,32767);V=Mb(Mb(M+V|0,-32768,32767)-H|0,-32768,32767);T=Mb(Mb(F+T|0,-32768,32767)-W|0,-32768,32767);H=Mb(H+((B(K,u[i+8>>1])|0)/-65536|0)|0,-32768,32767);M=u[i+8>>1];F=u[i+10>>1];j=_+ra|0;q=Mb(W+((B(I,u[i+10>>1])|0)/-65536|0)|0,-32768,32767);u[j+2>>1]=q;u[j>>1]=H;M=(B(H,M)|0)/65536|0;H=Mb(M+K|0,-32768,32767);j=_+ka|0;F=(B(q,F)|0)/65536|0;q=Mb(F+I|0,-32768,32767);u[j+2>>1]=q;u[j>>1]=H;j=Mb(H+J|0,-32768,32767);Ra=g,Sa=(v[g>>2]+B(j,u[i+48>>1])|0)+B(Mb(q+G|0,-32768,32767),u[i+50>>1])|0,v[Ra>>2]=Sa;M=Mb(Mb(M,-32768,32767)+V|0,-32768,32767);q=u[i+52>>1];j=Mb(F,-32768,32767);Ra=g,Sa=(v[g+4>>2]+B(q,M)|0)+B(Mb(j+T|0,-32768,32767),u[i+54>>1])|0,v[Ra+4>>2]=Sa;g=g+8|0;Z=Z+4|0;j=o+1|0;o=j&2047;n=n-1|0;if(n){continue}break}}v[i+4>>2]=o;i=p+v[l+76>>2]&4095;v[l+76>>2]=i;g=p+v[l+68>>2]&8191;v[l+68>>2]=g;b=(p<<3)+b|0;e=e-p|0;if(e){continue}break}}v[l+68>>2]=g&8191;b=a;f=0;i=0;a=l;n=v[a+56>>2];G=v[a+52>>2];e=d;if(d){g=v[a+60>>2];o=v[a+64>>2];while(1){f=v[b>>2];i=v[b+4>>2];h=o-i|0;h=(((h|0)/1024|0)-h|0)+n|0;v[c+4>>2]=h+v[c+4>>2];g=g-f|0;g=(((g|0)/1024|0)-g|0)+G|0;v[c>>2]=g+v[c>>2];n=h+((h|0)/-512|0)|0;G=g+((g|0)/-512|0)|0;c=c+8|0;b=b+8|0;o=i;g=f;e=e-1|0;if(e){continue}break}}v[a+64>>2]=i;v[a+60>>2]=f;v[a+56>>2]=n;v[a+52>>2]=G;Ld:{if(w[l+12|0]){v[l+16>>2]=v[l+20>>2];break Ld}a=v[l+16>>2];if(a>>>0>d>>>0){v[l+16>>2]=a-d;break Ld}NL(l,m,k);v[l+16>>2]=0}t[l+12|0]=0}if(v[N+946300>>2]){n=0;h=0;c=s<<2;g=N;o=x[g+480214>>1]!=0;a=g+1074332|0;da=z[a>>2];Ia=z[a+4>>2];while(1){b=(g+B(n,160)|0)+906300|0;a=v[b>>2];Md:{if(!a|!v[a+24>>2]){break Md}if(!ni(a+44|0)){break Md}i=v[b>>2];if(!(kb[v[v[i>>2]+112>>2]](i)|0)){kb[v[v[i>>2]+108>>2]](i,1);kb[v[v[i>>2]+120>>2]](i)}a=i+44|0;e=Nd(a,0);f=Nd(a,1);Nd:{if(t[i+28|0]&1){lB(v[i+24>>2],e,f,d,da);break Nd}a=i+40|0;if(v[i+36>>2]?1:v[a>>2]){To(v[i+24>>2],d,a,i+36|0);lB(v[i+24>>2],e,f,d,da);break Nd}Qb(e,0,c);Qb(f,0,c)}v[i+28>>2]=v[i+28>>2]&-2;if(Aw(b)){break Md}o=!(w[i+28|0]&4)|o}n=n+1|0;if((n|0)!=250){continue}break}j=g+12|0;i=g+12300|0;e=g+14348|0;lB(j,i,e,d,da);a=g+1074476|0;q=w[a|0];t[a|0]=0;a=i;c=e;while(1){G=(g+B(h,160)|0)+906300|0;b=v[G>>2];Od:{if(!b|!v[b+24>>2]){break Od}if(!ni(b+44|0)){break Od}T=v[G>>2];Pd:{if(Aw(G)){break Pd}b=v[G>>2];if(kb[v[v[b>>2]+144>>2]](b)|w[v[G>>2]+28|0]&2){break Pd}n=0;if(!h){break Od}while(1){if((Vk((g+B(n,160)|0)+906300|0)|0)==(h|0)){break Pd}n=n+1|0;if((n|0)!=(h|0)){continue}break}break Od}b=T+44|0;F=Nd(b,0);p=Nd(b,1);V=v[G>>2];k=(a|0)==(F|0);a=k?i:a;b=a;c=k?e:c;f=c;Qd:{if(!(w[G+28|0]|w[G+29|0]<<8|(w[G+30|0]<<16|w[G+31|0]<<24))){break Qd}b=a;l=Vk(G);f=c;if(l>>>0>249){break Qd}f=c;if(h>>>0>=l>>>0){break Qd}l=v[(g+B(l,160)|0)+906300>>2];f=c;if(!l){break Qd}if(!(w[V+28|0]&4)){kb[v[v[l>>2]+148>>2]](l)}l=l+44|0;f=c;if(!ni(l)){break Qd}b=Nd(l,0);f=Nd(l,1)}Rd:{if(!Aw(G)){break Rd}Sd:{if(k){break Sd}n=0;if(!d){break Sd}while(1){M=n<<2;l=M+F|0;m=a+M|0;z[l>>2]=z[m>>2]+z[l>>2];k=p+M|0;l=c+M|0;z[k>>2]=z[l>>2]+z[k>>2];v[m>>2]=0;v[l>>2]=0;n=n+1|0;if((d|0)!=(n|0)){continue}break}}c=f;a=b;if(!(o&1)){break Rd}a=v[G>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}a=b;n=Vk(G);if(n>>>0>249|h>>>0>=n>>>0){break Rd}while(1){c=n&255;a=(g+B(c,160)|0)+906300|0;n=Vk(a);a=v[a>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}if(c>>>0<n>>>0?n>>>0<=249:0){continue}break}c=f;a=b}Td:{Ud:{if(!((w[G+24|0]&2)>>>1|0)){if(!gF(G)|!(w[V+28|0]&4)){break Ud}}n=0;if(!d){break Td}while(1){k=n<<2;l=k+b|0;z[l>>2]=z[k+F>>2]+z[l>>2];l=f+k|0;z[l>>2]=z[k+p>>2]+z[l>>2];n=n+1|0;if((d|0)!=(n|0)){continue}break}break Td}if(q){kb[v[v[T>>2]+128>>2]](T)}kb[v[v[T>>2]+60>>2]](T,b,f,d);v[V+32>>2]=d+v[V+32>>2];if(!gF(G)){break Td}if((kb[v[v[T>>2]+156>>2]](T)|0)<1|y[V+32>>2]<v[g+24620>>2]<<2>>>0){break Td}n=0;Vd:{if(!d){break Vd}while(1){Wd:{l=n<<2;da=z[l+b>>2];if(da>=C(1.1920928955078125e-7)|da<=C(-1.1920928955078125e-7)){break Wd}da=z[f+l>>2];if(da>=C(1.1920928955078125e-7)|da<=C(-1.1920928955078125e-7)){break Wd}n=n+1|0;if((d|0)!=(n|0)){continue}break Vd}break}v[V+32>>2]=0;break Td}v[V+28>>2]=v[V+28>>2]|4}v[V+28>>2]=v[V+28>>2]&-3}h=h+1|0;if((h|0)!=250){continue}break}b=0;if(d){while(1){f=j;da=C(z[a>>2]*Ia);Xd:{if(C(D(da))<C(2147483648)){e=~~da;break Xd}e=-2147483648}v[f>>2]=e;f=j;da=C(z[c>>2]*Ia);Yd:{if(C(D(da))<C(2147483648)){e=~~da;break Yd}e=-2147483648}v[f+4>>2]=e;j=j+8|0;c=c+4|0;a=a+4|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}}}if(v[N+24624>>2]==1){b=ma;i=0;a=s;if(a){while(1){c=b+(i<<3)|0;v[b+(i<<2)>>2]=(v[c+4>>2]+v[c>>2]|0)/2;i=i+1|0;if((a|0)!=(i|0)){continue}break}}}if(w[La+33|0]){k=gb-16|0;gb=k;Zd:{_d:{g=N;$d:{if(!v[g+1074376>>2]){c=g+1074460|0;v[c>>2]=0;v[c+4>>2]=0;v[g+1074468>>2]=v[g+1074456>>2];break $d}b=v[g+1074468>>2];f=v[g+1074456>>2];ae:{if((b|0)==(f|0)){i=v[g+1074460>>2];break ae}v[g+1074468>>2]=f;c=g+24604|0;a=g+1074460|0;be:{if((b|0)<(f|0)){i=LS(c);break be}i=KS(c)}v[a>>2]=i;v[g+1074464>>2]=i}c=g+1074460|0;if((i|0)>=1){break _d}}e=0;break Zd}l=(v[g+1074468>>2]<<12)-v[g+1074472>>2]|0;e=(l|0)/(i|0)|0;if(w[g+1074368|0]!=2){break Zd}v[k+12>>2]=50;f=g+1074464|0;v[k+8>>2]=1e4/(v[f>>2]+1|0);b=v[If(k+12|0,k+8|0)>>2];a=e>>31;if((b|0)>=(a+e^a)){break Zd}a=v[f>>2];i=v[c>>2];while(1){i=a+i|0;e=(l|0)/(i|0)|0;f=e>>31;if((b|0)<(f^e+f)){continue}break}v[c>>2]=i}ce:{de:{switch(v[g+24624>>2]-1|0){case 0:if((d|0)<1){break ce}b=v[g+1074456>>2];h=b<<12;a=b;l=b>>31;i=g+12|0;b=0;while(1){ee:{if(v[c>>2]>=1){j=v[g+1074472>>2]+e|0;v[g+1074472>>2]=j;f=v[i>>2];Ra=i,Sa=Ac(pqa(oqa(f,f>>31,j,j>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;v[g+1074460>>2]=v[g+1074460>>2]-1;break ee}f=v[i>>2];Ra=i,Sa=Ac(pqa(oqa(f,f>>31,a,l),jb,256,0),jb),v[Ra>>2]=Sa;v[g+1074472>>2]=h}i=i+4|0;b=b+1|0;if((d|0)!=(b|0)){continue}break};break ce;case 1:if((d|0)<1){break ce}b=v[g+1074456>>2];l=b<<12;a=b;j=b>>31;i=g+12|0;b=0;while(1){fe:{if(v[c>>2]>=1){h=v[g+1074472>>2]+e|0;v[g+1074472>>2]=h;f=v[i>>2];Ra=i,Sa=Ac(pqa(oqa(f,f>>31,h,h>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;f=v[g+1074472>>2];h=f;m=f>>31;f=v[i+4>>2];Ra=i,Sa=Ac(pqa(oqa(h,m,f,f>>31),jb,1048576,0),jb),v[Ra+4>>2]=Sa;v[g+1074460>>2]=v[g+1074460>>2]-1;break fe}f=v[i>>2];Ra=i,Sa=Ac(pqa(oqa(f,f>>31,a,j),jb,256,0),jb),v[Ra>>2]=Sa;f=v[i+4>>2];Ra=i,Sa=Ac(pqa(oqa(f,f>>31,a,j),jb,256,0),jb),v[Ra+4>>2]=Sa;v[g+1074472>>2]=l}i=i+8|0;b=b+1|0;if((d|0)!=(b|0)){continue}break};break ce;case 3:break de;default:break ce}}if((d|0)<1){break ce}a=v[g+1074456>>2];l=a<<12;f=a;j=a>>31;i=g+12|0;b=g+8204|0;n=0;while(1){ge:{if(v[c>>2]>=1){h=v[g+1074472>>2]+e|0;v[g+1074472>>2]=h;a=v[i>>2];Ra=i,Sa=Ac(pqa(oqa(a,a>>31,h,h>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;a=v[g+1074472>>2];h=a;m=a>>31;a=v[i+4>>2];Ra=i,Sa=Ac(pqa(oqa(h,m,a,a>>31),jb,1048576,0),jb),v[Ra+4>>2]=Sa;a=v[g+1074472>>2];h=a;m=a>>31;a=v[b>>2];Ra=b,Sa=Ac(pqa(oqa(h,m,a,a>>31),jb,1048576,0),jb),v[Ra>>2]=Sa;a=v[g+1074472>>2];h=a;m=a>>31;a=v[b+4>>2];Ra=b,Sa=Ac(pqa(oqa(h,m,a,a>>31),jb,1048576,0),jb),v[Ra+4>>2]=Sa;v[g+1074460>>2]=v[g+1074460>>2]-1;break ge}a=v[i>>2];Ra=i,Sa=Ac(pqa(oqa(a,a>>31,f,j),jb,256,0),jb),v[Ra>>2]=Sa;a=v[i+4>>2];Ra=i,Sa=Ac(pqa(oqa(a,a>>31,f,j),jb,256,0),jb),v[Ra+4>>2]=Sa;a=v[b>>2];Ra=b,Sa=Ac(pqa(oqa(a,a>>31,f,j),jb,256,0),jb),v[Ra>>2]=Sa;a=v[b+4>>2];Ra=b,Sa=Ac(pqa(oqa(a,a>>31,f,j),jb,256,0),jb),v[Ra+4>>2]=Sa;v[g+1074472>>2]=l}b=b+8|0;i=i+8|0;n=n+1|0;if((d|0)!=(n|0)){continue}break}}gb=k+16|0}if(v[Da>>2]!=128){f=N+12|0;c=N+8204|0;a=s;e=v[N+24604>>2];b=v[N+24624>>2];he:{if((e|0)==128|b>>>0<2){break he}hO(f,a,e);if(b>>>0<4){break he}hO(c,a,e)}}if(v[N+24624>>2]==4){b=ma;a=Ka;i=s-1|0;if((i|0)>-1){while(1){e=b+(i<<4)|0;f=i<<3;c=f|4;v[e+12>>2]=v[c+a>>2];v[e+8>>2]=v[a+f>>2];v[e+4>>2]=v[b+c>>2];v[e>>2]=v[b+f>>2];c=(i|0)>0;i=i-1|0;if(c){continue}break}}}if(w[fa+20|0]){c=v[fa+16>>2];f=mg(Y+72|0,ma,v[N+24624>>2],s);b=v[v[c>>2]+8>>2];v[Y+24>>2]=v[f+8>>2];a=v[f+4>>2];v[Y+16>>2]=v[f>>2];v[Y+20>>2]=a;kb[b|0](c,Y+16|0)}c=mg(Y+56|0,ma,v[N+24624>>2],s);b=v[v[Ca>>2]+8>>2];v[Y+8>>2]=v[c+8>>2];a=v[c+4>>2];v[Y>>2]=v[c>>2];v[Y+4>>2]=a;kb[b|0](Ca,Y);i=v[N+1074380>>2]-s|0;v[N+1074380>>2]=i;v[N+1074376>>2]=s+v[N+1074376>>2];Ja=s+Ja|0;a=v[N+480208>>2];if(a&512){break i}ua=ua-s|0;if(ua){continue}break}}gb=Y+128|0;gb=fa+48|0;return Ja}function Loa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-496|0;gb=d;vc(b);g=gb-32|0;gb=g;f=g+24|0;h=d+304|0;Qr(f,h);j=yb(f);f=v[g+28>>2];i=v[g+24>>2];v[g+8>>2]=i;v[g+12>>2]=f;v[g>>2]=i;v[g+4>>2]=f;i=g+16|0;f=b;cc(i,f,g);i=yb(i);if((i|0)==(j|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(j|0);if(!f){VW(h)}a:{b:{c:{if(!f){break c}if(!tX(d+304|0)){break c}if(!Pb(b,Qc(sX(d+304|0),jb))){break c}if(!c){e=1;break c}Hd(a,32);t[d+303|0]=0;j=Kb(d+288|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if(v[d+304>>2]==778924148){v[22708]=0;R(558,a|0,16777216);e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;e=T(195,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(190,b|0,e-4|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;s=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break G}break b}H:{I:{J:{K:{L:{e=w[d+344|0]|w[d+345|0]<<8;M:{if(e>>>0<2185|e>>>0>4095){break M}v[22708]=0;e=T(195,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;Q(190,b|0,e-4|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;s=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}if(s>>>0<256){break M}v[22708]=0;e=T(195,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break M}v[22708]=0;e=Q(190,b|0,s|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if(!e){break M}v[22708]=0;e=T(559,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if(!e){break M}v[22708]=0;R(558,a|0,16777216);e=v[22708];v[22708]=0;if((e|0)==1){break b}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=4096){v[22708]=0;b=Q(2,d+104|0,13586)|0;c=v[22708];v[22708]=0;if((c|0)==1){break F}v[22708]=0;U(560,a|0,1,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);e=0;break d}a=P()|0;O()|0;vb(b);break a}if((w[d+344|0]|w[d+345|0]<<8)>>>0<2194){break M}v[22708]=0;e=Q(2,d+104|0,13115)|0;f=v[22708];v[22708]=0;if((f|0)==1){break L}v[22708]=0;U(560,a|0,4,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break K}vb(e)}if(v[a+480180>>2]!=32){break G}if(((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break H}f=(w[d+344|0]|w[d+345|0]<<8)&4095;e=f<<16;if(v[d+364>>2]!=1414548815){break J}t[d+303|0]=1;break I}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e);break a}if(f>>>0<297){break I}e=w[d+364|0]|w[d+365|0]<<8|e}v[a+1074308>>2]=e;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=2184?(w[d+346|0]|w[d+347|0]<<8)!=2184:0)){t[d+303|0]=1;v[a+1074308>>2]=18284544;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=535|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[22708]=0;e=xv(d+368|0,255,64);f=v[22708];v[22708]=0;if((f|0)==1){break b}N:{if(e){v[a+1074308>>2]=18219008;v[22708]=0;h=Q(2,d+104|0,12019)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break N}a=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[22708]=0;h=Q(2,d+104|0,13937)|0;e=v[22708];v[22708]=0;if((e|0)==1){break E}}Eb(j,h);vb(h);t[d+303|0]=1;break G}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=514|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){v[a+1074308>>2]=17367040;v[22708]=0;e=Q(2,d+104|0,11911)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);t[d+303|0]=1;break G}a=P()|0;O()|0;break a}if((w[d+344|0]|w[d+345|0]<<8)!=768|(w[d+346|0]|w[d+347|0]<<8)!=768|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|(w[d+336|0]|w[d+337|0]<<8)!=256)){break G}if(w[d+357|0]|w[d+356|0]!=128){break G}v[a+1074308>>2]=18285088;t[d+303|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+348|0]|w[d+349|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+348|0]|w[d+349|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+348|0]|w[d+349|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+348|0]|w[d+349|0]<<8)<<3&32768;v[22708]=0;Cp(d+216|0,3,d+304|4);e=v[22708];v[22708]=0;if((e|0)==1){break D}v[22708]=0;R(324,d+104|0,d+216|0);e=v[22708];v[22708]=0;if((e|0)==1){break D}e=d+104|0;Eb(a+1298268|0,e);vb(e);if(!(!(w[d+350|0]&4)|v[a+1074308>>2]-1>>>0<18285313)){v[a+480216>>2]=w[d+334|0];v[a+480220>>2]=w[d+335|0]}e=w[d+352|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+354|0]){v[a+480196>>2]=w[d+354|0]}t[d+104|0]=31;e=w[d+355|0];v[22708]=0;t[d+216|0]=e;e=pf(d+104|0,d+216|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);t[d+104|0]=w[d+353|0];v[22708]=0;t[d+216|0]=128;e=ac(d+104|0,d+216|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];e=0;while(1){i=(d+304|0)+e|0;g=i- -64|0;O:{if(w[g|0]==255){break O}v[22708]=0;h=(e<<5)+a|0;f=h+480280|0;We(f);l=v[22708];v[22708]=0;if((l|0)==1){break C}E=h+480286|0,F=Fd(w[i+128|0],0,64),u[E>>1]=F;if(t[g|0]<=-1){v[f>>2]=v[f>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[h+480284>>1]=g<<2;break O}if((g|0)!=100){break O}v[f>>2]=v[f>>2]|256}e=e+1|0;if((e|0)!=64){continue}break}v[22708]=0;Q(190,b|0,192)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}P:{if(!(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2187|(w[d+344|0]|w[d+345|0]<<8)>>>0>2189)){e=0;v[22708]=0;f=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break B}if(f){break d}v[22708]=0;f=T(192,b|0)|0;g=v[22708];v[22708]=0;Q:{if((g|0)==1){break Q}if(f>>>0>4e3){break d}g=Sb(a+484360|0);v[22708]=0;f=W(563,g|0,b|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Q}if(!f){break d}break P}a=P()|0;O()|0;break a}e=Sb(a+484360|0);f=w[d+336|0]|w[d+337|0]<<8;v[22708]=0;fa(521,e|0,b|0,f|0,255,254)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}}r=mc(d+272|0);q=mc(d+256|0);n=mc(d+240|0);f=w[d+338|0]|w[d+339|0]<<8;e=0;v[22708]=0;f=W(564,b|0,r|0,f|0)|0;g=v[22708];v[22708]=0;R:{if((g|0)==1){break R}if(!f){break z}f=w[d+340|0]|w[d+341|0]<<8;v[22708]=0;f=W(564,b|0,q|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break R}if(!f){break z}f=w[d+342|0]|w[d+343|0]<<8;v[22708]=0;f=W(564,b|0,n|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break R}if(!f){break z}v[d+236>>2]=-1;E=d,F=Vb(r),v[E+104>>2]=F;E=d,F=Zb(r),v[E+216>>2]=F;if(!Gb(d+104|0,d+216|0)){break A}while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}E=d,F=Vb(q),v[E+104>>2]=F;E=d,F=Zb(q),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}}E=d,F=Vb(n),v[E+104>>2]=F;E=d,F=Zb(n),v[E+216>>2]=F;if(Gb(d+104|0,d+216|0)){while(1){e=v[d+104>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+236>>2])){v[d+236>>2]=e}e=d+104|0;Qe(e);if(Gb(e,d+216|0)){continue}break}}S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if(t[d+350|0]&1){e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22708]=0;v[d+104>>2]=e;e=Fb(d+236|0,d+104|0);f=v[22708];v[22708]=0;if((f|0)==1){break ba}v[d+236>>2]=v[e>>2]}e=0;g=w[d+344|0]|w[d+345|0]<<8;ca:{if((w[d+346|0]|w[d+347|0]<<8)!=532|(g?(g|0)!=532:0)|(w[d+335|0]|w[d+334|0])){break ca}if(w[d+348|0]&192|(w[d+357|0]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break ca}da:{if(!(w[d+340|0]|w[d+341|0]<<8)|(w[d+338|0]|w[d+339|0]<<8)){break da}if((v[b+8>>2]+(Nb(q)<<2)|0)+2>>>0>y[d+236>>2]){break da}if(w[d+340|0]|w[d+341|0]<<8){g=0;while(1){v[22708]=0;e=T(192,b|0)|0;f=v[22708];v[22708]=0;ea:{if((f|0)!=1){if(!e){break ea}pg(b,((g&65535)<<2)+4|0);break da}a=P()|0;O()|0;break g}g=g+1|0;if((g&65535)>>>0<(w[d+340|0]|w[d+341|0]<<8)>>>0){continue}break}}v[22708]=0;e=Q(2,d+104|0,12177)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}Eb(j,e);vb(e)}e=1;if(w[d+344|0]|w[d+345|0]<<8){break ca}v[22708]=0;f=Q(2,d+104|0,12535)|0;g=v[22708];v[22708]=0;if((g|0)==1){break _}Eb(j,f);vb(f)}fa:{if(w[d+350|0]&2){v[22708]=0;f=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Z}v[22708]=0;g=f<<3;h=Q(191,b|0,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Z}if(!(!h|y[d+236>>2]<g+v[b+8>>2]>>>0)){v[22708]=0;g=a+1298368|0;R(565,g|0,f|0);h=v[22708];v[22708]=0;if((h|0)==1){break Z}E=d,F=Vb(g),v[E+216>>2]=F;E=d,F=Zb(g),v[E+192>>2]=F;if(Gb(d+216|0,d+192|0)){while(1){g=v[d+216>>2];v[22708]=0;R(566,b|0,d+104|0);h=v[22708];v[22708]=0;if((h|0)==1){break Y}v[22708]=0;QE(d+104|0,g);g=v[22708];v[22708]=0;if((g|0)==1){break Y}g=d+216|0;v[g>>2]=v[g>>2]+48;if(Gb(g,d+192|0)){continue}break}}if(!(!f&e)){break fa}if(w[d+350|0]&4){v[22708]=0;e=Q(2,d+104|0,12568)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}v[22708]=0;e=Q(2,d+104|0,12199)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}pg(b,2);break fa}if(!e|(w[d+350|0]|w[d+351|0]<<8)>>>0>1){break fa}v[22708]=0;e=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break aa}if(!e){v[22708]=0;e=Q(2,d+104|0,12177)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}pg(b,2)}ga:{if(!(w[d+350|0]&8?1:w[d+348|0]&128)){break ga}v[22708]=0;e=a+901404|0;f=Q(568,b|0,e|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break h}if(!f){break ga}v[22708]=0;Iu(e);e=v[22708];v[22708]=0;if((e|0)==1){break h}}if((w[d+344|0]|w[d+345|0]<<8)>>>0<=531){v[22708]=0;Vo(a+901404|0);e=v[22708];v[22708]=0;if((e|0)==1){break h}}v[22708]=0;z=T(215,d+216|0)|0;e=v[22708];v[22708]=0;ha:{ia:{ja:{ka:{la:{ma:{if((e|0)!=1){v[22708]=0;e=Q(555,b|0,11149)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ma}if(e){v[22708]=0;e=T(192,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break la}v[22708]=0;U(288,d+192|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break la}e=d+192|0;f=jc(d+104|0,e);Vc(z,f);xb(f);xb(e)}u[a+480188>>1]=1;v[22708]=0;e=Q(555,b|0,11154)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ma}if(e){v[22708]=0;e=T(192,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ka}v[22708]=0;U(288,d+192|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break ka}e=d+192|0;f=jc(d+104|0,e);xb(e);v[22708]=0;e=T(195,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ja}v[22708]=0;u[d+192>>1]=(e>>>0)/20;e=Pc(28868,d+192|0);g=v[22708];v[22708]=0;if((g|0)==1){break ja}g=x[e>>1];u[a+480188>>1]=g;if(g){e=0;while(1){v[22708]=0;W(571,f|0,((e<<5)+a|0)+480289|0,20)|0;h=v[22708];v[22708]=0;if((h|0)==1){break ja}e=e+1|0;if((g|0)!=(e|0)){continue}break}}xb(f)}if(y[b+8>>2]>y[d+236>>2]){break ia}e=v[d+236>>2]-v[b+8>>2]|0;break ha}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;xb(f);break i}v[22708]=0;e=T(467,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break X}}v[22708]=0;U(288,d+104|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break X}e=d+104|0;A=jc(d+192|0,e);xb(e);v[22708]=0;D=Q(572,a|0,A|0)|0;e=v[22708];v[22708]=0;na:{oa:{if((e|0)==1){break oa}if(!(t[d+350|0]&1)|!(w[d+358|0]|w[d+359|0]<<8)){break na}e=w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24);v[22708]=0;e=Q(190,b|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break oa}if(!e){break na}e=w[d+358|0]|w[d+359|0]<<8;v[22708]=0;ca(509,a+1298292|0,b|0,e|0,4)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break na}}a=P()|0;O()|0;break j}e=0;u[a+480192>>1]=0;if(w[d+348|0]&4){u[d+104>>1]=w[d+338|0]|w[d+339|0]<<8;v[22708]=0;u[d+32>>1]=255;f=Pc(d+104|0,d+32|0);g=v[22708];v[22708]=0;if((g|0)==1){break W}u[a+480192>>1]=x[f>>1]}pa:{qa:{ra:{sa:{if(x[a+480192>>1]){while(1){f=Lb(r,e);ta:{if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break ta}f=Lb(r,e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22708]=0;f=Q(190,b|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break sa}if(!f){break ta}v[22708]=0;f=Q(191,b|0,554)|0;g=v[22708];v[22708]=0;if((g|0)==1){break sa}if(!f){break ta}v[22708]=0;f=W(376,a|0,e+1&65535,0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}if(!f){break ta}g=w[d+346|0]|w[d+347|0]<<8;v[22708]=0;ca(573,a|0,b|0,f|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}t[f+33|0]=w[d+357|0]}e=e+1|0;if(e>>>0<x[a+480192>>1]){continue}break}}v[d+188>>2]=0;if(w[d+340|0]|w[d+341|0]<<8){e=Lb(q,(w[d+340|0]|w[d+341|0]<<8)-1|0);v[d+188>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}u[d+104>>1]=w[d+340|0]|w[d+341|0]<<8;v[22708]=0;u[d+32>>1]=3999;e=Pc(d+104|0,d+32|0);f=v[22708];v[22708]=0;if((f|0)==1){break qa}u[a+480190>>1]=x[e>>1];e=0;if(x[a+480190>>1]){break pa}f=0;h=0;break S}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}l=c&2;k=d+124|0;h=0;f=0;while(1){g=Lb(q,e);ua:{if(!(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break ua}g=Lb(q,e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[22708]=0;g=Q(190,b|0,g|0)|0;i=v[22708];v[22708]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((i|0)==1){break Ba}if(!g){break ua}v[22708]=0;g=Q(574,b|0,d+104|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Ba}if(!g){break ua}v[22708]=0;g=e+1|0;o=B(g,104)+a|0;i=o+484380|0;p=Q(575,d+104|0,i|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break Aa}v[22708]=0;Cp(d+88|0,3,k);m=v[22708];v[22708]=0;if((m|0)==1){break za}v[22708]=0;R(324,d+32|0,d+88|0);m=v[22708];v[22708]=0;if((m|0)==1){break za}v[22708]=0;Q(301,((g<<5)+a|0)+946304|0,d+32|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break ya}vb(d+32|0);v[22708]=0;p=Q(190,b|0,p|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break Aa}if(!p){break ua}f=x[o+484414>>1];if(!(f&512)){break xa}v[22708]=0;f=Q(576,b|0,d+32|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){if(!f){break wa}v[d+16>>2]=v[d+40>>2];v[22708]=0;f=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=f;U(577,i|0,1,d+8|0);f=v[22708];v[22708]=0;if((f|0)!=1){break wa}}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+32|0);break j}if(!(f&16384)){f=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;RE(d+32|0,d+104|0,f);f=v[22708];v[22708]=0;if((f|0)==1){break T}Ca:{if(l){g=0;v[22708]=0;W(329,d+32|0,i|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break Ca}break T}g=1;f=w[d+35|0];if(f>>>0>18){break Ca}f=1<<f;Da:{if(!(f&126991)){if(f&396800){break Da}break Ca}if(!w[d+32|0]){break Ca}}f=v[i>>2];v[22708]=0;f=wv(d+32|0,f);g=v[22708];v[22708]=0;if((g|0)==1){break T}g=0;v[22708]=0;Q(318,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break T}}if(w[d+35|0]!=1){break va}h=v[i>>2]!=0|h;break va}v[22708]=0;Q(580,b|0,d+84|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break U}f=v[d+84>>2];if(!(!l|!f)){f=Kb(d+32|0);v[22708]=0;W(413,b|0,f|0,v[d+84>>2])|0;i=v[22708];v[22708]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((i|0)!=1){v[22708]=0;R(581,d+72|0,13508);i=v[22708];v[22708]=0;if((i|0)==1){break Ka}v[d+68>>2]=g;v[22708]=0;U(13,d+56|0,0,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ja}v[22708]=0;Y(582,d+88|0,d+72|0,d+68|0,d+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ia}v[22708]=0;U(560,a|0,2,d+88|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ha}vb(d+88|0);vb(d+56|0);Hb(d+72|0);vb(f);break wa}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Fa}a=P()|0;O()|0;break Ga}a=P()|0;O()|0;vb(d+88|0)}vb(d+56|0)}Hb(d+72|0)}vb(f);break j}v[22708]=0;Q(318,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break U}}g=0}f=v[b+8>>2];v[22708]=0;v[d+32>>2]=f;f=Mc(d+188|0,d+32|0);i=v[22708];v[22708]=0;if((i|0)==1){break V}v[d+188>>2]=v[f>>2];f=(g|0)!=0}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}break S}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}u[d+104>>1]=1;e=x[a+480190>>1];v[22708]=0;u[d+32>>1]=e;e=Le(d+104|0,d+32|0);g=v[22708];v[22708]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((g|0)!=1){u[a+480190>>1]=x[e>>1];Va:{if(!(h&1)|(w[d+344|0]|w[d+345|0]<<8)!=516|(w[d+350|0]|w[d+351|0]<<8|(w[d+346|0]|w[d+347|0]<<8)!=512)){break Va}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&65527)!=21|(w[d+352|0]!=128|w[d+353|0]!=48)){break Va}if(w[d+357|0]|w[d+356|0]!=128|(w[d+358|0]|w[d+359|0]<<8)){break Va}h=d+432|0;g=d+368|0;e=1;while(1){e=(w[g|0]|128)!=160?0:e;g=g+1|0;if((h|0)!=(g|0)){continue}break}h=d+496|0;g=d+432|0;while(1){e=w[g|0]==64&e;g=g+1|0;if((h|0)!=(g|0)){continue}break}g=20;while(1){e=!w[(d+g|0)+308|0]&e;g=g+1|0;if((g|0)!=26){continue}break}if(!e){break Va}v[22708]=0;e=Q(2,d+104|0,7125)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Ma}Eb(j,e);vb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;E=d,F=Nb(n),u[E+104>>1]=F;e=v[a+8>>2];v[22708]=0;e=Pc(d+104|0,e+10|0);g=v[22708];v[22708]=0;if((g|0)==1){break Ua}e=x[e>>1];u[d+84>>1]=e;if((Nb(n)|0)!=(e|0)){v[22708]=0;_(584,d+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ta}e=Nb(n);v[22708]=0;v[d+88>>2]=e;Y(585,d+104|0,d+32|0,d+88|0,d+84|0);e=v[22708];v[22708]=0;if((e|0)==1){break Sa}v[22708]=0;U(560,a|0,2,d+104|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ra}vb(d+104|0);Hb(d+32|0)}if(c&1){break Pa}u[d+84>>1]=0;break Oa}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}if(!x[d+84>>1]){break Oa}e=0;while(1){c=Lb(n,e);Wa:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Wa}c=Lb(n,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Na}if(!c){break Wa}v[22708]=0;c=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break k}v[22708]=0;i=T(287,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}if((i-1&65535)>>>0>1023){break Wa}v[22708]=0;g=Q(318,b|0,4)|0;h=v[22708];v[22708]=0;if((h|0)==1){break l}if(!g){break Wa}v[22708]=0;U(288,d+32|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break m}c=d+32|0;l=jc(d+104|0,c);xb(c);g=0;h=x[a+480188>>1];v[22708]=0;c=Q(586,c|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}while(1){Xa:{v[22708]=0;h=Q(191,d+104|0,1)|0;k=v[22708];v[22708]=0;Ya:{Za:{if((k|0)!=1){if(!h){break Xa}v[22708]=0;h=T(374,l|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}k=h<<24>>24;if(k){break Za}g=g+1|0;break Ya}break p}_a:{h=k&127;o=h?h-1|0:0;h=o&65535;if(oc(c)>>>0>h>>>0){break _a}v[22708]=0;t[d+88|0]=0;U(587,c|0,h+1|0,d+88|0);p=v[22708];v[22708]=0;if((p|0)!=1){break _a}break p}if((k|0)<=-1){v[22708]=0;k=T(374,l|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break p}E=kc(c,h),F=k,t[E|0]=F}if(!(!(w[kc(c,h)|0]&15)|h>>>0<x[a+480188>>1])){u[a+480188>>1]=o+1}if(t[kc(c,h)|0]&1){v[22708]=0;Q(318,d+104|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}}if(w[kc(c,h)|0]&2){v[22708]=0;Q(318,d+104|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}}if(w[kc(c,h)|0]&4){v[22708]=0;Q(318,d+104|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break p}}if(!(w[kc(c,h)|0]&8)){break Ya}v[22708]=0;Q(318,d+104|0,2)|0;h=v[22708];v[22708]=0;if((h|0)==1){break p}}if(g>>>0<i>>>0){continue}}break}g=v[b+8>>2];v[22708]=0;v[d+88>>2]=g;g=Mc(d+188|0,d+88|0);h=v[22708];v[22708]=0;if((h|0)==1){break p}v[d+188>>2]=v[g>>2];gc(c);xb(d+104|0)}e=e+1|0;if(e>>>0<x[d+84>>1]){continue}break}}c=v[d+188>>2];if(!c){break La}v[22708]=0;Q(190,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}if(!(f&1)){break La}while(1){$a:{v[22708]=0;c=Q(191,b|0,4)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}if(!c){break La}v[22708]=0;c=Q(555,b|0,11128)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}ab:{if(!c){v[22708]=0;c=Q(555,b|0,11133)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}if(!c){break ab}}v[22708]=0;c=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){pg(b,8);if(!(c&1616928864)|c&-2139062144){break ab}break La}a=P()|0;O()|0;break j}v[22708]=0;c=T(287,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $a}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22708]=0;c=Q(588,a|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}c=c|w[d+303|0];t[d+303|0]=c;if(!(!c|D)){vv(a+1074312|0);t[a+1074368|0]=0}v[22708]=0;Y(589,a|0,b|0,0,d+303|0);c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;o=a+484344|0;R(330,o|0,x[d+84>>1]);c=v[22708];v[22708]=0;if((c|0)==1){break q}e=0;u[d+68>>1]=0;bb:{if(!x[d+84>>1]){break bb}while(1){cb:{db:{c=Lb(n,e&65535);eb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Lb(n,x[d+68>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break eb}if(c){break db}}v[22708]=0;c=W(331,o|0,x[d+68>>1],64)|0;e=v[22708];v[22708]=0;if((e|0)==1){break eb}if(!c){v[22708]=0;_(590,d+32|0);c=v[22708];v[22708]=0;fb:{gb:{hb:{if((c|0)!=1){v[22708]=0;U(591,d+104|0,d+32|0,d+68|0);c=v[22708];v[22708]=0;if((c|0)==1){break hb}v[22708]=0;U(560,a|0,2,d+104|0);c=v[22708];v[22708]=0;if((c|0)==1){break gb}vb(d+104|0);Hb(d+32|0);break bb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break fb}a=P()|0;O()|0;vb(d+104|0)}Hb(d+32|0);break j}c=_b(o,x[d+68>>1]);v[22708]=0;R(592,c|0,z|0);c=v[22708];v[22708]=0;if((c|0)!=1){break cb}}a=P()|0;O()|0;break j}v[22708]=0;c=T(287,b|0)|0;e=v[22708];v[22708]=0;ib:{jb:{if((e|0)!=1){v[22708]=0;p=T(287,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break jb}v[22708]=0;e=Q(318,b|0,4)|0;f=v[22708];v[22708]=0;if((f|0)==1){break jb}if(!e){break cb}v[22708]=0;e=W(331,o|0,x[d+68>>1],p|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break jb}if(e){break ib}break cb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22708]=0;U(288,d+32|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=d+32|0;k=jc(d+104|0,c);xb(c);c=_b(o,x[d+68>>1]);v[22708]=0;R(592,c|0,z|0);c=v[22708];v[22708]=0;kb:{if((c|0)!=1){c=x[a+480188>>1];v[22708]=0;l=Q(586,d+32|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){c=x[a+480188>>1];e=d+72|0;hi(e);v[22708]=0;i=W(593,d+88|0,c|0,e|0)|0;c=v[22708];v[22708]=0;lb:{if((c|0)!=1){E=d,F=Vb(_b(o,x[d+68>>1])),v[E+56>>2]=F;m=0;mb:{if(!p){break mb}while(1){v[22708]=0;c=Q(191,d+104|0,1)|0;e=v[22708];v[22708]=0;nb:{if((e|0)!=1){ob:{if(!c){break mb}v[22708]=0;c=T(374,k|0)|0;e=v[22708];v[22708]=0;pb:{if((e|0)!=1){c=c<<24>>24;if(c){break pb}DX(d+56|0,x[a+480188>>1]);m=m+1|0;break nb}break ob}qb:{e=c&127;h=e?e-1&65535:0;if(oc(l)>>>0>h>>>0){break qb}v[22708]=0;t[d+72|0]=0;e=h+1|0;U(587,l|0,e|0,d+72|0);f=v[22708];v[22708]=0;if((f|0)==1){break ob}f=d+72|0;hi(f);v[22708]=0;U(594,i|0,e|0,f|0);e=v[22708];v[22708]=0;if((e|0)!=1){break qb}break ob}if((c|0)<=-1){v[22708]=0;c=T(374,k|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ob}E=kc(l,h),F=c,t[E|0]=F}e=d+72|0;hi(e);if(h>>>0<x[a+480188>>1]){e=ad(d+56|0,h)}if(w[kc(l,h)|0]&16){E=e,F=w[ad(i,h)|0],t[E|0]=F}if(w[kc(l,h)|0]&32){E=e,F=w[ad(i,h)+1|0],t[E+1|0]=F}if(w[kc(l,h)|0]&64){E=e,F=w[ad(i,h)+2|0],t[E+2|0]=F;E=e,F=w[ad(i,h)+4|0],t[E+4|0]=F}if(t[kc(l,h)|0]<=-1){E=e,F=w[ad(i,h)+3|0],t[E+3|0]=F;E=e,F=w[ad(i,h)+5|0],t[E+5|0]=F}if(t[kc(l,h)|0]&1){v[22708]=0;c=T(374,k|0)|0;f=v[22708];v[22708]=0;C=e;rb:{sb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break sb}f=c;break rb}break ob}f=253;if((c-121&255)>>>0<132){break rb}f=(c&255)==253?0:c}t[C|0]=f;E=ad(i,h),F=f,t[E|0]=F}if(w[kc(l,h)|0]&2){v[22708]=0;c=T(374,k|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ob}t[e+1|0]=c;E=ad(i,h),F=c,t[E+1|0]=F}if(w[kc(l,h)|0]&4){v[22708]=0;g=T(374,k|0)|0;f=v[22708];v[22708]=0;C=e;tb:{ub:{vb:{if((f|0)!=1){if(g>>>0>64){break vb}t[e+4|0]=g;f=1;break ub}break ob}if(!(g<<24>>24>-1|g>>>0>192)){f=2;t[e+2|0]=2;t[e+4|0]=g^128;break tb}if(g>>>0<=74){f=5;t[e+2|0]=5;t[e+4|0]=g-65;break tb}if(g>>>0<=84){f=6;t[e+2|0]=6;t[e+4|0]=g-75;break tb}if(g>>>0<=94){f=3;t[e+2|0]=3;t[e+4|0]=g-85;break tb}if(g>>>0<=104){f=4;t[e+2|0]=4;t[e+4|0]=g-95;break tb}if(g>>>0<=114){f=13;t[e+2|0]=13;t[e+4|0]=g-105;break tb}if(g>>>0<=124){f=12;t[e+2|0]=12;t[e+4|0]=g-115;break tb}f=g+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;f=11;break ub}f=g+53|0;c=f&255;if(c>>>0<=9){t[e+4|0]=f;f=8;t[e+2|0]=8;if(!c|v[a+1074308>>2]-1>>>0>18285139){break tb}f=7;break ub}f=g+33|0;if((f&255)>>>0>=10){f=w[e+2|0];break tb}t[e+4|0]=f;f=15}t[C+2|0]=f}E=ad(i,h),F=f,t[E+2|0]=F;c=w[e+4|0];E=ad(i,h),F=c,t[E+4|0]=F}if(!(w[kc(l,h)|0]&8)){break nb}v[22708]=0;R(403,d+24|0,k|0);c=v[22708];v[22708]=0;if((c|0)!=1){wb:{c=d+24|0;f=qd(c);t[e+3|0]=w[c|0];t[e+5|0]=w[f|0];v[22708]=0;Uu(e,1);c=v[22708];v[22708]=0;if((c|0)==1){break wb}c=w[e+3|0];E=ad(i,h),F=c,t[E+3|0]=F;c=w[e+5|0];E=ad(i,h),F=c,t[E+5|0]=F;break nb}}}}a=P()|0;O()|0;hn(i);break lb}if(m>>>0<p>>>0){continue}break}}hn(i);gc(l);xb(d+104|0);break cb}a=P()|0;O()|0}gc(l);break kb}a=P()|0;O()|0;break kb}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}e=x[d+68>>1]+1|0;u[d+68>>1]=e;if(x[d+84>>1]>(e&65535)>>>0){continue}break}}c=a+1074308|0;xb:{yb:{zb:{if(v[a+1074308>>2]){break zb}if((w[d+344|0]|w[d+345|0]<<8)==2184){v[a+1074308>>2]=18284544;break zb}if(!v[c>>2]){break yb}}if(!gd(j)){break yb}v[22708]=0;e=Q(2,d+32|0,14713)|0;f=v[22708];v[22708]=0;Ab:{Bb:{Cb:{Db:{Eb:{Fb:{if((f|0)!=1){v[22708]=0;R(162,d+88|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break Fb}v[22708]=0;U(3,d+104|0,e|0,d+88|0);f=v[22708];v[22708]=0;if((f|0)==1){break Eb}f=d+104|0;Eb(j,f);vb(f);vb(d+88|0);vb(e);if(v[d+364>>2]==1414548815|((w[d+344|0]|w[d+345|0]<<8)&61440)!=20480){break Ab}v[22708]=0;c=Q(2,d+104|0,13949)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Cb}v[22708]=0;Q(113,j|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Bb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Db}a=P()|0;O()|0;vb(d+88|0)}vb(e);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if(!dH(c)){break xb}v[22708]=0;c=Q(2,d+104|0,14185)|0;e=v[22708];v[22708]=0;Gb:{if((e|0)!=1){v[22708]=0;Q(113,j|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Gb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if((w[d+344|0]|w[d+345|0]<<8)==8191){c=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)}else{c=(w[d+344|0]|w[d+345|0]<<8)-4176|0}Hb:{switch((w[d+344|0]|w[d+345|0]<<8)>>>12|0){case 0:if(D){v[22708]=0;c=Q(2,d+104|0,5473)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Ib:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+350|0]|w[d+351|0]<<8|(w[d+348|0]|w[d+349|0]<<8)!=9)){break Ib}if(w[d+335|0]|w[d+334|0]|(w[d+338|0]|w[d+339|0]<<8|((w[d+342|0]|w[d+343|0]<<8)+1|0)!=(w[d+336|0]|w[d+337|0]<<8))){break Ib}if(w[d+352|0]!=128|w[d+353|0]!=100|(w[d+354|0]!=1|w[d+356|0]!=128)){break Ib}if(w[d+357|0]|(w[d+358|0]|w[d+359|0]<<8)|(w[d+360|0]|w[d+361|0]<<8|(w[d+362|0]<<16|w[d+363|0]<<24)|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)))){break Ib}v[22708]=0;c=Q(2,d+104|0,7106)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Jb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=512|(w[d+335|0]|w[d+334|0])){break Jb}if(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)){break Jb}v[a+1074308>>2]=16777381;v[22708]=0;c=Q(2,d+104|0,12100)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);t[d+303|0]=1;break xb}a=P()|0;O()|0;break j}if(!((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|v[d+364>>2]!=1229080643)){v[22708]=0;c=Q(2,d+104|0,5525)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);v[22708]=0;Q(410,a+1074312|0,38)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break xb}break r}a=P()|0;O()|0;break j}Kb:{if((w[d+344|0]|w[d+345|0]<<8)!=532|(w[d+346|0]|w[d+347|0]<<8)!=532|(w[d+357|0]|(w[d+350|0]|w[d+351|0]<<8)>>>0>1)){break Kb}if(!x[a+480190>>1]|(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24)|((w[d+348|0]|w[d+349|0]<<8)&4294)!=4)){break Kb}v[22708]=0;c=Q(70,d+104|0,10806)|0;e=v[22708];v[22708]=0;Lb:{Mb:{if((e|0)!=1){v[22708]=0;e=Q(596,a+484527|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Mb}vb(c);if(!e){break Kb}v[22708]=0;c=Q(2,d+104|0,5551)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Lb}Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0;break j}Nb:{if(w[d+344|0]|w[d+345|0]<<8){break Nb}if(!gd(j)){break Nb}v[22708]=0;c=Q(2,d+104|0,6892)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}if((w[d+346|0]|w[d+347|0]<<8)>>>0>767){break xb}if(!gd(j)){break xb}Ob:{Pb:{Qb:{Rb:{Sb:{if((w[d+346|0]|w[d+347|0]<<8)>>>0>=533){v[22708]=0;c=Q(2,d+104|0,12147)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break Sb}a=P()|0;O()|0;break j}if((w[d+344|0]|w[d+345|0]<<8)>>>0>=533){v[22708]=0;R(597,d+32|0,1124);c=v[22708];v[22708]=0;Tb:{if((c|0)!=1){c=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;v[d+88>>2]=c-532;U(598,d+104|0,d+32|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break Tb}c=d+104|0;Eb(j,c);vb(c);Hb(d+32|0);break Sb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j}v[22708]=0;R(411,d+32|0,1423);c=v[22708];v[22708]=0;if((c|0)==1){break Rb}v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22708]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break Qb}v[22708]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break Pb}c=d+104|0;Eb(j,c);vb(c);vb(d+88|0);Hb(d+32|0)}c=a+1298368|0;if(!cd(c)|!(w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24))){break xb}e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22708]=0;e=tw(e,f);f=v[22708];v[22708]=0;if((f|0)==1){break u}f=Er(d+104|0);v[f+44>>2]=e;v[22708]=0;R(601,c|0,f|0);c=v[22708];v[22708]=0;if((c|0)!=1){break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Ob}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 1:e=w[d+344|0]|w[d+345|0]<<8;f=w[d+364|0]|w[d+365|0]<<8|(w[d+366|0]<<16|w[d+367|0]<<24);v[22708]=0;U(602,d+104|0,e|0,f|0);e=v[22708];v[22708]=0;Ub:{Vb:{Wb:{Xb:{if((e|0)!=1){e=d+104|0;Eb(j,e);vb(e);if((c|0)>1915){break Xb}g=v[a+480208>>2];if(!(g&16)){break Wb}v[22708]=0;Q(410,a+1074312|0,7)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}break Vb}a=P()|0;O()|0;break j}if((c|0)>4200){break xb}g=v[a+480208>>2]}if(!(g&16)){v[22708]=0;Q(410,a+1074312|0,7)|0;e=v[22708];v[22708]=0;if((e|0)==1){break r}}if((c|0)>2385){break Ub}}v[22708]=0;Q(410,a+1074312|0,38)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}}v[22708]=0;c=a+1074312|0;Q(410,c|0,102)|0;e=v[22708];v[22708]=0;if((e|0)==1){break r}v[22708]=0;Q(410,c|0,48)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}break xb;case 4:v[22708]=0;R(603,d+32|0,1487);c=v[22708];v[22708]=0;Yb:{Zb:{_b:{if((c|0)!=1){v[d+72>>2]=w[d+345|0]&15;c=w[d+344|0];v[22708]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break _b}v[22708]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break Zb}c=d+104|0;Eb(j,c);vb(c);vb(d+88|0);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Yb}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j;case 6:v[22708]=0;c=Q(2,d+104|0,5473)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j;case 7:if(!((w[d+344|0]|w[d+345|0]<<8)!=32767|(w[d+346|0]|w[d+347|0]<<8)!=533)){v[22708]=0;c=Q(2,d+104|0,2138)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}v[22708]=0;R(158,d+32|0,1259);c=v[22708];v[22708]=0;$b:{if((c|0)!=1){v[d+88>>2]=w[d+345|0]&15;v[d+72>>2]=(w[d+344|0]|w[d+345|0]<<8)>>>4&15;c=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;v[d+56>>2]=c&15;ha(159,d+104|0,d+32|0,d+88|0,d+72|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break $b}c=d+104|0;Eb(j,c);vb(c);Hb(d+32|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+32|0);break j;case 13:break Hb;default:break xb}}v[22708]=0;c=Q(2,d+104|0,3180)|0;e=v[22708];v[22708]=0;if((e|0)==1){break t}Eb(j,c);vb(c)}ac:{if(v[a+480180>>2]!=16777216|(w[d+344|0]|w[d+345|0]<<8)>>>0<2186){break ac}v[22708]=0;c=Q(190,b|0,s|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}if(!c){break ac}c=w[d+344|0]|w[d+345|0]<<8;v[22708]=0;U(604,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}}b=v[a+480180>>2];bc:{if((b|0)==16777216){v[22708]=0;Q(2,d+104|0,11111)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break bc}a=P()|0;O()|0;break j}v[22708]=0;R(411,d+32|0,1423);c=v[22708];v[22708]=0;if((c|0)==1){break y}v[d+72>>2]=w[d+347|0];c=w[d+346|0];v[22708]=0;v[d+56>>2]=c;R(599,d+88|0,d+56|0);c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;Y(582,d+104|0,d+32|0,d+72|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break w}}c=d+104|0;Eb(a+1298304|0,c);vb(c);if((b|0)!=16777216){vb(d+88|0);Hb(d+32|0)}cc:{if(v[a+480180>>2]==16777216){v[22708]=0;Q(2,d+104|0,7394)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break cc}break s}v[22708]=0;Q(2,d+104|0,3184)|0;b=v[22708];v[22708]=0;if((b|0)==1){break s}}b=d+104|0;Eb(a+1298316|0,b);vb(b);Eb(a+1298328|0,j);v[a+1298364>>2]=v[a+1074308>>2]?8:5;xb(A);xb(z);e=1}di(n);di(q);di(r);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0;break v}a=P()|0;O()|0;vb(d+88|0)}Hb(d+32|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;gc(c);break n}a=P()|0;O()|0}xb(d+104|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0}xb(A)}xb(z);break g}a=P()|0;O()|0}di(n);di(q);di(r);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}vb(j)}gb=d+496|0;return e|0}a=P()|0;O()|0}vb(j);S(a|0);L()}function dna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;d=gb-1712|0;gb=d;vc(b);a:{if(!Jh(b,d+1704|0)){break a}if(!QV(d+1704|0)){break a}if(!c){f=1;break a}e=w[d+1704|3];t[d+1703|0]=e;v[d+1696>>2]=-1;v[d+1692>>2]=1048576;if(e>>>0>=5){e=sg(b);v[d+1696>>2]=e;if(!Pb(b,e)){break a}v[d+304>>2]=134217727;N=d,V=v[Fb(d+304|0,d+1696|0)>>2]<<5,v[N+1692>>2]=V}C=mc(d+1680|0);e=d+1704|4;h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22708]=0;v[d+304>>2]=h;h=Fb(d+1692|0,d+304|0);g=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}h=v[h>>2];v[22708]=0;R(729,C|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break x}e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22708]=0;e=W(730,b|0,C|0,e|0)|0;h=v[22708];v[22708]=0;y:{if((h|0)==1){break y}if(!e){break t}if(w[d+1703|0]>=5){v[22708]=0;Q(190,b|0,v[d+1696>>2]+12|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break y}}v[22708]=0;R(367,a|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break y}v[22708]=0;Ag(a);e=v[22708];v[22708]=0;if((e|0)==1){break y}v[22708]=0;Vd(d+1648|0,C);h=v[22708];v[22708]=0;e=a;z:{A:{B:{C:{if((h|0)==1){break C}h=Ud(d+1640|0);v[22708]=0;g=v[d+1652>>2];v[d+96>>2]=v[d+1648>>2];v[d+100>>2]=g;g=v[h+4>>2];v[d+88>>2]=v[h>>2];v[d+92>>2]=g;l=W(732,d+1656|0,d+96|0,d+88|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break C}v[22708]=0;W(533,l|0,a+1298268|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break B}v[22708]=0;W(533,l|0,a+1298292|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break B}v[22708]=0;h=Q(733,l|0,d+1216|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}if(!h|!w[d+1216|0]|t[d+1216|0]<0){break u}h=d+1225|0;if((w[h|0]|w[h+1|0]<<8)>>>0>255){break u}g=d+1227|0;if((w[g|0]|w[g+1|0]<<8)>>>0>3999){break u}n=d+1216|0;u[a+480188>>1]=w[n|0];j=a+484360|0;n=n|3;bf(Sb(j),w[n|0]|w[n+1|0]<<8);u[a+480192>>1]=w[h|0]|w[h+1|0]<<8;u[a+480190>>1]=w[g|0]|w[g+1|0]<<8;h=d+1229|0;if(w[h|0]){break A}h=6;break z}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}h=w[h|0]}v[e+480196>>2]=h;e=a;h=d+1230|0;if(w[h|0]){h=w[h|0]}else{h=125}v[e+480204>>2]=B(h,1e4);n=d+1231|0;D:{if(t[n+1|0]&1){v[22708]=0;R(558,a|0,32);e=v[22708];v[22708]=0;if((e|0)!=1){break D}break d}if(w[n|0]&2){v[22708]=0;R(558,a|0,2);e=v[22708];v[22708]=0;if((e|0)==1){break d}break D}if(w[n|0]&128){v[22708]=0;R(558,a|0,1);e=v[22708];v[22708]=0;if((e|0)==1){break d}break D}if(w[n|0]&8){v[22708]=0;R(558,a|0,16);e=v[22708];v[22708]=0;if((e|0)==1){break d}break D}v[22708]=0;R(558,a|0,4);e=v[22708];v[22708]=0;if((e|0)==1){break d}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[n|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[n|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[n|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[n+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[n+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[n+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[n+2|0]&8){v[22708]=0;W(409,a+1074312|0,5,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}}E:{e=v[a+480180>>2];F:{if((e|0)!=2){if((e|0)!=32){break F}t[d+304|0]=w[d+1235|0];v[22708]=0;t[d+224|0]=128;e=ac(d+304|0,d+224|0);h=v[22708];v[22708]=0;if((h|0)==1){break w}v[a+480200>>2]=w[e|0]<<1;break F}t[d+304|0]=w[d+1235|0];v[22708]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);h=v[22708];v[22708]=0;if((h|0)==1){break E}v[a+480200>>2]=w[e|0]<<2}I=a+480188|0;g=d+1237|0;h=t[g|0];e=a;if(t[g|0]<=-1){h=h+52|0}else{F=_w(+(h|0)*3.1/20);G:{if(F<4294967296&F>=0){h=~~F>>>0;break G}h=0}h=h+51|0}v[e+480228>>2]=h;v[22708]=0;u[d+304>>1]=64;e=Pc(I,d+304|0);h=v[22708];v[22708]=0;if((h|0)!=1){H:{h=x[e>>1];if(h){while(1){e=v[a+480180>>2];if((e|0)==32){t[d+304|0]=w[(d+f|0)+1238|0];v[22708]=0;t[d+224|0]=64;e=ac(d+304|0,d+224|0);g=v[22708];v[22708]=0;if((g|0)==1){break H}u[((f<<5)+a|0)+480286>>1]=w[e|0];e=v[a+480180>>2]}I:{if((e|0)==4){break I}e=(d+f|0)+1302|0;if(w[e|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break I}if(w[e|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break I}u[((f<<5)+a|0)+480284>>1]=w[e|0]}f=f+1|0;if((h|0)!=(f|0)){continue}break}}f=0;g=0;while(1){f=w[(d+g|0)+1366|0]!=0|f;g=g+1|0;if((g|0)!=16){continue}break}while(1){f=w[((k<<1)+d|0)+1383|0]!=0|f;k=k+1|0;if((k|0)!=128){continue}break}if(f&1){f=0;while(1){J:{e=(d+f|0)+1366|0;if(w[e|0]){v[22708]=0;_(734,d+224|0);h=v[22708];v[22708]=0;K:{L:{M:{N:{O:{if((h|0)!=1){e=w[e|0];v[22708]=0;v[d+248>>2]=e-1;R(735,d+1192|0,d+248|0);e=v[22708];v[22708]=0;if((e|0)==1){break O}v[22708]=0;U(443,d+304|0,d+224|0,d+1192|0);e=v[22708];v[22708]=0;if((e|0)==1){break N}v[22708]=0;R(444,d+1168|0,((f<<5)+a|0)+901692|0);e=v[22708];v[22708]=0;if((e|0)==1){break M}v[22708]=0;Q(401,d+1168|0,d+304|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break M}vb(d+304|0);vb(d+1192|0);Hb(d+224|0);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;break K}g=P()|0;O()|0;break L}g=P()|0;O()|0;vb(d+304|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22708]=0;e=Q(70,d+304|0,18720)|0;h=v[22708];v[22708]=0;P:{if((h|0)!=1){v[22708]=0;R(444,d+224|0,((f<<5)+a|0)+901692|0);h=v[22708];v[22708]=0;if((h|0)==1){break P}v[22708]=0;Q(401,d+224|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}vb(e);break J}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){e=(d+1216|0)+(f<<1)|0;h=e;Q:{if(w[e+167|0]){v[22708]=0;_(736,d+224|0);g=v[22708];v[22708]=0;R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){h=w[h+167|0];v[22708]=0;v[d+192>>2]=h-1;R(735,d+1192|0,d+192|0);h=v[22708];v[22708]=0;if((h|0)==1){break X}e=w[e+166|0];v[22708]=0;t[d+168|0]=e;R(737,d+1168|0,d+168|0);e=v[22708];v[22708]=0;if((e|0)==1){break W}v[22708]=0;Y(738,d+304|0,d+224|0,d+1192|0,d+1168|0);e=v[22708];v[22708]=0;if((e|0)==1){break V}v[22708]=0;R(444,d+248|0,((f<<5)+a|0)+902204|0);e=v[22708];v[22708]=0;if((e|0)==1){break U}v[22708]=0;Q(401,d+248|0,d+304|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}vb(d+304|0);vb(d+1168|0);vb(d+1192|0);Hb(d+224|0);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;break R}g=P()|0;O()|0;break S}g=P()|0;O()|0;break T}g=P()|0;O()|0;vb(d+304|0)}vb(d+1168|0)}vb(d+1192|0)}Hb(d+224|0);break c}v[22708]=0;e=Q(70,d+304|0,18720)|0;h=v[22708];v[22708]=0;Y:{if((h|0)!=1){v[22708]=0;R(444,d+224|0,((f<<5)+a|0)+902204|0);h=v[22708];v[22708]=0;if((h|0)==1){break Y}v[22708]=0;Q(401,d+224|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Y}vb(e);break Q}g=P()|0;O()|0;break c}g=P()|0;O()|0;vb(e);break c}f=f+1|0;if((f|0)!=128){continue}break}}e=Sb(j);f=d+1216|1;f=w[f|0]|w[f+1|0]<<8;v[22708]=0;fa(521,e|0,l|0,f|0,255,254)|0;e=v[22708];v[22708]=0;Z:{_:{$:{aa:{ba:{ca:{if((e|0)!=1){e=d+1216|0;j=e|5;f=w[j|0]|w[j+1|0]<<8;e=w[e|0];v[22708]=0;U(288,d+304|0,l|0,B(e,f)<<1);e=v[22708];v[22708]=0;if((e|0)==1){break ca}e=d+304|0;G=jc(d+1192|0,e);xb(e);f=w[j|0]|w[j+1|0]<<8;v[22708]=0;U(288,e|0,l|0,f<<1);e=v[22708];v[22708]=0;if((e|0)==1){break ba}e=d+304|0;H=jc(d+1168|0,e);xb(e);e=d+1216|7;e=w[e|0]|w[e+1|0]<<8;v[22708]=0;A=Q(328,d+1152|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break aa}N=d,V=Vb(A),v[N+248>>2]=V;N=d,V=Zb(A),v[N+192>>2]=V;if(Gb(d+248|0,d+192|0)){while(1){e=v[d+248>>2];v[22708]=0;f=T(192,l|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break $}v[22708]=0;U(288,d+224|0,l|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break _}h=e;e=d+304|0;f=d+224|0;Vc(h,jc(e,f));xb(e);xb(f);e=d+248|0;Fh(e);if(Gb(e,d+192|0)){continue}break}}e=v[a+480180>>2];s=1;p=c&1;if(!p){break Z}f=w[j|0]|w[j+1|0]<<8;v[22708]=0;R(330,a+484344|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Z}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}D=a+484344|0;da:{ea:{fa:{ga:{ha:{ia:{if(w[j|0]|w[j+1|0]<<8){q=(e|0)==16?14:(e|0)==32?1:13;while(1){v[22708]=0;e=T(287,H|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break da}v[d+224>>2]=e;ja:{if(!p){break ja}v[22708]=0;e=W(331,D|0,m&65535,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break da}if(!e){break ja}i=0;if(!w[d+1216|0]){break ja}while(1){v[22708]=0;e=T(287,G|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ea}ka:{if(Je(A)>>>0<=e>>>0){break ka}o=Kg(A,e);vc(o);e=_b(D,m);v[22708]=0;f=Xc(e,0,i&65535);e=v[22708];v[22708]=0;if((e|0)==1){break h}h=0;if(!v[d+224>>2]){break ka}while(1){v[22708]=0;z=T(374,o|0)|0;e=v[22708];v[22708]=0;la:{ma:{if((e|0)!=1){if(!z){break ka}hi(d+304|0);k=0;r=z&15;if(r){break ma}break la}g=P()|0;O()|0;break g}while(1){na:{v[22708]=0;R(739,o|0,d+248|0);e=v[22708];v[22708]=0;if((e|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{e=w[d+248|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break qa;case 33:break ua;case 30:case 31:break va;case 29:break wa;case 28:break xa;case 26:break ya;case 19:case 20:break za;case 17:break Aa;case 15:break Ba;case 14:break Ca;case 10:break Da;case 6:break Ea;case 5:break Fa;case 1:break Ga;case 0:break Ha;default:break Ia}}switch(e-48|0){case 4:break ra;case 1:case 2:break sa;case 0:break ta;default:break qa}}e=w[d+249|0];Ja:{if(e>>>0<=119){t[d+304|0]=e+q;break Ja}Ka:{switch(e-254|0){case 1:t[d+304|0]=255;break Ja;case 0:t[d+304|0]=254;break Ja;default:break Ka}}t[d+304|0]=253}v[22708]=0;e=yv(d+304|0);g=v[22708];v[22708]=0;if((g|0)==1){break na}s=e&s;break oa}t[d+305|0]=w[d+249|0]+1;break oa}La:{if(w[d+306|0]){break La}e=v[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break La}e=w[d+249|0];if(e&15){break La}t[d+306|0]=11;t[d+308|0]=e>>>4;break oa}g=0;e=w[d+249|0];while(1){if((e|0)==w[g+39104|0]){t[d+308|0]=g;t[d+306|0]=11;break oa}g=g+1|0;if((g|0)!=10){continue}break}}t[d+307|0]=4;t[d+309|0]=w[d+249|0];break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>9|v[a+480180>>2]!=32)){t[d+308|0]=e;t[d+306|0]=8;break oa}t[d+309|0]=e;t[d+307|0]=5;break oa}Ma:{if(w[d+306|0]){break Ma}Na:{e=v[a+480180>>2];if((e|0)!=4){if((e|0)!=32){break Ma}g=w[d+249|0];if((g|0)!=255){break Na}t[d+308|0]=64;t[d+306|0]=2;break oa}g=w[d+249|0];if(g&15){break Ma}break pa}if(!(g&3)){break pa}}t[d+307|0]=9;t[d+309|0]=w[d+249|0];break oa}e=w[d+249|0];if(!(w[d+306|0]|e>>>0>64|v[a+480180>>2]==1)){t[d+308|0]=e;t[d+306|0]=1;break oa}t[d+309|0]=e;t[d+307|0]=13;break oa}t[d+307|0]=14;e=w[d+249|0];t[d+309|0]=e;if(v[a+480180>>2]==32){break oa}t[d+309|0]=B((e&240)>>>4|0,10)+(e&15);break oa}e=w[d+249|0];t[d+309|0]=e;if(e>>>0<=31){t[d+307|0]=16;break oa}t[d+307|0]=17;break oa}g=w[d+249|0];if(g>>>0>=16){t[d+308|0]=g>>>4;t[d+306|0]=(e|0)==20?3:5;break oa}t[d+308|0]=g;t[d+306|0]=(e|0)==20?4:6;break oa}e=w[d+249|0];if(e>>>0>=16){t[d+306|0]=10;t[d+308|0]=e>>>4;break oa}t[d+308|0]=e;t[d+306|0]=9;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|16;break oa}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|32;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33136|0];break oa}t[d+309|0]=w[d+249|0];e=w[d+307|0];t[d+307|0]=(e|0)==4?6:(e|0)==5?7:11;break oa}e=w[d+249|0];t[d+308|0]=(e>>>0)%10;if(e>>>0<=9){t[d+306|0]=5;break oa}if(e>>>0<=19){t[d+306|0]=6;break oa}if(e>>>0<=29){t[d+306|0]=3;break oa}if(e>>>0>39){break oa}t[d+306|0]=4;break oa}t[d+308|0]=w[d+249|0];t[d+306|0]=w[e+33136|0];break oa}e=w[d+249|0]+33|0;if((e&255)>>>0>9){break oa}t[d+308|0]=e;t[d+306|0]=15;break oa}if(e>>>0>=56){break oa}t[d+309|0]=w[d+249|0];t[d+307|0]=w[w[d+248|0]+33136|0];break oa}t[d+306|0]=2;t[d+308|0]=g>>>2}k=k+1|0;if(r>>>0>(k&255)>>>0){continue}break la}break}g=P()|0;O()|0;break g}v[22708]=0;v[d+248>>2]=(z>>>4|0)+h;e=Fb(d+248|0,d+224|0);g=v[22708];v[22708]=0;if((g|0)==1){break ia}e=v[e>>2];if(e>>>0>h>>>0){while(1){g=v[d+304>>2];t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=x[d+308>>1];t[f+4|0]=g;t[f+5|0]=g>>>8;f=B(w[d+1216|0],6)+f|0;h=h+1|0;if((e|0)!=(h|0)){continue}break}h=e}if(y[d+224>>2]>h>>>0){continue}break}}i=i+1|0;if(w[d+1216|0]>(i&65535)>>>0){continue}break}}m=m+1|0;if(m>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}}if(!((s^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ha}j=0;break ga}g=P()|0;O()|0;break g}j=!((w[n|0]|w[n+1|0]<<8|(w[n+2|0]<<16|w[n+3|0]<<24))&512);e=0;if(v[a+480180>>2]!=4){break fa}}e=x[a+480192>>1]}v[22708]=0;s=Q(740,d+1136|0,e|0)|0;e=v[22708];v[22708]=0;h=1;if((e|0)!=1){Oa:{Pa:{Qa:{if(x[a+480192>>1]){g=1;while(1){Ra:{Sa:{Ta:{if(!j){v[22708]=0;f=W(376,a|0,g&65535,0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ta}if(f){break Sa}}while(1){v[22708]=0;e=T(374,l|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}if(e){continue}break}if(w[d+1703|0]>=5){while(1){v[22708]=0;e=T(374,l|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){g=P()|0;O()|0;break i}if(e){continue}break}}v[22708]=0;Q(318,l|0,826)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break Ra}}g=P()|0;O()|0;break i}e=Kb(d+224|0);v[22708]=0;W(533,l|0,e|0,-1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break Qa}v[22708]=0;Q(301,f+492|0,e|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break Qa}Ua:{if(w[d+1703|0]<5){break Ua}v[22708]=0;W(533,l|0,e|0,-1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break Qa}v[22708]=0;Q(301,f+524|0,e|0)|0;k=v[22708];v[22708]=0;if((k|0)!=1){break Ua}break Qa}v[22708]=0;k=Q(741,l|0,d+304|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Qa}if(!k){break Pa}k=v[a+480180>>2];v[22708]=0;U(742,d+304|0,f|0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break Qa}if(v[a+480180>>2]==4){f=Lb(s,h-1|0);h=x[d+1106>>1]|x[d+1108>>1]<<16;t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24}vb(e)}g=g+1|0;h=g&65535;if(h>>>0<=x[a+480192>>1]){continue}break}}if(!j){break Oa}u[a+480192>>1]=0;break Oa}g=P()|0;O()|0;vb(e);break i}vb(e)}e=x[a+480190>>1];v[22708]=0;z=Q(743,d+288|0,e|0)|0;e=v[22708];v[22708]=0;r=1;if((e|0)!=1){r=w[d+1703|0]<=4?!(t[n|0]&1):r;J=c&2;e=0;Va:{if(!x[a+480190>>1]){break Va}k=1;h=1;while(1){c=e;m=Kb(d+272|0);v[22708]=0;W(533,l|0,m|0,-1)|0;e=v[22708];v[22708]=0;Wa:{Xa:{Ya:{Za:{_a:{if((e|0)==1){break _a}v[22708]=0;Q(301,((k<<5)+a|0)+946304|0,m|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break _a}g=B(k,104)+a|0;if(w[d+1703|0]<5){break Za}v[22708]=0;W(533,l|0,m|0,-1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break _a}v[22708]=0;Q(303,g+484423|0,m|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break Za}}g=P()|0;O()|0;break Ya}v[22708]=0;e=Q(744,l|0,d+304|0)|0;f=v[22708];v[22708]=0;$a:{ab:{bb:{cb:{db:{eb:{fb:{if((f|0)==1){break fb}if(!e){break eb}e=v[a+480180>>2];v[22708]=0;f=g+484380|0;Y(745,d+304|0,f|0,e|0,r|0);e=v[22708];v[22708]=0;if((e|0)==1){break fb}j=0;gb:{if(((w[d+324|0]|w[d+325|0]<<8)&61440)!=28672|w[d+1703|0]<5){break gb}v[22708]=0;j=T(746,l|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break gb}g=P()|0;O()|0;break Ya}if(!J){break Xa}K=w[d+324|0]|w[d+325|0]<<8;o=K&61440;if(!(o|(w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24)))){e=w[d+324|0]|w[d+325|0]<<8;e=Rc(d+224|0,e&1?16:8,e&1024?3:1,0,0);v[22708]=0;W(329,e|0,f|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break Xa}g=P()|0;O()|0;break Ya}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);if(!((e|0)>-1|(e+k|0)<1)){e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22708]=0;Q(747,f|0,(B(e+k|0,104)+a|0)+484380|0)|0;f=v[22708];v[22708]=0;e=c;if((f|0)!=1){break Wa}g=P()|0;O()|0;break Ya}if((w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24))<1){break Xa}if(t[d+324|0]&1){e=g+484414|0;u[e>>1]=x[e>>1]|1}if(w[d+325|0]&4){e=g+484414|0;u[e>>1]=x[e>>1]|64}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);v[22708]=0;U(288,d+224|0,b|0,e|0);i=v[22708];v[22708]=0;hb:{ib:{M=d;jb:{kb:{if((i|0)!=1){p=d+224|0;i=jc(d+248|0,p);xb(p);p=fd(f);e=(o|0)==16384;if(!((o|0)!=8192?e:1)){break ib}v[22708]=0;q=T(195,d+248|0)|0;E=v[22708];v[22708]=0;if((E|0)==1){break hb}v[d+224>>2]=q;E=v[d+224>>2];q=4/(p>>>0)|0;if(E>>>0>4294967295/(q>>>0)>>>0){break kb}q=B(q,E);break jb}g=P()|0;O()|0;break Ya}q=-1}v[M+224>>2]=q;qc(f,q);if(!e){if((o|0)!=8192){break ib}v[22708]=0;e=T(386,f|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break ab}if(!e){break cb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(748,i|0,e|0,f|0,p|0);f=v[22708];v[22708]=0;e=c;if((f|0)!=1){break bb}break ab}e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(749,i|0,e|0,f|0,p|0);f=v[22708];v[22708]=0;e=c;if((f|0)==1){break ab}break bb}v[22708]=0;e=T(386,f|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break ab}if(!e){break cb}if(t[d+324|0]&1){e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(750,i|0,e|0,f|0,p|0);f=v[22708];v[22708]=0;e=c;if((f|0)==1){break ab}break bb}e=v[g+484400>>2];f=v[f>>2];v[22708]=0;Y(751,i|0,e|0,f|0,p|0);f=v[22708];v[22708]=0;e=c;if((f|0)==1){break ab}break bb}if((K&45056)==12288){e=PV(d+224|0,i,w[d+343|0]|w[d+344|0]<<8,j);f=Vl(z,k-1|0);Vc(f,e);v[f+20>>2]=v[e+20>>2];xb(e);break cb}if((o|0)!=32768){e=1;if((o|0)!=4096){break bb}e=le(d+224|0,i);v[22708]=0;Q(752,d+216|0,i|0)|0;j=v[22708];v[22708]=0;if((j|0)!=1){lb:{if(!w[d+221|0]){break lb}j=x[d+218>>1]<<1;if((j&65535)>>>0>(w[d+343|0]|w[d+344|0]<<8)>>>0){break lb}j=(w[d+343|0]|w[d+344|0]<<8)-j|0;t[d+343|0]=j;t[d+344|0]=j>>>8;v[22708]=0;Q(190,d+248|0,x[d+216>>1])|0;j=v[22708];v[22708]=0;if((j|0)==1){break db}v[22708]=0;j=T(467,d+248|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break db}v[22708]=0;U(288,d+168|0,d+248|0,j|0);j=v[22708];v[22708]=0;if((j|0)==1){break db}j=d+192|0;k=d+168|0;Vc(e,jc(j,k));xb(j);xb(k)}v[22708]=0;e=fa(753,a|0,h&65535,e|0,1,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break db}mb:{if(!e){v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break db}c=1;break mb}nb:{if(!(w[d+343|0]|w[d+344|0]<<8)){break nb}e=w[d+343|0]|w[d+344|0]<<8;if(aj(f)>>>0<=e>>>0){break nb}e=w[d+343|0]|w[d+344|0]<<8;j=jj(f);g=g+484400|0;zh(zb(v[g>>2]),zb(v[g>>2])+(w[d+343|0]|w[d+344|0]<<8)|0,aj(f)-(w[d+343|0]|w[d+344|0]<<8)|0);v[f>>2]=v[f>>2]-((e>>>0)/(j>>>0)|0)}e=v[d+312>>2];v[d+164>>2]=e;v[d+68>>2]=e;if(y[f>>2]>(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))>>>0){v[f>>2]=w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24)}}e=c;xb(d+224|0);break bb}break db}v[22708]=0;e=Q(576,i|0,d+224|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){if(!e){break cb}v[d+80>>2]=v[d+232>>2];v[22708]=0;e=v[d+228>>2];v[d+72>>2]=v[d+224>>2];v[d+76>>2]=e;U(577,f|0,1,d+72|0);e=v[22708];v[22708]=0;if((e|0)!=1){break cb}}g=P()|0;O()|0;break $a}g=P()|0;O()|0;break $a}g=P()|0;O()|0;break Ya}vb(m);e=c;break Va}g=P()|0;O()|0;xb(d+224|0);break $a}e=c}xb(d+248|0);break Wa}g=P()|0;O()|0}xb(d+248|0)}vb(m);break k}e=c}vb(m);h=h+1|0;k=h&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}if(!(!J|!x[a+480190>>1])){f=1;i=1;while(1){c=Vl(z,f-1|0);v[22708]=0;b=T(275,c|0)|0;h=v[22708];v[22708]=0;ob:{pb:{qb:{if((h|0)!=1){if(!b){break ob}h=x[c+22>>1];b=h+i&65535;rb:{sb:{k=(h|0)!=0&(b|0)!=0&b>>>0<=x[a+480190>>1];if(!k){v[22708]=0;T(195,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break sb}break l}g=x[c+20>>1];h=Vl(z,b-1|0);vc(h);b=x[c+20>>1];v[22708]=0;b=Q(191,h|0,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break l}if(!b){break ob}v[d+224>>2]=0;v[d+248>>2]=0;v[22708]=0;U(755,d+304|0,h|0,g|0);b=v[22708];v[22708]=0;tb:{if((b|0)!=1){v[22708]=0;b=Sd(d+304|0);g=v[22708];v[22708]=0;if((g|0)==1){break tb}b=zb(b);g=Ui(v[d+304>>2]);v[22708]=0;b=fa(756,b|0,g|0,d+224|0,d+248|0,0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break tb}v[22708]=0;Q(318,h|0,v[d+224>>2])|0;h=v[22708];v[22708]=0;if((h|0)==1){break tb}zc(d+304|0);break rb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}vc(c);b=0;v[d+224>>2]=0;v[d+248>>2]=0}v[22708]=0;R(757,d+304|0,c|0);h=v[22708];v[22708]=0;ub:{vb:{if((h|0)!=1){v[22708]=0;j=Sd(d+304|0);h=v[22708];v[22708]=0;if((h|0)==1){break ub}g=v[d+304>>2];if(!k){b=zb(j);h=Ui(g);v[22708]=0;b=fa(756,b|0,h|0,d+224|0,d+248|0,0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break qb}v[22708]=0;Q(318,c|0,v[d+224>>2])|0;h=v[22708];v[22708]=0;if((h|0)==1){break qb}h=v[d+224>>2];g=g-h|0;j=h+j|0}if(b){break vb}e=1;break pb}g=P()|0;O()|0;break k}v[22708]=0;f=B(f,104)+a|0;k=f+484380|0;T(386,k|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break qb}o=f+484400|0;q=f+484414|0;f=0;h=v[d+248>>2];while(1){wb:{if(y[k>>2]<=f>>>0|(!g|(h|0)!=1?h:0)){break wb}if(!Md(k)){break wb}v[d+192>>2]=0;v[d+168>>2]=0;h=zb(j);m=Ui(g);v[22708]=0;h=la(758,b|0,h|0,m|0,d+192|0,d+272|0,d+168|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break qb}v[22708]=0;v[d+224>>2]=h;Q(318,c|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break qb}p=v[d+224>>2];ck(d+168|0,Ui(v[k>>2]-f|0));xb:{if(v[d+168>>2]<1){break xb}if(v[d+192>>2]!=(fd(k)|0)){break xb}if(t[q|0]&1){h=mg(d+152|0,v[o>>2]+(B(fd(k),f)<<1)|0,fd(k),v[d+168>>2]);m=mg(d+136|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22708]=0;v[d- -64>>2]=v[h+8>>2];r=v[h+4>>2];v[d+56>>2]=v[h>>2];v[d+60>>2]=r;v[d+48>>2]=v[m+8>>2];h=v[m+4>>2];v[d+40>>2]=v[m>>2];v[d+44>>2]=h;R(759,d+56|0,d+40|0);h=v[22708];v[22708]=0;if((h|0)!=1){break xb}break qb}h=mg(d+120|0,v[o>>2]+B(fd(k),f)|0,fd(k),v[d+168>>2]);m=mg(d+104|0,v[d+272>>2],v[d+192>>2],v[d+168>>2]);v[22708]=0;v[d+32>>2]=v[h+8>>2];r=v[h+4>>2];v[d+24>>2]=v[h>>2];v[d+28>>2]=r;v[d+16>>2]=v[m+8>>2];h=v[m+4>>2];v[d+8>>2]=v[m>>2];v[d+12>>2]=h;R(760,d+24|0,d+8|0);h=v[22708];v[22708]=0;if((h|0)==1){break qb}}v[22708]=0;m=v[d+168>>2];h=ky(b);r=v[22708];v[22708]=0;if((r|0)==1){break qb}g=g-p|0;j=j+p|0;v[d+248>>2]=h;f=f+m|0;continue}break}v[22708]=0;ly(b);b=v[22708];v[22708]=0;if((b|0)!=1){break pb}break qb}break qb}g=P()|0;O()|0;break k}g=P()|0;O()|0;zc(d+304|0);break k}zc(d+304|0)}i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}yb:{if(v[a+480180>>2]!=4){break yb}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break yb}b=w[Lb(s,f)|0];c=w[Lb(s,f)+1|0];h=w[Lb(s,f)+2|0];g=w[Lb(s,f)+3|0];v[22708]=0;f=f+1|0;ka(763,a|0,f&65535,b|0,c|0,h|0,g|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}g=P()|0;O()|0;break k}zb:{Ab:{Bb:{Cb:{if(!(w[n+2|0]&16)){break Cb}v[22708]=0;b=Q(191,l|0,1)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}if(!b){break Cb}f=0;v[22708]=0;b=T(374,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break n}if(!(!(b&1)|!x[I>>1])){while(1){v[22708]=0;b=T(192,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Bb}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[22708]=0;b=Q(191,l|0,1)|0;c=v[22708];v[22708]=0;Db:{if((c|0)!=1){if(!b){break Cb}v[22708]=0;b=T(374,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ab}if(!b){break Cb}v[22708]=0;c=T(192,l|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break zb}v[22708]=0;U(288,d+224|0,l|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break zb}c=d+224|0;f=jc(d+304|0,c);xb(c);if(b>>>0>250){break Db}v[22708]=0;R(605,f|0,(B(b,160)+a|0)+906140|0);b=v[22708];v[22708]=0;if((b|0)!=1){break Db}g=P()|0;O()|0;xb(d+304|0);break k}g=P()|0;O()|0;break k}xb(d+304|0);continue}}j=a+901404|0;k=a+1074308|0;h=Kb(d+192|0);g=0;c=0;Eb:{Fb:{while(1){v[22708]=0;b=Q(191,l|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Eb}if(!b){break Fb}v[22708]=0;f=T(192,l|0)|0;b=v[22708];v[22708]=0;Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{if((b|0)!=1){v[22708]=0;b=T(192,l|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Wb}v[22708]=0;U(288,d+304|0,l|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break Vb}i=d+304|0;b=jc(d+224|0,i);xb(i);if((f|0)<=1397900629){if((f|0)==1229211981){break Tb}if((f|0)!=1229476432){break Hb}v[22708]=0;f=T(374,b|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}v[a+480216>>2]=f;v[22708]=0;b=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break q}v[a+480220>>2]=b;break Hb}if((f|0)==1397900630){break Ub}if((f|0)!=1414548815){break Hb}v[22708]=0;f=Q(555,b|0,11149)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}if(!f){break Rb}v[22708]=0;f=T(192,b|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;U(288,d+304|0,d+224|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Sb}}g=P()|0;O()|0;break p}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}Xb:{Yb:{Zb:{f=v[a+480180>>2];switch(f-2|0){case 1:break Hb;case 0:break Ib;case 2:break Yb;default:break Zb}}if((f|0)==16){break Xb}if((f|0)!=32){break Hb}v[22708]=0;g=T(287,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;c=T(287,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break Hb}break q}v[d+304>>2]=32;v[22708]=0;f=T(195,d+224|0)|0;i=v[22708];v[22708]=0;_b:{if((i|0)==1){break _b}v[22708]=0;v[d+248>>2]=f;f=Fb(d+304|0,d+248|0);i=v[22708];v[22708]=0;if((i|0)==1){break _b}f=v[f>>2];v[22708]=0;U(764,b|0,h|0,f|0);b=v[22708];v[22708]=0;if((b|0)!=1){break Hb}}g=P()|0;O()|0;break p}v[22708]=0;b=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Gb}v[22708]=0;R(765,d+248|0,1320);f=v[22708];v[22708]=0;$b:{if((f|0)!=1){v[d+168>>2]=b>>>4;v[22708]=0;v[d+272>>2]=b&15;Y(460,d+304|0,d+248|0,d+168|0,d+272|0);b=v[22708];v[22708]=0;if((b|0)==1){break $b}b=d+304|0;Eb(h,b);vb(b);Hb(d+248|0);break Hb}g=P()|0;O()|0;break p}g=P()|0;O()|0;Hb(d+248|0);break p}v[22708]=0;Q(568,b|0,j|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;Iu(j);b=v[22708];v[22708]=0;if((b|0)==1){break q}break Hb}f=d+248|0;i=d+304|0;m=jc(f,i);xb(i);v[22708]=0;f=T(195,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Qb}u[d+304>>1]=f>>>5;f=Te(D);v[22708]=0;u[d+168>>1]=f;f=Pc(d+304|0,d+168|0);i=v[22708];v[22708]=0;if((i|0)==1){break Qb}i=x[f>>1];if(i){f=0;while(1){v[22708]=0;W(766,m|0,d+304|0,32)|0;o=v[22708];v[22708]=0;if((o|0)==1){break Qb}o=_b(D,f);v[22708]=0;Q(767,o|0,d+304|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break Qb}f=f+1|0;if((i|0)!=(f|0)){continue}break}}xb(d+248|0)}v[22708]=0;f=Q(555,b|0,11154)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}if(!f){break Ob}v[22708]=0;f=T(192,b|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;U(288,d+248|0,d+224|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Pb}}g=P()|0;O()|0;break p}g=P()|0;O()|0;xb(d+248|0);break p}f=d+304|0;i=d+248|0;m=jc(f,i);xb(i);v[22708]=0;f=T(195,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Nb}u[d+248>>1]=(f>>>0)/20;f=x[a+480188>>1];v[22708]=0;u[d+168>>1]=f;f=Pc(d+248|0,d+168|0);i=v[22708];v[22708]=0;if((i|0)==1){break Nb}i=x[f>>1];if(i){f=0;while(1){v[22708]=0;W(571,m|0,((f<<5)+a|0)+480289|0,20)|0;o=v[22708];v[22708]=0;if((o|0)==1){break Nb}f=f+1|0;if((i|0)!=(f|0)){continue}break}}xb(d+304|0)}v[22708]=0;Q(588,a|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break q}v[22708]=0;Y(589,a|0,b|0,1,0);f=v[22708];v[22708]=0;if((f|0)==1){break q}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[22708]=0;U(604,a|0,b|0,g&65535);b=v[22708];v[22708]=0;if((b|0)==1){break q}}if(!v[k>>2]){break Hb}v[22708]=0;b=Q(2,d+248|0,14713)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Mb}v[22708]=0;R(162,d+168|0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break Lb}v[22708]=0;U(3,d+304|0,b|0,d+168|0);f=v[22708];v[22708]=0;if((f|0)==1){break Kb}f=d+304|0;Eb(h,f);vb(f);vb(d+168|0);vb(b);break Hb}g=P()|0;O()|0;xb(d+304|0);break p}g=P()|0;O()|0;break p}g=P()|0;O()|0;break Jb}g=P()|0;O()|0;vb(d+168|0)}vb(b);break p}v[22708]=0;g=T(287,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break q}}xb(d+224|0);continue}break}g=P()|0;O()|0;break p}ac:{bc:{cc:{dc:{ec:{fc:{gc:{if(v[a+480180>>2]!=32){break gc}b=g&65535;if(b>>>0<256){break gc}if(b>>>0<532){break fc}}hc:{if(v[a+480180>>2]!=2){break hc}b=g&65535;if(b>>>0<12544){break hc}if(b>>>0<12820){break fc}}if(v[a+480180>>2]!=2){break ec}b=g&65535;if(b>>>0<4864|b>>>0>4895){break ec}}v[22708]=0;Vo(j);b=v[22708];v[22708]=0;if((b|0)==1){break dc}}if(!(t[n+2|0]&1)){break ac}f=v[a+1074308>>2];if(!f){if(x[a+480192>>1]){f=1;while(1){b=v[(((f&65535)<<2)+a|0)+900380>>2];if(b){v[22708]=0;g=ki(b,2);n=v[22708];v[22708]=0;if((n|0)==1){break cc}n=v[a+480180>>2];v[22708]=0;U(768,g|0,4,n|0);g=v[22708];v[22708]=0;if((g|0)==1){break bc}t[b+19|0]=w[b+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[22708]=0;b=a+1074312|0;Q(410,b|0,27)|0;f=v[22708];v[22708]=0;if((f|0)==1){break dc}v[22708]=0;Q(410,b|0,57)|0;b=v[22708];v[22708]=0;if((b|0)==1){break dc}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[22708]=0;Q(410,a+1074312|0,73)|0;b=v[22708];v[22708]=0;if((b|0)==1){break dc}f=v[a+1074308>>2]}if(f>>>0>19267583){break ac}v[22708]=0;Q(410,a+1074312|0,50)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ac}}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}ic:{jc:{kc:{lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{if(gd(h)){v[22708]=0;_(769,d+224|0);b=v[22708];v[22708]=0;wc:{if((b|0)!=1){v[22708]=0;U(726,d+304|0,d+224|0,d+1703|0);b=v[22708];v[22708]=0;if((b|0)==1){break wc}break vc}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}v[22708]=0;_(770,d+224|0);b=v[22708];v[22708]=0;if((b|0)==1){break uc}v[22708]=0;Y(771,d+304|0,d+224|0,d+1703|0,h|0);b=v[22708];v[22708]=0;if((b|0)==1){break tc}}b=d+304|0;Eb(h,b);vb(b);b=d+224|0;Hb(b);v[22708]=0;R(725,b|0,1108);b=v[22708];v[22708]=0;if((b|0)==1){break rc}v[22708]=0;U(726,d+304|0,d+224|0,d+1703|0);b=v[22708];v[22708]=0;if((b|0)==1){break qc}b=d+304|0;Eb(a+1298304|0,b);vb(b);Hb(d+224|0);v[22708]=0;b=Q(2,b|0,12195)|0;f=v[22708];v[22708]=0;if((f|0)==1){break pc}Eb(a+1298316|0,b);vb(b);b=v[a+480180>>2];if((b|0)>15){break sc}switch(b-1|0){case 1:break lc;case 3:break mc;case 0:break nc;default:break v}}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}if((b|0)==16){break oc}if((b|0)==32){break kc}if((b|0)!=16777216){break v}v[22708]=0;b=Q(2,d+304|0,7394)|0;c=v[22708];v[22708]=0;if((c|0)==1){break jc}Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,11111)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ic}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;Hb(d+224|0);break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,7399)|0;c=v[22708];v[22708]=0;xc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,5512)|0;c=v[22708];v[22708]=0;if((c|0)==1){break xc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,9556)|0;c=v[22708];v[22708]=0;yc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,11475)|0;c=v[22708];v[22708]=0;if((c|0)==1){break yc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,7372)|0;c=v[22708];v[22708]=0;zc:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,12405)|0;c=v[22708];v[22708]=0;if((c|0)==1){break zc}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,7744)|0;c=v[22708];v[22708]=0;Ac:{if((c|0)!=1){Eb(a+1298352|0,b);vb(b);v[22708]=0;b=Q(2,d+304|0,12230)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ac}Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}v[22708]=0;b=Q(2,d+304|0,3184)|0;f=v[22708];v[22708]=0;Bc:{Cc:{Dc:{Ec:{Fc:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);if(!(c&65535)){break Bc}v[22708]=0;R(411,d+224|0,1423);b=v[22708];v[22708]=0;if((b|0)==1){break Fc}v[d+168>>2]=(c&65280)>>>8;v[22708]=0;v[d+272>>2]=c&255;R(599,d+248|0,d+272|0);b=v[22708];v[22708]=0;if((b|0)==1){break Ec}v[22708]=0;Y(582,d+304|0,d+224|0,d+168|0,d+248|0);b=v[22708];v[22708]=0;if((b|0)==1){break Dc}b=d+304|0;Eb(a+1298340|0,b);vb(b);vb(d+248|0);Hb(d+224|0);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break Cc}g=P()|0;O()|0;vb(d+248|0)}Hb(d+224|0);break o}v[22708]=0;b=Q(2,d+304|0,5688)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a+1298340|0,b);vb(b);break v}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break o}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break i}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break c}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break c}Eb(a+1298328|0,h);Gc:{if(v[a+1074308>>2]){v[a+1298364>>2]=8;break Gc}if(v[a+480180>>2]==1){v[a+1298364>>2]=2;break Gc}v[a+1298364>>2]=5}f=1;if(e&1){v[22708]=0;b=Q(2,d+304|0,13720)|0;c=v[22708];v[22708]=0;if((c|0)==1){break s}v[22708]=0;U(560,a|0,2,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break r}vb(b)}vb(h);fC(z);ci(s);jd(A);xb(H);xb(G)}xb(l)}gc(C);break a}g=P()|0;O()|0;break o}g=P()|0;O()|0;vb(b);break o}g=P()|0;O()|0}xb(d+224|0)}vb(h);break k}g=P()|0;O()|0;break k}g=P()|0;O()|0;break k}g=P()|0;O()|0}fC(z);break i}g=P()|0;O()|0}ci(s);break g}g=P()|0;O()|0}jd(A)}xb(H)}xb(G);break c}g=P()|0;O()|0}xb(l)}gc(C);S(g|0);L()}gb=d+1712|0;return f|0}function Rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,da=0,ea=0,ga=0,ha=0,ia=0,ja=C(0),ka=0,la=0,ma=0,na=C(0);e=gb-480|0;gb=e;vc(b);a:{b:{c:{if(!Jh(b,e+472|0)){break c}if(!UT(e+472|0)){break c}if((PT(b)|0)>-1){break c}if(!c){f=1;break c}Hd(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;jA(e+208|0,32);o=v[e+220>>2];d=a+1074320|0;v[d>>2]=v[e+216>>2];v[d+4>>2]=o;d=v[e+212>>2];v[a+1074312>>2]=v[e+208>>2];v[a+1074316>>2]=d;Sf(a+1074312|0,38);E=dd(e+456|0);H=dd(e+440|0);F=dd(e+424|0);o=dd(e+408|0);pg(b,4);i=a+480190|0;K=c&1;l=a+1298292|0;A=2500;G=!(c&2);d:{e:{f:{g:{h:{i:{while(1){v[22708]=0;c=Q(191,b|0,4)|0;d=v[22708];v[22708]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((d|0)!=1){t:{if(c){v[22708]=0;h=T(905,b|0)|0;c=v[22708];v[22708]=0;u:{if((c|0)==1){break u}v:{switch(h+21|0){case 20:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){if(x[a+480188>>1]){continue}d=c&65535;if(d-1>>>0>126){continue}u[a+480188>>1]=c;la=a,ma=Mb(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}a=P()|0;O()|0;break a;case 19:v[22708]=0;N=T(426,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break u}if(N>>>0<=1024){continue}break q;case 16:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){if((c&65535)==4){continue}break q}a=P()|0;O()|0;break a;case 15:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;w:{if((d|0)!=1){v[e+208>>2]=c;v[22708]=0;v[e+104>>2]=800;d=Fb(e+208|0,e+104|0);c=v[22708];v[22708]=0;if((c|0)==1){break w}c=a;J=+y[d>>2]*1.24*1e4;x:{if(J<4294967296&J>=0){d=~~J>>>0;break x}d=0}v[c+480204>>2]=d;continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a;case 17:case 18:v[22708]=0;Q(318,b|0,4)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 31:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}aa=1;A=Fd(c,0,1e4);continue;case 32:case 33:v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;y:{z:{if((d|0)!=1){aa=1;if(!c){continue}v[22708]=0;c=Q(2,e+208|0,9816)|0;d=v[22708];v[22708]=0;if((d|0)==1){break z}v[22708]=0;U(560,a|0,2,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break y}vb(c);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a;case 14:v[22708]=0;Q(318,b|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break u}p=!x[i>>1]|p;continue;case 11:A:{if(!K){break A}if(!cd(E)){break A}v[22708]=0;R(906,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=E;d=c;if(v[c>>2]){Od(d);EB(v[d>>2],bi(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Ru(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 3:case 4:case 10:if(dh(o)>>>0<=x[i>>1]){continue}B:{if((p|G)&1){break B}if(!fi(a)){break B}j=x[i>>1]+1|0;u[i>>1]=j;d=mc(e+392|0);v[22708]=0;c=T(215,e+208|0)|0;k=v[22708];v[22708]=0;C:{D:{E:{if((k|0)!=1){if((h|0)==-17){break E}if((h|0)!=-11){break D}v[22708]=0;h=T(426,b|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break C}v[22708]=0;U(288,e+368|0,b|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break C}h=e+104|0;k=e+368|0;Vc(c,jc(h,k));xb(h);xb(k);break j}a=P()|0;O()|0;break d}v[22708]=0;R(907,e+104|0,b|0);h=v[22708];v[22708]=0;F:{if((h|0)!=1){h=e+104|0;np(d,h);gc(h);v[22708]=0;Vd(e+360|0,d);h=v[22708];v[22708]=0;if((h|0)==1){break F}h=Ud(e+352|0);v[22708]=0;k=v[e+364>>2];v[e+32>>2]=v[e+360>>2];v[e+36>>2]=k;k=v[h+4>>2];v[e+24>>2]=v[h>>2];v[e+28>>2]=k;h=W(507,e+104|0,e+32|0,e+24|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break F}Vc(c,h);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22708]=0;R(908,e+104|0,b|0);h=v[22708];v[22708]=0;G:{if((h|0)!=1){h=e+104|0;np(d,h);gc(h);v[22708]=0;Vd(e+344|0,d);h=v[22708];v[22708]=0;if((h|0)==1){break G}h=Ud(e+336|0);v[22708]=0;k=v[e+348>>2];v[e+16>>2]=v[e+344>>2];v[e+20>>2]=k;k=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=k;h=W(507,e+104|0,e+16|0,e+8|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break G}Vc(c,h);xb(e+104|0);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 9:if(!fi(a)){continue}u[i>>1]=x[i>>1]+1;continue;case 8:H:{if(!K){break H}if(!cd(F)){break H}v[22708]=0;R(909,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=F;d=c;if(v[c>>2]){Od(d);qC(v[d>>2],pe(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;ci(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 7:if(cd(o)){v[22708]=0;R(910,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=o;d=c;if(v[c>>2]){Od(d);BB(v[d>>2],CB(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Pu(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 6:I:{if(!K){break I}if(!cd(H)){break I}v[22708]=0;R(911,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){j=e+208|0;h=j;c=H;d=c;if(v[c>>2]){Od(d);DB(v[d>>2],xi(d));la=wb(d),ma=0,v[la>>2]=ma;v[d>>2]=0;v[d+4>>2]=0}v[c>>2]=v[h>>2];v[c+4>>2]=v[h+4>>2];d=wb(h);la=wb(c),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[h>>2]=0;v[h+4>>2]=0;Ou(j);continue}a=P()|0;O()|0;break a}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break u;case 5:v[22708]=0;R(912,e+208|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break t}J:{if(cd(e+208|0)){break J}c=e+208|0;d=v[c>>2];c=oc(c);v[22708]=0;ca(913,l|0,d|0,c|0,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break J}a=P()|0;O()|0;gc(e+208|0);break a}gc(e+208|0);continue;case 0:case 1:case 2:break v;default:break q}}v[22708]=0;c=T(426,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break u}v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}a=P()|0;O()|0;break a}if(!x[a+480188>>1]|!N){break q}if(cd(o)){break q}if(K){if(cd(E)){break q}if(cd(F)){break q}if(cd(H)){break q}}if(dh(o)>>>0>=256){v[22708]=0;R(914,o|0,255);b=v[22708];v[22708]=0;if((b|0)==1){break b}}la=a,ma=dh(o),u[la+480192>>1]=ma;v[22708]=0;j=a+480192|0;b=Le(i,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}u[i>>1]=x[b>>1];if(p&1){v[22708]=0;b=Q(2,e+208|0,13550)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;U(560,a|0,2,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break l}vb(b)}f=x[j>>1];p=1;while(1){d=f&65535;f=0;c=1;b=1;K:{if(!d){break K}while(1){L:{h=Rl(o,c-1|0);d=h;M:{if(w[d|0]?t[d+128|0]<0:1){break M}if((Nu(h)|0)==(p&1)){break M}f=0;d=h;N:{if(!Nu(d)){break N}if(Ib(w[d+6|0]|w[d+7|0]<<8)){break N}if(Ib(w[d+14|0]|w[d+15|0]<<8)>>>0>20){break N}f=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==4}O:{P:{if(f){f=w[h+23|0];d=w[h+140|0];v[22708]=0;d=fa(915,h|0,a|0,(d&2)>>>1|0,(B(c,104)+a|0)+484380|0,A&65535)|0;l=v[22708];v[22708]=0;Q:{R:{S:{if((l|0)!=1){if(!d){break Q}v[22708]=0;d=Q(70,e+208|0,8013)|0;l=v[22708];v[22708]=0;if((l|0)==1){break S}v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break R}vb(d);d=b;if(dh(o)>>>0<=f>>>0){break O}la=h,ma=w[Rl(o,f)+143|0]+w[h+143|0]|0,t[la+143|0]=ma;break P}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=f+1|0;break O}f=0;T:{if(!Nu(h)){break T}if((Ib(w[d+6|0]|w[d+7|0]<<8)|0)!=1){break T}if((Ib(w[d+14|0]|w[d+15|0]<<8)|0)!=2){break T}f=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==10}d=b;if(!f){break O}hc(e+208|0,h,128);if(Ib(w[e+228|0]|w[e+229|0]<<8)>>>0>=x[i>>1]){break P}v[22708]=0;f=Q(900,e+104|0,0)|0;d=v[22708];v[22708]=0;U:{V:{W:{if((d|0)!=1){d=(B(Ib(w[e+228|0]|w[e+229|0]<<8),104)+a|0)+484484|0;if(Ib(w[e+244|0]|w[e+245|0]<<8)>>>0<x[a+480190>>1]){f=(B(Ib(w[e+244|0]|w[e+245|0]<<8),104)+a|0)+484484|0}v[22708]=0;d=ca(916,e+208|0,d|0,f|0,(B(c,104)+a|0)+484380|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break W}if(!d){break P}v[22708]=0;d=Q(70,e+368|0,8543)|0;f=v[22708];v[22708]=0;if((f|0)==1){break V}v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break U}vb(d);t[h+139|0]=w[h+139|0]+12;break P}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=b}v[22708]=0;c=d&65535;d=W(376,a|0,b&65535,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break L}if(!d|c>>>0>x[i>>1]){break M}v[22708]=0;Y(917,h|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[22708];v[22708]=0;if((c|0)==1){break L}}b=b+1|0;c=b&65535;f=x[j>>1];if(c>>>0<=f>>>0){continue}break K}break}a=P()|0;O()|0;break a}b=p&1;p=0;if(b){continue}break}k=Ik(e+104|0);j=Ik(e+368|0);b=Nb(F);ba=B(x[a+480188>>1],N);da=Lv((b>>>0)/(ba>>>0)|0);v[22708]=0;V=a+484344|0;R(330,V|0,da|0);b=v[22708];v[22708]=0;if((b|0)==1){a=P()|0;O()|0;break m}ea=a+484360|0;$l(Sb(ea));b=x[a+480188>>1];v[22708]=0;r=Q(918,e+392|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){la=e,ma=Vb(H),v[la+96>>2]=ma;la=e,ma=Zb(H),v[la+88>>2]=ma;if(!Gb(e+96|0,e+88|0)){break s}X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{while(1){ea:{q=v[e+96>>2];b=q;fa:{if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==1){break fa}if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==65535){break ea}b=Ib(w[q|0]|w[q+1|0]<<8);if(Ae(E)>>>0<=b>>>0){break fa}b=Ib(w[q+2|0]|w[q+3|0]<<8);if(Ae(E)>>>0<b>>>0){break fa}if(!Ib(w[q+2|0]|w[q+3|0]<<8)){break fa}if(Ae(E)-Ib(w[q+2|0]|w[q+3|0]<<8)>>>0<Ib(w[q|0]|w[q+1|0]<<8)>>>0){break fa}b=v[E>>2];td(e+208|0,b,b+(Ae(E)<<5)|0);c=Ib(w[q|0]|w[q+1|0]<<8);b=Ib(w[q+2|0]|w[q+3|0]<<8);d=v[e+208>>2]+(c<<5)|0;b=(b|0)==-1?(v[e+212>>2]-v[e+208>>2]>>5)-c|0:b;v[e+80>>2]=d;v[e+84>>2]=d+(b<<5);ga:{X=Sb(ea);if(cd(X)){break ga}v[22708]=0;R(710,X|0,65534);b=v[22708];v[22708]=0;if((b|0)!=1){break ga}a=P()|0;O()|0;break n}b=v[e+80>>2];ga=v[e+84>>2];if((b|0)==(ga|0)){break fa}while(1){G=b;c=Ib(Ib(w[q+8|0]|w[q+9|0]<<8)+Ib(w[b+16|0]|w[b+17|0]<<8)&65535);t[b+16|0]=c;t[b+17|0]=c>>>8;ha:{ia:{ja:{d=b;f=k;c=Yd(f);ka:{if(c){wb(f);while(1){h=c+14|0;if(!Lu(d,h)){f=1;if(!Lu(h,d)){break ka}c=c+4|0}c=v[c>>2];if(c){continue}break}}f=0}if(f){v[22708]=0;c=Q(919,k|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ja}I=x[c>>1];break ia}I=0;if(!K){break ia}c=Ib(w[b+12|0]|w[b+13|0]<<8);v[22708]=0;I=W(544,V|0,c|0,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ja}if((I|0)==65535){break fa}v[22708]=0;c=Q(919,k|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ja}u[c>>1]=I;c=b;if(Ib(w[c+8|0]|w[c+9|0]<<8)>>>0>=da>>>0){break ha}d=b;if(Ib(w[d+10|0]|w[d+11|0]<<8)>>>0>=N>>>0){break ha}ha=b;h=Ib(w[b+14|0]|w[b+15|0]<<8);la=e,ma=Vb(F),v[la+56>>2]=ma;f=e+56|0;la=e,ma=Zo(f,B(Ib(w[c+8|0]|w[c+9|0]<<8),ba)),v[la+208>>2]=ma;la=e,ma=Zo(e+208|0,B(Ib(w[d+10|0]|w[d+11|0]<<8),x[a+480188>>1])),v[la+72>>2]=ma;v[e+68>>2]=0;bj(f);ia=b;if(Ib(w[b+12|0]|w[b+13|0]<<8)){Z=0;while(1){c=_b(V,I);v[22708]=0;$=Xc(c,Z,0);c=v[22708];v[22708]=0;la:{ma:{if((c|0)!=1){s=0;p=0;if(x[a+480188>>1]){break ma}break la}a=P()|0;O()|0;break n}while(1){la=e,ma=Zb(F),v[la+208>>2]=ma;c=e+68|0;if(Gb(e+72|0,e+208|0)){c=v[e+72>>2]}la=e,ma=Zb(F),v[la+208>>2]=ma;if(Gb(e+72|0,e+208|0)){Qe(e+72|0)}d=B(s,6);i=c;if(t[c+1|0]<0|t[c+1|0]>84){f=255}else{f=w[i+1|0]+25|0}d=d+$|0;A=0;m=dh(o);l=c;M=w[c+3|0];na:{if(m>>>0<=M>>>0){break na}A=M+1|0;if(t[Rl(o,M)+142|0]&1|f<<24>>24<0){break na}f=nn(Ib(w[G+16|0]|w[G+17|0]<<8)+f<<24>>24)}oa:{if(!w[d|0]){break oa}if(!(w[l+3|0]|(w[c|0]|w[i+1|0]!=255))){if(!w[c+2|0]){break oa}}m=w[d+1|0];if(!m){break oa}if(dh(o)>>>0<m>>>0){break oa}if(w[Rl(o,m-1|0)+132|0]!=2){break oa}_o(d)}g=Pj(r,s);pa:{if(p&1){m=v[e+56>>2];t[d|0]=m;t[d+1|0]=m>>>8;t[d+2|0]=m>>>16;t[d+3|0]=m>>>24;m=x[e+60>>1];t[d+4|0]=m;t[d+5|0]=m>>>8;qa:{if(w[d+3|0]){break qa}m=s-1|0;if(w[g+21|0]==w[Pj(r,m)+21|0]){break qa}t[d+3|0]=21;m=w[Pj(r,m)+21|0];t[g+21|0]=m;t[d+5|0]=m}p=0;m=1;ra:{if(w[c|0]==9){break ra}if(w[c|0]==24|w[c|0]==25|!(w[c+2|0]==249|w[c+2|0]==250?w[c|0]:1)){break ra}m=0}if(!m){break pa}}m=d;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{switch(w[c|0]){case 5:i=w[g+17|0];break ya;case 0:Aa:{if(w[c+2|0]>=201){p=0;Ba:{switch(w[c+2|0]-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[g+16|0]=0;break ta;case 9:t[d+4|0]=1;t[d+2|0]=15;break ta;case 8:if((h&255)>>>0<2){break ta}h=h-1|0;break ua;case 7:if((h&255)==255){h=255;break ta}h=h+1|0;break ua;case 6:t[g+17|0]=f;if(w[g+18|0]!=(A&255)){break ta}t[d|0]=f;t[d+5|0]=255;t[d+3|0]=4;u[g+32>>1]=0;v[g+8>>2]=0;break ta;case 5:t[d+5|0]=242;t[d+3|0]=2;break ta;case 4:t[d+5|0]=242;t[d+3|0]=3;break ta;case 3:t[d+5|0]=244;t[d+3|0]=2;break ta;case 2:t[d+5|0]=244;t[d+3|0]=3;break ta;case 1:t[d+5|0]=248;t[d+3|0]=2;break ta;case 12:break Aa;case 0:break Ba;default:break ta}}t[d+5|0]=248;t[d+3|0]=3;break ta}if(t[i+1|0]<=-1){p=0;if(w[c+2|0]>99){break ta}}if(t[i+1|0]>=0){t[g+17|0]=f;t[d|0]=f;t[g+18|0]=A;t[d+1|0]=A;u[g+32>>1]=0;v[g+8>>2]=0}if(!w[c+2|0]){p=0;break ta}c=w[c+2|0];v[22708]=0;c=fn(+(c>>>0)*.64);f=v[22708];v[22708]=0;if((f|0)==1){break va}t[g+19|0]=c;n=z[g>>2];v[g>>2]=0;p=n!=C(0);break ta}t[d+4|0]=0;t[d+2|0]=14;t[g+16|0]=1;break ta;case 1:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(.0333000011742115);break sa;case 2:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(-.0333000011742115);break sa;case 12:t[e+208|0]=15;f=w[l+3|0];v[22708]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;Ca:{if((i|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22708]=0;t[e+52|0]=c>>>3;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Ca}t[g+24|0]=w[c|0]|f<<4;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 3:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(.0333000011742115);break sa;case 4:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(-.0333000011742115);break sa;case 15:i=f<<24>>24;if(!w[c+2|0]|(i|0)<0){break sa}l=i-w[g+17|0]|0;i=l>>31;i=i^i+(l<<5);v[e+208>>2]=i;t[g+17|0]=f;v[g+8>>2]=0;t[d|0]=f;t[d+3|0]=4;c=ei((i>>>0)/(w[c+2|0]<<1>>>0)|0);t[d+5|0]=c;t[g+27|0]=c;v[22708]=0;f=v[e+208>>2];v[e+52>>2]=B(c,(h&255)-1|0);c=pd(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)!=1){u[g+32>>1]=f-v[c>>2];break sa}a=P()|0;O()|0;break n;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break sa;case 13:t[e+208|0]=15;f=w[l+3|0];v[22708]=0;t[e+52|0]=f>>>3;f=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;Da:{if((i|0)!=1){f=w[f|0];t[e+208|0]=15;c=w[c+2|0];v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Da}t[g+23|0]=w[c|0]|f<<4;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 23:case 24:case 25:l=j;f=Yd(j);Ea:{if(f){wb(l);while(1){m=f+13|0;if(!Ku(i,m)){l=1;if(!Ku(m,i)){break Ea}f=f+4|0}f=v[f>>2];if(f){continue}break}}l=0}if(l){t[d+3|0]=31;v[22708]=0;c=Q(920,j|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break va}t[d+5|0]=w[c|0];break sa}if(QT(j)>>>0>127){break sa}f=QT(j);i=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;v[e+48>>2]=i;v[e+40>>2]=i;i=W(921,e+40|0,(((f&255)<<5)+a|0)+902204|0,a|0)|0;l=v[22708];v[22708]=0;Fa:{if((l|0)==1){break Fa}if(!i){break sa}t[d+3|0]=31;v[22708]=0;i=Q(920,j|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break Fa}f=f|-128;t[i|0]=f;t[d+5|0]=f;if(w[c|0]!=25?w[c|0]!=24:0){break sa}ka=1;break sa}a=P()|0;O()|0;break n;case 16:if(!w[c+2|0]){break sa}t[d+3|0]=15;v[e+208>>2]=15;f=w[l+3|0];v[22708]=0;v[e+52>>2]=f+1;f=pd(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)!=1){t[d+5|0]=v[f>>2];u[g+30>>1]=B(w[c+2|0],w[l+3|0]+1|0);break sa}a=P()|0;O()|0;break n;case 9:t[d+3|0]=16;h=w[c+2|0]?w[c+2|0]:4;t[d+5|0]=h;break sa;case 19:if(w[i+1|0]!=4?w[i+1|0]:0){break sa}t[e+47|0]=w[i+1|0]==4?w[l+3|0]:128;t[e+208|0]=w[c+2|0];v[22708]=0;t[e+52|0]=100;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;Ga:{Ha:{if((f|0)!=1){c=w[c|0];v[e+208>>2]=128;v[22708]=0;v[e+52>>2]=256-w[e+47|0];f=pd(e+208|0,e+52|0);l=v[22708];v[22708]=0;if((l|0)==1){break Ha}f=v[f>>2];v[22708]=0;t[e+208|0]=128;l=ac(e+208|0,e+47|0);m=v[22708];v[22708]=0;if((m|0)==1){break Ga}l=w[l|0];f=(B(c,f)|0)/128|0;m=f&255;if((m|0)!=w[g+20|0]){t[g+20|0]=f;t[d+3|0]=21;f=Qc(((B(m,w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[d+5|0]=f}if(w[i+1|0]!=4|(x[a+480188>>1]-1|0)<=(s|0)){break sa}f=s+1|0;i=Pj(r,f);c=B(c,l)>>>7|0;if(w[i+20|0]==(c&255)){break sa}t[i+20|0]=c;c=B(f,6)+$|0;t[c+3|0]=21;f=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[c+5|0]=f;break sa}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 17:case 20:t[d+3|0]=0;break sa;case 7:c=w[c+2|0];t[g+25|0]=0;t[g+26|0]=0;t[g+22|0]=c;break sa;case 8:t[g+22|0]=w[g+22|0]+w[c+2|0];break sa;case 14:t[g+25|0]=w[l+3|0];t[g+26|0]=w[c+2|0];break sa;case 18:break xa;case 6:break za;default:break sa}}t[g+18|0]=A;t[g+17|0]=f;t[d+1|0]=A;i=f}t[m|0]=i;if(f<<24>>24>=0){t[g+18|0]=A;t[d+1|0]=A}if(w[c|0]==5){t[d+4|0]=1;t[d+2|0]=11}if(!(w[g+26|0]?1:w[c+2|0]|w[g+22|0])){break wa}f=w[g+26|0];if(f){J=(si(+x[g+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(f>>>0)*.25}else{J=0}t[d+3|0]=44;f=w[g+22|0];c=w[c+2|0];v[22708]=0;c=fn(J+ +(c+f|0));f=v[22708];v[22708]=0;if((f|0)!=1){t[d+5|0]=c;break wa}a=P()|0;O()|0;break n}c=w[g+17|0]+w[c+2|0]&255;c=c?c>>>0<120?c:120:1;t[g+17|0]=c;t[d|0]=c;t[d+5|0]=255;t[d+3|0]=4}u[g+32>>1]=0;break sa}a=P()|0;O()|0;break n}t[d+5|0]=h;t[d+3|0]=16}c=Qc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);if(w[g+21|0]==(c&255)?p:1){t[g+21|0]=c;t[d+5|0]=c;t[d+3|0]=21}if(s&1|t[i+1|0]<1|(x[a+480188>>1]-1|0)<=(s|0)){break sa}if(dh(o)>>>0<=M>>>0){break sa}if(w[Rl(o,M)+132|0]!=1){break sa}f=s+1|0;c=B(f,6)+$|0;i=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=i;t[c+1|0]=i>>>8;t[c+2|0]=i>>>16;t[c+3|0]=i>>>24;i=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=i;t[c+5|0]=i>>>8;t[c+1|0]=w[c+1|0]+1;la=Pj(r,f),ma=w[g+19|0],t[la+19|0]=ma;la=Pj(r,f),na=z[g>>2],z[la>>2]=na;la=Pj(r,f),na=z[g+4>>2],z[la+4>>2]=na;la=Pj(r,f),na=z[g+8>>2],z[la+8>>2]=na;la=Pj(r,f),na=z[g+12>>2],z[la+12>>2]=na;la=Pj(r,f),ma=x[g+30>>1],u[la+30>>1]=ma}Ia:{if(w[d|0]){t[g+16|0]=0;break Ia}p=0;if(w[g+16|0]){break pa}}Ja:{Ka:{La:{Ma:{Na:{Oa:{if(!x[g+30>>1]){break Oa}v[22708]=0;c=h&255;u[e+208>>1]=c;f=Le(g+30|0,e+208|0);i=v[22708];v[22708]=0;if((i|0)==1){break Na}u[g+30>>1]=x[f>>1]-c;if(w[d+3|0]){break Oa}t[d+3|0]=15;t[d+5|0]=0}n=z[g>>2];if(n==C(0)){break Ja}c=h&255;n=C(C(n*C(c>>>0))+z[g+4>>2]);z[g+4>>2]=n;if(w[d+3|0]){break Ja}Pa:{Qa:{if(c>>>0>=2){f=c-1|0;D=C(f|0);if(!(D<=n)){break Qa}t[e+208|0]=15;v[22708]=0;c=ch(C(n/D));i=v[22708];v[22708]=0;Ra:{if((i|0)==1){break Ra}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Ra}c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(B(c,f)|0);t[d+3|0]=22;c=c<<4;break Ka}a=P()|0;O()|0;break n}if(!(n>=C(1))){break Pa}break La}if(n>=C(1)){break La}if(!(n<=C(1-c|0))){break Pa}t[e+208|0]=15;v[22708]=0;c=ch(C(C(-n)/D));i=v[22708];v[22708]=0;Sa:{if((i|0)==1){break Sa}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Sa}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(B(f,c)|0);t[d+3|0]=22;break Ka}a=P()|0;O()|0;break n}if(!(n<=C(-1))){break Ja}t[e+208|0]=14;v[22708]=0;c=ch(C(-n));f=v[22708];v[22708]=0;if((f|0)==1){break Ma}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ma}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(c>>>0);t[d+3|0]=22;c=c|-16;break Ka}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22708]=0;c=ch(n);f=v[22708];v[22708]=0;Ta:{if((f|0)==1){break Ta}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ta}c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(c>>>0);t[d+3|0]=22;c=c<<4|15;break Ka}a=P()|0;O()|0;break n}t[d+5|0]=c}Ua:{n=z[g+8>>2];if(n==C(0)){break Ua}c=h&255;n=C(C(n*C(c>>>0))+z[g+12>>2]);z[g+12>>2]=n;Va:{if(!w[d+3|0]){Wa:{Xa:{if(c>>>0>=2){f=c-1|0;D=C(f|0);if(!(D<=n)){break Xa}t[e+208|0]=223;v[22708]=0;c=ch(C(n/D));i=v[22708];v[22708]=0;Ya:{if((i|0)==1){break Ya}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Ya}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)|0);t[d+3|0]=2;t[d+5|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(n>=C(1))){break Wa}break Va}if(n>=C(1)){break Va}if(!(n<=C(1-c|0))){break Wa}t[e+208|0]=223;v[22708]=0;c=ch(C(C(-n)/D));i=v[22708];v[22708]=0;Za:{if((i|0)==1){break Za}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break Za}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)|0);t[d+3|0]=3;t[d+5|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(n<=C(-1))){break Ua}t[e+208|0]=14;v[22708]=0;c=ch(C(-n));f=v[22708];v[22708]=0;_a:{if((f|0)==1){break _a}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break _a}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(c>>>0);t[d+3|0]=3;t[d+5|0]=c|240;break Ua}a=P()|0;O()|0;break n}if(w[d+2|0]|c>>>0<2){break Ua}ja=C(n*C(.25));f=c-1|0;D=C(f|0);if(ja>=D){t[e+208|0]=9;v[22708]=0;c=ch(C(n/D));i=v[22708];v[22708]=0;$a:{if((i|0)==1){break $a}v[22708]=0;t[e+52|0]=c>>>2;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break $a}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)<<2);t[d+2|0]=12;t[d+4|0]=c;break Ua}a=P()|0;O()|0;break n}if(!(C(1-c|0)>=ja)){break Ua}t[e+208|0]=9;v[22708]=0;c=ch(C(C(-n)/D));i=v[22708];v[22708]=0;ab:{if((i|0)==1){break ab}v[22708]=0;t[e+52|0]=c>>>2;c=ac(e+208|0,e+52|0);i=v[22708];v[22708]=0;if((i|0)==1){break ab}c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)<<2);t[d+2|0]=13;t[d+4|0]=c;break Ua}a=P()|0;O()|0;break n}t[e+208|0]=15;v[22708]=0;c=ch(n);f=v[22708];v[22708]=0;bb:{if((f|0)==1){break bb}v[22708]=0;t[e+52|0]=c;c=ac(e+208|0,e+52|0);f=v[22708];v[22708]=0;if((f|0)==1){break bb}c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(c>>>0);t[d+3|0]=2;t[d+5|0]=c|240;break Ua}a=P()|0;O()|0;break n}cb:{db:{eb:{fb:{gb:{hb:{ib:{i=w[d+3|0];switch(i|0){case 4:break cb;case 0:break ib;default:break hb}}jb:{c=w[g+23|0];if(!c){c=w[g+24|0];if(c){break jb}if(!x[g+32>>1]){break cb}c=g+32|0;break gb}t[d+3|0]=5;t[d+5|0]=c;if(!x[g+32>>1]){break cb}break fb}t[d+3|0]=8;t[d+5|0]=c;if(x[g+32>>1]){break fb}break cb}if(!x[g+32>>1]){break cb}c=g+32|0;f=c;if(i){break eb}}t[d+3|0]=4;break db}f=g+32|0}c=f;t[d+2|0]=11}f=w[g+27|0];v[22708]=0;u[e+208>>1]=B(f,(h&255)-1|0);f=Pc(c,e+208|0);i=v[22708];v[22708]=0;if((i|0)!=1){u[c>>1]=x[c>>1]-x[f>>1];break cb}a=P()|0;O()|0;break n}u[g+28>>1]=x[g+28>>1]+B(w[g+25|0],h&255)&1023;p=0;if(s&1){break pa}c=w[g+18|0];if(!c){break pa}if(dh(o)>>>0<c>>>0){break pa}if(!(w[Rl(o,c-1|0)+142|0]&4)){break pa}v[e+56>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+60>>1]=w[d+4|0]|w[d+5|0]<<8;if(!w[e+57|0]){p=1;break pa}p=1;if(w[Rl(o,w[g+18|0]-1|0)+132|0]!=1){break pa}t[e+57|0]=w[e+57|0]+1}s=s+1|0;if(s>>>0<x[a+480188>>1]){continue}break}}Z=Z+1|0;if(Ib(w[ia+12|0]|w[ia+13|0]<<8)>>>0>Z>>>0){continue}break}}c=_b(V,I);d=Ib(w[ha+14|0]|w[ha+15|0]<<8);v[22708]=0;d=Ce(e+208|0,16,d&255);f=v[22708];v[22708]=0;if((f|0)!=1){d=Gh(Ue(d,0));v[22708]=0;Q(431,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break ia}}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}c=Zl(X);la=e,ma=Ib(w[b+4|0]|w[b+5|0]<<8),u[la+208>>1]=ma;v[22708]=0;u[e+56>>1]=1;d=Le(e+208|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break da}d=x[d>>1];v[22708]=0;ca(923,X|0,c|0,d|0,I&65535)|0;c=v[22708];v[22708]=0;if((c|0)==1){break da}c=Ib(w[q+8|0]|w[q+9|0]<<8);c=Ib(Ib(w[G+16|0]|w[G+17|0]<<8)-c&65535);t[G+16|0]=c;t[G+17|0]=c>>>8}b=b+32|0;if((ga|0)!=(b|0)){continue}break}}b=e+96|0;Yo(b);if(Gb(b,e+88|0)){continue}}break}c=0;if(!ka){break r}v[22708]=0;_(436,a+906300|0);b=v[22708];v[22708]=0;if((b|0)==1){break ca}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22708]=0;v[e+208>>2]=0;b=a+906332|0;yD(b,b+16|0,e+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break ba}v[22708]=0;b=Q(70,e+208|0,6713)|0;c=v[22708];v[22708]=0;if((c|0)==1){break aa}v[22708]=0;Nv(a+906348|0,b);c=v[22708];v[22708]=0;if((c|0)==1){break $}vb(b);v[22708]=0;b=Q(70,e+208|0,6706)|0;c=v[22708];v[22708]=0;if((c|0)==1){break _}v[22708]=0;Jr(a+906380|0,b);c=v[22708];v[22708]=0;if((c|0)==1){break Z}vb(b);v[22708]=0;b=Q(70,e+208|0,6698)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Y}v[22708]=0;Nv(a+906508|0,b);d=v[22708];v[22708]=0;c=1;if((d|0)==1){break X}vb(b);break r}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break m}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}c=0}if(x[a+480188>>1]){b=0;while(1){v[22708]=0;du(a,b&65535);d=v[22708];v[22708]=0;if((d|0)==1){break p}d=(b<<5)+a|0;u[d+480284>>1]=b<<8&256;if(c){t[d+480288|0]=1}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}v[22708]=0;b=Q(2,e+208|0,9351)|0;c=v[22708];v[22708]=0;kb:{lb:{mb:{nb:{if((c|0)!=1){Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,e+208|0,9553)|0;c=v[22708];v[22708]=0;if((c|0)==1){break nb}Eb(a+1298316|0,b);vb(b);if(aa){break lb}v[22708]=0;b=Q(2,e+208|0,9351)|0;c=v[22708];v[22708]=0;if((c|0)==1){break mb}break kb}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}if(dh(o)>>>0<=128){v[22708]=0;b=Q(2,e+208|0,6455)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break kb}a=P()|0;O()|0;break n}v[22708]=0;b=Q(2,e+208|0,11991)|0;c=v[22708];v[22708]=0;if((c|0)==1){break o}}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;HB(r);IT(j);HT(k);f=1}Pu(o);ci(F);Ou(H);Ru(E);break c}a=P()|0;O()|0;break n}a=P()|0;O()|0}HB(r)}IT(j);HT(k);break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}v[22708]=0;h=j&65535;j=W(925,a|0,h|0,c|0)|0;k=v[22708];v[22708]=0;ob:{pb:{qb:{rb:{if((k|0)==1){break rb}if(j){break ob}v[22708]=0;j=fa(926,a|0,h|0,c|0,0,0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break rb}if(j){break ob}v[22708]=0;j=ca(927,a|0,h|0,c|0,0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break rb}if(j){break ob}v[22708]=0;c=Q(928,(B(h,104)+a|0)+484380|0,c|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break rb}if(c){break ob}v[22708]=0;c=Q(2,e+104|0,13261)|0;j=v[22708];v[22708]=0;if((j|0)==1){break qb}v[22708]=0;U(560,a|0,2,c|0);j=v[22708];v[22708]=0;if((j|0)==1){break pb}vb(c);break ob}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}sb:{tb:{ub:{j=B(h,104)+a|0;if(w[j+484414|0]&64){if(fi(a)){break ub}}if(dh(o)>>>0<=h>>>0){break tb}if(w[Rl(o,h)+132|0]!=2){break tb}if(!fi(a)){break tb}u[i>>1]=x[i>>1]+1;break tb}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22708]=0;h=j+484380|0;k=B(c&65535,104)+a|0;ca(929,h|0,k+484380|0,h|0,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break sb}v[22708]=0;c=Q(70,e+104|0,3377)|0;h=v[22708];v[22708]=0;if((h|0)==1){break i}v[22708]=0;Q(303,k+484423|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break h}vb(c);v[22708]=0;c=Q(70,e+104|0,3280)|0;h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;Q(303,j+484423|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break f}vb(c)}xb(e+208|0);gc(d);p=0;continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(c)}xb(e+208|0)}gc(d);break a}gb=e+480|0;return f|0}a=P()|0;O()|0}Pu(o);ci(F);Ou(H);Ru(E);S(a|0);L()}function tna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0;d=gb-928|0;gb=d;vc(b);a:{if(!jW(b,d+872|0)){break a}if(!lW(d+872|0)){break a}if(!Pb(b,Qc(kW(d+872|0),jb))){break a}if(!c){e=1;break a}Hd(a,8);Ag(a);j=w[d+872|3]-48|0;t[d+871|0]=j;Zc(b,Yb(w[d+880|0]|w[d+881|0]<<8|(w[d+882|0]<<16|w[d+883|0]<<24)));g=d+560|0;Td(g,b,504);N=jc(d+848|0,g);xb(g);v[22708]=0;R(689,b|0,g|0);g=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((g|0)!=1){if(w[d+843|0]>63){break b}if(Ib(w[d+560|0]|w[d+561|0]<<8)<<16>>16<0){break b}Qb(d+480|0,0,80);o:{if(!Yb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24))){break o}g=Yb(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24));v[22708]=0;g=Q(190,b|0,g|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){if(!g){break o}v[22708]=0;R(690,b|0,d+480|0);g=v[22708];v[22708]=0;if((g|0)!=1){break o}}f=P()|0;O()|0;break e}v[22708]=0;U(691,d+472|0,b|0,j&255);g=v[22708];v[22708]=0;if((g|0)!=1){g=d+472|0;V=Ve(g);g=x[g>>1];if((g-1&65535)>>>0>126){break b}u[a+480188>>1]=g;J=dd(d+456|0);p:{if(Yb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24))){g=Yb(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24));v[22708]=0;Q(190,b|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){g=w[d+843|0];v[22708]=0;U(692,b|0,J|0,g|0);g=v[22708];v[22708]=0;if((g|0)!=1){break p}}f=P()|0;O()|0;break f}e=0;if(w[d+843|0]){break c}}g=w[d+843|0];u[a+480192>>1]=g;u[a+480190>>1]=g;e=1;X=1;if((j&255)>>>0>=2){X=t[d+824|0]>-1;g=x[a+480192>>1]}if(g&65535){F=c&2;G=!X;g=d- -64|0;l=g|2;H=g|7;K=g|6;q=g|5;r=g|4;h=d+24|4;p=1;o=1;while(1){v[22708]=0;s=o&65535;g=W(376,a|0,p&65535,s|0)|0;j=v[22708];v[22708]=0;q:{r:{if((j|0)!=1){if(!g){break d}i=v[((e<<2)+a|0)+900380>>2];u[d+28>>1]=0;v[d+24>>2]=0;v[22708]=0;E=T(215,d+144|0)|0;g=v[22708];v[22708]=0;s:{t:{u:{v:{if((g|0)!=1){j=e-1|0;g=Lb(J,j);w:{if(!Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break w}g=Lb(J,j);g=Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[22708]=0;g=Q(190,b|0,g|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break g}if(!g){break w}v[22708]=0;R(693,b|0,d+24|0);g=v[22708];v[22708]=0;if((g|0)==1){break g}g=Yb(w[d+24|0]|w[d+25|0]<<8|(w[d+26|0]<<16|w[d+27|0]<<24));v[22708]=0;U(288,d+432|0,b|0,g|0);g=v[22708];v[22708]=0;if((g|0)==1){break g}g=d- -64|0;j=d+432|0;Vc(E,jc(g,j));xb(g);xb(j)}j=Ib(w[h|0]|w[h+1|0]<<8);g=Ib(w[h|0]|w[h+1|0]<<8)&15;n=j<<16>>16;if((n|0)>-1){break v}v[22708]=0;qr(i,0);j=v[22708];v[22708]=0;ba=1;if((j|0)!=1){break u}break g}f=P()|0;O()|0;break f}if(g>>>0>6){break u}j=w[g+28918|0];if(!g){g=j;break r}u[a+480190>>1]=(x[a+480190>>1]+j|0)-1;g=i+108|0;m=i+236|0;C=j-2|0;f=4;while(1){k=B(f,12);e=(C<<3)+f|0;D=e+28972|0;z=w[e+28924|0]+o|0;e=0;while(1){A=e+k|0;la=wd(m,A),ma=z,u[la>>1]=ma;A=lc(g,A);t[A|0]=w[A|0]+w[D|0];e=e+1|0;if((e|0)!=12){continue}break}k=1;f=f+1|0;if((f|0)!=10){continue}break}g=j;break t}j=1;if((g|0)!=7){g=1;break r}k=0;v[22708]=0;BS(i,-24);j=v[22708];v[22708]=0;g=1;if((j|0)==1){break s}j=1}C=1;break q}break g}f=P()|0;O()|0;break f}k=0;if(G|(n|0)<0){break q}m=i+108|0;f=7;while(1){D=B(f,12);z=B(f,-12)+72|0;e=0;while(1){A=lc(m,e+D|0);t[A|0]=z+w[A|0];e=e+1|0;if((e|0)!=12){continue}break}f=f+1|0;if((f|0)!=10){continue}break}}v[22708]=0;R(696,N|0,d- -64|0);e=v[22708];v[22708]=0;x:{if((e|0)!=1){if(!(!w[r|0]|w[r|0]>16)){t[i+31|0]=w[r|0];C=1}if(!(!w[q|0]|w[q|0]>128)){t[i+30|0]=w[q|0]}e=0;f=0;if(!g){break x}y:{while(1){z:{v[22708]=0;e=B(e+s|0,104)+a|0;R(424,e+484380|0,8);i=v[22708];v[22708]=0;if((i|0)==1){break z}t[d+432|0]=w[K|0];v[22708]=0;t[d+400|0]=64;i=ac(d+432|0,d+400|0);m=v[22708];v[22708]=0;if((m|0)==1){break y}u[e+484410>>1]=w[i|0]<<2;t[e+484416|0]=w[H|0];f=f+1|0;e=f&65535;if(g>>>0>e>>>0){continue}break x}break}break g}break g}break g}A:{if(!F|(n|0)<0){break A}n=Rc(d+432|0,8,1,1,0);D=Ib(w[l|0]|w[l+1|0]<<8);e=d- -64|0;f=Ib(w[e|0]|w[e+1|0]<<8);i=Ib(w[l|0]|w[l+1|0]<<8);v[22708]=0;e=T(195,d+144|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break g}if(Ib(w[h|0]|w[h+1|0]<<8)&16){Yi(n,16);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&32){Ap(n,3);e=e>>>1|0}if(Ib(w[h|0]|w[h+1|0]<<8)&64){Cf(n,2)}e=k?(e>>>0)/((-1<<g^-1)>>>0)|0:e;if(!g){break A}i=f+i|0;k=0;m=0;while(1){k=B(k+s|0,104)+a|0;z=k+484380|0;v[z>>2]=e;v[22708]=0;W(329,n|0,z|0,E|0)|0;z=v[22708];v[22708]=0;if((z|0)==1){break g}f=f<<1;i=i<<1;if(D>>>0>=2){v[k+484388>>2]=i;v[k+484384>>2]=f;k=k+484414|0;u[k>>1]=x[k>>1]|2}e=e<<1;m=m+1|0;k=m&65535;if(k>>>0<g>>>0){continue}break}}o=j+o|0;xb(d+144|0);p=p+1|0;e=p&65535;if(e>>>0<=x[a+480192>>1]){continue}break}}g=d+480|4;B:{if(!Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))){break B}if(!Ib(w[d+488|0]|w[d+489|0]<<8)){break B}g=Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));v[22708]=0;g=Q(190,b|0,g|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break h}if(!g){break B}la=d,ma=Ib(w[d+488|0]|w[d+489|0]<<8),u[la+144>>1]=ma;g=w[d+843|0];v[22708]=0;u[d+64>>1]=g;g=Pc(d+144|0,d- -64|0);j=v[22708];v[22708]=0;if((j|0)==1){break i}l=x[g>>1];h=Ib(w[d+490|0]|w[d+491|0]<<8);if(!l){break B}g=d+144|0;i=g|5;m=g|3;k=g|1;j=d+72|0;p=d- -64|4;o=h>>>0<19;q=h>>>0<21;r=h>>>0<15;f=0;while(1){v[22708]=0;U(697,b|0,d+144|0,h|0);g=v[22708];v[22708]=0;C:{D:{E:{if((g|0)!=1){f=f+1|0;g=v[((f<<2)+a|0)+900380>>2];if(!w[d+144|0]){break C}s=rr(d- -64|0,0,64);rr(p,w[d+144|0]-1&65535,64);C=w[d+144|0];rr(j,C+(w[k|0]?64/w[k|0]|0:0)|0,0);v[d+428>>2]=3;v[d+424>>2]=s;v[22708]=0;e=v[d+428>>2];v[d>>2]=v[d+424>>2];v[d+4>>2]=e;e=g+48|0;R(698,e|0,d|0);n=v[22708];v[22708]=0;if((n|0)==1){break E}if(w[d+144|0]!=1){break D}la=d,ma=Vb(e),v[la+64>>2]=ma;Gd(d+416|0,d- -64|0);v[22708]=0;R(699,e|0,v[d+416>>2]);e=v[22708];v[22708]=0;if((e|0)!=1){break D}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}v[g>>2]=w[k|0]?w[k|0]<<9:32767;C=1;t[g+60|0]=w[g+60|0]|1}F:{if(o){break F}v[g+4>>2]=w[d+162|0]+1>>>1;if(q){break F}u[g+28>>1]=w[d+164|0]|w[d+165|0]<<8}g=B(x[wd(g+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[m|0]<<4;G:{H:{if(!r){la=g+484384|0,ma=Yb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24)),v[la>>2]=ma;la=g+484388|0,ma=Yb(w[d+154|0]|w[d+155|0]<<8|(w[d+156|0]<<16|w[d+157|0]<<24))+Yb(w[d+158|0]|w[d+159|0]<<8|(w[d+160|0]<<16|w[d+161|0]<<24))|0,v[la>>2]=ma;break H}if(h>>>0<6){break G}}if(t[i|0]&1){e=g+484414|0;u[e>>1]=x[e>>1]|2}if(w[i|0]&8){e=g+484414|0;u[e>>1]=x[e>>1]|6}if(!(w[i|0]&4)){break G}u[g+484412>>1]=0}if((f|0)!=(l|0)){continue}break}}if(!Yb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24))){break j}if(!Ib(w[d+504|0]|w[d+505|0]<<8)){break j}g=Yb(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24));v[22708]=0;g=Q(190,b|0,g|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break h}if(!g){break j}la=d,ma=Ib(w[d+504|0]|w[d+505|0]<<8),u[la+144>>1]=ma;g=w[d+843|0];v[22708]=0;u[d+64>>1]=g;g=Pc(d+144|0,d- -64|0);j=v[22708];v[22708]=0;if((j|0)!=1){e=x[g>>1];f=Ib(w[d+506|0]|w[d+507|0]<<8);if(!e){break j}k=0;I:while(1){J:{v[22708]=0;U(700,b|0,d+144|0,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break k}v[22708]=0;ZC(d+432|0,2,d+144|0);g=v[22708];v[22708]=0;if((g|0)==1){break l}v[22708]=0;R(324,d- -64|0,d+432|0);g=v[22708];v[22708]=0;if((g|0)==1){break l}k=k+1|0;h=((k<<2)+a|0)+900380|0;g=v[h>>2];v[22708]=0;Q(301,g+492|0,d- -64|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break m}g=d- -64|0;vb(g);j=v[h>>2];v[22708]=0;R(702,g|0,j|0);g=v[22708];v[22708]=0;if((g|0)==1){break n}g=d- -64|0;la=d,ma=pr(g),v[la+432>>2]=ma;la=d,ma=Eh(g),v[la+24>>2]=ma;while(1){v[22708]=0;g=Gb(d+432|0,d+24|0);j=v[22708];v[22708]=0;K:{if((j|0)!=1){if(g){break K}or(d- -64|0);if((e|0)!=(k|0)){continue I}break j}break J}v[22708]=0;g=Wl(d+432|0);j=v[22708];v[22708]=0;if((j|0)!=1){j=(x[g>>1]<<5)+a|0;i=j+946328|0;g=v[h>>2];l=v[g+520>>2];v[i>>2]=v[g+516>>2];v[i+4>>2]=l;l=v[g+512>>2];i=j+946320|0;v[i>>2]=v[g+508>>2];v[i+4>>2]=l;l=v[g+504>>2];i=j+946312|0;v[i>>2]=v[g+500>>2];v[i+4>>2]=l;i=v[g+496>>2];j=j+946304|0;v[j>>2]=v[g+492>>2];v[j+4>>2]=i;Tj(d+432|0);continue}break}}break}f=P()|0;O()|0;or(d- -64|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d- -64|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}g=0;v[22708]=0;Vo(a+901404|0);j=v[22708];v[22708]=0;if((j|0)==1){break h}t[a+901696|0]=w[2040];j=a+901692|0;e=w[2036]|w[2037]<<8|(w[2038]<<16|w[2039]<<24);t[j|0]=e;t[j+1|0]=e>>>8;t[j+2|0]=e>>>16;t[j+3|0]=e>>>24;vc(b);K=a+484360|0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{if(!w[V|0]){break T}da=c&1;s=a+484344|0;E=a+1298292|0;z=a+1298268|0;c=d+144|0;ea=c|1;l=c|4;c=d+48|0;j=c|4;F=c|2;fa=c|3;q=d+560|2;while(1){U:{v[22708]=0;Y(705,b|0,d+872|0,d+480|0,d+560|0);c=v[22708];v[22708]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((c|0)==1){break ja}c=Z&255;if(c){v[22708]=0;e=T(417,K|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break ja}if((e|0)==255){break d}}n=Sj(K,c);r=Ik(d+400|0);$l(n);m=w[d+871|0];if(m>>>0>1){break ha}if(Ib(w[q|0]|w[q+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break ga}c=d+144|0;hW(c,d+560|0);e=Ib(w[q|0]|w[q+1|0]<<8);v[22708]=0;U(706,n|0,c|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){break fa}la=d,ma=Vb(n),v[la+144>>2]=ma;la=d,ma=Zb(n),v[la+64>>2]=ma;if(Gb(d+144|0,d- -64|0)){break ia}break X}f=P()|0;O()|0;break f}while(1){c=d+144|0;e=v[c>>2];u[e>>1]=x[e>>1]+g;nf(c);if(Gb(c,d- -64|0)){continue}break}break X}hW(d+144|0,d+560|0);if(!Ib(w[d+156|0]|w[d+157|0]<<8)){break ga}if(Ib(w[d+156|0]|w[d+157|0]<<8)>>>0>64|x[a+480188>>1]>64){break ga}k=Yb(w[d+164|0]|w[d+165|0]<<8|(w[d+166|0]<<16|w[d+167|0]<<24));ka:{if(Ib(w[d+168|0]|w[d+169|0]<<8)){la=d,ma=Ib(w[d+168|0]|w[d+169|0]<<8),u[la+64>>1]=ma;v[22708]=0;u[d+432>>1]=800;c=Pc(d- -64|0,d+432|0);e=v[22708];v[22708]=0;if((e|0)==1){break ka}c=Qc(((x[c>>1]<<5)+50>>>0)/100|0,0)}else{c=32}e=Yb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22708]=0;h=Q(190,b|0,e|0)|0;e=v[22708];v[22708]=0;la:{if((e|0)==1){break la}e=0;ma:{na:{oa:{pa:{qa:{if(h&x[a+480188>>1]!=0){while(1){v[22708]=0;h=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break qa}t[d+64|0]=h;v[22708]=0;t[d+432|0]=64;h=ac(d- -64|0,d+432|0);f=v[22708];v[22708]=0;if((f|0)==1){break pa}u[((e<<5)+a|0)+480286>>1]=w[h|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}if(!Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break na}e=Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break la}if(!e){break na}e=0;if(!x[a+480188>>1]){break ma}while(1){v[22708]=0;h=T(707,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break oa}la=((e<<5)+a|0)+480284|0,ma=(Mb(h,-16,16)<<3)+128|0,u[la>>1]=ma;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break ma}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}v[22708]=0;yh(a,1);e=v[22708];v[22708]=0;if((e|0)==1){break la}}h=dd(d+128|0);e=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[22708]=0;f=Q(190,b|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ea}i=1;e=0;if(!f){break Y}f=Ib(w[q|0]|w[q+1|0]<<8);v[22708]=0;f=Q(191,b|0,f<<1)|0;p=v[22708];v[22708]=0;if((p|0)==1){break ea}if(!f){break Y}f=Ib(w[q|0]|w[q+1|0]<<8);v[22708]=0;f=W(708,b|0,h|0,f|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break ea}if(!f){break Y}la=d,ma=Vb(h),v[la+120>>2]=ma;la=d,ma=Zb(h),v[la+112>>2]=ma;if(!Gb(d+120|0,d+112|0)){break Z}while(1){e=v[d+120>>2];e=Ib(w[e|0]|w[e+1|0]<<8);ra:{if(Ib(w[d+158|0]|w[d+159|0]<<8)>>>0<e>>>0){break ra}f=Yb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[22708]=0;Q(190,b|0,f+(e<<2)|0)|0;e=v[22708];v[22708]=0;sa:{ta:{ua:{if((e|0)==1){break ua}v[22708]=0;e=T(426,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ua}v[22708]=0;e=Q(190,b|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ua}if(!e){break ra}v[22708]=0;e=Q(191,b|0,42)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ua}if(!e){break ra}v[22708]=0;R(709,b|0,d- -64|0);e=v[22708];v[22708]=0;va:{if((e|0)!=1){if(cd(n)){break va}v[22708]=0;R(710,n|0,65534);e=v[22708];v[22708]=0;if((e|0)!=1){break va}}f=P()|0;O()|0;break _}e=Ib(w[d+104|0]|w[d+105|0]<<8);v[22708]=0;v[d+60>>2]=e;e=Q(191,b|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ta}if(!e){v[22708]=0;e=T(467,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ta}qc(d+60|0,e)}qc(d+60|0,65534);f=tc(n);v[22708]=0;R(711,n|0,f+v[d+60>>2]|0);e=v[22708];v[22708]=0;if((e|0)==1){break $}e=0;if(!v[d+60>>2]){break sa}while(1){wa:{v[22708]=0;i=T(416,b|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break wa}i=i<<16>>16;if((i|0)>=0){v[22708]=0;R(710,n|0,g+i&65535);i=v[22708];v[22708]=0;if((i|0)==1){break wa}}e=e+1|0;if(e>>>0<y[d+60>>2]){continue}break sa}break}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}if(w[d+64|0]){v[22708]=0;R(712,d+48|0,d- -64|0);e=v[22708];v[22708]=0;xa:{if((e|0)!=1){v[22708]=0;R(713,d+24|0,d+48|0);e=v[22708];v[22708]=0;if((e|0)!=1){break xa}}f=P()|0;O()|0;break _}v[22708]=0;U(13,d+432|0,2,d+24|0);e=v[22708];v[22708]=0;if((e|0)==1){break ba}v[22708]=0;R(418,n|0,d+432|0);e=v[22708];v[22708]=0;if((e|0)==1){break ca}vb(d+432|0);vb(d+24|0)}if(!Yb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24))){break ra}e=Yb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break $}if(!e){break ra}while(1){ya:{v[22708]=0;e=Q(714,b|0,d+48|0)|0;i=v[22708];v[22708]=0;za:{Aa:{if((i|0)!=1){if(!e){break ra}e=w[fa|0];v[22708]=0;U(288,d+24|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break Aa}e=d+24|0;i=jc(d+432|0,e);xb(e);la=d,ma=Lv(Ib(w[d+48|0]|w[d+49|0]<<8)+f|0),u[la+24>>1]=ma;if((Ib(w[d+48|0]|w[d+49|0]<<8)|0)==65535){break ya}e=x[d+24>>1];if(tc(n)>>>0>e>>>0){break za}xb(d+432|0);break ra}f=P()|0;O()|0;break _}f=P()|0;O()|0;break _}Ba:{if(w[F|0]==1){e=65535}else{if(w[F|0]!=2){break Ba}v[22708]=0;e=T(416,i|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break da}v[22708]=0;i=Q(715,r|0,d+24|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break da}u[i>>1]=e;e=65534}la=sc(n,x[d+24>>1]),ma=e,u[la>>1]=ma}xb(d+432|0);continue}break}xb(d+432|0)}e=d+120|0;Pv(e);if(Gb(e,d+112|0)){continue}break}break Z}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}nr(r);break d}f=P()|0;O()|0;break L}f=P()|0;O()|0;break _}f=P()|0;O()|0;xb(d+432|0);break _}f=P()|0;O()|0;vb(d+432|0);break aa}f=P()|0;O()|0}vb(d+24|0);break _}f=P()|0;O()|0}Mv(h);break L}i=0;e=1}Mv(h);if(e){k=c>>>(k>>>1&1)|0;break W}nr(r);if(!i){break d}break V}v[22708]=0;yh(a,1);c=v[22708];v[22708]=0;Ca:{if((c|0)!=1){e=0;k=32;if(!x[a+480188>>1]){break W}while(1){t[d+144|0]=w[(d+e|0)+826|0];v[22708]=0;t[d+64|0]=64;c=ac(d+144|0,d- -64|0);h=v[22708];v[22708]=0;if((h|0)==1){break Ca}u[((e<<5)+a|0)+480286>>1]=w[c|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break W}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}e=w[d+823|0];A=w[d+823|0]&64;D=w[d+824|0]&32;G=(w[d+824|0]&31)+1|0;la=a,ma=eW(Ib(w[d+820|0]|w[d+821|0]<<8),A>>>6|0,D>>>5|0,G),v[la+480204>>2]=ma;la=a,ma=Fd(w[d+825|0],1,32),v[la+480196>>2]=ma;if(D){v[a+480216>>2]=G;v[a+480220>>2]=G<<2}Da:{Ea:{if(w[d+842|0]){t[d+144|0]=w[d+842|0];v[22708]=0;t[d+64|0]=64;c=ac(d+144|0,d- -64|0);h=v[22708];v[22708]=0;if((h|0)==1){break Ea}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=k;v[a+480232>>2]=k;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+823|0]>>>4^-1)&2;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!Yb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24))){break Qa}c=Yb(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24));v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Pa}if(!c){break Qa}c=Yb(w[d+528|0]|w[d+529|0]<<8|(w[d+530|0]<<16|w[d+531|0]<<24));v[22708]=0;W(413,b|0,z|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Pa}if(w[V|0]<2){break Qa}v[22708]=0;U(13,d+144|0,2,z|0);c=v[22708];v[22708]=0;if((c|0)==1){break Oa}v[22708]=0;R(418,n|0,d+144|0);c=v[22708];v[22708]=0;if((c|0)==1){break Na}vb(d+144|0)}Ra:{if(Yb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))>>>0<2){break Ra}c=Yb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24));v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Pa}if(!c){break Ra}c=Yb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24));v[22708]=0;ca(509,E|0,b|0,c-1|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Pa}}if(!Yb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24))){break Da}c=Yb(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24));v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Pa}if(!c){break Da}v[22708]=0;c=Q(191,b|0,12)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Pa}if(!c){break Da}v[22708]=0;Q(318,b|0,6)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Pa}v[22708]=0;c=T(416,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Pa}if((c|0)!=1){break Da}v[22708]=0;c=T(426,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break La}if(!c){break Da}v[22708]=0;h=Q(191,b|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break La}if(h){break Ma}break Da}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}f=P()|0;O()|0;vb(d+144|0);break L}Dc(d+144|0,E);v[22708]=0;ca(509,E|0,b|0,c|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ga}if(!gd(d+144|0)){v[22708]=0;c=W(716,d+432|0,2,13)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Ka}v[22708]=0;U(717,d- -64|0,d+144|0,c|0);h=v[22708];v[22708]=0;if((h|0)==1){break Ja}v[22708]=0;U(718,d+8|0,d- -64|0,E|0);h=v[22708];v[22708]=0;if((h|0)==1){break Ia}h=d+8|0;Eb(E,h);vb(h);vb(d- -64|0);vb(c)}vb(d+144|0);break Da}f=P()|0;O()|0;break L}f=P()|0;O()|0;break Fa}f=P()|0;O()|0;break Ha}f=P()|0;O()|0;vb(d- -64|0)}vb(c);break Fa}f=P()|0;O()|0}vb(d+144|0);break L}f=P()|0;O()|0;break L}Sa:{if(m>>>0<2){break Sa}if(!Yb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24))){break Sa}i=0;if(!x[a+480188>>1]){break Sa}while(1){c=Yb(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24));v[22708]=0;c=Q(190,b|0,c+(i<<2)|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break M}Ta:{if(!c){break Ta}v[22708]=0;c=T(426,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break M}v[22708]=0;c=Q(190,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break M}k=0;m=0;if(!c){break Ta}while(1){Ua:{v[22708]=0;c=Q(191,b|0,8)|0;h=v[22708];v[22708]=0;Va:{Wa:{Xa:{if((h|0)!=1){if(!c){break Ua}v[22708]=0;R(719,b|0,d+144|0);c=v[22708];v[22708]=0;if((c|0)==1){break Xa}if(!Yb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))){break Ua}switch((Yb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))&536870911)-1|0){case 1:break Va;case 0:break Wa;default:continue}}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}k=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}m=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}break}if(!k|!m){break Ta}v[22708]=0;c=Q(190,b|0,k|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break N}if(!c){break Ta}v[22708]=0;W(571,b|0,((i<<5)+a|0)+480289|0,m|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break N}}i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}}m=Ib(w[d+560|0]|w[d+561|0]<<8);v[22708]=0;c=g+m|0;R(330,s|0,c&65535);h=v[22708];v[22708]=0;if((h|0)==1){break S}if(m){ga=e&16;ia=g&65535;k=0;while(1){Ya:{if(!da){break Ya}e=Yb(w[d+888|0]|w[d+889|0]<<8|(w[d+890|0]<<16|w[d+891|0]<<24));v[22708]=0;e=Q(190,b|0,e+(k<<2)|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Q}if(!e){break Ya}v[22708]=0;e=T(426,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Q}v[22708]=0;e=Q(190,b|0,e|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Q}if(!e){break Ya}H=Kb(d+128|0);v[22708]=0;$=T(215,d- -64|0)|0;e=v[22708];v[22708]=0;Za:{_a:{if((e|0)!=1){h=w[d+871|0];if(h){break _a}v[22708]=0;R(720,b|0,d+144|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}u[d+120>>1]=w[d+144|0];p=w[ea|0]+1|0;e=48;break Za}f=P()|0;O()|0;break O}f=t[d+822|0];v[22708]=0;R(721,b|0,d+48|0);e=v[22708];v[22708]=0;$a:{ab:{if((e|0)!=1){la=d,ma=Ib(w[d+48|0]|w[d+49|0]<<8),u[la+120>>1]=ma;p=Ib(w[F|0]|w[F+1|0]<<8)+1|0;e=j;if(!Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break $a}i=v[b+8>>2];e=Yb(w[j|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22708]=0;Q(190,b|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break P}v[22708]=0;R(722,b|0,d+144|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}e=Yb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}if(!e){break ab}e=Yb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22708]=0;W(413,b|0,H|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break ab}break P}break P}bb:{if(!Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24))){break bb}e=Yb(w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24));v[22708]=0;e=Q(190,b|0,e|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}if(!e){break bb}v[22708]=0;e=T(426,b|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}v[22708]=0;e=Q(190,b|0,e|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break P}if(!e){break bb}v[22708]=0;U(288,d+24|0,b|0,B(x[d+120>>1],p)|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}e=d+432|0;o=d+24|0;Vc($,jc(e,o));xb(e);xb(o)}v[22708]=0;Q(190,b|0,i|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break P}}e=f+(h>>>0<3?48:24)|0}v[22708]=0;f=k+ia|0;i=W(331,s|0,f&65535,p|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}h=e;if(i){aa=_b(s,f);v[22708]=0;Q(428,aa|0,H|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break P}yg(d+120|0,x[a+480188>>1]);o=0;while(1){v[22708]=0;e=Xc(aa,o,0);f=v[22708];v[22708]=0;cb:{db:{if((f|0)!=1){i=0;if(x[d+120>>1]){break db}break cb}break P}while(1){eb:{if(!w[d+871|0]){v[22708]=0;R(723,d+144|0,b|0);f=v[22708];v[22708]=0;if((f|0)!=1){f=d+144|0;I=qd(f);_=Ve(f);f=w[f|0];t[e+1|0]=f>>>3&16|w[I|0]>>>4|f>>>1&32;t[e+3|0]=w[I|0]&15;t[e+5|0]=w[_|0];f=f&63;f=f?f+h|0:0;break eb}break P}v[22708]=0;R(531,d+144|0,b|0);f=v[22708];v[22708]=0;fb:{gb:{if((f|0)!=1){f=d+144|0;I=qd(f);_=Ve(f);ja=ej(f);v[22708]=0;M=T(374,$|0)|0;ka=v[22708];v[22708]=0;if((ka|0)==1){break P}t[e+4|0]=M;M=w[f|0];f=M&127;if(!f){break gb}f=f+h|0;break fb}break P}f=0;if((M|0)!=128){break fb}t[e|0]=254}t[e+1|0]=w[I|0]&63;t[e+3|0]=w[_|0];t[e+5|0]=w[ja|0]}if(f-1>>>0<=119){t[e|0]=f}v[22708]=0;ha(724,e|0,(A|0)!=0|0,(D|0)!=0|0,G|0,(ga|0)!=0|0);I=v[22708];v[22708]=0;if((I|0)!=1){C=(f|0)>84&X|C;e=e+6|0;i=i+1|0;if(x[d+120>>1]<=(i&65535)>>>0){break cb}continue}break}break P}o=o+1|0;if((p|0)!=(o|0)){continue}break}}xb(d- -64|0);vb(H)}k=k+1|0;if((m|0)!=(k|0)){continue}break}}la=d,ma=pr(r),v[la+64>>2]=ma;la=d,ma=Eh(r),v[la+432>>2]=ma;hb:{ib:{if(og(d- -64|0,d+432|0)){while(1){e=Wl(d- -64|0);c=e;h=Ve(e);jb:{kb:{lb:{e=x[e>>1];if(!e){e=0;break lb}v[22708]=0;f=Q(472,n|0,e-1&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ib}e=x[c>>1];if(!f){break lb}v[22708]=0;e=Q(545,n|0,e-1&65535)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break kb}break ib}if(x[h>>1]==((e&65535)+1|0)){break jb}v[22708]=0;e=W(544,s|0,1,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ib}if((e|0)==65535){break jb}la=sc(n,x[c>>1]),ma=e,u[la>>1]=ma}c=_b(s,e);h=Dv(x[h>>1]);v[22708]=0;h=Ce(d+144|0,12,h);f=v[22708];v[22708]=0;if((f|0)==1){break hb}h=pp(Ue(h,v[_b(s,e)+12>>2]-1|0));v[22708]=0;Q(431,c|0,h|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break hb}m=(m&65535)>>>0>e>>>0?m:e+1|0}c=d- -64|0;Tj(c);if(og(c,d+432|0)){continue}break}c=g+m|0}if(!Yb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))){break U}g=Yb(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24));v[22708]=0;g=Q(190,b|0,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break S}if(!g){break U}nr(r);g=c;break V}f=P()|0;O()|0;break L}f=P()|0;O()|0;break L}Z=Z+1|0;if(w[V|0]>(Z&255)>>>0){continue}break T}break}nr(r)}v[22708]=0;Ri(K,0);b=v[22708];v[22708]=0;if((b|0)==1){break R}if(!(C&1)){i=x[a+480192>>1];if(i){e=1;while(1){b=(((e&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Xb(nv(c));i=x[a+480192>>1]}v[b>>2]=0;e=e+1|0;if((e&65535)>>>0<=(i&65535)>>>0){continue}break}}u[a+480192>>1]=0}mb:{nb:{ob:{pb:{qb:{rb:{sb:{if(ba){v[22708]=0;b=Q(2,d+144|0,13461)|0;c=v[22708];v[22708]=0;if((c|0)==1){break sb}v[22708]=0;U(560,a|0,2,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break rb}vb(b)}f=18720;switch(w[d+871|0]){case 3:break nb;case 2:break ob;case 1:break pb;case 0:break qb;default:break mb}}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(b);break f}f=x[a+480188>>1]>4?14333:14319;break mb}f=14301;break mb}f=14283;break mb}f=14256}v[22708]=0;R(725,d- -64|0,13871);b=v[22708];v[22708]=0;tb:{ub:{vb:{if((b|0)!=1){v[22708]=0;U(726,d+144|0,d- -64|0,d+871|0);b=v[22708];v[22708]=0;if((b|0)==1){break vb}b=d+144|0;Eb(a+1298304|0,b);vb(b);Hb(d- -64|0);v[22708]=0;b=Q(2,b|0,9947)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ub}Eb(a+1298316|0,b);vb(b);v[22708]=0;Q(157,a+1298328|0,f|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break tb}v[a+1298364>>2]=2;e=1;break c}f=P()|0;O()|0;break f}f=P()|0;O()|0;Hb(d- -64|0);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break L}f=P()|0;O()|0;break f}f=P()|0;O()|0;break L}f=P()|0;O()|0;xb(d- -64|0)}vb(H);break L}f=P()|0;O()|0;break L}f=P()|0;O()|0}nr(r);break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;xb(d+144|0)}ci(J)}xb(N);S(f|0);L()}e=0}ci(J)}xb(N)}gb=d+928|0;return e|0}function sma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0;f=gb-1728|0;gb=f;vc(b);h=gb-32|0;gb=h;e=h+24|0;i=f+1600|0;gV(e,i);g=yb(e);e=v[h+28>>2];l=v[h+24>>2];v[h+8>>2]=l;v[h+12>>2]=e;v[h>>2]=l;v[h+4>>2]=e;l=h+16|0;e=b;cc(l,e,h);l=yb(l);if((l|0)==(g|0)){Rb(e,yb(h+24|0))}gb=h+32|0;e=(g|0)==(l|0);if(!e){fV(i)}a:{if(!e){break a}if(!jV(f+1600|0)){break a}if(!Pb(b,Qc(256,0))){break a}b:{if(!c){break b}Hd(a,1048576);Ag(a);d=gb-16|0;gb=d;e=Tb(d,1339);Dc(f+1344|0,e);vb(e);gb=d+16|0;q=f+1608|0;v[f+160>>2]=w[q+1|0];d=w[q|0];v[22708]=0;v[f+16>>2]=d;R(599,f+88|0,f+16|0);d=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){v[22708]=0;Y(582,f+240|0,f+1344|0,f+160|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break o}d=f+240|0;Eb(a+1298304|0,d);vb(d);e=f+88|0;vb(e);h=f+1344|0;Hb(h);g=Tb(d,12318);Eb(a+1298316|0,g);vb(g);Ke(e,2,f+1610|0);Bc(h,e);v[22708]=0;U(13,d|0,8,h|0);d=v[22708];v[22708]=0;if((d|0)==1){break j}d=f+240|0;Eb(a+1298328|0,d);vb(d);e=f+1344|0;vb(e);v[a+1298364>>2]=8;Hr(e,2,f+1642|0);Bc(d,e);Eb(a+1298268|0,d);vb(d);h=f+1712|0;u[a+480188>>1]=w[h|0]|w[h+1|0]<<8;h=Fd(w[f+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=h;A=f+1722|0;u[a+480192>>1]=w[A|0]|w[A+1|0]<<8;C=f+1724|0;u[a+480190>>1]=w[C|0]|w[C+1|0]<<8;h=Fd(w[f+1717|0],1,32);v[a+480216>>2]=h;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=h<<2;jw(b,e);D=a+484360|0;m=f+1706|0;Ur(Sb(D),e,w[m|0]|w[m+1|0]<<8,65535,65535);e=f+1708|0;bf(Sb(D),w[e|0]|w[e+1|0]<<8);Td(d,b,Ng(b));I=jc(f+1320|0,d);xb(d);v[22708]=0;d=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break m}v[22708]=0;U(288,f+240|0,b|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}d=f+240|0;G=jc(f+1296|0,d);xb(d);F=x[a+480188>>1];v[22708]=0;E=Q(191,I|0,274)|0;d=v[22708];v[22708]=0;if((d|0)==1){break l}if(E){u[a+480188>>1]=x[a+480188>>1]+8}H=c&1;if(!H){break k}d=f+1710|0;d=w[d|0]|w[d+1|0]<<8;v[22708]=0;R(330,a+484344|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){break k}g=P()|0;O()|0;break e}g=P()|0;O()|0;break n}g=P()|0;O()|0;vb(f+88|0)}Hb(f+1344|0);break c}g=P()|0;O()|0;break d}g=P()|0;O()|0;break e}n=a+484344|0;o=f+1718|0;l=f+1710|0;if(!(w[l|0]|w[l+1|0]<<8)){g=0;break f}g=0;while(1){v[22708]=0;d=T(287,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}v[f+160>>2]=d;v[22708]=0;d=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}v[22708]=0;U(288,f+88|0,b|0,d+1&-2);d=v[22708];v[22708]=0;if((d|0)==1){break h}d=f+88|0;p=jc(f+240|0,d);xb(d);qc(f+160|0,1024);d=v[f+160>>2];p:{if(!d|!H){break p}v[22708]=0;d=W(331,n|0,r&65535,d|0)|0;e=v[22708];v[22708]=0;q:{if((e|0)!=1){if(!d){break p}j=0;if(t[o|0]&1){i=0;while(1){v[22708]=0;d=Q(191,f+240|0,1)|0;e=v[22708];v[22708]=0;r:{if((e|0)!=1){if(!d){break p}v[22708]=0;d=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}s=0;if((d|0)!=255){break r}v[22708]=0;s=T(374,p|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;d=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break r}}break i}break i}s:{if(!(d&127)){break s}e=_b(n,r);v[22708]=0;h=Xc(e,i,j&65535);e=v[22708];v[22708]=0;if((e|0)==1){break i}Tv(f+88|0);if(d&1){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+88|0]=e}if(d&2){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+89|0]=e}if(d&4){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+90|0]=e}if(d&8){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+91|0]=e}if(d&16){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+92|0]=e}if(d&32){v[22708]=0;e=T(374,p|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}t[f+93|0]=e}if(d&64){v[22708]=0;d=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}t[f+94|0]=d}v[22708]=0;d=Q(790,h|0,f+88|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}v[f+16>>2]=s;v[22708]=0;v[f+64>>2]=v[f+160>>2]+(i^-1);k=Fb(f+16|0,f- -64|0);e=v[22708];v[22708]=0;if((e|0)==1){break i}g=d|g;e=0;d=h;J=v[k>>2];if(!J){break s}while(1){d=B(x[a+480188>>1],6)+d|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;k=w[h+4|0]|w[h+5|0]<<8;t[d+4|0]=k;t[d+5|0]=k>>>8;e=e+1|0;if((J|0)!=(e|0)){continue}break}}i=(i+s|0)+1|0;d=v[f+160>>2];if(i>>>0>=d>>>0){while(1){j=j+1|0;i=i-d|0;if(d>>>0<=i>>>0){continue}break}}if(F>>>0>(j&65535)>>>0){continue}break}break p}e=0;if(v[f+160>>2]){break q}break p}break i}while(1){d=_b(n,r);v[22708]=0;h=Uf(d,e);d=v[22708];v[22708]=0;t:{u:{if((d|0)!=1){d=0;if(F){break u}break t}break i}while(1){v:{v[22708]=0;R(791,p|0,f+88|0);i=v[22708];v[22708]=0;if((i|0)==1){break v}v[22708]=0;i=Q(790,h+B(d,6)|0,f+88|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}g=g|i;d=d+1|0;if((F|0)!=(d|0)){continue}break t}break}break i}e=e+1|0;if(e>>>0<y[f+160>>2]){continue}break}}xb(f+240|0);r=r+1|0;if(r>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break f}g=P()|0;O()|0;vb(f+1344|0);break c}g=P()|0;O()|0;xb(f+240|0);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}d=f+1714|0;e=w[d+1|0]<<8;if(!((w[d|0]|e)>>>0<=1|(e|w[d|0])>>>0>4999)){w:{if(g&1){i=0;d=w[d|0]|w[d+1|0]<<8;d=Ac(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break w}i=2;z=2646e3/+(B(B(v[a+480216>>2],v[a+480196>>2]),w[d|0]|w[d+1|0]<<8)>>>0)*1e4;x:{if(z<4294967296&z>=0){d=~~z>>>0;break x}d=0}}t[a+480224|0]=i;v[a+480204>>2]=d}d=x[a+480188>>1];v[22708]=0;t[f+240|0]=0;p=W(792,f+1280|0,d|0,f+240|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){i=a+1298280|0;r=a+1298292|0;k=f+240|3;s=0;y:{z:{A:{B:{C:{while(1){v[22708]=0;d=Q(191,G|0,8)|0;e=v[22708];v[22708]=0;D:{if((e|0)!=1){if(d){break D}if(x[a+480188>>1]){d=0;while(1){e=t[kc(p,d)|0];E:{if((e|0)<=(d|0)|(e|0)>=x[a+480188>>1]){break E}h=((e<<5)+a|0)+480288|0;e=w[h|0];if(!e){break E}g=((d<<5)+a|0)+480288|0;i=w[g|0];if(!i){t[g|0]=e;break E}g=(B(i-1&255,160)+a|0)+906300|0;if((Vk(g)|0)!=255){while(1){g=(B(Vk(g),160)+a|0)+906300|0;if((Vk(g)|0)!=255){continue}break}}e=g+28|0;h=w[h|0]-1&255;h=h>>>0<250?h+128|0:0;t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[f+232>>2]=0;v[f+236>>2]=0;v[f+224>>2]=0;v[f+228>>2]=0;v[f+216>>2]=0;v[f+220>>2]=0;v[f+208>>2]=0;v[f+212>>2]=0;F:{G:{H:{I:{J:{K:{if(E){v[22708]=0;R(793,I|0,f+240|0);d=v[22708];v[22708]=0;L:{if((d|0)!=1){g=0;while(1){d=x[a+480192>>1];v[22708]=0;d=EO(a,d+1&65535);e=v[22708];v[22708]=0;M:{N:{O:{P:{Q:{R:{S:{if((e|0)!=1){e=g<<1;h=e+(f+224|0)|0;u[h>>1]=d;j=e+(f+208|0)|0;e=f+e|0;i=e+242|0;u[j>>1]=w[i|0]|w[i+1|0]<<8;if((d|0)==65535){break N}e=w[e+242|0]|w[e+243|0]<<8;v[22708]=0;d=W(376,a|0,d|0,e+1&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break S}if(!d){break M}v[22708]=0;R(441,f+160|0,1571);e=v[22708];v[22708]=0;if((e|0)==1){break R}v[22708]=0;v[f+16>>2]=g+1;U(795,f+88|0,f+160|0,f+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break Q}v[22708]=0;Q(301,d+492|0,f+88|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break P}vb(f+88|0);Hb(f+160|0);break M}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break O}g=P()|0;O()|0;vb(f+88|0)}Hb(f+160|0);break y}u[h>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break L}g=P()|0;O()|0;break y}e=w[f+240|0]|w[f+241|0]<<8;d=0;v[22708]=0;r=Q(328,f+16|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break F}if(w[f+240|0]|w[f+241|0]<<8){while(1){v[22708]=0;e=T(287,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break H}v[22708]=0;U(288,f+160|0,b|0,e<<5);e=v[22708];v[22708]=0;if((e|0)==1){break I}e=f+88|0;h=f+160|0;g=jc(e,h);Vc(Kg(r,d),g);xb(e);xb(h);d=d+1|0;if(d>>>0<(w[f+240|0]|w[f+241|0]<<8)>>>0){continue}break}}d=w[l|0]|w[l+1|0]<<8;h=0;v[22708]=0;j=W(796,f+88|0,d|0,33236)|0;d=v[22708];v[22708]=0;if((d|0)==1){break J}if(w[m|0]|w[m+1|0]<<8){while(1){g=f+h|0;T:{if(w[g+258|0]>=(w[f+240|0]|w[f+241|0]<<8)>>>0){break T}if(x[sc(Sb(D),h)>>1]>=(w[l|0]|w[l+1|0]<<8)>>>0){break T}e=x[sc(Sb(D),h)>>1];U:{if(x[sc(j,e)>>1]==65535){d=w[g+258|0];K=sc(j,e),M=d,u[K>>1]=M;break U}if(x[sc(j,e)>>1]==w[g+258|0]){break U}v[22708]=0;d=W(797,n|0,e|0,0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break K}if((d|0)==65535){break U}K=sc(Sb(D),h),M=d,u[K>>1]=M;e=d}v[22708]=0;d=me(n,e);i=v[22708];v[22708]=0;if((i|0)==1){break K}if(!d){break T}E=Kg(r,w[g+258|0]);vc(E);v[22708]=0;d=T(195,E|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break K}if(!v[_b(n,e)+12>>2]){break T}H=d>>>5|0;i=0;while(1){d=_b(n,e);g=x[a+480188>>1];v[22708]=0;d=Xc(d,i,g-8&65535);g=v[22708];v[22708]=0;if((g|0)==1){break K}g=0;while(1){hi(f+160|0);k=x[f+164>>1];t[d+4|0]=k;t[d+5|0]=k>>>8;k=v[f+160>>2];t[d|0]=k;t[d+1|0]=k>>>8;t[d+2|0]=k>>>16;t[d+3|0]=k>>>24;V:{if(i>>>0>=H>>>0){break V}v[22708]=0;Q(798,E|0,f+160|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break K}if(t[f+160|0]>-1){break V}t[d|0]=61;t[d+1|0]=w[(f+224|0)+(g<<1)|0];k=w[f+160|0]&31;t[f+64|0]=k;if(k){zf(f- -64|0,15);t[d+3|0]=20;t[d+5|0]=w[f+64|0]|208}t[d+2|0]=1;t[d+4|0]=w[f+161|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}i=i+1|0;if(i>>>0<y[_b(n,e)+12>>2]){continue}break}}h=h+1|0;if(h>>>0<(w[m|0]|w[m+1|0]<<8)>>>0){continue}break}}Ye(j);jd(r)}if(!(!(w[o|0]&2)|!(w[l|0]|w[l+1|0]<<8))){i=0;d=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);e=(((d&8?x[a+480188>>1]:F)&65535)+((w[q|0]|w[q+1|0]<<8)>>>0>591?s:0)|0)+(d>>>4&1)|0;while(1){d=0;W:{if(!e){break W}while(1){X:{v[22708]=0;h=Q(191,b|0,4)|0;g=v[22708];v[22708]=0;if((g|0)==1){break X}if(!h){break W}h=w[q|0]|w[q+1|0]<<8;v[22708]=0;R(799,h|0,b|0);h=v[22708];v[22708]=0;if((h|0)==1){break X}d=d+1|0;if((e|0)!=(d|0)){continue}break W}break}g=P()|0;O()|0;break y}i=i+1|0;if(i>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}}v[22708]=0;l=Q(328,f+192|0,255)|0;d=v[22708];v[22708]=0;Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){d=f+88|0;r=d|7;D=d|1;F=d|4;s=d|2;k=d|3;h=0;while(1){d=h;v[22708]=0;R(800,b|0,f+160|0);e=v[22708];v[22708]=0;ca:{da:{ea:{fa:{if((e|0)!=1){v[22708]=0;e=T(192,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break fa}h=w[q|0]|w[q+1|0]<<8;v[22708]=0;e=(e|0)==32?428:e;e=h>>>0>513?e?e+4|0:e:e;U(288,f+88|0,b|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break ea}h=d+1|0;g=f+240|0;i=f+88|0;j=jc(g,i);j=le(f+16|0,Vc(Kg(l,d),j));xb(g);xb(i);if(d>>>0>=(w[A|0]|w[A+1|0]<<8)>>>0){break ca}v[22708]=0;d=h&65535;g=W(376,a|0,d|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break da}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}if(!g){break ca}v[22708]=0;Ke(f+88|0,2,f+160|0);d=v[22708];v[22708]=0;ga:{ha:{ia:{if((d|0)==1){break ia}v[22708]=0;R(324,f+240|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break ia}v[22708]=0;Q(301,g+492|0,f+240|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ha}vb(f+240|0);if(!e){break ca}v[22708]=0;R(801,j|0,f+240|0);d=v[22708];v[22708]=0;if((d|0)==1){break $}n=0;if((w[q|0]|w[q+1|0]<<8)>>>0<513){break ga}v[22708]=0;n=T(287,j|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break ga}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;vb(f+240|0);break Z}i=3;ja:{if((w[q|0]|w[q+1|0]<<8)>>>0<514){break ja}v[22708]=0;i=T(192,j|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break ja}g=P()|0;O()|0;break Z}v[g>>2]=w[f+342|0]|w[f+343|0]<<8;t[g+16|0]=w[((w[f+344|0]|w[f+345|0]<<8)&3)+33238|0];t[g+17|0]=w[(w[f+345|0]&3)+33238|0];t[g+18|0]=w[((w[f+344|0]|w[f+345|0]<<8)>>>12&3)+33242|0];o=0;ka:{la:{ma:{na:{while(1){oa:{if(!(i&1)){break oa}v[22708]=0;R(802,j|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break na}v[22708]=0;e=ki(g,w[o+33246|0]);d=v[22708];v[22708]=0;if((d|0)==1){break ma}d=e;if((o|0)!=3){m=w[e+12|0]&-17}else{m=w[e+12|0]&-17|w[f+88|0]<<4&16}t[d+12|0]=m;t[e+12|0]=w[e+12|0]&254|t[f+88|0]&1;t[e+12|0]=w[e+12|0]&251|w[f+88|0]<<1&4;t[e+12|0]=w[e+12|0]&253|w[f+88|0]>>>1&2;t[f+64|0]=w[D|0];v[22708]=0;t[f+48|0]=16;d=ac(f- -64|0,f+48|0);m=v[22708];v[22708]=0;if((m|0)==1){break la}d=w[d|0];v[22708]=0;R(446,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break la}d=w[s|0];t[e+15|0]=d;t[e+16|0]=d;t[e+13|0]=w[k|0];t[e+14|0]=w[F|0];d=0;if(!Nb(e)){break oa}while(1){m=(f+88|0)+(d<<2)|0;E=w[m+8|0]|w[m+9|0]<<8;K=Lb(e,d),M=E,u[K>>1]=M;m=Fd(w[m+10|0]|w[m+11|0]<<8,0,64);K=Lb(e,d),M=m,t[K+2|0]=M;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}i=i>>>1|0;o=o+1|0;if((o|0)!=4){continue}break}if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}v[22708]=0;fm(g,127,1);d=v[22708];v[22708]=0;if((d|0)==1){break ba}v[22708]=0;em(g,0,1);d=v[22708];v[22708]=0;if((d|0)==1){break ba}if(!n){break ca}v[22708]=0;R(805,j|0,f+88|0);d=v[22708];v[22708]=0;if((d|0)==1){break _}if(!(n&2)){break ka}d=w[s|0]|w[s+1|0]<<8;v[22708]=0;d=AA(a,+(d>>>0));e=v[22708];v[22708]=0;if((e|0)==1){break _}v[22708]=0;fm(g,d,1);d=v[22708];v[22708]=0;if((d|0)==1){break _}d=w[F|0];v[22708]=0;em(g,d,1);d=v[22708];v[22708]=0;if((d|0)!=1){break ka}break _}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}t[g+25|0]=w[D|0]==1;if(!(n&4)){break ca}t[g+31|0]=w[r|0]+1;t[g+34|0]=w[f+96|0]+1;if(t[f+96|0]<=-1){t[g+30|0]=w[f+103|0]+1}if(w[f+100|0]){d=0;i=g+108|0;while(1){e=d+1|0;v[f+64>>2]=e+t[f+100|0];hV(f- -64|0);j=v[f+64>>2];K=lc(i,d),M=j,t[K|0]=M;d=e;if(d>>>0<128){continue}break}}v[22708]=0;qr(g,0);d=v[22708];v[22708]=0;if((d|0)==1){break _}}xb(f+16|0);if((h|0)!=255){continue}break}q=WB(f+88|0);h=f+16|4;n=WB(f+160|0);g=0;pa:{qa:{while(1){v[22708]=0;R(800,b|0,f+240|0);d=v[22708];v[22708]=0;if((d|0)==1){break pa}v[22708]=0;d=T(192,b|0)|0;e=v[22708];v[22708]=0;ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{if((e|0)!=1){v[22708]=0;U(288,f+16|0,b|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break ya}e=f+16|0;i=jc(f- -64|0,e);xb(e);if((w[C|0]|w[C+1|0]<<8)>>>0>g>>>0){v[22708]=0;Ke(f+48|0,2,f+240|0);e=v[22708];v[22708]=0;if((e|0)==1){break ra}v[22708]=0;R(324,f+16|0,f+48|0);e=v[22708];v[22708]=0;if((e|0)==1){break ra}v[22708]=0;Q(301,((g<<5)+a|0)+946336|0,f+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break xa}vb(f+16|0)}if(!d|(w[C|0]|w[C+1|0]<<8)>>>0<=g>>>0){break sa}v[22708]=0;d=B(g+1|0,104)+a|0;e=d+484380|0;R(424,e|0,32);j=v[22708];v[22708]=0;if((j|0)==1){break wa}v[22708]=0;R(807,i|0,f+16|0);i=v[22708];v[22708]=0;if((i|0)==1){break va}v[e>>2]=w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24);v[d+484404>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if(w[f+24|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|1;v[e>>2]=v[e>>2]>>>1}if(w[f+25|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|64;v[e>>2]=v[e>>2]>>>1}i=2;za:{if(w[f+27|0]!=1){i=6;if(w[f+27|0]!=2){break za}}e=d+484414|0;u[e>>1]=x[e>>1]|i}v[d+484384>>2]=w[f+28|0]|w[f+29|0]<<8|(w[f+30|0]<<16|w[f+31|0]<<24);v[d+484388>>2]=w[f+32|0]|w[f+33|0]<<8|(w[f+34|0]<<16|w[f+35|0]<<24);u[d+484410>>1]=(w[f+36|0]|w[f+37|0]<<8)>>>7;if(w[f+38|0]!=128){break ua}e=d+484414|0;j=x[e>>1]|256;u[e>>1]=j;break ta}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;vb(f+16|0);break qa}g=P()|0;O()|0;break qa}g=P()|0;O()|0;break qa}u[d+484408>>1]=t[f+38|0]+128;j=x[d+484414>>1]}e=d+484414|0;u[e>>1]=j|32;t[d+484416|0]=w[f+39|0];if(w[f+26|0]&2){d=f+48|0;Db(d,n,g);er(d)}if(w[f+26|0]&5){u[e>>1]=x[e>>1]|16384}if(!(w[f+26|0]&8)){break sa}d=f+48|0;Db(d,q,g);er(d);d=0;while(1){e=d<<1;Aa:{if(x[e+(f+208|0)>>1]!=(g|0)){break Aa}e=v[((x[e+(f+224|0)>>1]<<2)+a|0)+900380>>2];if(!e){break Aa}t[e+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}xb(f- -64|0);g=g+1|0;if((g|0)==256){break aa}continue}break}g=P()|0;O()|0}xb(f- -64|0);break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break Z}Ba:{if(!(w[A|0]|w[A+1|0]<<8)){break Ba}i=0;Ca:{Da:{while(1){Ea:{d=Kg(l,i);v[22708]=0;d=T(195,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ea}Fa:{if(!d){i=i+1|0;break Fa}d=Kg(l,i);vc(d);v[22708]=0;R(801,d|0,f+240|0);d=v[22708];v[22708]=0;if((d|0)==1){break Da}j=dd(f+16|0);d=w[f+240|0]|w[f+241|0]<<8;v[22708]=0;U(808,b|0,j|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break Ca}i=i+1|0;e=v[((i<<2)+a|0)+900380>>2];if(!(!e|w[e+34|0])){v[e+4>>2]=32;v[22708]=0;qr(e,0);d=v[22708];v[22708]=0;if((d|0)==1){break Ca}s=e+108|0;C=e+236|0;d=0;while(1){h=d+f|0;Ga:{if(w[h+242|0]>=(w[f+240|0]|w[f+241|0]<<8)>>>0){break Ga}o=ze(j,w[h+242|0]);h=w[o|0];g=h+1|0;m=d+12|0;K=wd(C,m),M=g,u[K>>1]=M;if(h>>>0>=x[a+480190>>1]){break Ga}h=B(g,104)+a|0;t[h+484418|0]=w[f+338|0]&3;t[h+484419|0]=w[f+339|0];t[h+484420|0]=w[f+340|0];t[h+484421|0]=w[f+341|0];u[h+484412>>1]=w[o+1|0]<<1;t[h+484417|0]=w[o+2|0];h=f- -64|0;g=g-1|0;Db(h,q,g);if(Cb(h)){t[e+14|0]=0}h=f- -64|0;Db(h,n,g);if(!Cb(h)){break Ga}K=lc(s,m),M=61,t[K|0]=M}d=d+1|0;if((d|0)!=96){continue}break}}ms(j)}if((w[A|0]|w[A+1|0]<<8)>>>0>i>>>0){continue}break Ba}break}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;ms(j);break Y}Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!(!(c&2)|!x[a+480190>>1])){g=0;while(1){g=g+1|0;d=B(g,104)+a|0;c=d+484416|0;e=t[c|0];h=d+484417|0;i=t[h|0];v[22708]=0;j=d+484380|0;Oo(j,(+(e-49|0)+ +(i|0)*-.0078125)/-12);e=v[22708];v[22708]=0;if((e|0)==1){break Ha}t[h|0]=0;t[c|0]=0;c=x[d+484414>>1];Ra:{if(!(c&16384)){c=Rc(f+240|0,c&1?16:8,c&64?3:1,0,12);v[22708]=0;W(329,c|0,j|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break Ra}g=P()|0;O()|0;break Y}v[22708]=0;e=T(192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Qa}v[22708]=0;Q(318,b|0,12)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Qa}c=Kb(f+240|0);v[22708]=0;W(413,b|0,c|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Pa}v[22708]=0;Q(303,d+484423|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break Pa}v[22708]=0;R(581,f- -64|0,13508);d=v[22708];v[22708]=0;if((d|0)==1){break Oa}v[f+12>>2]=g;d=Jk(a);v[22708]=0;U(13,f+48|0,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break Na}v[22708]=0;Y(582,f+16|0,f- -64|0,f+12|0,f+48|0);d=v[22708];v[22708]=0;if((d|0)==1){break Ma}v[22708]=0;U(560,a|0,2,f+16|0);d=v[22708];v[22708]=0;if((d|0)==1){break La}vb(f+16|0);vb(f+48|0);Hb(f- -64|0);vb(c)}if(x[a+480190>>1]>g>>>0){continue}break}}jd(l);gc(p);xb(G);xb(I);break b}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Ia}g=P()|0;O()|0;break Ia}g=P()|0;O()|0;break Ja}g=P()|0;O()|0;break Ka}g=P()|0;O()|0;vb(f+16|0)}vb(f+48|0)}Hb(f- -64|0)}vb(c);break Y}g=P()|0;O()|0;break Y}g=P()|0;O()|0;break Z}g=P()|0;O()|0}xb(f+16|0)}jd(l);break y}g=P()|0;O()|0;Ye(j);break G}g=P()|0;O()|0;break G}g=P()|0;O()|0;break G}g=P()|0;O()|0}jd(r);break y}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}v[22708]=0;e=T(192,G|0)|0;h=v[22708];v[22708]=0;d=a;Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{if((h|0)!=1){v[22708]=0;h=T(192,G|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break eb}v[22708]=0;U(288,f+240|0,G|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break eb}j=f+240|0;h=jc(f+88|0,j);xb(j);if((e|0)<=844387157){if((e|0)==4674381){break Wa}if((e|0)==5068115){break Va}if(g&1|(e|0)!=726487106){break Ta}t[a+480224|0]=2;v[22708]=0;z=+pa(810,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break Sa}if(!(z>1e-8)){break Ta}z=2646e3/(z*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4;if(!(z<4294967296&z>=0)){break db}e=~~z>>>0;break cb}if((e|0)<=1314144591){if((e|0)==844387158){break Ua}if((e|0)!=1280004692){break Ta}j=0;if(!x[a+480188>>1]){break Ta}while(1){v[22708]=0;d=Q(191,f+88|0,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break B}if(!d){break Ta}d=Kb(f+240|0);v[22708]=0;W(533,h|0,d|0,-1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ab}e=Jb(d);H=Ab(d);v[22708]=0;Xe(f+16|0,3,e,H);e=v[22708];v[22708]=0;if((e|0)==1){break $a}v[22708]=0;R(324,f+160|0,f+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break $a}v[22708]=0;Q(399,((j<<5)+a|0)+480289|0,f+160|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break _a}vb(f+160|0);vb(d);j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}break Ta}if((e|0)==1397445204){break bb}if((e|0)!=1314144592){break Ta}d=0;if(!(w[l|0]|w[l+1|0]<<8)){break Ta}while(1){v[22708]=0;e=Q(191,f+88|0,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break Ya}if(!e){break Ta}v[22708]=0;e=am(n,d&65535);j=v[22708];v[22708]=0;if((j|0)==1){break Ya}if(!e){break Ta}e=Kb(f+240|0);v[22708]=0;W(533,h|0,e|0,-1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break Xa}j=_b(n,d);v[22708]=0;Q(428,j|0,e|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break Xa}vb(e);d=d+1|0;if(d>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){continue}break}break Ta}g=P()|0;O()|0;break y}g=P()|0;O()|0;break y}e=0}v[d+480204>>2]=e;break Ta}v[22708]=0;d=T(287,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}v[a+480232>>2]=d>>>9;v[a+480228>>2]=d>>>8;d=0;if(!x[a+480188>>1]){break Ta}while(1){v[22708]=0;e=Q(812,h|0,f+240|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break C}if(e){u[((d<<5)+a|0)+480286>>1]=(w[f+240|0]|w[f+241|0]<<8)>>>10;e=w[k|0];K=kc(p,d),M=e,t[K|0]=M}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}break Ta}g=P()|0;O()|0;break Za}g=P()|0;O()|0;break Za}g=P()|0;O()|0;vb(f+160|0)}vb(d);break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;vb(e);break z}v[22708]=0;Q(318,f+88|0,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break A}v[22708]=0;d=T(467,f+88|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}v[22708]=0;ca(509,r|0,h|0,d|0,2)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break Ta}break A}v[22708]=0;Q(813,h|0,f+16|0)|0;d=v[22708];v[22708]=0;fb:{if((d|0)!=1){d=Kb(f+240|0);v[22708]=0;W(533,h|0,d|0,-1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break fb}if(yr(d,9883)){v[22708]=0;U(13,f+160|0,8,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break fb}e=f+160|0;Eb(i,e);vb(e)}vb(d);break Ta}g=P()|0;O()|0;break z}g=P()|0;O()|0;vb(d);break z}v[22708]=0;s=T(192,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break A}}xb(f+88|0);continue}break}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0}xb(f+88|0)}gc(p);break e}g=P()|0;O()|0}xb(G)}xb(I)}S(g|0);L()}d=1}gb=f+1728|0;return d|0}function Cg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,D=0,E=0,F=0;e=gb-2736|0;gb=e;a:{b:{c:{d:{e:{f:{if(es(c)){qc(b,268435456);D=v[c+8>>2];p=e+2712|0;d=p;v[d>>2]=0;v[d+4>>2]=0;mc(d+8|0);v[e+2708>>2]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{f=e;q:{r:{s:{t:{if(w[a+3|0]-4>>>0<=4){v[22708]=0;d=T(467,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}v[e+2708>>2]=d;break t}d=w[a+3|0];if(d>>>0>18){break t}d=1<<d;u:{if(!(d&126991)){if(d&396800){break u}break t}if(!w[a|0]){break t}}d=v[b>>2];v[22708]=0;d=wv(a,d);i=v[22708];v[22708]=0;if((i|0)==1){break s}v[22708]=0;U(755,e+544|0,c|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break s}d=e+544|0;i=v[d+4>>2];v[p>>2]=v[d>>2];v[p+4>>2]=i;np(p+8|0,d+8|0);zc(d);d=0;v[22708]=0;g=Sd(p);i=v[22708];v[22708]=0;if((i|0)==1){break n}v[e+2708>>2]=v[p>>2];if(!g){break g}}d=w[a+3|0];if(d>>>0>18){break p}i=1<<d;v:{if(!(i&126991)){h=0;if(i&396800){break v}break p}h=!w[a|0]}if(h|y[b>>2]<262145){break p}d=v[e+2708>>2];i=w[a+3|0];v[22708]=0;v[e+520>>2]=((i|0)==11)<<4;i=Fb(e+520|0,e+2708|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[e+544>>2]=d-v[i>>2];d=w[a+3|0];if(d>>>0>16){break r}w:{if(!(1<<d&126991)){if((d|0)==11){break w}break r}if(!(w[a|0]&7)){break r}}d=v[e+544>>2];if(d>>>0<=2147483647){d=d<<1;break q}d=-1;break q}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=0;v[22708]=0;i=fp(a);h=v[22708];v[22708]=0;x:{y:{if((h|0)!=1){z:{A:{switch(w[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:d=w[a|0];break z;case 9:d=16;break z;case 11:d=4;break z;case 10:case 17:case 18:break A;default:break z}}d=8}i=B(d,i)>>>3|0;d=i-1|0;h=v[e+544>>2];if(d>>>0>-1-h>>>0){break y}h=d+h|0;break x}a=P()|0;O()|0;break a}h=-1}d=(h>>>0)/(i>>>0)|0}v[f+544>>2]=d;qc(b,d);break o}f=e;B:{C:{D:{E:{if(!(w[a+3|0]==4|w[a+3|0]==5|(w[a+3|0]==8|w[a+3|0]==7))){if(w[a+3|0]!=6){break o}d=0;if(y[e+2708>>2]<10){break g}v[22708]=0;Q(318,c|0,4)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}v[22708]=0;d=T(192,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break E}v[e+520>>2]=d;d=v[e+2708>>2];v[22708]=0;v[e+2704>>2]=d;d=Fb(e+520|0,e+2704|0);i=v[22708];v[22708]=0;if((i|0)==1){break D}v[e+544>>2]=v[d>>2];pg(c,8);d=v[e+544>>2];if(d>>>0>50529027){break C}d=B(d,85);break B}v[e+544>>2]=v[e+2708>>2];v[22708]=0;f=fp(a);i=v[22708];v[22708]=0;h=e;F:{G:{if((i|0)!=1){i=v[e+544>>2];f=8/(f>>>0)|0;if(i>>>0>4294967295/(f>>>0)>>>0){break G}f=B(f,i);break F}a=P()|0;O()|0;break a}f=-1}v[h+544>>2]=f;qc(b,f);break o}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=-1}v[f+544>>2]=d;qc(b,(d>>>0)/(w[a|0]>>>3>>>0)|0)}if(!v[b>>2]){d=0;break g}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[22708]=0;d=T(386,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}if(!d){d=0;v[b>>2]=0;break g}if(je(a,Rc(e+544|0,8,1,0,11))){v[22708]=0;a=Q(1184,c|0,e+544|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){d=0;if(!a){break h}a=v[b>>2];v[22708]=0;v[e+520>>2]=a+1>>>1;a=T(467,c|0)|0;d=v[22708];v[22708]=0;H:{if((d|0)!=1){qc(e+520|0,a);a=zb(g);d=v[e+520>>2];if(d){break H}d=16;break h}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];g=0;while(1){f=e+544|0;i=w[f|w[a|0]&15]+g|0;t[b|0]=i;g=w[f|w[a|0]>>>4]+(i&255)|0;t[b+1|0]=g;a=a+1|0;b=b+2|0;d=d-1|0;if(d){continue}break}d=v[e+520>>2]+16|0;break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=5?w[a+3|0]!=4:0)){a=w[a+3|0];v[22708]=0;a=ca(1185,e+1616|0,c|0,b|0,(a|0)==5|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}xb(a);d=v[c+8>>2]-D|0;break h}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[22708]=0;Q(318,c|0,4)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;a=T(192,c|0)|0;d=v[22708];v[22708]=0;I:{J:{K:{if((d|0)!=1){v[22708]=0;v[e+520>>2]=a;d=T(374,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break K}v[22708]=0;U(1186,e+544|0,c|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break I}a=e+544|0;qc(e+520|0,v[a>>2]);v[22708]=0;f=v[e+520>>2];a=Sd(a);i=v[22708];v[22708]=0;if((i|0)!=1){i=v[e+544>>2];h=v[b+20>>2];b=aj(b);v[22708]=0;ha(1187,a|0,i|0,h|0,b|0,d<<24>>24);a=v[22708];v[22708]=0;if((a|0)!=1){break J}}a=P()|0;O()|0;zc(e+544|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=f+9|0;zc(e+544|0);break h}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[e+2708>>2];d=x[Pm(e+1608|0)>>1];v[22708]=0;d=JQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16){break m}d=0;v[22708]=0;f=Q(191,c|0,8)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}if(!f){break h}v[22708]=0;f=T(192,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}v[e+2708>>2]=f;if(f>>>0<4){break h}v[22708]=0;U(288,e+520|0,c|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;f=Lp(e+544|0,e+520|0);i=v[22708];v[22708]=0;if((i|0)==1){break c}xb(e+520|0);v[22708]=0;i=T(1189,f|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break e}if(!v[b>>2]){break j}h=w[a|0];n=(h|0)!=16;while(1){L:{if(n){break L}v[22708]=0;o=Q(200,f|0,8)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break L}a=V(27364)|0;break k}v[22708]=0;l=Q(200,f|0,1)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;a=Q(200,f|0,1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}M:{N:{O:{if(!a){g=8;while(1){v[22708]=0;a=Q(200,f|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break M}if(a){break O}g=g+16|0;continue}}v[22708]=0;a=Q(200,f|0,3)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break N}break l}v[22708]=0;a=Q(200,f|0,4)|0;k=v[22708];v[22708]=0;if((k|0)==1){break l}a=a+g|0}j=(j&255)+(((l?-1:0)^a)&255)|0;P:{if((h|0)!=16){t[v[b+20>>2]+d|0]=j;break P}u[v[b+20>>2]+(d<<1)>>1]=o&255|j<<8}d=d+1|0;if(d>>>0<y[b>>2]){continue}break j}break}a=V(27364)|0;break k}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){d=0;if(y[e+2708>>2]<5){break h}a=zb(zb(v[b+20>>2]));b=aj(b);v[22708]=0;d=W(1190,c|0,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|(w[a+3|0]!=18?w[a+3|0]!=17:0)|(w[a+1|0]!=2?w[a+1|0]!=1:0))){d=v[b>>2];v[22708]=0;f=fp(a);i=v[22708];v[22708]=0;if((i|0)!=1){v[e+544>>2]=B(d,f);qc(e+544|0,v[e+2708>>2]);b=v[b+20>>2];d=v[e+544>>2];f=w[a+3|0];a=v[e+544>>2];v[e+544>>2]=a-1;if((f|0)!=17){if(!a){break h}while(1){E=b,F=x[wd(37268,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}if(!a){break h}while(1){E=b,F=x[wd(36756,zb(w[g|0]))>>1],u[E>>1]=F;a=v[e+544>>2];v[e+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break h}a=P()|0;O()|0;break a}if(!(w[a|0]!=8|w[a+1|0]!=1)){Q:{R:{S:{T:{U:{a=w[a+3|0];switch(a|0){case 2:break R;case 1:break S;case 0:break T;default:break U}}d=0;switch(a-10|0){case 0:break Q;case 2:break R;default:break h}}v[22708]=0;d=IQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=HQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}a=v[e+2708>>2];d=w[FA(e+512|0)|0];v[22708]=0;d=GQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=FQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=8|w[a+1|0]!=3)){V:{W:{X:{Y:{f=w[a+3|0];switch(f|0){case 2:break V;case 1:break X;case 0:break Y;default:break W}}v[22708]=0;d=EQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=DQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=12){break h}}d=v[e+2708>>2];f=w[FA(e+504|0)|0];v[22708]=0;d=CQ(b,g,d,f);f=v[22708];v[22708]=0;if((f|0)==1){break f}if(w[a+3|0]!=12){break h}f=v[b>>2]<<1;if((f|0)<1){break h}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=8|w[a+1|0]!=2)){d=0;Z:{switch(w[a+3|0]){case 0:v[22708]=0;d=BQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=AQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break Z;default:break h}}a=v[e+2708>>2];d=w[FA(e+496|0)|0];v[22708]=0;d=zQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){_:{$:{aa:{ba:{a=w[a+3|0];switch(a|0){case 0:break ba;case 2:break _;case 1:break aa;default:break $}}v[22708]=0;d=yQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=xQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if((a|0)!=12){break h}}a=v[e+2708>>2];d=x[Pm(e+488|0)>>1];v[22708]=0;d=wQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){d=0;ca:{switch(w[a+3|0]){case 0:v[22708]=0;d=vQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=uQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ca;default:break h}}a=v[e+2708>>2];d=x[Pm(e+480|0)>>1];v[22708]=0;d=tQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){da:{ea:{fa:{ga:{f=w[a+3|0];switch(f|0){case 2:break da;case 1:break fa;case 0:break ga;default:break ea}}v[22708]=0;d=sQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=rQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if((f|0)!=12){break h}}d=v[e+2708>>2];f=x[Pm(e+472|0)>>1];v[22708]=0;d=pQ(b,g,d,f);f=v[22708];v[22708]=0;if((f|0)==1){break f}if(w[a+3|0]!=12){break h}f=v[b>>2];if(f<<1<1){break h}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break h}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){d=0;ha:{switch(w[a+3|0]){case 0:v[22708]=0;d=oQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=nQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ha;default:break h}}a=v[e+2708>>2];d=x[Pm(e+464|0)>>1];v[22708]=0;d=mQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){d=0;ia:{switch(w[a+3|0]){case 0:v[22708]=0;d=lQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=kQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ia;default:break h}}a=v[e+2708>>2];d=x[Pm(e+456|0)>>1];v[22708]=0;d=jQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){d=0;ja:{switch(w[a+3|0]){case 0:v[22708]=0;d=iQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 1:v[22708]=0;d=hQ(b,g,v[e+2708>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h;case 2:break ja;default:break h}}a=v[e+2708>>2];d=x[Pm(e+448|0)>>1];v[22708]=0;d=gQ(b,g,a,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=fQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=eQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=dQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=cQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=bQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=aQ(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=$P(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=_P(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=ZP(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=YP(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=XP(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=WP(b,g,d);a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1231,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1232,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1233,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1234,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1235,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1236,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){d=v[e+2708>>2];if(!w[a+2|0]){v[22708]=0;d=W(1237,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[22708]=0;d=W(1238,b|0,g|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=24|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];ka:{if(!w[a+2|0]){v[e+8>>2]=v[e+440>>2];v[e+436>>2]=0;a=v[e+436>>2];v[e>>2]=v[e+432>>2];v[e+4>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+4>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d+2|0])<<24;la:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break la}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;ma:{if(!a){break ma}j=v[k+12>>2];if(!j){break ma}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g+2|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;na:{if((f|0)>0?1:(f|0)>=0){f=rqa(h,f,i,0);h=jb;break na}l=n;h=rqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3);break ka}v[e+24>>2]=v[e+424>>2];v[e+420>>2]=0;a=v[e+420>>2];v[e+16>>2]=v[e+416>>2];v[e+20>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,(d>>>0)/3|0);d=zb(g);a=v[e+20>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+2|0]);j=zb(w[d+1|0])<<16|f<<8|zb(w[d|0])<<24;oa:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break oa}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+3|0;i=i-1|0;if(i){continue}break}}m=e+544|0;pa:{if(!a){break pa}j=v[k+12>>2];if(!j){break pa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+2|0]);o=d;f=zb(w[g+1|0])<<16|f<<8|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;qa:{if((f|0)>0?1:(f|0)>=0){f=rqa(h,f,i,0);h=jb;break qa}l=n;h=rqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+3|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=B(v[k+12>>2],3)}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}f=oqa(x[b+32>>1],0,a,0)+1073741824|0;a=jb;a=f>>>0<1073741824?a+1|0:a;E=b,F=Fd(Qc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[e+544>>2]=-2147483648;d=v[e+2708>>2];ra:{if(!w[a+2|0]){v[e+40>>2]=v[e+408>>2];v[e+404>>2]=0;a=v[e+404>>2];v[e+32>>2]=v[e+400>>2];v[e+36>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,d>>>2|0);d=zb(g);a=v[e+36>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d|0]);j=f|zb(w[d+1|0])<<8|zb(w[d+2|0])<<16|zb(w[d+3|0])<<24;sa:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break sa}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;ta:{if(!a){break ta}j=v[k+12>>2];if(!j){break ta}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g|0]);o=d;f=f|zb(w[g+1|0])<<8|zb(w[g+2|0])<<16|zb(w[g+3|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ua:{if((f|0)>0?1:(f|0)>=0){f=rqa(h,f,i,0);h=jb;break ua}l=n;h=rqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2;break ra}v[e+56>>2]=v[e+392>>2];v[e+388>>2]=0;a=v[e+388>>2];v[e+48>>2]=v[e+384>>2];v[e+52>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],fd(b)),v[E+12>>2]=F;qc(k+12|0,d>>>2|0);d=zb(g);a=v[e+52>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[d+3|0]);j=f|zb(w[d+2|0])<<8|zb(w[d+1|0])<<16|zb(w[d|0])<<24;va:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break va}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;d=d+4|0;i=i-1|0;if(i){continue}break}}m=e+544|0;wa:{if(!a){break wa}j=v[k+12>>2];if(!j){break wa}n=a-1|0;s=a>>>1|0;i=a;d=v[h+20>>2];while(1){f=zb(w[g+3|0]);o=d;f=f|zb(w[g+2|0])<<8|zb(w[g+1|0])<<16|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;xa:{if((f|0)>0?1:(f|0)>=0){f=rqa(h,f,i,0);h=jb;break xa}l=n;h=rqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=id(Ac(f,h),16),u[E>>1]=F;g=g+4|0;d=d+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;d=v[k+12>>2]<<2}if(!d){break h}a=v[e+544>>2];if((a|0)==-2147483648){break h}a=oqa(x[b+32>>1],0,a,0)+1073741824|0;f=jb;f=a>>>0<1073741824?f+1|0:f;E=b,F=Fd(Qc((f&2147483647)<<1|a>>>31,f>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break h}ya:{if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[e+544>>2]=1065353216;d=v[e+2708>>2];za:{if(!w[a+2|0]){v[e+372>>2]=0;v[e+376>>2]=1065353216;a=v[e+380>>2];v[e+72>>2]=v[e+376>>2];v[e+76>>2]=a;v[22708]=0;a=v[e+372>>2];v[e+64>>2]=v[e+368>>2];v[e+68>>2]=a;d=fa(1239,b|0,g|0,d|0,e+544|0,e- -64|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break za}break ya}v[e+356>>2]=0;v[e+360>>2]=1065353216;a=v[e+364>>2];v[e+88>>2]=v[e+360>>2];v[e+92>>2]=a;v[22708]=0;a=v[e+356>>2];v[e+80>>2]=v[e+352>>2];v[e+84>>2]=a;d=fa(1240,b|0,g|0,d|0,e+544|0,e+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break ya}}if(!d){break h}q=z[e+544>>2];if(q==C(1)){break h}a=b;h=a;q=fe(Fo(C(q*C(x[a+32>>1])),C(1),C(64)));a=65535;Aa:{if(q>=C(65535)){break Aa}a=0;if(q<=C(0)){break Aa}a=~~q>>>0;if(q<C(4294967296)&q>=C(0)){break Aa}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}Ba:{if(!(w[a|0]!=64|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[e+544>>2]=0;v[e+548>>2]=1072693248;d=v[e+2708>>2];Ca:{if(!w[a+2|0]){v[e+336>>2]=0;v[e+340>>2]=1072693248;v[e+328>>2]=0;v[e+332>>2]=0;v[e+104>>2]=0;v[e+108>>2]=0;v[e+112>>2]=0;v[e+116>>2]=1072693248;a=v[e+348>>2];v[e+120>>2]=v[e+344>>2];v[e+124>>2]=a;v[22708]=0;a=v[e+324>>2];v[e+96>>2]=v[e+320>>2];v[e+100>>2]=a;d=fa(1241,b|0,g|0,d|0,e+544|0,e+96|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break Ca}break Ba}v[e+304>>2]=0;v[e+308>>2]=1072693248;v[e+296>>2]=0;v[e+300>>2]=0;v[e+136>>2]=0;v[e+140>>2]=0;v[e+144>>2]=0;v[e+148>>2]=1072693248;a=v[e+316>>2];v[e+152>>2]=v[e+312>>2];v[e+156>>2]=a;v[22708]=0;a=v[e+292>>2];v[e+128>>2]=v[e+288>>2];v[e+132>>2]=a;d=fa(1242,b|0,g|0,d|0,e+544|0,e+128|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break Ba}}if(!d){break h}r=A[e+544>>3];if(r==1){break h}a=b;h=a;r=ee(BA(r*+x[a+32>>1],1,64));a=65535;Da:{if(r>=65535){break Da}a=0;if(r<=0){break Da}a=~~r>>>0;if(r<4294967296&r>=0){break Da}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+280>>2]=939524096;v[22708]=0;a=v[e+284>>2];v[e+160>>2]=v[e+280>>2];v[e+164>>2]=a;d=ca(1243,b|0,g|0,d|0,e+160|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[e+272>>2]=939524096;v[22708]=0;a=v[e+276>>2];v[e+168>>2]=v[e+272>>2];v[e+172>>2]=a;d=ca(1244,b|0,g|0,d|0,e+168|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+264>>2]=939524096;v[22708]=0;a=v[e+268>>2];v[e+176>>2]=v[e+264>>2];v[e+180>>2]=a;d=ca(1245,b|0,g|0,d|0,e+176|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[e+256>>2]=939524096;v[22708]=0;a=v[e+260>>2];v[e+184>>2]=v[e+256>>2];v[e+188>>2]=a;d=ca(1246,b|0,g|0,d|0,e+184|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14)){d=v[e+2708>>2];if(!w[a+2|0]){v[e+248>>2]=872415232;v[22708]=0;a=v[e+252>>2];v[e+192>>2]=v[e+248>>2];v[e+196>>2]=a;d=ca(1243,b|0,g|0,d|0,e+192|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}v[e+240>>2]=872415232;v[22708]=0;a=v[e+244>>2];v[e+200>>2]=v[e+240>>2];v[e+204>>2]=a;d=ca(1244,b|0,g|0,d|0,e+200|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}d=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break h}d=v[e+2708>>2];if(!w[a+2|0]){v[e+232>>2]=872415232;v[22708]=0;a=v[e+236>>2];v[e+208>>2]=v[e+232>>2];v[e+212>>2]=a;d=ca(1245,b|0,g|0,d|0,e+208|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break h}break f}v[e+224>>2]=872415232;v[22708]=0;a=v[e+228>>2];v[e+216>>2]=v[e+224>>2];v[e+220>>2]=a;d=ca(1246,b|0,g|0,d|0,e+216|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(27364)|0}if((O()|0)!=(ea(27364)|0)){break d}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break i}}d=i+4|0;xb(f);break h}a=P()|0;O()|0;break d}v[22708]=0;Q(190,c|0,d+D|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}}zc(p)}gb=e+2736|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(f);break a}a=P()|0;O()|0;xb(e+520|0);break a}a=P()|0;O()|0}zc(p);S(a|0);L()}function su(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,da=0,ea=0,ga=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;n=gb-192|0;gb=n;Z=dd(a);o=n+160|0;t[o+26|0]=0;u[o+24>>1]=0;v[o+16>>2]=0;v[o+20>>2]=-1;v[o+8>>2]=-1;v[o+12>>2]=-1;v[o>>2]=0;v[o+4>>2]=0;G=v[d+16>>2];X=w[d+6|0];$=b+484360|0;if(X>>>0>=Qi($)>>>0){X=w[$+16|0]}z=Sj($,X);v[22708]=0;r=Q(1247,n+120|0,b|0)|0;a=v[22708];v[22708]=0;a:{if((a|0)!=1){f=v[r+4>>2];v[22708]=0;H=W(1248,n+80|0,b|0,X|0)|0;a=v[22708];v[22708]=0;b:{if((a|0)!=1){g=x[d+4>>1];c:{d:{if(g>>>0>=tc(z)>>>0){break d}while(1){v[22708]=0;a=Q(472,z|0,g&65535)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(a){break d}v[d>>2]=0;g=g+1|0;u[d+4>>1]=g;if(tc(z)>>>0>(g&65535)>>>0){continue}break}}a=v[d>>2];v[f+52>>2]=a;v[f+48>>2]=a;v[o+16>>2]=a;u[f+74>>1]=g;u[f+72>>1]=g;u[o+24>>1]=g;I=n+72|0;Ud(I);ga=xr(n- -64|0);ia=c&7;la=(ia|0)!=7;e:{if(la){break e}Il(I,1);Il(I,2);Il(I,3);Il(I,28);Il(I,38);Il(I,40);Il(I,39);Il(I,41);RP(ga,12);RP(ga,13);if((G|0)!=2){break e}a=x[d+12>>1];if(tc(z)>>>0<=a>>>0){break e}a=x[sc(z,a)>>1];v[22708]=0;k=b+484344|0;g=me(k,a);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!g){break e}e=_b(k,a);g=v[d+8>>2];v[22708]=0;e=QP(e,g);i=v[22708];v[22708]=0;if((i|0)==1){break c}if(!e){break e}e=0;a=_b(k,a);v[22708]=0;g=Xc(a,g,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}if(!x[b+480188>>1]){break e}a=r+20|0;while(1){f:{g:{h:{switch(w[g|0]-253|0){case 0:if(x[b+480192>>1]){break g}break;case 1:case 2:break g;default:break h}}v[22708]=0;k=ce(g);i=v[22708];v[22708]=0;if((i|0)==1){break c}if(!k){break f}if(tu(g)){break f}}sa=ze(a,e),ta=-1,v[sa>>2]=ta}g=g+6|0;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}T=f+74|0;K=f+48|0;M=f+80|0;oa=f+44|0;F=r+20|0;ka=r+8|0;aa=c&1;ba=f+20|0;D=b+1074312|0;ma=f+616|0;J=b+484344|0;da=32768;pa=(G|0)!=3;na=(G|0)!=2;e=0;g=0;i:{j:{while(1){N=g;k:{l:{while(1){i=x[d+12>>1];qa=A[d+8>>3];while(1){v[22708]=0;Rz(n+32|0,b,f,e&1);a=v[22708];v[22708]=0;if((a|0)==1){break c}k=w[n+32|0];if(!(A[r+32>>3]>=qa?pa:1)){break l}g=x[f+72>>1];a=f;m:{if(tc(z)>>>0>g>>>0){g=x[sc(z,x[f+72>>1])>>1];break m}g=65535}u[a+70>>1]=g;v[22708]=0;a=me(J,g&65535);g=v[22708];v[22708]=0;if((g|0)==1){break i}if(!((i|0)==x[f+72>>1]?x[f+70>>1]==65535|na|a:1)){break l}n:{if(x[f+70>>1]<Te(J)>>>0){break n}while(1){a=f;h=a;o:{p:{if(x[a+70>>1]!=65535){g=x[f+72>>1];if(tc(z)>>>0>g>>>0){break p}}if(x[z+28>>1]==x[f+72>>1]){break n}g=x[z+28>>1];break o}g=x[f+72>>1]+1|0}u[h+72>>1]=g;a=f;q:{if(tc(z)>>>0>(g&65535)>>>0){g=x[sc(z,x[f+72>>1])>>1];break q}g=65535}u[a+70>>1]=g;u[f+74>>1]=x[f+72>>1];v[22708]=0;a=me(J,g&65535);g=v[22708];v[22708]=0;if((g|0)==1){break i}r:{if(a){break r}a=x[f+72>>1];g=Iq(n+32|0,ma);v[22708]=0;a=fa(1251,H|0,a|0,0,g|0,(k|0)!=0|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!a){break r}if(G>>>0<2){a=x[f+72>>1];v[o+8>>2]=0;u[o+20>>1]=a;if(!G){break n}}v[22708]=0;a=ca(1252,H|0,T|0,K|0,1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break i}if(!a){break n}A[o>>3]=A[r+32>>3];v[22708]=0;R(1253,Z|0,o|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[o+16>>2]=v[K>>2];u[o+24>>1]=x[T>>1];v[22708]=0;_(1254,r|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}a=x[f+74>>1];u[f+72>>1]=a;sa=f,ta=x[sc(z,a)>>1],u[sa+70>>1]=ta;v[f+52>>2]=v[f+48>>2];break n}if(x[f+70>>1]>=Te(J)>>>0){continue}break}}if(x[T>>1]==65535){break j}a=x[f+70>>1];v[22708]=0;a=me(J,a);g=v[22708];v[22708]=0;if((g|0)==1){break i}if(!a){if(x[z+28>>1]==x[f+72>>1]){if(!G){break j}v[22708]=0;a=ca(1252,H|0,T|0,K|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break i}if(!a){break j}A[o>>3]=A[r+32>>3];v[22708]=0;R(1253,Z|0,o|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[o+16>>2]=v[K>>2];u[o+24>>1]=x[T>>1];v[22708]=0;_(1254,r|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[f+52>>2]=v[f+48>>2];continue}u[f+74>>1]=x[f+72>>1]+1;continue}break}if(y[f+48>>2]>=y[_b(J,x[f+70>>1])+12>>2]){v[K>>2]=0}if(!(v[K>>2]==v[d+8>>2]?x[f+72>>1]!=x[d+12>>1]|na:1)){break l}g=0;if(!((G|0)==3|y[H+28>>2]<da>>>0)){v[r+32>>2]=0;v[r+36>>2]=2146435072;v[H+28>>2]=0;da=da>>>(da>>>0>256)|0;g=1}a=v[f+48>>2];i=x[f+72>>1];h=Iq(n+32|0,ma);v[22708]=0;a=fa(1251,H|0,i|0,a|0,h|0,(k|0)!=0|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}if((a|g)==1){if(G>>>0<2){u[o+20>>1]=x[f+72>>1];v[o+8>>2]=v[f+48>>2];if(!G){break j}}v[22708]=0;a=ca(1252,H|0,T|0,K|0,1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(!a){break j}A[o>>3]=A[r+32>>3];v[22708]=0;R(1253,Z|0,o|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[o+16>>2]=v[K>>2];u[o+24>>1]=x[T>>1];v[22708]=0;_(1254,r|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[f+52>>2]=v[f+48>>2];continue}u[o+22>>1]=x[f+72>>1];v[o+12>>2]=v[f+48>>2];v[22708]=0;Qz(b,f,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}if(y[f+48>>2]>=y[_b(J,x[f+70>>1])+12>>2]){v[K>>2]=0}if(k){continue}break}a=_b(J,x[f+70>>1]);k=v[f+48>>2];v[22708]=0;g=Xc(a,k,0);a=v[22708];v[22708]=0;s:{if((a|0)!=1){a=n+32|0;Db(a,D,77);e=Cb(a);h=0;if(x[b+480188>>1]){break s}break k}break c}while(1){t:{if(sa=zA(g),ta=1,ua=!e|!(w[((h<<5)+b|0)+480281|0]&4),ua?sa:ta){_o((B(h,872)+f|0)+1404|0);break t}v[22708]=0;a=Bg(g);k=v[22708];v[22708]=0;if((k|0)==1){break c}if(a){u:{if(!aa){break u}a=w[g+1|0];if(a-251>>>0<5|!a){break u}v[22708]=0;k=Eo(g);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;a=Hq(g);i=v[22708];v[22708]=0;if((i|0)==1){break c}u[n+8>>1]=a;a=n+32|0;t[a|0]=w[g+1|0];u[a+2>>1]=x[n+8>>1];v[22708]=0;a=Q(1259,ka|0,a|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}u[a>>1]=k}_o((B(h,872)+f|0)+1404|0);break t}a=B(h,872)+f|0;k=a+1408|0;i=w[g+4|0]|w[g+5|0]<<8;t[k|0]=i;t[k+1|0]=i>>>8;a=a+1404|0;k=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[a|0]=k;t[a+1|0]=k>>>8;t[a+2|0]=k>>>16;t[a+3|0]=k>>>24;v:{switch(w[g+3|0]-16|0){case 0:a=w[g+5|0];v[22708]=0;U(1260,b|0,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}break t;case 1:a=n+32|0;Db(a,D,5);if(!Cb(a)){break t}a=w[g+5|0];if(!a){break t}v[22708]=0;U(1260,b|0,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break t}break c;case 4:a=w[g+5|0];k=a&240;if((k|0)!=224){if((k|0)!=96){break t}v[f+24>>2]=v[f+24>>2]+(a&15);break t}if(v[ba>>2]){break t}a=w[g+5|0]&15;if(a?0:v[b+480180>>2]&2){break t}v[ba>>2]=a+1;break t;case 3:break v;default:break t}}a=w[g+5|0];if((a&240)!=224){break t}v[ba>>2]=(a&15)+1}g=g+6|0;h=h+1|0;if(h>>>0<x[b+480188>>1]){continue}break}break k}t[o+26|0]=1;break j}k=uk(f);v[22708]=0;v[n+32>>2]=1;a=Mc(ba,n+32|0);g=v[22708];v[22708]=0;w:{if((g|0)!=1){a=v[a>>2];u[f+68>>1]=65535;v[f+60>>2]=-1;v[f+64>>2]=-1;if(!x[b+480188>>1]){break w}V=k-1|0;g=k-a|0;q=B(g,1e4);h=0;while(1){x:{i=B(h,872)+f|0;a=i+1404|0;y:{if(zA(a)){break y}m=i+616|0;e=w[i+1409|0];ea=i+1407|0;l=w[ea|0];z:{A:{if(!aa){break A}j=w[a|0];s=i+1405|0;p=w[s|0];if(p){t[i+1415|0]=0;t[i+1419|0]=p;sa=ze(F,h),ta=255,t[sa+5|0]=ta}v[22708]=0;p=ce(a);E=v[22708];v[22708]=0;if((E|0)==1){break x}if(p){t[i+1415|0]=j}v[22708]=0;p=ce(a);E=v[22708];v[22708]=0;if((E|0)==1){break x}B:{if(!(w[s|0]?1:p)){break B}C:{s=i+1419|0;p=w[s|0];if(!p|p>>>0>x[b+480192>>1]){break C}p=v[((w[s|0]<<2)+b|0)+900380>>2];if(!p|!(t[p+15|0]&1)){break C}p=v[p+8>>2];v[22708]=0;So(m,p,b);p=v[22708];v[22708]=0;if((p|0)!=1){break C}break c}j=aA(b,j,w[s|0]);if(!j){break B}j=B(j,104)+b|0;if(!(w[j+484414|0]&32)){break B}j=x[j+484408>>1];v[22708]=0;So(m,j,b);j=v[22708];v[22708]=0;if((j|0)!=1){break B}break c}D:{E:{F:{j=w[i+1406|0];switch(j-1|0){case 1:break A;case 2:case 3:break E;case 0:break F;default:break D}}sa=ze(F,h),ta=w[i+1408|0],t[sa+5|0]=ta;break A}a=w[i+1408|0];if(!a){break A}t[i+1450|0]=a;break A}if(!w[i+1408|0]|(j|0)!=11){break A}j=n+32|0;yA(j,b,a,0);a=Ve(j);u[i+1384>>1]=x[j>>1];if(w[a|0]){break z}}G:{H:{switch(l-12|0){case 0:v[22708]=0;xA(b,f,h&65535);a=v[22708];v[22708]=0;if((a|0)!=1){break G}break x;case 2:v[22708]=0;a=wA(b,f,h&65535,e);j=v[22708];v[22708]=0;if((j|0)!=1){if((a|0)==-1){break G}v[f+60>>2]=a;break G}break c;case 5:a=n+32|0;Db(a,D,5);if(Cb(a)){break G}a=v[f+48>>2];j=x[f+70>>1];v[22708]=0;a=Om(b,j,a,h&65535,0);j=v[22708];v[22708]=0;I:{J:{if((j|0)!=1){a=B(a,1e4);if(!aa|!(v[b+480180>>2]&16777250)){break I}if(a>>>0<1e4){break J}t[i+1451|0]=(a>>>0)/1e4;break I}break c}a=B(w[i+1451|0],1e4)}j=(a>>>0)/1e4|0;K:{if(a>>>0>319999){break K}s=B(q,j&15);a=v[f+44>>2];if((j&240)==16){a=a+s|0;break K}j=a-s|0;a=a>>>0<j>>>0?0:j}v[f+44>>2]=a;a=v[v[b+8>>2]+20>>2];j=v[v[b+8>>2]+24>>2];s=n+32|0;Db(s,D,8);Fp(oa,B(a,1e4),Cb(s)?255e4:B(j,1e4));break G;case 8:L:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break G}v[i+704>>2]=v[i+704>>2]&-257|((e|0)==145)<<8;break G;case 1:t[i+1452|0]=e&15;break G;case 2:ru(b,f,m,e&15);break G;case 6:break L;default:break G}}t[i+1460|0]=e&15;break G;case 7:a=e&240;if((a|0)!=240){if((a|0)!=96){break G}ru(b,f,m,e&15);break G}t[i+1460|0]=e&15;break G;case 1:case 3:case 4:case 6:break G;default:break H}}if((l|0)!=28|(e&240)!=160){break G}a=n+32|0;Db(a,D,58);if(Cb(a)){break G}t[i+1452|0]=e&15}if(!aa){break y}M:{N:{O:{P:{Q:{R:{S:{switch(l-2|0){case 0:if(!e){break z}a=n+32|0;Db(a,D,90);if(!Cb(a)){t[i+1428|0]=e}t[i+1427|0]=e;break z;case 1:if(!e){break z}a=n+32|0;Db(a,D,90);if(!Cb(a)){t[i+1427|0]=e}t[i+1428|0]=e;break z;case 2:if(!e){break z}u[i+1384>>1]=e;break z;case 8:if(!e){break z}v[i+1280>>2]=e<<8;break z;case 4:case 9:if(!e){break z}t[i+1425|0]=e;break z;case 11:sa=ze(F,h),ta=e,t[sa+5|0]=ta;break z;case 21:a=e<<(!(v[b+480180>>2]&59593760)&e<<24>>24>-1)&255;if(a>>>0<=128){v[M>>2]=a<<1;break z}if(v[b+480180>>2]&16777250){break z}v[M>>2]=256;break z;case 22:a=n+32|0;Db(a,D,9);T:{if(Cb(a)){a=i+1433|0;if(e){t[a|0]=e;break T}e=w[a|0];break T}if(e){t[f+1433|0]=e;break T}e=w[f+1433|0]}a=M;l=e&240;j=e&15;U:{if(!(!l|(j|0)!=15)){p=v[M>>2]+(l>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break U}p=v[M>>2]-(j<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!j|(l|0)!=240)){break U}p=v[M>>2]+B(g,(e>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(l){break U}p=v[M>>2]-B(g,j<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=p;Rd(M,0,256);break z;case 19:if(e>>>0>64){break z}v[i+1364>>2]=e;break z;case 20:a=i+1432|0;V:{if(e){t[a|0]=e;break V}e=w[a|0]}l=e&255;j=i+1364|0;a=v[j>>2];s=e&240;e=e&15;W:{if(!(!s|(e|0)!=15)){v[n+32>>2]=a+(l>>>4|0);break W}if(!(!e|(s|0)!=240)){v[n+32>>2]=a-e;break W}if(e){v[n+32>>2]=a-B(e,g);break W}v[n+32>>2]=a+B(g,l>>>4|0)}Rd(n+32|0,0,64);v[j>>2]=v[n+32>>2];break z;case 7:Nm(b,m,e,8);break z;case 25:break M;case 6:break N;case 24:break O;case 3:break P;case 5:break Q;case 18:break R;case 17:break S;default:break z}}if(!x[b+480188>>1]|e>>>0>15){break R}l=(e&1)<<14;a=0;while(1){j=B(a,872)+f|0;v[j+704>>2]=(l|v[j+704>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((e&240)!=128){break z}Nm(b,m,e&15,4);break z}if(e){t[i+1425|0]=e}e=0}Hl(m,e);break z}NP(b,m,e);break z}MP(m,e);break z}LP(m,e)}X:{Y:{switch(w[i+1406|0]-2|0){case 0:Nm(b,m,w[i+1408|0],6);break X;case 5:a=n+32|0;Db(a,D,53);e=Cb(a);a=w[i+1408|0];if(e){t[i+1439|0]=a&15;break X}Hl(m,a<<4);break X;case 6:break Y;default:break X}}Hl(m,w[i+1408|0])}Z:{_:{$:{aa:{a=w[ea|0];switch(a-5|0){case 3:break _;case 0:case 2:break $;case 1:break y;default:break aa}}switch(a-26|0){case 1:break Z;case 0:break $;default:break y}}ba:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ba}}a=g}e=w[i+1439|0];m=n+32|0;Db(m,D,21);m=Cb(m);i=i+1435|0;a=B(a,e);t[i|0]=w[i|0]+(m?a<<2:a);break y}ca:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ca}}a=g}e=w[i+1442|0];m=n+32|0;Db(m,D,21);m=Cb(m);i=i+1436|0;a=B(a,e);t[i|0]=w[i|0]+(m?a<<2:a);break y}a=i+1437|0;t[a|0]=w[a|0]+B(V,w[i+1445|0]);v[22708]=0;Tz(b,m);a=v[22708];v[22708]=0;if((a|0)==1){break x}}h=h+1|0;if(h>>>0<x[b+480188>>1]){continue}break w}break}break c}break c}if(v[f+40>>2]==65535?v[b+480180>>2]==4:0){break j}v[f+32>>2]=v[b+480216>>2];if(KP(_b(J,x[f+70>>1]))){sa=f,ta=v[_b(J,x[f+70>>1])+16>>2],v[sa+32>>2]=ta}v[22708]=0;g=Q(1266,b|0,f|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){a=B(g,k);A[r+32>>3]=A[r+32>>3]+ +(a>>>0)/+y[b+24620>>2];v[f>>2]=a+v[f>>2];if(!(!x[b+480188>>1]|la)){a=0;ea=(N|0)!=0&(g|0)!=(N|0);while(1){da:{if(v[ze(F,a)>>2]==-1){break da}l=B(a,872)+f|0;V=l+1404|0;q=l+1316|0;if(!v[q>>2]){if(zA(V)){break da}}s=1;ea:{fa:{p=l+1407|0;switch(w[p|0]-4|0){case 0:case 2:break ea;default:break fa}}s=w[l+1406|0]==11}if(w[l+1405|0]){v[l+1276>>2]=0}m=l+1409|0;j=w[m|0];v[22708]=0;E=ce(V);e=v[22708];v[22708]=0;ga:{if((e|0)==1){break ga}i=l+616|0;h=j&15;e=0;ha:{ia:{if(!E){break ia}ja:{if(!s){break ja}if(!w[ze(F,a)+4|0]){break ja}e=v[q>>2];v[22708]=0;ha(1267,n+32|0,b|0,i|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[n+36>>2];v[l+624>>2]=v[n+32>>2];v[l+628>>2]=e}t[l+1418|0]=w[l+1415|0];E=l+1308|0;ra=v[E>>2];e=w[l+1419|0];if(e){v[22708]=0;Do(b,i,e,s,1,1);e=v[22708];v[22708]=0;if((e|0)==1){break i}}e=w[V|0];v[22708]=0;ja(1269,b|0,i|0,e|0,s|0,1,0,65535);e=v[22708];v[22708]=0;if((e|0)==1){break i}j=j>>>4|0;sa=ze(F,a),ta=1,t[sa+4|0]=ta;q=w[p|0];ka:{if(!((w[m|0]&240)!=208|(q-19&255)>>>0>1)){e=h;if(k>>>0>e>>>0){break ka}}e=(q|0)==33?j>>>0<k>>>0?j:0:0}e=!(v[b+480180>>2]&16777250)|(!e|y[ba>>2]<2)?e:B(v[f+20>>2]-1|0,v[f+24>>2]+v[f+40>>2]|0)+e|0;if(!s){sa=ze(F,a),ta=0,v[sa>>2]=ta}q=w[p|0];la:{ma:{if((q|0)==9){break ma}na:{if((q|0)!=19){if((q|0)!=20|(j|0)!=8){break na}break ma}if((j|0)==8){break ma}}if(w[l+1406|0]!=2){break la}}v[E>>2]=ra}oa:{pa:{qa:{switch(q-42|0){default:if((q|0)!=10){break pa}v[22708]=0;Y(1270,b|0,i|0,a&65535,f|0);j=v[22708];v[22708]=0;if((j|0)==1){break i}break ia;case 2:break oa;case 1:break pa;case 0:break qa}}if(!v[l+720>>2]){break pa}v[22708]=0;Y(1271,r|0,a&65535,N|0,-1);e=v[22708];v[22708]=0;if((e|0)==1){break i}e=w[m|0];v[22708]=0;uA(i,e);e=v[22708];v[22708]=0;if((e|0)==1){break i}e=v[f+40>>2]-1|0;break ia}if(w[l+1406|0]!=15){break ia}j=l+1408|0;if(w[j|0]>9){break ia}q=v[l+720>>2];if(!q){break ia}j=w[j|0];ra:{if(!j){j=v[l+1280>>2];break ra}j=v[yf(q+68|0,j-1|0)>>2];v[l+1280>>2]=j}v[22708]=0;Mm(b,i,j);j=v[22708];v[22708]=0;if((j|0)!=1){break ia}break c}q=oqa(w[m|0],0,v[l+692>>2],0);j=jb;E=j>>>8|0;j=Qc((j&255)<<24|q>>>8,E);v[22708]=0;Mm(b,i,j);j=v[22708];v[22708]=0;if((j|0)==1){break i}}sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{switch(w[V|0]-253|0){case 0:if(x[b+480192>>1]){break za}break;case 1:case 2:break za;default:break Aa}}j=w[p|0];if((j-19&255)>>>0<=1){q=0;if((w[m|0]&240)!=192){break xa}if(h>>>0<k>>>0){break za}break xa}q=0;E=j&255;if((E|0)==33&(h|0)!=0&e+h>>>0<k>>>0){break za}if((E|0)!=25){break ya}}j=w[p|0];q=1}if((j&255)==13){break wa}}if(w[l+1406|0]==1){v[l+1304>>2]=w[l+1408|0]<<2}if(!v[l+720>>2]|q){break va}h=0;if((j&255)>>>0>44){break ta}break ua}v[l+1304>>2]=w[m|0]<<2;j=13;if(!(!v[l+720>>2]|q)){break ua}}if(!q){break sa}break ha}q=n+32|0;Db(q,I,j&255);h=1;if(Cb(q)){break ta}h=0;if(w[p|0]!=19){break ta}h=w[m|0]&240;h=(h|0)==16|(h|0)==32}j=w[l+1406|0];if(j>>>0<=15){q=n+32|0;Al(q,ga,j);if(Cb(q)|h){break ha}break sa}if(h){break ha}}if(ea){v[22708]=0;Y(1271,r|0,a&65535,N|0,-1);h=v[22708];v[22708]=0;if((h|0)==1){break ga}}h=w[p|0];Ba:{if(h>>>0<=18){if(!k|(!(v[b+480180>>2]==1?w[m|0]:1)|((h|0)!=11?h-6>>>0>=2:0))){break Ba}j=l+1467|0;h=0;while(1){t[j|0]=!h|w[j|0]&254;Co(b,i,w[m|0]);h=h+1|0;if((k|0)!=(h|0)){continue}break}break Ba}Ca:{switch(h-19|0){case 0:h=w[m|0];if(!(h&15)){if(!(v[b+480180>>2]&1048580)){break Ba}h=w[m|0]}m=l+1467|0;t[m|0]=w[m|0]|1;m=h&240;if((m|0)!=176){if((m|0)!=160){break Ba}Gq(b,i,h&15,0);break Ba}Fq(b,i,h&15,0);break Ba;case 1:Da:{Ea:{Fa:{h=w[m|0];switch(h-158|0){case 1:break Ea;case 0:break Fa;default:break Da}}v[22708]=0;Y(1271,r|0,a&65535,N|0,-1);h=v[22708];v[22708]=0;if((h|0)==1){break ga}v[l+704>>2]=v[l+704>>2]&-129;break Ba}v[22708]=0;Y(1271,r|0,a&65535,N|0,-1);h=v[22708];v[22708]=0;if((h|0)==1){break ga}v[l+704>>2]=v[l+704>>2]|128;if(!v[l+692>>2]|v[i+4>>2]){break Ba}v[22708]=0;h=ce(V);m=v[22708];v[22708]=0;if((m|0)==1){break ga}if(!(w[l+704|0]&2?h:1)){break Ba}m=v[l+692>>2]-1|0;v[i>>2]=-1;v[i+4>>2]=m;break Ba}if((h&240)!=112|h>>>0<115){break Ba}v[22708]=0;jB(i,h,b);h=v[22708];v[22708]=0;if((h|0)!=1){break Ba}break ga;default:break Ca}}if(h-35>>>0>=2){break Ba}v[22708]=0;h=a&65535;Y(1271,r|0,h|0,N|0,-1);m=v[22708];v[22708]=0;if((m|0)==1){break ga}v[22708]=0;Y(1275,b|0,h|0,f|0,0);h=v[22708];v[22708]=0;if((h|0)==1){break ga}}m=l+1467|0;h=w[m|0]|1;t[m|0]=h;Ga:{Ha:{Ia:{Ja:{Ka:{j=l+1406|0;switch(w[j|0]-3|0){case 11:break Ha;case 0:case 1:break Ia;case 3:break Ja;case 2:break Ka;default:break Ga}}h=w[l+1408|0];l=n+32|0;Db(l,D,41);Gq(b,i,h,Cb(l));break Ga}h=w[l+1408|0];l=n+32|0;Db(l,D,41);Fq(b,i,h,Cb(l));break Ga}h=w[l+1408|0];La:{if(h){break La}p=n+32|0;Db(p,D,41);h=0;if(!Cb(p)){break La}h=w[l+1450|0];if(!h){break Ga}}if(!k){break Ga}l=w[j|0]==3?h<<4:h;h=0;while(1){t[m|0]=!h|w[m|0]&254;Co(b,i,l&255);h=h+1|0;if((k|0)!=(h|0)){continue}break}break Ga}i=w[l+1408|0];if(i>>>0>1){break Ga}t[m|0]=h&251|!i<<2}if(w[m|0]&4){break da}if(s){h=ze(F,a);i=v[h>>2];v[h>>2]=i+k;v[22708]=0;Y(1271,r|0,a&65535,g|0,(e+i|0)+1|0);e=v[22708];v[22708]=0;if((e|0)!=1){break da}break c}i=ze(F,a);v[i>>2]=v[i>>2]+(k-e|0);break da}v[22708]=0;kB(i);e=v[22708];v[22708]=0;if((e|0)==1){break ga}sa=ze(F,a),ta=0,v[sa>>2]=ta;break da}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}e=GP(b,f,0);continue}break}break c}if(!(!x[b+480188>>1]|(ia|0)!=7)){a=0;while(1){Ma:{if(v[ze(F,a)>>2]==-1){break Ma}v[22708]=0;Y(1271,r|0,a&65535,N|0,-1);d=v[22708];v[22708]=0;if((d|0)!=1){break Ma}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if(w[o+26|0]){u[o+20>>1]=x[f+72>>1];v[o+8>>2]=v[f+48>>2]}A[o>>3]=A[r+32>>3];v[22708]=0;R(1253,Z|0,o|0);a=v[22708];v[22708]=0;Na:{if((a|0)==1){break Na}Oa:{Pa:{if(!aa){break Pa}Qa:{Ra:{if(G?w[o+26|0]:1){g=b+1074376|0;e=hc(g,f,614);a=0;while(1){k=B(a,872);d=(k+f|0)+616|0;k=hc((e+k|0)+616|0,d,88);v[k+88>>2]=v[d+88>>2];hc(k+92|0,d+92|0,576);v[k+668>>2]=v[d+668>>2];hc(k+672|0,d+672|0,52);xo(k+724|0,d+724|0);xo(k+732|0,d+732|0);xo(k+740|0,d+740|0);hc(k+748|0,d+748|0,123);a=a+1|0;if((a|0)!=256){continue}break}tA(g);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1298260|0;if(Dd(d)){f=v[d>>2];v[22708]=0;ZA(f);f=v[22708];v[22708]=0;if((f|0)==1){break Na}}if(x[b+480188>>1]){k=(ia|0)==7;while(1){f=B(a,872)+b|0;g=w[f+1075791|0];if(g){t[f+1075794|0]=g}g=ze(F,a);if(!(k|w[g+5|0]==255)){v[22708]=0;t[n+32|0]=64;g=ac(g+5|0,n+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[f+1075680>>2]=w[g|0]<<2}Sa:{g=f+1075096|0;e=v[g>>2];if(!e|!(w[e+35|0]&2)){break Sa}if(!Dd(d)){break Sa}e=v[d>>2];g=v[g>>2];v[22708]=0;h=e;e=a&65535;Du(h,e,g+68|0);g=v[22708];v[22708]=0;if((g|0)!=1){g=v[d>>2];v[22708]=0;Pi(g,e,1);g=v[22708];v[22708]=0;if((g|0)!=1){break Sa}}break c}v[f+1075008>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=WB(n+32|0);sa=n,ta=pr(ka),v[sa+24>>2]=ta;sa=n,ta=Eh(ka),v[sa+16>>2]=ta;if(!og(n+24|0,n+16|0)){break Ra}while(1){f=Wl(n+24|0);k=w[f|0]-1&255;a=v[(B(k,160)+b|0)+906300>>2];if(a){g=n+8|0;Db(g,d,k);if(!Cb(g)){v[22708]=0;R(1280,d|0,k|0);k=v[22708];v[22708]=0;if((k|0)==1){break Oa}k=v[v[a>>2]+172>>2];v[22708]=0;R(k|0,a|0,-1);k=v[22708];v[22708]=0;if((k|0)==1){break Oa}}k=x[f+2>>1];g=v[v[a>>2]+44>>2];f=x[f+4>>1];v[22708]=0;Aa(g|0,a|0,k|0,C(C(C(f>>>0)/C(999))));a=v[22708];v[22708]=0;if((a|0)==1){break Oa}}a=n+24|0;Tj(a);if(og(a,n+16|0)){continue}break}break Ra}if((c|0)==3){break Qa}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2];break Qa}g=250;a=d;e=a;Ta:{while(1){f=1;if(v[e>>2]){break Ta}e=e+4|0;g=g-32|0;if(g>>>0>31){continue}break}f=(v[a+28>>2]&67108863)!=0}if(!f){break Qa}a=0;while(1){f=n+8|0;Db(f,d,a);Ua:{if(!Cb(f)){break Ua}f=v[(B(a,160)+b|0)+906300>>2];k=v[v[f>>2]+176>>2];v[22708]=0;_(k|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Ua}break c}a=a+1|0;if((a|0)!=250){continue}break}}if(w[$+16|0]==(X|0)){break Pa}v[22708]=0;Ri($,X);a=v[22708];v[22708]=0;if((a|0)==1){break Na}}if(c&9){c=H;b=b+1298224|0;d=b;a=b;if(v[a>>2]){Ec(a);lR(a);hR(a);km(wb(a),v[a>>2],ug(a));sa=wb(a),ta=0,v[sa>>2]=ta;v[a>>2]=0;v[a+4>>2]=0}kp(d,c);v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];a=wb(c);sa=wb(d),ta=v[a>>2],v[sa>>2]=ta;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;a=b+12|0;Kq(a,v[fc(a)>>2]);b=c+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];fc(b);fc(a);v[a+8>>2]=v[b+8>>2];d=v[wb(a)>>2];c=fc(a);Va:{if(!d){v[a>>2]=c;break Va}sa=v[fc(a)>>2],ta=c,v[sa+8>>2]=ta;sa=b,ta=fc(b),v[sa>>2]=ta;sa=fc(b),ta=0,v[sa>>2]=ta;sa=wb(b),ta=0,v[sa>>2]=ta}}Eq(H);FP(r);gb=n+192|0;return}}}}a=P()|0;O()|0;Eq(H);break b}a=P()|0;O()|0}FP(r);break a}a=P()|0;O()|0}dn(Z);S(a|0);L()}function s6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=C(0),A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=0,M=0,N=C(0),O=0,P=0,Q=C(0),R=0,S=C(0),T=0,U=0,V=0,W=0,X=C(0),Y=C(0),Z=C(0),_=0,$=0,ba=0,ca=C(0),da=0,ea=C(0),fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0;fa=gb-16|0;gb=fa;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<1){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{l=b+e|0;if(w[l|0]!=79|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))!=(w[90128]|w[90129]<<8|(w[90130]<<16|w[90131]<<24))){break f}h=b+26|0;if((h|0)>=(a|0)){break e}j=b+27|0;p=e+h|0;c=w[p|0];if((a|0)<=(j+c|0)){break e}i=c+27|0;f=0;if(c){while(1){i=w[e+(f+j|0)|0]+i|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){$=22;f=jy(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){f=jy(f,0);$=$+1|0;if(($|0)!=26){continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=i-26;v[c+1424>>2]=w[l+22|0]|w[l+23|0]<<8|(w[l+24|0]<<16|w[l+25|0]<<24);f=w[e+(h+w[p|0]|0)|0]==255?-1:w[l+6|0]|w[l+7|0]<<8|(w[l+8|0]<<16|w[l+9|0]<<24);v[c+1436>>2]=h;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<1){break b}}a=0;while(1){l=d+B(a,20)|0;p=l+1432|0;c=v[p>>2];f=0;j=v[l+1436>>2];h=b-j|0;k=l+1428|0;i=v[k>>2];h=(h|0)<(i|0)?h:i;if((h|0)>=1){while(1){c=jy(c,w[e+(f+j|0)|0]);n=f+1|0;f=n;if((h|0)!=(n|0)){continue}break}}f=i-h|0;v[k>>2]=f;v[p>>2]=c;g:{if(!f){f=c;c=l+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+j|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;l=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=l;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!eJ(a)){v[f>>2]=0;b=0;break a}ja=gb-16|0;gb=ja;h=fa+4|0;j=h;l=a;c=l;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}p=Ne(g);if(v[g+96>>2]){break i}if((p|0)!=79){break j}if((Ne(g)|0)!=103){break j}if((Ne(g)|0)!=103){break j}if((Ne(g)|0)!=83){break j}if(!$I(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;ec(g,32);break i}k=gy(g);break i}ec(g,30)}if(!k){break h}if(nc(c,1)){ec(c,35);break h}m=ja;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=nc(c,Bm(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ja+12>>2]=g;k=c+B(g,6)|0;if(!w[k+412|0]){i=v[c+112>>2];g=i>>1;break m}i=v[c+116>>2];g=i>>1;n=nc(c,1);H=nc(c,1);if(n|!w[k+412|0]){break m}v[j>>2]=i-v[c+112>>2]>>2;j=v[c+112>>2]+i>>2;break l}aa(3382,10528,3152,8021);L()}v[j>>2]=0;j=g}v[m+8>>2]=j;n:{if(!(!w[k+412|0]|H)){g=B(i,3);v[fa+8>>2]=g-v[c+112>>2]>>2;i=g+v[c+112>>2]>>2;break n}v[fa+8>>2]=g}v[ja+4>>2]=i;i=1}if(i){o:{ga=v[h>>2];pa=v[fa+8>>2];oa=v[ja+4>>2];ra=h;i=0;R=gb-2368|0;gb=R;q=v[l+404>>2];qa=l+B(v[ja+12>>2],6)|0;D=w[qa+413|0];W=q+B(D,40)|0;ha=W;ba=v[(l+(w[qa+412|0]<<2)|0)+104>>2];p:{p=v[l+4>>2];q:{if((p|0)>0){while(1){c=w[(v[ha+4>>2]+B(i,3)|0)+2|0];O=(R+1344|0)+(i<<2)|0;v[O>>2]=0;g=w[(c+W|0)+9|0];if(!x[(l+(g<<1)|0)+132>>1]){ec(l,21);c=0;break q}h=v[l+260>>2];r:{s:{if(nc(l,1)){c=2;k=v[(l+(i<<2)|0)+996>>2];p=h+B(g,1596)|0;F=v[(w[p+1588|0]<<2)+69708>>2];g=Bm(F)-1|0;Aa=k,Ba=nc(l,g),u[Aa>>1]=Ba;Aa=k,Ba=nc(l,g),u[Aa+2>>1]=Ba;j=0;if(w[p|0]){while(1){T=w[(j+p|0)+1|0];h=T+p|0;n=w[h+33|0];g=0;r=w[h+49|0];t:{if(!r){break t}h=v[l+124>>2]+B(w[h+65|0],2096)|0;if(v[l+1396>>2]<=9){rl(l)}m=v[l+1392>>2];g=u[(h+((m&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){E=m;m=w[g+v[h+8>>2]|0];v[l+1392>>2]=E>>>m;P=v[l+1396>>2]-m|0;m=(P|0)<0;v[l+1396>>2]=m?0:P;g=m?-1:g;break u}g=Am(l,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(n){K=-1<<r^-1;h=c+n|0;while(1){m=0;n=u[((p+(T<<4)|0)+((g&K)<<1)|0)+82>>1];v:{if((n|0)<0){break v}n=v[l+124>>2]+B(n&65535,2096)|0;if(v[l+1396>>2]<=9){rl(l)}P=v[l+1392>>2];m=u[(n+((P&1023)<<1)|0)+36>>1];w:{if((m|0)>=0){E=P;P=w[m+v[n+8>>2]|0];v[l+1392>>2]=E>>>P;H=v[l+1396>>2]-P|0;P=(H|0)<0;v[l+1396>>2]=P?0:H;m=P?-1:m;break w}m=Am(l,n)}if(!w[n+23|0]){break v}m=v[v[n+2088>>2]+(m<<2)>>2]}g=g>>r;u[k+(c<<1)>>1]=m;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}j=j+1|0;if(j>>>0<w[p|0]){continue}break}}if(v[l+1396>>2]!=-1){break s}}v[O>>2]=1;break r}u[R+320>>1]=257;j=p+1592|0;c=v[p+1592>>2];if((c|0)>=3){g=2;while(1){h=p+338|0;n=g<<1;r=n+p|0;O=w[r+1088|0];P=O<<1;m=x[h+P>>1];T=w[r+1089|0];K=T<<1;H=u[k+P>>1];r=u[K+k>>1]-H|0;P=r>>31;h=(B(x[h+n>>1]-m|0,P^r+P)|0)/(x[h+K>>1]-m|0)|0;m=H+((r|0)<0?0-h|0:h)|0;P=k+n|0;n=x[P>>1];x:{y:{if(n){h=R+320|0;t[h+T|0]=1;t[h+O|0]=1;t[g+h|0]=1;h=n<<16>>16;r=F-m|0;if((h|0)>=((m|0)>(r|0)?r:m)<<1){if((m|0)<(r|0)){break x}m=F+(n^-1)|0;break y}if(h&1){m=m-(h+1>>>1|0)|0;break y}m=(h>>1)+m|0;break y}t[(R+320|0)+g|0]=0}u[P>>1]=m;c=v[j>>2]}g=g+1|0;if((g|0)<(c|0)){continue}break}}m=0;if((c|0)<=0){break r}while(1){if(!w[(R+320|0)+m|0]){u[k+(m<<1)>>1]=65535;c=v[j>>2]}m=m+1|0;if((m|0)<(c|0)){continue}break}}i=i+1|0;p=v[l+4>>2];if((i|0)<(p|0)){continue}break}}z:{A:{c=v[l+80>>2];if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){hc(R+320|0,R+1344|0,p<<2);h=x[W>>1];if(h){j=v[ha+4>>2];m=0;while(1){i=j+B(m,3)|0;g=w[i+1|0];n=R+1344|0;i=n+(w[i|0]<<2)|0;if(!(v[(g<<2)+n>>2]?v[i>>2]:0)){v[(R+1344|0)+(g<<2)>>2]=0;v[i>>2]=0}m=m+1|0;if((h|0)!=(m|0)){continue}break}}P=ba>>1;ma=q+B(D,40)|0;if(w[ma+8|0]){c=0;while(1){B:{if((p|0)<1){g=0;break B}i=v[ha+4>>2];m=0;g=0;while(1){if(w[(i+B(m,3)|0)+2|0]==(c|0)){k=g+R|0;h=m<<2;C:{if(v[h+(R+1344|0)>>2]){j=1;h=0;break C}j=0;h=v[(h+l|0)+800>>2]}t[k|0]=j;v[(R+256|0)+(g<<2)>>2]=h;g=g+1|0}m=m+1|0;if((m|0)!=(p|0)){continue}break}}ia=R+256|0;D=R;I=gb-16|0;gb=I;h=l;H=v[h+4>>2];m=v[h+396>>2];i=w[(c+ma|0)+24|0];U=m+B(i,24)|0;k=v[U+4>>2];p=P;na=x[(h+(i<<1)|0)+268>>1];j=p<<((na|0)==2);n=j>>>0>k>>>0?k:j;k=v[U>>2];E=(n-(j>>>0>k>>>0?k:j)>>>0)/y[U+8>>2]|0;F=E<<2;j=B(H,F+4|0);V=v[v[h+124>>2]+B(w[U+13|0],2096)>>2];wa=v[h+92>>2];D:{if(v[h+80>>2]){j=ao(h,j);H=v[h+4>>2];break D}j=Cd(j)}k=0;if((H|0)>=1){n=(H<<2)+j|0;while(1){v[(k<<2)+j>>2]=n;n=n+F|0;k=k+1|0;if((H|0)!=(k|0)){continue}break}}F=j;E:{F:{G:{if((g|0)>=1){j=p<<2;k=0;while(1){if(!w[k+D|0]){Qb(v[ia+(k<<2)>>2],0,j)}k=k+1|0;if((k|0)!=(g|0)){continue}break}if((g|0)==1|(na|0)!=2){break G}k=0;while(1){if(!w[k+D|0]){break F}k=k+1|0;if((k|0)!=(g|0)){continue}break}break E}k=0;if((na|0)==2){break F}}sa=m+B(i,24)|0;xa=sa;ya=(E|0)<1;H=0;while(1){if(!ya){j=0;ta=(g|0)<1;za=ta|(H|0)!=0;p=0;while(1){k=0;if(!za){while(1){if(!w[k+D|0]){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){rl(h)}m=v[h+1392>>2];n=u[(i+((m&1023)<<1)|0)+36>>1];H:{if((n|0)>=0){q=m;m=w[n+v[i+8>>2]|0];v[h+1392>>2]=q>>>m;r=v[h+1396>>2]-m|0;m=(r|0)<0;v[h+1396>>2]=m?0:r;n=m?-1:n;break H}n=Am(h,i)}n=w[i+23|0]?v[v[i+2088>>2]+(n<<2)>>2]:n;if((n|0)==-1){break E}v[v[F+(k<<2)>>2]+(j<<2)>>2]=v[v[sa+16>>2]+(n<<2)>>2]}k=k+1|0;if((k|0)!=(g|0)){continue}break}}I:{if((V|0)<1){break I}n=0;if((p|0)>=(E|0)){break I}while(1){k=0;if(!ta){while(1){J:{if(w[k+D|0]){break J}m=k<<2;i=u[(v[xa+20>>2]+(w[v[v[m+F>>2]+(j<<2)>>2]+n|0]<<4)|0)+(H<<1)>>1];if((i|0)<0){break J}O=h;i=v[h+124>>2]+B(i&65535,2096)|0;da=v[m+ia>>2];_=v[U+8>>2];m=v[U>>2]+B(_,p)|0;K:{L:{M:{if(na){M=0;T=1;if((_|0)<=0){break K}while(1){ka=da+(m<<2)|0;K=_-M|0;r=0;o=C(0);G=YI(O,i);N:{if((G|0)<0){break N}q=i;r=v[i>>2];K=(r|0)<(K|0)?r:K;la=B(r,G);O:{P:{if(w[i+22|0]){G=0;if((K|0)>0){break P}break O}G=0;if((K|0)<=0){break O}while(1){r=ka+(G<<2)|0;z[r>>2]=z[r>>2]+C(z[v[q+28>>2]+(G+la<<2)>>2]+C(0));r=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}while(1){r=ka+(G<<2)|0;o=C(o+z[v[q+28>>2]+(G+la<<2)>>2]);z[r>>2]=z[r>>2]+o;o=C(o+z[q+12>>2]);r=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break N}r=1}if(!r){break M}r=v[i>>2];m=r+m|0;M=r+M|0;if((_|0)>(M|0)){continue}break}break K}M=0;q=(_|0)/v[i>>2]|0;if((q|0)<=0){break L}ka=da+(m<<2)|0;while(1){la=ka+(M<<2)|0;G=_-(m+M|0)|0;K=q;r=0;o=C(0);ua=YI(O,i);Q:{if((ua|0)<0){break Q}r=1;T=i;da=v[i>>2];va=(G|0)>(da|0)?da:G;if((va|0)<1){break Q}da=B(da,ua);G=0;while(1){r=la+(B(G,K)<<2)|0;s=C(o+z[v[T+28>>2]+(G+da<<2)>>2]);z[r>>2]=z[r>>2]+s;o=w[T+22|0]?s:o;r=1;G=G+1|0;if((va|0)!=(G|0)){continue}break}}if(!r){break M}M=M+1|0;if((q|0)!=(M|0)){continue}break}break L}T=0;break K}T=1}if(!T){break E}}k=k+1|0;if((k|0)!=(g|0)){continue}break}}p=p+1|0;n=n+1|0;if((V|0)<=(n|0)){break I}if((p|0)<(E|0)){continue}break}}j=j+1|0;if((p|0)<(E|0)){continue}break}}H=H+1|0;if((H|0)!=8){continue}break}break E}if((g|0)==(k|0)){break E}m=m+B(i,24)|0;r=m;O=(g|0)!=2;D=(E|0)<1;T=(g|0)<3;n=0;while(1){R:{if(!O){k=0;H=0;if(D){break R}while(1){j=v[U>>2]+B(v[U+8>>2],k)|0;v[I+12>>2]=j&1;v[I+8>>2]=j>>1;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){rl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];S:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break S}j=Am(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}T:{if((V|0)<1){break T}i=0;if((k|0)>=(E|0)){break T}while(1){j=v[U+8>>2];q=u[(v[r+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];U:{if((q|0)>=0){if(_I(h,v[h+124>>2]+B(q&65535,2096)|0,ia,2,I+12|0,I+8|0,p,j)){break U}break E}j=v[U>>2]+(j+B(j,k)|0)|0;v[I+8>>2]=j>>1;v[I+12>>2]=j&1}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break T}if((k|0)<(E|0)){continue}break}}H=H+1|0;if((k|0)<(E|0)){continue}break}break R}if(T){break R}k=0;H=0;if(D){break R}while(1){i=v[U>>2]+B(v[U+8>>2],k)|0;j=(i|0)/(g|0)|0;v[I+12>>2]=i-B(g,j);v[I+8>>2]=j;if(!n){i=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){rl(h)}q=v[h+1392>>2];j=u[(i+((q&1023)<<1)|0)+36>>1];V:{if((j|0)>=0){K=q;q=w[j+v[i+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;j=q?-1:j;break V}j=Am(h,i)}j=w[i+23|0]?v[v[i+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[F>>2]+(H<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}W:{if((V|0)<1){break W}i=0;if((k|0)>=(E|0)){break W}while(1){j=v[U+8>>2];q=u[(v[r+20>>2]+(w[v[v[F>>2]+(H<<2)>>2]+i|0]<<4)|0)+(n<<1)>>1];X:{if((q|0)>=0){if(_I(h,v[h+124>>2]+B(q&65535,2096)|0,ia,g,I+12|0,I+8|0,p,j)){break X}break E}j=v[U>>2]+(j+B(j,k)|0)|0;q=(j|0)/(g|0)|0;v[I+8>>2]=q;v[I+12>>2]=j-B(g,q)}k=k+1|0;i=i+1|0;if((V|0)<=(i|0)){break W}if((k|0)<(E|0)){continue}break}}H=H+1|0;if((k|0)<(E|0)){continue}break}}n=n+1|0;if((n|0)!=8){continue}break}}if(!v[h+80>>2]){Xb(F)}v[h+92>>2]=wa;gb=I+16|0;c=c+1|0;if(c>>>0<w[ma+8|0]){p=v[l+4>>2];continue}break}c=v[l+80>>2]}if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){i=x[W>>1];if(i){h=(P|0)>1?P:1;g=l+800|0;while(1){c=i;i=c-1|0;if((ba|0)>=2){j=v[ha+4>>2]+B(i,3)|0;p=v[g+(w[j+1|0]<<2)>>2];j=v[g+(w[j|0]<<2)>>2];m=0;while(1){k=m<<2;n=k+p|0;A=z[n>>2];k=j+k|0;o=z[k>>2];Y:{if(o>C(0)){if(A>C(0)){s=C(o-A);break Y}s=o;o=C(o+A);break Y}if(A>C(0)){s=C(o+A);break Y}s=o;o=C(o-A)}z[k>>2]=o;z[n>>2]=s;m=m+1|0;if((h|0)!=(m|0)){continue}break}}if((c|0)>1){continue}break}}m=0;if(v[l+4>>2]<=0){break z}U=P<<2;while(1){g=m<<2;h=g+l|0;c=h;Z:{if(v[g+(R+320|0)>>2]){Qb(v[c+800>>2],0,U);break Z}g=ba;j=v[c+800>>2];T=v[h+996>>2];k=1;c=l;h=w[(W+w[(v[W+4>>2]+B(m,3)|0)+2|0]|0)+9|0];_:{if(!x[(c+(h<<1)|0)+132>>1]){ec(c,21);break _}r=g>>1;F=v[c+260>>2]+B(h,1596)|0;g=B(w[F+1588|0],u[T>>1]);c=0;n=v[F+1592>>2];if((n|0)>=2){G=F+1592|0;I=F+1588|0;while(1){h=w[(k+F|0)+838|0]<<1;i=u[h+T>>1];if((i|0)>=0){i=B(w[I|0],i&65535);h=x[(h+F|0)+338>>1];if((h|0)!=(c|0)){p=j;n=c;D=i-g|0;q=h-c|0;O=(D|0)/(q|0)|0;K=(h|0)>(r|0)?r:h;$:{if((K|0)<=(c|0)){break $}c=p+(n<<2)|0;z[c>>2]=z[((g&255)<<2)+69728>>2]*z[c>>2];c=n+1|0;if((K|0)<=(c|0)){break $}n=D>>31;E=n+D^n;n=O>>31;n=E-B(q,n+O^n)|0;D=(D|0)>-1?1:-1;H=0;while(1){E=p+(c<<2)|0;H=n+H|0;M=(H|0)<(q|0);g=(g+O|0)+(M?0:D)|0;z[E>>2]=z[((g&255)<<2)+69728>>2]*z[E>>2];H=H-(M?0:q)|0;c=c+1|0;if((K|0)!=(c|0)){continue}break}}n=v[G>>2];c=h}g=i}k=k+1|0;if((n|0)>(k|0)){continue}break}}if((c|0)<(r|0)){o=z[(g<<2)+69728>>2];while(1){g=j+(c<<2)|0;z[g>>2]=o*z[g>>2];c=c+1|0;if((r|0)!=(c|0)){continue}break}}}}m=m+1|0;c=v[l+4>>2];if((m|0)<(c|0)){continue}break}break A}aa(3382,10528,3335,2726);L()}aa(3382,10528,3302,2726);L()}m=0;if((c|0)<=0){break z}while(1){ha=w[qa+412|0];F=ba;V=F>>1;g=V<<2;r=l;na=v[l+92>>2];p=v[(l+(m<<2)|0)+800>>2];c=V<<2;W=p+c|0;aa:{if(v[l+80>>2]){n=ao(r,g);break aa}n=Cd(g)}h=(n+c|0)-8|0;i=v[(r+(ha<<2)|0)+1068>>2];ba:{if(F>>>0<2){c=i;break ba}g=p;c=i;while(1){z[h+4>>2]=C(z[g>>2]*z[c>>2])-C(z[g+8>>2]*z[c+4>>2]);z[h>>2]=C(z[g>>2]*z[c+4>>2])+C(z[g+8>>2]*z[c>>2]);c=c+8|0;h=h-8|0;g=g+16|0;if((W|0)!=(g|0)){continue}break}}if(h>>>0>=n>>>0){g=((V<<2)+p|0)-12|0;while(1){z[h+4>>2]=C(z[g>>2]*z[c+4>>2])-C(z[g+8>>2]*z[c>>2]);z[h>>2]=C(z[c>>2]*C(-z[g>>2]))-C(z[g+8>>2]*z[c+4>>2]);g=g-16|0;c=c+8|0;h=h-8|0;if(n>>>0<=h>>>0){continue}break}}ia=F>>2;if((F|0)>=16){c=ia<<2;h=c+n|0;k=c+p|0;c=(i+(V<<2)|0)-32|0;j=p;g=n;while(1){o=z[g>>2];s=z[h>>2];A=z[h+4>>2];J=z[g+4>>2];z[k+4>>2]=A+J;z[k>>2]=z[h>>2]+z[g>>2];A=C(A-J);o=C(s-o);z[j+4>>2]=C(A*z[c+16>>2])-C(o*z[c+20>>2]);z[j>>2]=C(o*z[c+16>>2])+C(A*z[c+20>>2]);o=z[g+8>>2];s=z[h+8>>2];A=z[h+12>>2];J=z[g+12>>2];z[k+12>>2]=A+J;z[k+8>>2]=z[h+8>>2]+z[g+8>>2];A=C(A-J);o=C(s-o);z[j+12>>2]=C(A*z[c>>2])-C(o*z[c+4>>2]);z[j+8>>2]=C(o*z[c>>2])+C(A*z[c+4>>2]);g=g+16|0;h=h+16|0;j=j+16|0;k=k+16|0;c=c-32|0;if(i>>>0<=c>>>0){continue}break}}D=Bm(F);g=F>>4;k=V-1|0;c=F>>3;h=0-c|0;ZI(g,p,k,h,i);ZI(g,p,k-ia|0,h,i);_=F>>5;g=0-g|0;dq(_,p,k,g,i,16);dq(_,p,k-c|0,g,i,16);dq(_,p,k-(c<<1)|0,g,i,16);dq(_,p,k+B(c,-3)|0,g,i,16);j=2;if((D|0)>=10){j=D-4>>>1|0;h=2;while(1){g=h;h=g+1|0;q=2<<g;if((q|0)>=1){O=8<<g;T=F>>g+4;c=0;g=F>>g+2;K=0-(g>>1)|0;while(1){dq(T,p,k-B(c,g)|0,K,i,O);c=c+1|0;if((q|0)!=(c|0)){continue}break}}if((h|0)!=(j|0)){continue}break}}ma=D-7|0;if((ma|0)>(j|0)){while(1){g=j;j=g+1|0;c=F>>g+6;if((c|0)>=1){T=2<<g;K=8<<g;da=K<<2;H=F>>g+2;U=0-(H>>1)|0;h=i;g=k;while(1){G=p;I=g;E=U;D=h;q=K;M=H;O=T;if((O|0)>=1){ka=D+B(q,12)|0;o=z[ka>>2];la=D+(q<<3)|0;s=z[la>>2];q=D+(q<<2)|0;A=z[q>>2];J=z[ka+4>>2];Q=z[la+4>>2];X=z[q+4>>2];Y=z[D+4>>2];ea=z[D>>2];D=G+(I<<2)|0;G=D+(E<<2)|0;q=0-M<<2;while(1){I=G-4|0;S=z[I>>2];Z=z[D>>2];ca=z[G>>2];z[D>>2]=Z+ca;E=D-4|0;N=z[E>>2];z[E>>2]=N+z[I>>2];Z=C(Z-ca);N=C(N-S);z[I>>2]=C(Y*Z)+C(ea*N);z[G>>2]=C(ea*Z)-C(Y*N);I=G-12|0;Z=z[I>>2];E=D-8|0;N=z[E>>2];M=E;E=G-8|0;ca=z[E>>2];z[M>>2]=N+ca;M=D-12|0;S=z[M>>2];z[M>>2]=S+z[I>>2];N=C(N-ca);S=C(S-Z);z[I>>2]=C(X*N)+C(A*S);z[E>>2]=C(A*N)-C(X*S);I=G-20|0;Z=z[I>>2];E=D-16|0;N=z[E>>2];M=E;E=G-16|0;ca=z[E>>2];z[M>>2]=N+ca;M=D-20|0;S=z[M>>2];z[M>>2]=S+z[I>>2];N=C(N-ca);S=C(S-Z);z[I>>2]=C(Q*N)+C(s*S);z[E>>2]=C(s*N)-C(Q*S);I=G-28|0;Z=z[I>>2];E=D-24|0;N=z[E>>2];M=E;E=G-24|0;ca=z[E>>2];z[M>>2]=N+ca;M=D-28|0;S=z[M>>2];z[M>>2]=S+z[I>>2];N=C(N-ca);S=C(S-Z);z[I>>2]=C(J*N)+C(o*S);z[E>>2]=C(o*N)-C(J*S);G=q+G|0;D=q+D|0;I=(O|0)>1;O=O-1|0;if(I){continue}break}}g=g-8|0;h=(da<<2)+h|0;D=(c|0)>1;c=c-1|0;if(D){continue}break}}if((j|0)!=(ma|0)){continue}break}}c=p;g=F;if((0-(_<<4)|0)<=-1){c=c+(k<<2)|0;h=c-(_<<6)|0;o=z[i+(g>>3<<2)>>2];ea=C(-o);while(1){Q=z[c>>2];g=c-32|0;X=z[g>>2];z[c>>2]=Q+X;j=c-4|0;s=z[j>>2];i=j;j=c-36|0;Y=z[j>>2];z[i>>2]=s+Y;i=c-8|0;A=z[i>>2];k=i;i=c-40|0;N=z[i>>2];z[k>>2]=A+N;k=c-12|0;J=z[k>>2];q=k;k=c-44|0;S=z[k>>2];z[q>>2]=J+S;z[g>>2]=Q-X;z[j>>2]=s-Y;j=c-16|0;s=z[j>>2];q=j;j=c-48|0;Z=z[j>>2];z[q>>2]=s+Z;A=C(A-N);J=C(J-S);z[i>>2]=o*C(A+J);z[k>>2]=o*C(J-A);i=c-28|0;A=z[i>>2];k=c-60|0;J=z[k>>2];D=c-24|0;Q=z[D>>2];q=c-56|0;X=z[q>>2];O=c-20|0;Y=z[O>>2];E=O;O=c-52|0;N=z[O>>2];z[E>>2]=Y+N;z[D>>2]=Q+X;z[i>>2]=A+J;z[j>>2]=Y-N;z[O>>2]=-C(s-Z);s=C(A-J);A=C(Q-X);z[q>>2]=o*C(s-A);z[k>>2]=C(A+s)*ea;XI(c);XI(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}D=V-4|0;c=(n+(ia<<2)|0)-16|0;if(n>>>0<=c>>>0){h=n+(D<<2)|0;g=v[(r+(ha<<2)|0)+1100>>2];while(1){j=(x[g>>1]<<2)+p|0;z[h+12>>2]=z[j>>2];z[h+8>>2]=z[j+4>>2];z[c+12>>2]=z[j+8>>2];z[c+8>>2]=z[j+12>>2];j=(x[g+2>>1]<<2)+p|0;z[h+4>>2]=z[j>>2];z[h>>2]=z[j+4>>2];z[c+4>>2]=z[j+8>>2];z[c>>2]=z[j+12>>2];g=g+4|0;h=h-16|0;c=c-16|0;if(n>>>0<=c>>>0){continue}break}}h=n+(V<<2)|0;i=h-16|0;if(n>>>0<i>>>0){g=v[(r+(ha<<2)|0)+1084>>2];k=h;c=n;while(1){o=z[c+4>>2];j=k-4|0;s=z[j>>2];A=C(o-s);J=z[g+4>>2];o=C(o+s);s=z[c>>2];q=k-8|0;Q=z[q>>2];X=C(s-Q);Y=z[g>>2];ea=C(C(J*o)-C(X*Y));z[c+4>>2]=A+ea;s=C(s+Q);o=C(C(X*J)+C(o*Y));z[c>>2]=s+o;z[j>>2]=ea-A;z[q>>2]=s-o;o=z[c+12>>2];j=k-12|0;s=z[j>>2];A=C(o-s);J=z[g+12>>2];o=C(o+s);s=z[c+8>>2];Q=z[i>>2];X=C(s-Q);Y=z[g+8>>2];ea=C(C(J*o)-C(X*Y));z[c+12>>2]=A+ea;s=C(s+Q);o=C(C(X*J)+C(o*Y));z[c+8>>2]=s+o;z[i>>2]=s-o;z[j>>2]=ea-A;g=g+16|0;c=c+16|0;k=i;i=i-16|0;if(c>>>0<i>>>0){continue}break}}i=h-32|0;if(n>>>0<=i>>>0){c=v[(r+(ha<<2)|0)+1076>>2]+(V<<2)|0;g=(D<<2)+p|0;k=((F<<2)+p|0)-16|0;while(1){o=z[h-8>>2];s=z[c-4>>2];A=z[h-4>>2];J=z[c-8>>2];Q=C(C(o*s)-C(A*J));z[p>>2]=Q;z[g+12>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W>>2]=o;z[k+12>>2]=o;o=z[h-16>>2];s=z[c-12>>2];A=z[h-12>>2];J=z[c-16>>2];Q=C(C(o*s)-C(A*J));z[p+4>>2]=Q;z[g+8>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+4>>2]=o;z[k+8>>2]=o;o=z[h-24>>2];s=z[c-20>>2];A=z[h-20>>2];J=z[c-24>>2];Q=C(C(o*s)-C(A*J));z[p+8>>2]=Q;z[g+4>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+8>>2]=o;z[k+4>>2]=o;o=z[i>>2];s=z[c-28>>2];A=z[h-28>>2];c=c-32|0;J=z[c>>2];Q=C(C(o*s)-C(A*J));z[p+12>>2]=Q;z[g>>2]=-Q;o=C(C(J*C(-o))-C(s*A));z[W+12>>2]=o;z[k>>2]=o;k=k-16|0;g=g-16|0;W=W+16|0;p=p+16|0;h=i;i=h-32|0;if(n>>>0<=i>>>0){continue}break}}if(!v[r+80>>2]){Xb(n)}v[r+92>>2]=na;m=m+1|0;if((m|0)<v[l+4>>2]){continue}break}}bJ(l);ca:{if(w[l+1377|0]){v[l+1060>>2]=0-P;t[l+1377|0]=0;v[l+1064>>2]=1;v[l+1412>>2]=ba-oa;break ca}c=v[l+1412>>2];if(!c){break ca}g=pa-ga|0;if((g|0)<=(c|0)){v[l+1412>>2]=c-g;v[ra>>2]=pa;ga=pa;break ca}ga=c+ga|0;v[ra>>2]=ga;v[l+1412>>2]=0}g=v[l+1064>>2];c=l;da:{ea:{fa:{if(v[c+1388>>2]==v[c+1404>>2]){ga:{if(!g|!(w[l+1375|0]&4)){break ga}g=v[l+1408>>2];h=v[l+1060>>2];if(g>>>0>=h+(oa-ga|0)>>>0){break ga}c=g-h|0;c=(c>>>0>g>>>0?0:c)+ga|0;c=(c|0)>(oa|0)?oa:c;v[fa+12>>2]=c;v[l+1060>>2]=c+v[l+1060>>2];break da}v[l+1064>>2]=1;g=v[l+1408>>2]+(ga-P|0)|0;break fa}if(!g){break ea}g=v[l+1060>>2]}v[c+1060>>2]=(pa-ga|0)+g}if(v[l+84>>2]!=v[l+92>>2]?v[l+80>>2]:0){break p}v[fa+12>>2]=oa}c=1}gb=R+2368|0;break o}aa(3382,10528,3451,2726);L()}}else{c=0}gb=ja+16|0;if(!c){ha:{ia:{ja:{c=v[a+100>>2];switch(c-32|0){case 0:break ia;case 3:break ja;default:break ha}}v[a+100>>2]=0;while(1){if(Aa=0,Ba=(ph(a)|0)!=-1,Ca=v[a+96>>2],Ca?Aa:Ba){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ha}v[a+100>>2]=0;while(1){if(Aa=0,Ba=(ph(a)|0)!=-1,Ca=v[a+96>>2],Ca?Aa:Ba){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}j=fa;p=v[j+12>>2];n=v[j+4>>2];k=n;g=v[j+8>>2];ka:{la:{ma:{na:{c=a;i=v[c+992>>2];oa:{if(!i){h=v[c+4>>2];i=0;break oa}F=i<<1;pa:{if((F|0)==v[c+112>>2]){h=l+1092|0}else{h=0;if((F|0)!=v[l+116>>2]){break pa}h=l+1096|0}h=v[h>>2]}l=h;if(!l){break la}h=v[c+4>>2];if((h|0)<=0){break na}F=(i|0)<1;while(1){if(!F){ba=c+($<<2)|0;m=ba;h=0;while(1){R=v[ba+800>>2]+(h+k<<2)|0;q=R;o=z[R>>2];R=h<<2;z[q>>2]=C(o*z[R+l>>2])+C(z[R+v[m+928>>2]>>2]*z[l+(i+(h^-1)<<2)>>2]);h=h+1|0;if((i|0)!=(h|0)){continue}break}h=v[c+4>>2]}$=$+1|0;if(($|0)<(h|0)){continue}break}i=v[c+992>>2]}F=p-g|0;v[c+992>>2]=F;if((h|0)>=1){$=0;while(1){if((g|0)<(p|0)){ba=c+($<<2)|0;m=ba;h=0;l=g;while(1){z[v[m+928>>2]+(h<<2)>>2]=z[v[ba+800>>2]+(l<<2)>>2];h=h+1|0;l=g+h|0;if((h|0)!=(F|0)){continue}break}h=v[c+4>>2]}$=$+1|0;if(($|0)<(h|0)){continue}break}}if(!i){break la}break ma}v[c+992>>2]=p-g}h=c;i=v[c+1416>>2];c=((g|0)>(p|0)?p:g)-k|0;v[h+1416>>2]=i+c;break ka}c=0}g=c;v[j+12>>2]=c;l=v[a+4>>2];if((l|0)>=1){c=0;while(1){h=(c<<2)+a|0;v[h+864>>2]=v[h+800>>2]+(n<<2);c=c+1|0;if((l|0)!=(c|0)){continue}break}}if(d){v[d>>2]=l}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}gb=fa+16|0;return b|0}function r6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=C(0),K=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=C(0);s=gb-1520|0;gb=s;f=s+8|0;g=Qb(f,0,1512);if(e){h=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=h;e=h&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[s+56|0]=1;v[s+48>>2]=a+b;v[s+40>>2]=a;b=0;p=gb-1024|0;gb=p;t[f+1377|0]=1;a:{if(!pt(f)){break a}e=w[f+1375|0];if(!(e&2)){ec(f,34);break a}if(e&4){ec(f,34);break a}if(e&1){ec(f,34);break a}if(v[f+1116>>2]!=1){ec(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!iy(f,p+1018|0,6)|w[p+1018|0]!=102|(w[p+1019|0]!=105|w[p+1020|0]!=115)){break b}if(w[p+1021|0]!=104|w[p+1022|0]!=101|w[p+1023|0]!=97){break b}if((Ne(f)|0)!=100){break b}if(Ne(f)){break b}ec(f,38);break a}ec(f,34);break a}if((Ne(f)|0)!=1){ec(f,34);break a}if(!iy(f,p+1018|0,6)){ec(f,10);break a}if(!hy(p+1018|0)){ec(f,34);break a}if(yj(f)){ec(f,34);break a}e=Ne(f);v[f+4>>2]=e;if(!e){ec(f,34);break a}if(e>>>0>=17){ec(f,5);break a}e=yj(f);v[f>>2]=e;if(!e){ec(f,34);break a}yj(f);yj(f);yj(f);e=Ne(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){ec(f,20);break a}if((e<<24)-1610612736>>24<=-1){ec(f,20);break a}if(g>>>0>h>>>0){ec(f,20);break a}if(!(Ne(f)&1)){ec(f,34);break a}if(!pt(f)){break a}if(!gy(f)){break a}if(!fy(f)){break a}c:{d:{if((ph(f)|0)==3){while(1){Q=(p+1018|0)+b|0,R=ph(f),t[Q|0]=R;b=b+1|0;if((b|0)!=6){continue}break}if(!hy(p+1018|0)){ec(f,20);break c}g=ey(f);e=_d(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=ph(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=ey(f);v[f+28>>2]=0;v[f+24>>2]=b;e:{f:{if((b|0)<1){break f}b=_d(f,b<<2);v[f+28>>2]=b;if(!b){ec(f,3);break c}if(v[f+24>>2]<1){break f}while(1){g=ey(f);b=_d(f,g+1|0);h=i<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=ph(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;i=i+1|0;if((i|0)<v[f+24>>2]){continue}break}}if(!(ph(f)&1)){ec(f,20);break c}dJ(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=fy(f);dJ(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!gy(f)){break a}if(!eJ(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){h=e<<24;g=0;while(1){h=h>>31&79764919^h<<1;g=g+1|0;if((g|0)!=8){continue}break}v[(e<<2)+459712>>2]=h;e=e+1|0;if((e|0)!=256){continue}break}if((ph(f)|0)==5){while(1){Q=(p+1018|0)+b|0,R=ph(f),t[Q|0]=R;b=b+1|0;if((b|0)!=6){continue}break}if(!hy(p+1018|0)){ec(f,20);break c}b=nc(f,8)+1|0;v[f+120>>2]=b;b=_d(f,B(b,2096));v[f+124>>2]=b;if(!b){ec(f,3);break c}Qb(b,0,B(v[f+120>>2],2096));g:{h:{i:{j:{if(v[f+120>>2]>=1){while(1){b=v[f+124>>2];if((nc(f,8)&255)!=66){ec(f,20);break c}if((nc(f,8)&255)!=67){ec(f,20);break c}if((nc(f,8)&255)!=86){ec(f,20);break c}e=b+B(G,2096)|0;Q=e,R=nc(f,8)&255|nc(f,8)<<8,v[Q>>2]=R;Q=e,R=nc(f,8)&255|(nc(f,8)<<8&65280|nc(f,8)<<16),v[Q+4>>2]=R;b=0;k=nc(f,1);if(!k){b=nc(f,1)}t[e+23|0]=b;q=e+4|0;g=v[q>>2];k:{if(v[e>>2]){h=g;break k}h=0;if(!g){break k}ec(f,20);break c}l:{if(b&255){h=ao(f,h);break l}h=_d(f,h);v[e+8>>2]=h}if(!h){ec(f,3);break c}m:{if(!k){b=0;j=0;g=v[q>>2];if((g|0)<=0){break m}while(1){n:{o:{if(w[e+23|0]){if(!nc(f,1)){break o}}g=nc(f,5)+1|0;t[b+h|0]=g;if((g&255)!=32){j=j+1|0;break n}ec(f,20);break c}t[b+h|0]=255}b=b+1|0;g=v[q>>2];if((b|0)<(g|0)){continue}break}break m}i=nc(f,5);j=0;b=0;g=v[q>>2];if((g|0)<1){break m}while(1){k=nc(f,Bm(g-b|0));i=i+1|0;if((i|0)>=32){ec(f,20);break c}g=b+k|0;if((g|0)>v[q>>2]){ec(f,20);break c}Qb(b+h|0,i,k);b=g;g=v[q>>2];if((b|0)<(g|0)){continue}break}}p:{q:{if(w[e+23|0]){if(g>>2>(j|0)){break q}b=e;k=f;if(v[f+16>>2]<(g|0)){v[f+16>>2]=g;g=v[q>>2]}j=b;b=_d(k,g);v[j+8>>2]=b;if(!b){ec(f,3);break c}hc(b,h,v[q>>2]);xj(f,h,v[q>>2]);h=v[e+8>>2];t[e+23|0]=0;g=v[q>>2]}k=0;b=0;i=0;if((g|0)>=1){while(1){i=((w[b+h|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((g|0)!=(b|0)){continue}break}}v[e+2092>>2]=i;b=_d(f,g<<2);v[e+32>>2]=b;if(b){l=e+2092|0;break p}ec(f,3);break c}v[e+2092>>2]=j;l=e+2092|0;r:{if(!j){k=0;b=0;break r}b=_d(f,j);v[e+8>>2]=b;if(!b){ec(f,3);break c}b=ao(f,v[l>>2]<<2);v[e+32>>2]=b;if(!b){ec(f,3);break c}k=ao(f,v[l>>2]<<2);if(!k){break j}g=v[q>>2];b=v[l>>2]}b=(b<<3)+g|0;if(b>>>0<=y[f+16>>2]){break p}v[f+16>>2]=b}j=e;o=h;n=v[q>>2];i=k;m=0;b=gb-128|0;gb=b;A=Qb(b,0,128);s:{t:{u:{v:{w:{x:{y:{z:{if((n|0)<1){break z}while(1){if(w[m+o|0]!=255){break z}m=m+1|0;if((n|0)!=(m|0)){continue}break}break y}if((m|0)!=(n|0)){break x}}g=1;if(!v[j+2092>>2]){break w}aa(12829,10528,1103,4632);L()}b=m+o|0;g=w[b|0];if(g>>>0>=32){break v}WI(j,0,m,0,g,i);g=w[b|0];if(g){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;r=(b|0)==(g|0);b=b+1|0;if(!r){continue}break}}K=1;r=m+1|0;if((n|0)<=(r|0)){g=1;break w}while(1){M=o+r|0;m=w[M|0];A:{if((m|0)==255){break A}if(m>>>0>31){break u}g=0;b=m;if(!b){break w}while(1){N=A+(b<<2)|0;I=v[N>>2];if(!I){I=(b|0)>1;b=b-1|0;if(I){continue}break w}break}v[N>>2]=0;WI(j,zm(I),r,K,m,i);K=K+1|0;m=w[M|0];if((m|0)<=(b|0)){break A}while(1){g=A+(m<<2)|0;if(v[g>>2]){break t}v[g>>2]=I+(1<<32-m);m=m-1|0;if((m|0)>(b|0)){continue}break}}g=1;r=r+1|0;if((n|0)!=(r|0)){continue}break}}gb=A+128|0;break s}aa(12357,10528,1104,4632);L()}aa(12350,10528,1118,4632);L()}aa(12873,10528,1133,4632);L()}if(!g){if(w[e+23|0]){xj(f,k,0)}ec(f,20);break c}b=v[l>>2];if(b){b=_d(f,(b<<2)+4|0);v[e+2084>>2]=b;if(!b){ec(f,3);break c}b=_d(f,(v[l>>2]<<2)+4|0);v[e+2088>>2]=b;if(!b){ec(f,3);break c}v[e+2088>>2]=b+4;v[b>>2]=-1;m=h;o=k;i=0;n=0;B:{b=e;if(w[b+23|0]){n=v[b+2092>>2];if((n|0)<=0){break B}while(1){g=i<<2;Q=g+v[b+2084>>2]|0,R=zm(v[g+v[b+32>>2]>>2]),v[Q>>2]=R;i=i+1|0;n=v[b+2092>>2];if((i|0)<(n|0)){continue}break}break B}if(v[b+4>>2]>=1){while(1){if(VI(b,w[i+m|0])){Q=v[b+2084>>2]+(n<<2)|0,R=zm(v[v[b+32>>2]+(i<<2)>>2]),v[Q>>2]=R;n=n+1|0}i=i+1|0;if((i|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(n|0)){break B}aa(4573,10528,1200,7252);L()}JI(v[b+2084>>2],n,2285);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;C:{n=w[b+23|0];I=v[b+(n?2092:4)>>2];if((I|0)<1){break C}g=0;while(1){D:{j=g;i=b;if(n&255){j=v[o+(g<<2)>>2]}M=w[j+m|0];E:{if(!VI(i,M)){break E}N=g<<2;j=zm(v[N+v[b+32>>2]>>2]);A=v[b+2084>>2];i=0;n=v[b+2092>>2];if((n|0)>=2){while(1){r=n>>>1|0;O=r+i|0;K=j>>>0<y[A+(O<<2)>>2];i=K?i:O;n=K?r:n-r|0;if((n|0)>1){continue}break}}n=i<<2;if((j|0)!=v[n+A>>2]){break D}if(w[b+23|0]){v[n+v[b+2088>>2]>>2]=v[o+N>>2];t[v[b+8>>2]+i|0]=M;break E}v[n+v[b+2088>>2]>>2]=g}g=g+1|0;if((I|0)==(g|0)){break C}n=w[b+23|0];continue}break}aa(9485,10528,1230,7252);L()}}if(w[e+23|0]){xj(f,k,v[l>>2]<<2);xj(f,v[e+32>>2],v[l>>2]<<2);xj(f,h,v[q>>2]);v[e+32>>2]=0}b=e;Qb(b+36|0,255,2048);g=v[b+(w[b+23|0]?2092:4)>>2];if((g|0)>=1){j=(g|0)<32767?g:32767;k=v[b+8>>2];h=0;while(1){F:{if(w[h+k|0]>10){break F}G:{if(w[b+23|0]){g=zm(v[v[b+2084>>2]+(h<<2)>>2]);break G}g=v[v[b+32>>2]+(h<<2)>>2]}if(g>>>0>1023){break F}while(1){u[(b+(g<<1)|0)+36>>1]=h;k=v[b+8>>2];g=(1<<w[k+h|0])+g|0;if(g>>>0<1024){continue}break}}h=h+1|0;if((j|0)!=(h|0)){continue}break}}b=nc(f,4);t[e+21|0]=b;b=b&255;if(b>>>0>=3){ec(f,20);break c}if(b){Q=e,S=cJ(nc(f,32)),z[Q+12>>2]=S;Q=e,S=cJ(nc(f,32)),z[Q+16>>2]=S;Q=e,R=nc(f,4)+1|0,t[Q+20|0]=R;Q=e,R=nc(f,1),t[Q+22|0]=R;h=v[e>>2];g=v[q>>2];H:{if(w[e+21|0]==1){F=H(_w(+C(C(Tp(+C(g|0)))/C(h|0))));I:{if(D(F)<2147483648){b=~~F;break I}b=-2147483648}F=+(h|0);P=H(gk(+C(C(b|0)+C(1)),F));J:{if(D(P)<2147483648){h=~~P;break J}h=-2147483648}b=((h|0)<=(g|0))+b|0;E=C(b|0);if(gk(+C(E+C(1)),F)<=+(g|0)){b=-1}else{F=H(gk(+E,F));K:{if(D(F)<2147483648){h=~~F;break K}h=-2147483648}b=(h|0)>(g|0)?-1:b}if((b|0)>-1){break H}ec(f,20);break c}b=B(g,h)}v[e+24>>2]=b;if(!b){ec(f,20);break c}g=ao(f,b<<1);if(!g){break i}b=0;i=v[e+24>>2];if((i|0)>0){while(1){h=nc(f,w[e+20|0]);if((h|0)==-1){xj(f,g,v[e+24>>2]<<1);ec(f,20);break c}u[g+(b<<1)>>1]=h;b=b+1|0;i=v[e+24>>2];if((b|0)<(i|0)){continue}break}}L:{if(w[e+21|0]==1){h=w[e+23|0];M:{if(h){b=v[l>>2];if(b){break M}break L}b=v[q>>2]}b=_d(f,B(v[e>>2],b)<<2);v[e+28>>2]=b;if(!b){xj(f,g,v[e+24>>2]<<1);ec(f,3);break c}o=v[(h?l:q)>>2];if((o|0)>=1){n=e+2088|0;E=C(0);m=0;while(1){l=m;l=h?v[v[n>>2]+(l<<2)>>2]:l;N:{k=v[e>>2];if((k|0)<1){break N}j=v[e+24>>2];b=1;i=0;while(1){J=C(E+C(C(z[e+16>>2]*C(x[g+(((l>>>0)/(b>>>0)>>>0)%(j>>>0)<<1)>>1]))+z[e+12>>2]));z[v[e+28>>2]+(B(k,m)+i<<2)>>2]=J;E=w[e+22|0]?J:E;i=i+1|0;k=v[e>>2];if((i|0)>=(k|0)){break N}j=v[e+24>>2];oqa(j,0,b,0);if(!jb){b=B(b,j);continue}else{xj(f,g,j<<1);ec(f,20);break c}}}m=m+1|0;if((o|0)!=(m|0)){continue}break}}t[e+21|0]=2;i=v[e+24>>2];break L}b=_d(f,i<<2);v[e+28>>2]=b;i=v[e+24>>2];if(!b){break h}if((i|0)<1){break L}E=C(0);J=C(C(C(z[e+16>>2]*C(x[g>>1]))+z[e+12>>2])+C(0));z[b>>2]=J;b=1;i=v[e+24>>2];if((i|0)<=1){break L}while(1){E=w[e+22|0]?J:E;J=C(E+C(C(z[e+16>>2]*C(x[g+(b<<1)>>1]))+z[e+12>>2]));z[v[e+28>>2]+(b<<2)>>2]=J;b=b+1|0;i=v[e+24>>2];if((b|0)<(i|0)){continue}break}}xj(f,g,i<<1)}G=G+1|0;if((G|0)<v[f+120>>2]){continue}break}}O:{e=nc(f,6)+1&255;if(!e){break O}b=0;while(1){if(!nc(f,16)){b=b+1|0;if((e|0)!=(b|0)){continue}break O}break}ec(f,20);break c}b=nc(f,6)+1|0;v[f+128>>2]=b;b=_d(f,B(b,1596));v[f+260>>2]=b;if(!b){break g}m=0;if(v[f+128>>2]<=0){break d}G=0;P:while(1){b=nc(f,16);u[((m<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(f,20);break c}if(!b){e=v[f+260>>2]+B(m,1596)|0;Q=e,R=nc(f,8),t[Q|0]=R;Q=e,R=nc(f,16),u[Q+2>>1]=R;Q=e,R=nc(f,16),u[Q+4>>1]=R;Q=e,R=nc(f,6),t[Q+6|0]=R;Q=e,R=nc(f,8),t[Q+7|0]=R;b=(nc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){Q=b+g|0,R=nc(f,8),t[Q|0]=R;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}ec(f,4);break c}l=v[f+260>>2]+B(m,1596)|0;e=nc(f,5);t[l|0]=e;b=-1;i=0;g=0;if(e&255){while(1){e=nc(f,4);t[(g+l|0)+1|0]=e;e=e&255;b=(b|0)<(e|0)?e:b;g=g+1|0;if(g>>>0<w[l|0]){continue}break}while(1){e=i+l|0;Q=e,R=nc(f,3)+1|0,t[Q+33|0]=R;g=nc(f,2);t[e+49|0]=g;Q:{if(g&255){g=nc(f,8);t[e+65|0]=g;if(v[f+120>>2]<=(g&255)){ec(f,20);break c}if(w[e+49|0]==31){break Q}}g=0;while(1){R:{h=nc(f,8)-1|0;u[((l+(i<<4)|0)+(g<<1)|0)+82>>1]=h;if(v[f+120>>2]<=h<<16>>16){break R}g=g+1|0;if((g|0)<1<<w[e+49|0]){continue}break Q}break}ec(f,20);break c}e=(b|0)!=(i|0);i=i+1|0;if(e){continue}break}}h=2;Q=l,R=nc(f,2)+1|0,t[Q+1588|0]=R;b=nc(f,4);v[l+1592>>2]=2;k=0;u[l+338>>1]=0;t[l+1589|0]=b;u[l+340>>1]=1<<b;o=l+1592|0;j=w[l|0];S:{if(j){b=l+1589|0;while(1){g=0;e=l+w[(k+l|0)+1|0]|0;if(w[e+33|0]){while(1){h=nc(f,w[b|0]);u[(l+(v[o>>2]<<1)|0)+338>>1]=h;h=v[o>>2]+1|0;v[o>>2]=h;g=g+1|0;if(g>>>0<w[e+33|0]){continue}break}j=w[l|0]}k=k+1|0;if(k>>>0<(j&255)>>>0){continue}break}if((h|0)<=0){break S}}g=0;while(1){b=x[(l+(g<<1)|0)+338>>1];e=(p+16|0)+(g<<2)|0;u[e+2>>1]=g;u[e>>1]=b;h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}}k=l+338|0;JI(p+16|0,h,2284);g=0;h=v[o>>2];b=h-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(g|0)){g=0;T:{if((h|0)<=0){break T}while(1){t[(g+l|0)+838|0]=w[((p+16|0)+(g<<2)|0)+2|0];h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}g=2;if((h|0)<=2){break T}while(1){v[p+12>>2]=0;v[p+8>>2]=0;b=k;h=0;e=g;if((e|0)>=1){i=b+(e<<1)|0;n=-1;q=65536;while(1){A=b+(h<<1)|0;j=x[A>>1];if(!((n|0)>=(j|0)|x[i>>1]<=j>>>0)){v[p+12>>2]=h;j=x[A>>1];n=j}if(!((j|0)>=(q|0)|x[i>>1]>=j>>>0)){v[p+8>>2]=h;q=x[A>>1]}h=h+1|0;if((e|0)!=(h|0)){continue}break}}b=l+(g<<1)|0;t[b+1088|0]=v[p+12>>2];t[b+1089|0]=v[p+8>>2];h=v[o>>2];g=g+1|0;if((h|0)>(g|0)){continue}break}}G=(h|0)>(G|0)?h:G;m=m+1|0;if((m|0)<v[f+128>>2]){continue P}m=G<<1;break d}e=p+16|0;j=x[e+(g<<2)>>1];g=g+1|0;if((j|0)!=x[e+(g<<2)>>1]){continue}break}break}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}xj(f,g,i<<1);ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}ec(f,3);break c}ec(f,3);break c}ec(f,20);break c}b=nc(f,6)+1|0;v[f+264>>2]=b;b=_d(f,B(b,24));v[f+396>>2]=b;if(!b){ec(f,3);break c}l=0;Qb(b,0,B(v[f+264>>2],24));U:{if(v[f+264>>2]>=1){while(1){b=v[f+396>>2];e=nc(f,16);u[((l<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){ec(f,20);break c}h=b+B(l,24)|0;Q=h,R=nc(f,24),v[Q>>2]=R;b=nc(f,24);v[h+4>>2]=b;if(b>>>0<y[h>>2]){ec(f,20);break c}Q=h,R=nc(f,24)+1|0,v[Q+8>>2]=R;Q=h,R=nc(f,6)+1|0,t[Q+12|0]=R;b=nc(f,8);t[h+13|0]=b;V:{W:{if(v[f+120>>2]>(b&255)){b=0;if(w[h+12|0]){break W}g=0;break V}ec(f,20);break c}while(1){g=(p+16|0)+b|0;j=nc(f,3);if(nc(f,1)){e=nc(f,5)}else{e=0}t[g|0]=j+(e<<3);b=b+1|0;g=w[h+12|0];if(b>>>0<g>>>0){continue}break}}b=_d(f,g<<4);v[h+20>>2]=b;if(!b){break U}if(w[h+12|0]){k=0;while(1){e=w[(p+16|0)+k|0];b=0;while(1){X:{if(e>>>b&1){g=nc(f,8);o=b<<1;j=k<<4;u[o+(j+v[h+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[o+(j+v[h+20>>2]|0)>>1]){break X}ec(f,20);break c}u[(v[h+20>>2]+(k<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if(k>>>0<w[h+12|0]){continue}break}}b=_d(f,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);v[h+16>>2]=b;if(!b){ec(f,3);break c}j=0;Qb(b,0,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];g=w[h+13|0];if(v[(b+B(g,2096)|0)+4>>2]>0){while(1){e=v[B(g,2096)+b>>2];b=_d(f,e);k=j<<2;v[k+v[h+16>>2]>>2]=b;Y:{g=v[k+v[h+16>>2]>>2];if(g){if((e|0)<1){break Y}b=e-1|0;t[g+b|0]=(j>>>0)%w[h+12|0];g=j;if((e|0)==1){break Y}while(1){e=b-1|0;o=w[h+12|0];g=(g|0)/(o|0)|0;t[e+v[k+v[h+16>>2]>>2]|0]=(g|0)%(o|0);o=(b|0)>1;b=e;if(o){continue}break}break Y}ec(f,3);break c}j=j+1|0;b=v[f+124>>2];g=w[h+13|0];if((j|0)<v[(b+B(g,2096)|0)+4>>2]){continue}break}}l=l+1|0;if((l|0)<v[f+264>>2]){continue}break}}b=nc(f,6)+1|0;v[f+400>>2]=b;b=_d(f,B(b,40));v[f+404>>2]=b;if(!b){ec(f,3);break c}k=0;Qb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>=1){while(1){b=v[f+404>>2];if(nc(f,16)){ec(f,20);break c}e=b+B(k,40)|0;b=_d(f,B(v[f+4>>2],3));v[e+4>>2]=b;if(!b){ec(f,3);break c}b=e;if(nc(f,1)){g=nc(f,4)+1|0}else{g=1}t[b+8|0]=g;Z:{if(nc(f,1)){b=nc(f,8)+1|0;u[e>>1]=b;_:{g=v[f+4>>2];b=b&65535;if((g|0)>=(b|0)){j=0;if(b){break _}break Z}ec(f,20);break c}while(1){g=nc(f,Bm(g-1|0));b=B(j,3);t[b+v[e+4>>2]|0]=g;g=nc(f,Bm(v[f+4>>2]-1|0));t[(b+v[e+4>>2]|0)+1|0]=g;g=v[f+4>>2];b=b+v[e+4>>2]|0;h=w[b|0];if((g|0)<=(h|0)){ec(f,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){ec(f,20);break c}if((b|0)!=(h|0)){j=j+1|0;if(j>>>0>=x[e>>1]){break Z}continue}break}ec(f,20);break c}u[e>>1]=0}if(nc(f,2)){ec(f,20);break c}h=v[f+4>>2];$:{aa:{b=w[e+8|0];if(b>>>0<=1){g=0;if((h|0)>0){while(1){t[(v[e+4>>2]+B(g,3)|0)+2|0]=0;g=g+1|0;if((g|0)<v[f+4>>2]){continue}break}b=w[e+8|0]}if(!(b&255)){break $}break aa}g=0;if((h|0)<=0){break aa}while(1){ba:{b=nc(f,4);h=B(g,3);t[(h+v[e+4>>2]|0)+2|0]=b;if(w[(h+v[e+4>>2]|0)+2|0]>=w[e+8|0]){break ba}g=g+1|0;if((g|0)<v[f+4>>2]){continue}break aa}break}ec(f,20);break c}b=0;while(1){nc(f,8);h=b+e|0;g=h;Q=g,R=nc(f,8),t[Q+9|0]=R;h=nc(f,8);t[g+24|0]=h;if(v[f+128>>2]<=w[g+9|0]){ec(f,20);break c}if(v[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=w[e+8|0]){break $}continue}break}ec(f,20);break c}k=k+1|0;if((k|0)<v[f+400>>2]){continue}break}}b=nc(f,6);v[f+408>>2]=b+1;ca:{if(b>>>0>=2147483647){break ca}g=0;while(1){b=B(g,6)+f|0;Q=b,R=nc(f,1),t[Q+412|0]=R;Q=b,R=nc(f,16),u[Q+414>>1]=R;Q=b,R=nc(f,16),u[Q+416>>1]=R;e=nc(f,8);t[b+413|0]=e;if(x[b+414>>1]){ec(f,20);break c}if(x[b+416>>1]){ec(f,20);break c}if(v[f+400>>2]>(e&255)){g=g+1|0;if((g|0)>=v[f+408>>2]){break ca}continue}break}ec(f,20);break c}bJ(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>=1){while(1){e=(b<<2)+f|0;Q=e,R=_d(f,v[f+116>>2]<<2),v[Q+800>>2]=R;Q=e,R=_d(f,v[f+116>>2]<<1&2147483646),v[Q+928>>2]=R;g=_d(f,m);v[e+996>>2]=g;h=v[e+800>>2];if(g?!h|!v[e+928>>2]:1){ec(f,3);break c}Qb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!aJ(f,0,v[f+112>>2])){break a}if(!aJ(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;l=f;m=h<<1&2147483646;q=m;o=v[f+264>>2];if((o|0)<1){e=4}else{i=v[f+396>>2];h=0;j=0;while(1){k=i+B(j,24)|0;n=v[k+4>>2];e=g>>>0>n>>>0?n:g;n=v[k>>2];k=(e-(g>>>0>n>>>0?n:g)>>>0)/y[k+8>>2]|0;h=(h|0)<(k|0)?k:h;j=j+1|0;if((o|0)!=(j|0)){continue}break}e=(h<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<m>>>0?q:e;v[l+12>>2]=e;da:{ea:{if(!v[f+80>>2]){break ea}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break da}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break ea}ec(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}aa(4388,10528,4196,5960);L()}ec(f,3)}b=0}gb=p+1024|0;fa:{ga:{if(!b){v[d>>2]=v[s+104>>2]?1:v[s+108>>2];break ga}b=_d(s+8|0,1512);if(b){Q=c,R=v[hc(b,s+8|0,1512)+32>>2]-a|0,v[Q>>2]=R;v[d>>2]=0;break fa}}fJ(s+8|0);b=0}gb=s+1520|0;return b|0}function eZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-400|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!Jh(b,d+392|0)){break D}if(!AD(d+392|0)){break D}if(!c){p=1;break D}q=le(d+368|0,b);v[22708]=0;R(404,d+352|0,q|0);b=v[22708];v[22708]=0;E:{F:{G:{H:{I:{J:{K:{L:{if((b|0)!=1){v[22708]=0;U(405,d+208|0,d+352|0,1229866575);b=v[22708];v[22708]=0;if((b|0)==1){break J}v[22708]=0;p=Q(406,d+208|0,d+336|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break L}xb(d+208|0);if(!p){break E}v[22708]=0;R(367,a|0,524288);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;Ag(a);b=v[22708];v[22708]=0;if((b|0)!=1){break K}break c}e=P()|0;O()|0;break a}e=P()|0;O()|0;xb(d+208|0);break b}v[a+480208>>2]=12;H=a,I=Fd(Ib(w[d+344|0]|w[d+345|0]<<8),1,127),u[H+480188>>1]=I;H=d,I=Ib(w[d+336|0]|w[d+337|0]<<8),u[H+208>>1]=I;v[22708]=0;u[d+312>>1]=255;b=Pc(d+208|0,d+312|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+336|2;H=d,I=Ib(w[b|0]|w[b+1|0]<<8),u[H+208>>1]=I;v[22708]=0;u[d+312>>1]=3999;b=Pc(d+208|0,d+312|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}u[a+480190>>1]=x[b>>1];v[22708]=0;b=a+1074312|0;W(409,b|0,6,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}v[22708]=0;Q(410,b|0,21)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}v[22708]=0;Q(410,b|0,13)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=Q(2,d+208|0,6439)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,d+208|0,7587)|0;f=v[22708];v[22708]=0;if((f|0)==1){break g}Eb(a+1298316|0,b);vb(b);v[22708]=0;R(411,d+312|0,1445);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(412,d+288|0,d+392|4);b=v[22708];v[22708]=0;if((b|0)==1){break j}v[22708]=0;R(412,d+264|0,d+392|5);b=v[22708];v[22708]=0;if((b|0)==1){break l}v[22708]=0;Y(136,d+208|0,d+312|0,d+288|0,d+264|0);b=v[22708];v[22708]=0;if((b|0)==1){break m}b=d+208|0;Eb(a+1298328|0,b);vb(b);vb(d+264|0);vb(d+288|0);b=d+312|0;Hb(b);v[a+1298364>>2]=2;v[22708]=0;U(405,b|0,d+352|0,1312902469);b=v[22708];v[22708]=0;if((b|0)==1){break n}v[22708]=0;b=T(195,d+312|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break p}v[22708]=0;f=a+1298268|0;W(413,d+312|0,f|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break p}v[22708]=0;U(405,d+288|0,d+352|0,1397706311);b=v[22708];v[22708]=0;if((b|0)==1){break q}b=a+484360|0;$l(Sb(b));M:{g=d+336|4;g=Ib(w[g|0]|w[g+1|0]<<8);N:{if(!g){break N}while(1){v[22708]=0;i=Q(191,d+288|0,46)|0;k=v[22708];v[22708]=0;O:{if((k|0)!=1){if(!i){break N}v[22708]=0;R(414,d+288|0,d+208|0);i=v[22708];v[22708]=0;if((i|0)!=1){if(!gd(f)){break O}v[22708]=0;Q(415,f|0,d+208|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break O}}e=P()|0;O()|0;break r}e=P()|0;O()|0;break r}v[22708]=0;i=T(416,d+288|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break M}if(!cd(Sb(b))){v[22708]=0;k=T(417,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break M}if((k|0)==255){break N}}k=Sb(b);v[22708]=0;U(6,d+264|0,2,d+208|0);j=v[22708];v[22708]=0;if((j|0)==1){break s}v[22708]=0;R(418,k|0,d+264|0);k=v[22708];v[22708]=0;if((k|0)==1){break t}vb(d+264|0);k=Sb(b);v[22708]=0;U(419,k|0,d+288|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break M}e=e+1|0;if(g>>>0>(e&65535)>>>0){continue}break}}v[22708]=0;Ri(b,0);b=v[22708];v[22708]=0;if((b|0)==1){break u}v[22708]=0;U(405,d+264|0,d+352|0,1229869908);b=v[22708];v[22708]=0;if((b|0)==1){break v}v[22708]=0;b=T(421,d+264|0)|0;e=v[22708];v[22708]=0;P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)==1){break W}X:{Y:{Z:{_:{$:{aa:{if(!b){break aa}if(x[a+480192>>1]){e=1;while(1){v[22708]=0;R(422,d+264|0,d+208|0);b=v[22708];v[22708]=0;ba:{ca:{da:{if((b|0)!=1){b=Ib(w[d+238|0]|w[d+239|0]<<8);v[22708]=0;b=W(376,a|0,e&65535,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break da}if(!b){break ba}if(Ib(w[d+238|0]|w[d+239|0]<<8)>>>0>3999){break ba}v[22708]=0;Lr(d+96|0,2,d+208|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;R(324,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)!=1){break ca}}e=P()|0;O()|0;break V}e=P()|0;O()|0;break V}e=P()|0;O()|0;break V}v[22708]=0;Q(301,b+492|0,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}vb(d+120|0);v[22708]=0;Lr(d+96|0,2,d+208|0);f=v[22708];v[22708]=0;if((f|0)==1){break _}v[22708]=0;R(324,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break _}f=Ib(w[d+238|0]|w[d+239|0]<<8);v[22708]=0;Q(301,((f<<5)+a|0)+946304|0,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Z}vb(d+120|0);v[b>>2]=0;H=b,I=Ib(w[d+254|0]|w[d+255|0]<<8)+128&65535,v[H+8>>2]=I;qc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=Ib(w[d+238|0]|w[d+239|0]<<8);v[22708]=0;b=B(b,104)+a|0;R(424,b+484380|0,0);f=v[22708];v[22708]=0;if((f|0)==1){break Y}H=d,I=Ib(w[d+240|0]|w[d+241|0]<<8),u[H+120>>1]=I;v[22708]=0;u[d+96>>1]=64;f=Pc(d+120|0,d+96|0);g=v[22708];v[22708]=0;if((g|0)==1){break X}u[b+484410>>1]=x[f>>1]<<2;H=b+484404|0,I=Yb(w[d+242|0]|w[d+243|0]<<8|(w[d+244|0]<<16|w[d+245|0]<<24)),v[H>>2]=I;if(!Yb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))){break ba}if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&3)){break ba}f=Yb(w[d+246|0]|w[d+247|0]<<8|(w[d+248|0]<<16|w[d+249|0]<<24));v[b+484384>>2]=f;H=b+484388|0,I=Yb(w[d+250|0]|w[d+251|0]<<8|(w[d+252|0]<<16|w[d+253|0]<<24))+f|0,v[H>>2]=I;b=b+484414|0;u[b>>1]=x[b>>1]|2;if(!(Ib(w[d+256|0]|w[d+257|0]<<8)&2)){break ba}u[b>>1]=x[b>>1]|4}e=e+1|0;if(x[a+480192>>1]>=(e&65535)>>>0){continue}break}}v[22708]=0;U(405,d+184|0,d+352|0,1447382614);b=v[22708];v[22708]=0;if((b|0)==1){break W}b=v[d+196>>2];v[d+40>>2]=v[d+192>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+200>>2];v[22708]=0;b=v[d+188>>2];v[d+32>>2]=v[d+184>>2];v[d+36>>2]=b;Y(425,d+32|0,0,a|0,0);b=v[22708];v[22708]=0;if((b|0)==1){break W}v[22708]=0;U(405,d+160|0,d+352|0,1346719318);b=v[22708];v[22708]=0;if((b|0)==1){break W}b=v[d+172>>2];v[d+16>>2]=v[d+168>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+176>>2];v[22708]=0;b=v[d+164>>2];v[d+8>>2]=v[d+160>>2];v[d+12>>2]=b;Y(425,d+8|0,1,a|0,w[d+396|0]>2|0);b=v[22708];v[22708]=0;if((b|0)==1){break W}if(!x[a+480192>>1]){break aa}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}xb(d+264|0);v[22708]=0;U(405,d+208|0,d+352|0,1346458708);b=v[22708];v[22708]=0;if((b|0)==1){break U}v[22708]=0;b=T(275,d+208|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break T}if(!b|!(c&1)){break I}v[22708]=0;U(405,d+264|0,d+352|0,1347305805);b=v[22708];v[22708]=0;if((b|0)==1){break S}v[22708]=0;Q(318,d+264|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break R}i=d+336|6;b=Ib(w[i|0]|w[i+1|0]<<8);v[22708]=0;k=a+484344|0;R(330,k|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break R}b=dd(d+144|0);if(Ib(w[i|0]|w[i+1|0]<<8)){break Q}break P}e=P()|0;O()|0;vb(d+120|0);break V}e=P()|0;O()|0;break V}e=P()|0;O()|0;vb(d+120|0);break V}e=P()|0;O()|0;break V}e=P()|0;O()|0;break V}e=P()|0;O()|0}xb(d+264|0);break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break x}e=d+96|0;z=e|5;A=e|3;C=e|4;D=e|2;E=e|1;while(1){v[22708]=0;y=T(416,d+208|0)|0;e=v[22708];v[22708]=0;ea:{fa:{ga:{ha:{ia:{if((e|0)!=1){v[22708]=0;e=T(426,d+208|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ia}v[22708]=0;U(288,d+96|0,d+208|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break ha}e=d+96|0;f=jc(d+120|0,e);xb(e);v[22708]=0;e=W(331,k|0,m&65535,y|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ga}if(!e){break ea}o=Kb(d+80|0);v[22708]=0;U(427,d+264|0,o|0,-1);e=v[22708];v[22708]=0;if((e|0)!=1){e=_b(k,m);v[22708]=0;Q(428,e|0,o|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break fa}}break A}e=P()|0;O()|0;break y}e=P()|0;O()|0;break y}e=P()|0;O()|0;break y}e=P()|0;O()|0;break z}e=_b(k,m);v[22708]=0;e=Uf(e,0);g=v[22708];v[22708]=0;if((g|0)==1){break A}Od(b);n=0;ja:{while(1){v[22708]=0;g=Q(191,d+120|0,1)|0;j=v[22708];v[22708]=0;ka:{la:{ma:{if((j|0)!=1){if(!g){break ja}v[22708]=0;j=T(374,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break A}if(j){break la}H=d,I=Vb(b),v[H+72>>2]=I;H=d,I=Zb(b),v[H+64>>2]=I;if(Gb(d+72|0,d- -64|0)){break ma}break ka}break A}while(1){na:{e=v[d+72>>2];g=_b(k,m);j=w[e+1|0];e=w[e|0];v[22708]=0;e=Ce(d+96|0,e,j);j=v[22708];v[22708]=0;if((j|0)==1){break na}e=Ue(e,n);v[22708]=0;Q(431,g|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break na}e=d+72|0;Pv(e);if(Gb(e,d- -64|0)){continue}break ka}break}break A}hi(d+96|0);r=x[a+480188>>1];v[22708]=0;g=T(374,f|0)|0;h=v[22708];v[22708]=0;oa:{pa:{if((h|0)!=1){s=j-1|0;qa:{if(!(g&1)){break qa}v[22708]=0;h=T(374,f|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break A}if(!h){break qa}l=j>>>0>r>>>0?d+96|0:B(s,6)+e|0;if((h|0)!=31){if(h>>>0>253){break qa}h=(B(h>>>4|0,12)+(h&15)|0)+13|0}else{h=255}t[l|0]=h}if(!(g&2)){break oa}v[22708]=0;h=T(374,f|0)|0;l=v[22708];v[22708]=0;if((l|0)!=1){break pa}}break A}t[(j>>>0>r>>>0?E:(B(s,6)+e|0)+1|0)|0]=h}if(!(g&60)){continue}t[d+63|0]=0;t[d+62|0]=0;t[d+61|0]=0;t[d+60|0]=0;if(g&4){v[22708]=0;h=T(374,f|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break A}t[d+62|0]=h}if(g&8){v[22708]=0;h=T(374,f|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break A}t[d+60|0]=h}if(g&16){v[22708]=0;h=T(374,f|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break A}t[d+63|0]=h}if(g&32){v[22708]=0;g=T(374,f|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break A}t[d+61|0]=g}TY(d+63|0,d+61|0);TY(d+62|0,d+60|0);g=w[d+62|0];if(!(w[d+63|0]==13|g?(g|0)!=13:0)){gi(d+63|0,d+62|0);gi(d+61|0,d+60|0)}v[22708]=0;so(d- -64|0,d+63|0,d+61|0,d+62|0,d+60|0);g=v[22708];v[22708]=0;ra:{if((g|0)==1){break ra}v[22708]=0;g=rz(w[d+64|0],w[d+65|0]);h=v[22708];v[22708]=0;if((h|0)==1){break ra}sa:{if(!g){break sa}H=d,I=Vb(b),v[H+72>>2]=I;Gd(d+56|0,d+72|0);v[22708]=0;U(434,b|0,v[d+56>>2],d- -64|0);g=v[22708];v[22708]=0;if((g|0)!=1){break sa}break A}g=B(s,6)+e|0;j=j>>>0>r>>>0;t[(j?D:g+2|0)|0]=w[d+63|0];t[(j?C:g+4|0)|0]=w[d+61|0];h=w[d+62|0];t[(j?A:g+3|0)|0]=h;t[(j?z:g+5|0)|0]=w[d+60|0];if((h|0)==43){F=1;continue}if((h|0)!=31){continue}G=1;continue}break A}Od(b);n=n+1|0;if(y>>>0<=n>>>0){break ja}e=_b(k,m);v[22708]=0;e=Uf(e,n);g=v[22708];v[22708]=0;if((g|0)!=1){continue}break}break A}vb(o)}xb(d+120|0);m=m+1|0;if(Ib(w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break}}Mv(b);xb(d+264|0);if(!(c&4)){break G}f=0;if(!F){break H}e=x[a+480188>>1];if(!e){f=1;break H}b=0;while(1){f=1;g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;if((e|0)!=(b|0)){continue}break}break H}e=P()|0;O()|0;break r}e=P()|0;O()|0;break b}f=0;if(!(c&4)){break F}}v[d+120>>2]=-1778364416;v[d+124>>2]=-16756736;v[22708]=0;U(405,d+264|0,d+352|0,1146310725);b=v[22708];v[22708]=0;ta:{ua:{va:{wa:{xa:{ya:{if((b|0)!=1){v[22708]=0;b=T(421,d+264|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break va}if(!b){break xa}v[22708]=0;g=T(416,d+264|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break va}if(g){break ya}e=f;break wa}e=P()|0;O()|0;break w}b=0;e=f;while(1){v[22708]=0;m=T(374,d+264|0)|0;i=v[22708];v[22708]=0;za:{Aa:{if((i|0)!=1){if(x[a+480188>>1]<=b>>>0){break za}if(!f){break Aa}i=((b<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-67108865|((m|0)!=0)<<26;break za}break va}if(m){break za}e=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break wa}xb(d+264|0);if(!f){break G}break ta}v[22708]=0;Q(435,d+264|0,d+120|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ua}}e=P()|0;O()|0;xb(d+264|0);break w}xb(d+264|0);if(!(e&1)){break G}}v[22708]=0;_(436,a+906300|0);b=v[22708];v[22708]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((b|0)==1){break Ga}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22708]=0;v[d+264>>2]=0;b=a+906332|0;yD(b,b+16|0,d+264|0);b=v[22708];v[22708]=0;if((b|0)==1){break Fa}v[22708]=0;b=Q(70,d+264|0,6713)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ea}v[22708]=0;Nv(a+906348|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break Da}vb(b);v[22708]=0;b=Q(70,d+264|0,6677)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ca}v[22708]=0;Jr(a+906380|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break Ba}vb(b);v[22708]=0;b=a+906304|0;R(440,b|0,8);e=v[22708];v[22708]=0;if((e|0)==1){break Ga}RY(d+264|0,w[d+121|0],w[d+123|0],w[d+125|0],w[d+127|0]);e=v[d+268>>2];b=v[b>>2];f=v[d+264>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break G}e=P()|0;O()|0;break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;vb(b);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;vb(b);break w}if(!G){break F}b=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{while(1){cb:{v[d+80>>2]=B(b,127)>>>5;v[22708]=0;R(441,d+120|0,1202);e=v[22708];v[22708]=0;if((e|0)==1){break cb}v[22708]=0;R(442,d+96|0,d+80|0);e=v[22708];v[22708]=0;if((e|0)==1){break bb}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);e=v[22708];v[22708]=0;if((e|0)==1){break ab}v[22708]=0;e=(b<<5)+a|0;R(444,d+144|0,e+902204|0);f=v[22708];v[22708]=0;if((f|0)==1){break $a}v[22708]=0;Q(401,d+144|0,d+264|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $a}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22708]=0;R(441,f|0,1184);f=v[22708];v[22708]=0;if((f|0)==1){break Ya}v[22708]=0;R(442,d+96|0,d+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break Xa}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break Wa}v[22708]=0;R(444,d+144|0,e+903228|0);f=v[22708];v[22708]=0;if((f|0)==1){break Va}v[22708]=0;Q(401,d+144|0,d+264|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Va}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22708]=0;R(441,f|0,1175);f=v[22708];v[22708]=0;if((f|0)==1){break Sa}v[22708]=0;R(442,d+96|0,d+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ra}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break Qa}v[22708]=0;R(444,d+144|0,e+904252|0);f=v[22708];v[22708]=0;if((f|0)==1){break Pa}v[22708]=0;Q(401,d+144|0,d+264|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Pa}vb(d+264|0);vb(d+96|0);f=d+120|0;Hb(f);v[22708]=0;R(441,f|0,1148);f=v[22708];v[22708]=0;if((f|0)==1){break Ma}v[22708]=0;R(442,d+96|0,d+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break La}v[22708]=0;U(443,d+264|0,d+120|0,d+96|0);f=v[22708];v[22708]=0;if((f|0)==1){break Ka}v[22708]=0;R(444,d+144|0,e+905276|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ja}v[22708]=0;Q(401,d+144|0,d+264|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ja}vb(d+264|0);vb(d+96|0);Hb(d+120|0);b=b+1|0;if((b|0)!=32){continue}break F}break}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Za}e=P()|0;O()|0;break _a}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Ta}e=P()|0;O()|0;break Ua}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Na}e=P()|0;O()|0;break Oa}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;break Ha}e=P()|0;O()|0;break Ia}e=P()|0;O()|0;vb(d+264|0)}vb(d+96|0)}Hb(d+120|0);break w}v[22708]=0;U(405,d+264|0,d+352|0,1397575756);b=v[22708];v[22708]=0;if((b|0)==1){break B}v[22708]=0;b=T(275,d+264|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break C}if(!(!x[a+480190>>1]|(!b|!(c&2)))){f=1;e=1;while(1){v[22708]=0;b=T(426,d+264|0)|0;c=v[22708];v[22708]=0;db:{if((c|0)!=1){v[22708]=0;c=T(426,d+264|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break C}if(!(b&7)){break db}f=(B(f,104)+a|0)+484380|0;v[f>>2]=c;b=Rc(d+120|0,b&4?32:b&2?16:8,1,1,0);v[22708]=0;W(329,b|0,f|0,d+264|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break db}break C}break C}e=e+1|0;f=e&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}xb(d+264|0);xb(d+208|0);xb(d+288|0);xb(d+312|0)}ke(d+352|0);xb(q)}gb=d+400|0;return p|0}e=P()|0;O()|0;xb(d+264|0);break w}e=P()|0;O()|0;break w}e=P()|0;O()|0;vb(o)}xb(d+120|0)}Mv(b)}xb(d+264|0)}xb(d+208|0);break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;vb(d+264|0);break r}e=P()|0;O()|0}xb(d+288|0);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0}xb(d+312|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+264|0);break k}e=P()|0;O()|0}vb(d+288|0);break i}e=P()|0;O()|0}Hb(d+312|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}ke(d+352|0)}xb(q);S(e|0);L()}function Ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=gb-352|0;gb=d;vc(b);a:{if(!Br(b,d+336|0)){break a}if(!OU(d+336|0)){break a}q=le(d+312|0,b);p=hh(d+296|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[22708]=0;R(849,d|0,q|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}break t}v[22708]=0;R(850,d|0,q|0);b=v[22708];v[22708]=0;if((b|0)==1){break s}}NU(p,d);ke(d);v[22708]=0;U(851,d|0,p|0,1413891155);b=v[22708];v[22708]=0;u:{v:{if((b|0)!=1){v[22708]=0;e=Q(852,d|0,11388)|0;b=v[22708];v[22708]=0;if((b|0)==1){break v}xb(d);if(!e){break b}if(c){break u}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;xb(d);break c}v[22708]=0;R(367,a|0,4194304);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[22708]=0;U(851,d+272|0,p|0,1280592212);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=T(195,d+272|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}v[22708]=0;W(616,d+272|0,a+1298268|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}l=a+484360|0;$l(Sb(l));k=dd(d+256|0);t[d+255|0]=0;v[22708]=0;U(853,d+240|0,p|0,1196314451);b=v[22708];v[22708]=0;if((b|0)==1){break i}b=d+240|0;y=d,z=Vb(b),v[y+232>>2]=z;y=d,z=Zb(b),v[y+224>>2]=z;w:{x:{y:{z:{A:{B:{if(!Gb(d+232|0,d+224|0)){break B}i=d+12|0;h=d+24|0;n=d+44|0;while(1){e=le(d+200|0,v[d+232>>2]);v[22708]=0;f=Q(854,e|0,d+184|0)|0;b=v[22708];v[22708]=0;C:{D:{E:{F:{G:{H:{if((b|0)!=1){b=1;if(!(f&w[d+193|0]==1)){break C}y=a,z=Fd(w[d+194|0],x[a+480188>>1],127),u[y+480188>>1]=z;v[22708]=0;g=T(855,d|0)|0;b=v[22708];v[22708]=0;I:{J:{K:{L:{if((b|0)!=1){b=d+168|0;of(b,d+184|0,9,1);v[22708]=0;R(324,d+120|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break L}v[22708]=0;R(856,d+160|0,n|0);b=v[22708];v[22708]=0;if((b|0)==1){break K}v[22708]=0;Q(401,d+160|0,d+120|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break K}vb(d+120|0);if(cd(Sb(l))){break I}v[22708]=0;b=T(417,l|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break J}if((b|0)!=255){break I}b=2;break D}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}b=Sb(l);v[22708]=0;U(6,d+120|0,5,n|0);f=v[22708];v[22708]=0;M:{N:{O:{if((f|0)!=1){v[22708]=0;R(418,b|0,d+120|0);b=v[22708];v[22708]=0;if((b|0)==1){break O}vb(d+120|0);v[22708]=0;R(850,d+168|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break N}b=d+168|0;y=d,z=Vb(b),v[y+152>>2]=z;y=d,z=Zb(b),v[y+144>>2]=z;if(Gb(d+152|0,d+144|0)){break M}break G}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(d+120|0);break l}b=P()|0;O()|0;break l}P:{Q:{while(1){R:{e=v[d+152>>2];qn(d+120|0,e);b=d+160|0;Zi(b,e);e=1;S:{b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b|0)!=1212960847){if((b|0)!=1312903248){break S}b=0;if(!x[a+480188>>1]){break S}T:{while(1){v[22708]=0;f=Q(191,d+120|0,2)|0;j=v[22708];v[22708]=0;if((j|0)==1){break T}if(!f){break S}v[22708]=0;R(403,d+96|0,d+120|0);f=v[22708];v[22708]=0;U:{V:{W:{X:{if((f|0)!=1){f=d+96|0;j=qd(f);switch(w[f|0]){case 4:break V;case 2:break W;case 0:break X;default:break U}}break H}f=w[j|0];y=kc(d,b),z=f^128,t[y|0]=z;f=d+104|0;re(f,h,b);Df(f,0);break U}y=kc(d,b),z=128,t[y|0]=z;f=d+104|0;re(f,h,b);Df(f,1);break U}y=kc(d,b),z=128,t[y|0]=z;f=d+104|0;re(f,h,b);Df(f,0)}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break S}break H}if(bn(d+160|0)>>>0<9){break S}b=0;v[22708]=0;Q(318,d+120|0,2)|0;e=v[22708];v[22708]=0;j=65535;if((e|0)==1){break R}while(1){v[22708]=0;e=Q(191,d+120|0,1)|0;f=v[22708];v[22708]=0;Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((f|0)!=1){f=1;if(!e){break $}v[22708]=0;o=T(374,d+120|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break H}e=0;switch(o|0){case 14:break Z;case 13:break _;case 0:break $;case 12:break aa;case 8:break ba;case 7:break ca;case 4:break da;case 1:break ea;default:break S}}break H}if(x[d+36>>1]==65535){y=d,z=Zl(Sb(l)),u[y+36>>1]=z}e=Zl(Sb(l));v[22708]=0;u[d+38>>1]=e;e=Q(857,d+120|0,d+255|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break H}fa:{ga:{switch(e-254|0){case 1:v[22708]=0;e=65535;f=v[22708];v[22708]=0;if((f|0)!=1){break fa}break H;case 0:break ga;default:break fa}}v[22708]=0;e=65534;f=v[22708];v[22708]=0;if((f|0)==1){break H}}f=Sb(l);v[22708]=0;R(710,f|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break H}j=(j&65535)==65535?b:j;break Y}v[22708]=0;e=T(287,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break H}if(e>>>0>=(j&65535)>>>0){u[d+40>>1]=e-j}bf(Sb(l),x[d+40>>1]);break Y}v[22708]=0;e=T(374,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break H}t[d+43|0]=e;break Y}v[22708]=0;e=T(374,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break H}t[d+42|0]=e;break Y}v[22708]=0;e=Q(813,d+120|0,d+104|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break H}f=0;if(!(e&!w[d+104|0])|w[d+105|0]!=255|(w[d+106|0]|w[d+107|0])){break $}if(w[d+108|0]!=1){break $}if(!w[d+109|0]){break Y}}e=f;break S}v[22708]=0;R(723,d+112|0,d+120|0);e=v[22708];v[22708]=0;ha:{ia:{ja:{ka:{if((e|0)!=1){f=d+112|0;e=f;o=qd(e);f=Ve(e);m=w[e|0];if(oc(d)>>>0<=m>>>0){break Y}switch(w[f|0]){case 4:break ia;case 2:break ja;case 0:break ka;default:break ha}}break H}f=w[o|0];y=kc(d,w[e|0]),z=f^128,t[y|0]=z;f=d+104|0;re(f,h,w[e|0]);Df(f,0);break ha}y=kc(d,w[e|0]),z=128,t[y|0]=z;f=d+104|0;re(f,h,w[e|0]);Df(f,1);break ha}y=kc(d,w[e|0]),z=128,t[y|0]=z;f=d+104|0;re(f,h,w[e|0]);Df(f,0)}la:{if(r){break la}r=0;if(!dr(k)){break Y}if(w[kc(MU(k),w[e|0])|0]!=w[kc(d,w[e|0])|0]){break la}f=d+104|0;re(f,MU(k)+24|0,w[e|0]);f=Cb(f);o=d+96|0;re(o,h,w[e|0]);if((Cb(o)|0)==(f|0)){break Y}}r=1;break Y}v[22708]=0;R(403,d+104|0,d+120|0);e=v[22708];v[22708]=0;if((e|0)==1){break P}f=d+104|0;e=f;f=qd(e);o=w[e|0];if(oc(i)>>>0<=o>>>0){break Y}f=w[f|0];y=kc(i,w[e|0]),z=(f>>>2|0)+1|0,t[y|0]=z}b=b+1|0;continue}}xb(d+120|0);if(!e){break Q}b=d+152|0;on(b);if(Gb(b,d+144|0)){continue}break G}break}break H}b=1;break E}break H}b=P()|0;O()|0;break k}b=P()|0;O()|0;xb(d+120|0);break F}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break E}b=Sb(l);v[22708]=0;_(860,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=0;v[22708]=0;R(861,k|0,g|0);e=v[22708];v[22708]=0;if((e|0)!=1){break E}}b=P()|0;O()|0}ke(d+168|0);break l}ke(d+168|0)}Yu(g)}xb(d+200|0);if(!b){b=d+232|0;Fh(b);if(Gb(b,d+224|0)){continue}break B}break}e=0;if((b|0)!=2){break A}}e=0;v[22708]=0;Ri(l,0);b=v[22708];v[22708]=0;if((b|0)==1){break q}if(cd(k)){break A}if(c&2){v[22708]=0;U(853,d+200|0,p|0,1347244868);b=v[22708];v[22708]=0;if((b|0)==1){break w}b=d+200|0;y=d,z=Vb(b),v[y+184>>2]=z;y=d,z=Zb(b),v[y+160>>2]=z;f=w[d+255|0];if(Gb(d+184|0,d+160|0)){e=a+480190|0;h=d+13|0;j=d+17|0;while(1){b=v[d+184>>2];ma:{na:{oa:{pa:{qa:{if(!f){v[22708]=0;g=Q(862,b|0,d|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break qa}if(!g){break ma}g=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[22708]=0;g=Le(e,d+104|0);i=v[22708];v[22708]=0;if((i|0)==1){break qa}u[a+480190>>1]=x[g>>1];v[22708]=0;R(863,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[22708];v[22708]=0;if((g|0)==1){break qa}g=d+168|0;LU(g,h);v[22708]=0;R(324,d+120|0,g|0);g=v[22708];v[22708]=0;ra:{if((g|0)!=1){v[22708]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ra}vb(d+120|0);break oa}b=P()|0;O()|0;break na}b=P()|0;O()|0;vb(d+120|0);break na}v[22708]=0;g=Q(864,b|0,d|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break pa}if(!g){break ma}g=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[22708]=0;g=Le(e,d+104|0);i=v[22708];v[22708]=0;if((i|0)==1){break pa}u[a+480190>>1]=x[g>>1];v[22708]=0;R(865,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[22708];v[22708]=0;if((g|0)==1){break pa}g=d+168|0;LU(g,j);v[22708]=0;R(324,d+120|0,g|0);g=v[22708];v[22708]=0;sa:{if((g|0)!=1){v[22708]=0;Q(301,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break sa}vb(d+120|0);break oa}b=P()|0;O()|0;break na}b=P()|0;O()|0;vb(d+120|0);break na}b=P()|0;O()|0;break na}b=P()|0;O()|0;break na}if((x[d+104>>1]-1&65535)>>>0>3998){break ma}g=Rc(d,8,1,0,2);v[22708]=0;W(329,g|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ma}b=P()|0;O()|0}jd(d+200|0);break j}b=d+184|0;Fh(b);if(Gb(b,d+160|0)){continue}break}}jd(d+200|0)}b=0;y=a,z=w[an(k,0)+43|0],v[y+480196>>2]=z;y=a,z=B(w[an(k,0)+42|0],1e4),v[y+480204>>2]=z;bf(Sb(l),x[an(k,0)+40>>1]);if(x[a+480188>>1]){while(1){v[22708]=0;e=(b<<5)+a|0;f=e+480280|0;We(f);h=v[22708];v[22708]=0;if((h|0)==1){break x}y=e+480286|0,z=w[kc(an(k,0)+12|0,b)|0],u[y>>1]=z;y=e+480284|0,z=w[kc(an(k,0),b)|0],u[y>>1]=z;re(d,an(k,0)+24|0,b);e=Cb(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}ta:{if(w[d+255|0]){v[22708]=0;Q(2,d|0,14199)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ta}break m}v[22708]=0;Q(2,d|0,14072)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}}Eb(a+1298304|0,d);vb(d);v[22708]=0;b=Q(2,d|0,7407)|0;f=v[22708];v[22708]=0;e=1;if((f|0)==1){break y}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;if(!(c&1)|!x[a+480188>>1]){break A}v[22708]=0;U(853,d+120|0,p|0,1146045008);b=v[22708];v[22708]=0;if((b|0)==1){break n}b=Je(d+120|0);v[22708]=0;j=a+484344|0;R(330,j|0,b&65535);b=v[22708];v[22708]=0;if((b|0)==1){break p}b=d+120|0;y=d,z=Vb(b),v[y+168>>2]=z;y=d,z=Zb(b),v[y+184>>2]=z;if(Gb(d+168|0,d+184|0)){while(1){h=v[d+168>>2];v[22708]=0;b=T(195,h|0)|0;c=v[22708];v[22708]=0;ua:{va:{wa:{if((c|0)==1){break wa}v[22708]=0;c=T(192,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break ua}v[22708]=0;b=Q(866,h|0,8)|0;c=v[22708];v[22708]=0;if((c|0)==1){break wa}if(b){break va}break ua}b=P()|0;O()|0;break o}v[22708]=0;o=Q(857,h|0,d+255|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;i=T(287,h|0)|0;b=v[22708];v[22708]=0;xa:{if((b|0)==1){break xa}v[22708]=0;b=W(331,j|0,o|0,i|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break xa}if(!b|!i){break ua}n=0;ya:{za:{Aa:{while(1){Ba:{b=_b(j,o);v[22708]=0;c=Uf(b,n);b=v[22708];v[22708]=0;if((b|0)==1){break ya}v[22708]=0;b=T(287,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break za}Ca:{if(b>>>0>=3){v[22708]=0;U(288,d+200|0,h|0,b-2|0);b=v[22708];v[22708]=0;if((b|0)==1){break Aa}b=d+200|0;g=jc(d,b);xb(b);while(1){v[22708]=0;b=Q(191,d|0,3)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ca}if(b){v[22708]=0;R(403,d+200|0,g|0);b=v[22708];v[22708]=0;Da:{Ea:{Fa:{Ga:{if((b|0)!=1){b=d+200|0;f=b;b=qd(b);u[d+160>>1]=x[a+480188>>1]-1;b=w[b|0];v[22708]=0;u[d+104>>1]=b;b=Pc(d+160|0,d+104|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ba}e=x[b>>1];b=t[f|0];if((b|0)>-1){break Da}v[22708]=0;b=T(374,g|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break Ba}if(w[d+255|0]){break Fa}if((b|0)!=255){break Ga}b=254;break Ea}break Ba}if(b>>>0>128){break Ea}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ea}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[f|0]}if(b&64){v[22708]=0;b=T(374,g|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break Ba}t[(c+B(e,6)|0)+1|0]=b+1;b=w[f|0]}if(b&32){v[22708]=0;b=T(374,g|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break Ba}t[d+160|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;v[22708]=0;t[d+104|0]=127;m=ac(d+160|0,d+104|0);s=v[22708];v[22708]=0;if((s|0)==1){break Ba}t[b+4|0]=w[m|0]+1>>>1;b=w[f|0]}if(!(b&16)){continue}v[22708]=0;R(403,d+160|0,g|0);b=v[22708];v[22708]=0;if((b|0)==1){break Ba}b=c+B(e,6)|0;m=d+160|0;f=w[qd(m)|0];t[b+5|0]=f;Ha:{switch(w[m|0]-1|0){case 0:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f<<4|15;continue}t[b+5|0]=f<<3|15;continue;case 1:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f<<4;continue}t[b+5|0]=f<<3&240;continue;case 2:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1|240;continue;case 3:t[(c+B(e,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=f&15;continue}if(f>>>0<=1){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1&15;continue;case 10:t[(c+B(e,6)|0)+3|0]=2;y=b,z=Xu(f,w[d+255|0])|240,t[y+5|0]=z;continue;case 11:t[(c+B(e,6)|0)+3|0]=2;y=b,z=Xu(f,w[d+255|0]),t[y+5|0]=z;continue;case 12:t[(c+B(e,6)|0)+3|0]=3;y=b,z=Xu(f,w[d+255|0])|240,t[y+5|0]=z;continue;case 13:t[(c+B(e,6)|0)+3|0]=3;y=b,z=Xu(f,w[d+255|0]),t[y+5|0]=z;continue;case 14:t[(c+B(e,6)|0)+3|0]=4;if(w[d+255|0]){continue}t[b+5|0]=(f&252)>>>2;continue;case 16:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&1|16;continue;case 15:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=f&240;continue;case 17:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=(f&240)>>>4;continue;case 18:t[(c+B(e,6)|0)+3|0]=20;continue;case 20:t[(c+B(e,6)|0)+3|0]=5;continue;case 21:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|48;continue;case 22:t[(c+B(e,6)|0)+3|0]=7;t[b+5|0]=f|240;continue;case 23:t[(c+B(e,6)|0)+3|0]=7;continue;case 30:t[(c+B(e,6)|0)+3|0]=8;continue;case 31:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|64;continue;case 40:t[(c+B(e,6)|0)+3|0]=10;v[22708]=0;e=T(374,g|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Ba}t[b+5|0]=e;v[22708]=0;Q(318,d|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}break Ba;case 41:t[(c+B(e,6)|0)+3|0]=15;continue;case 42:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|192;continue;case 43:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|208;continue;case 50:t[(c+B(e,6)|0)+3|0]=12;t[b+5|0]=(f&254)>>>1;v[22708]=0;Q(318,d|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}break Ba;case 51:t[(c+B(e,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|176;continue;case 53:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|224;continue;case 60:t[(c+B(e,6)|0)+3|0]=16;continue;case 61:t[(c+B(e,6)|0)+3|0]=17;continue;case 70:t[(c+B(e,6)|0)+3|0]=1;continue;case 71:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|32;continue;case 72:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|128;continue;default:break Ha}}t[(c+B(e,6)|0)+3|0]=0;continue}break}xb(d)}n=n+1|0;if((i|0)==(n|0)){break ua}continue}}break}b=P()|0;O()|0;xb(d);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=d+168|0;Fh(b);if(Gb(b,d+184|0)){continue}break}}if(dr(k)>>>0>=2){c=0;while(1){b=Sj(l,c&255);e=an(k,c);f=x[sc(b,x[e+36>>1])>>1];v[22708]=0;f=me(j,f);h=v[22708];v[22708]=0;Ia:{Ja:{if((h|0)!=1){if(!f){break Ia}f=x[e+36>>1];v[22708]=0;f=Q(545,b|0,f|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break Ja}}b=P()|0;O()|0;break o}if(!(!r|!x[a+480188>>1])){g=e+24|0;b=0;while(1){re(d,g,b);i=Cb(d);h=_b(j,f);Ka:{if(i){v[22708]=0;i=Ce(d,20,145);n=v[22708];v[22708]=0;if((n|0)!=1){i=Gh(op(Ue(i,0),b&65535));v[22708]=0;Q(431,h|0,i|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break Ka}}b=P()|0;O()|0;break o}i=w[kc(e,b)|0];v[22708]=0;i=Ce(d,9,i);n=v[22708];v[22708]=0;if((n|0)!=1){i=Gh(op(Ue(i,0),b&65535));v[22708]=0;Q(431,h|0,i|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break Ka}}b=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(j,f);h=w[e+43|0];v[22708]=0;h=Ce(d,16,h);g=v[22708];v[22708]=0;if((g|0)==1){break z}h=Gh(Ue(h,0));v[22708]=0;Q(431,b|0,h|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break z}b=_b(j,f);e=w[e+42|0];v[22708]=0;e=Ce(d,17,e);f=v[22708];v[22708]=0;if((f|0)!=1){e=Gh(Ue(e,0));v[22708]=0;Q(431,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break Ia}}b=P()|0;O()|0;break o}c=c+1|0;if(dr(k)>>>0>c>>>0){continue}break}}jd(d+120|0);e=1}jd(d+240|0);JU(k);xb(d+272|0);break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break j}b=P()|0;O()|0}jd(d+120|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}Yu(g)}xb(d+200|0)}jd(d+240|0);break h}b=P()|0;O()|0}JU(k);break f}b=P()|0;O()|0}xb(d+272|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}ke(p);xb(q);S(b|0);L()}ke(p);xb(q)}gb=d+352|0;return e|0}function mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;e=f+24|0;k=d+248|0;Bv(e,k);g=yb(e);e=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=e;v[f>>2]=h;v[f+4>>2]=e;e=b;h=f+16|0;cc(h,b,f);h=yb(h);if((h|0)==(g|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(h|0);if(!e){QX(k)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!e){break u}if(!TX(d+248|0)){break u}if(!c){i=1;break u}Hd(a,1024);Ag(a);v[a+480208>>2]=v[a+480208>>2]|12;Sf(a+1074312|0,21);if(Ib(w[d+264|0]|w[d+265|0]<<8)){F=a,G=B(Ib(w[d+264|0]|w[d+265|0]<<8),1e4),v[F+480204>>2]=G}if(Ib(w[d+262|0]|w[d+263|0]<<8)){F=a,G=Ib(w[d+262|0]|w[d+263|0]<<8),v[F+480196>>2]=G}if(!w[d+258|0]){yh(a,1)}e=d+248|4;Qv(b,a+1298268|0,Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=le(d+144|0,b);v[22708]=0;R(519,d+232|0,b|0);e=v[22708];v[22708]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){xb(b);v[22708]=0;U(520,d+144|0,d+232|0,1395544366);b=v[22708];v[22708]=0;if((b|0)==1){break E}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break L}if(!b){break F}v[22708]=0;b=T(416,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break L}v[22708]=0;e=T(416,d+144|0)|0;f=v[22708];v[22708]=0;N:{if((f|0)==1){break N}v[22708]=0;Q(318,d+144|0,4)|0;f=v[22708];v[22708]=0;if((f|0)==1){break N}f=a+484360|0;g=Sb(f);v[22708]=0;fa(521,g|0,d+144|0,b|0,65535,65535)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break M}}break L}a=P()|0;O()|0;xb(b);break a}bf(Sb(f),e);b=d+144|0;xb(b);v[22708]=0;U(520,b|0,d+232|0,1346458708);b=v[22708];v[22708]=0;if((b|0)==1){break K}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break J}if(!b){break H}v[22708]=0;b=T(416,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[22708]=0;b=T(416,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break J}v[22708]=0;p=a+484344|0;R(330,p|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break J}v[22708]=0;k=T(426,d+144|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break J}switch(k-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}if(!k){break G}}xb(d+144|0);break A}xb(d+144|0);v[22708]=0;U(520,d+208|0,d+232|0,1398157625);b=v[22708];v[22708]=0;if((b|0)==1){break D}v[22708]=0;b=T(421,d+208|0)|0;e=v[22708];v[22708]=0;O:{if((e|0)==1){break O}if(!b){break B}v[22708]=0;Q(318,d+208|0,2)|0;b=v[22708];v[22708]=0;if((b|0)==1){break O}v[22708]=0;e=T(426,d+208|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=a;f=b;r=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(r<4294967296&r>=0){b=~~r>>>0;break P}b=0}v[f+480204>>2]=b;v[22708]=0;Q(522,d+208|0,d+144|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+144|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+80>>2]=G;v[22708]=0;v[d+64>>2]=180;e=pd(d+80|0,d- -64|0);f=v[22708];v[22708]=0;if((f|0)!=1){e=v[e>>2]-90|0;f=e>>31;F=((b<<5)+a|0)+480284|0,G=Ac(pqa(e<<7|45,f<<7|e>>>25,90,0),jb)+128|0,u[F>>1]=G;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}xb(d+144|0);break A}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[22708]=0;Q(318,d+208|0,16)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=Q(191,d+208|0,2)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(b){v[22708]=0;b=T(416,d+208|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}u[d+80>>1]=b;v[22708]=0;u[d+64>>1]=256;b=Pc(d+80|0,d- -64|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[22708]=0;Q(318,d+208|0,128)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=Q(522,d+208|0,d+80|0)|0;e=v[22708];v[22708]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}e=(d+80|0)+(b<<1)|0;F=d,G=Ib(w[e|0]|w[e+1|0]<<8),v[F+64>>2]=G;v[22708]=0;v[d+40>>2]=128;e=pd(d- -64|0,d+40|0);f=v[22708];v[22708]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}xb(d+208|0);v[22708]=0;U(520,d+144|0,d+232|0,1413830740);b=v[22708];v[22708]=0;R:{S:{if((b|0)!=1){v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(!b){break R}v[22708]=0;R(523,d+144|0,d+80|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}if((Ib(w[d+90|0]|w[d+91|0]<<8)|0)!=65535){break S}v[22708]=0;Q(318,d+144|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break S}break d}a=P()|0;O()|0;break b}v[22708]=0;b=T(467,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;ca(509,a+1298292|0,d+144|0,b|0,2)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}}xb(d+144|0);v[22708]=0;U(520,d+80|0,d+232|0,1229869908);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=T(421,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){if(b){v[22708]=0;b=T(416,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}T:{e=b<<16>>16;g=e&32767;if(g>>>0>3999){break T}v[22708]=0;b=Q(191,d+80|0,B(g,(e>>>14&2)+50|0)|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break y}if(!b){break T}u[a+480190>>1]=g;i=a+480190|0;if(!g){break z}h=d+162|0;b=1;j=(e|0)>-1;U:{V:{while(1){W:{e=b;f=d;X:{Y:{Z:{if(!j){v[22708]=0;e=T(416,d+80|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break Z}e=e+1|0}u[f+40>>1]=e;v[22708]=0;R(524,d+80|0,d+144|0);e=v[22708];v[22708]=0;if((e|0)!=1){if((x[d+40>>1]-1&65535)>>>0>3998){break X}v[22708]=0;e=Le(i,d+40|0);f=v[22708];v[22708]=0;if((f|0)!=1){break Y}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];e=x[d+40>>1];f=Yb(w[d+266|0]|w[d+267|0]<<8|(w[d+268|0]<<16|w[d+269|0]<<24));v[22708]=0;Y(525,d+144|0,(B(e,104)+a|0)+484380|0,f|0,k|0);e=v[22708];v[22708]=0;if((e|0)==1){break W}v[22708]=0;Qk(d- -64|0,2,h);e=v[22708];v[22708]=0;if((e|0)==1){break V}v[22708]=0;R(324,d+208|0,d- -64|0);e=v[22708];v[22708]=0;if((e|0)==1){break V}v[22708]=0;Q(301,((x[d+40>>1]<<5)+a|0)+946304|0,d+208|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}vb(d+208|0)}e=b&65535;b=b+1|0;if(e>>>0<g>>>0){continue}break z}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+208|0);break f}xb(d+80|0);break A}break w}a=P()|0;O()|0;break f}break v}v[22708]=0;b=T(416,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break x}}a=P()|0;O()|0;break f}if((b|0)==4){u[d+144>>1]=x[i>>1];v[22708]=0;u[d+208>>1]=255;b=Pc(d+144|0,d+208|0);e=v[22708];v[22708]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[22708]=0;U(520,d+208|0,d+232|0,1229278806);b=v[22708];v[22708]=0;if((b|0)==1){break i}b=d- -64|0;g=b|4;i=b|3;h=b|5;j=b|7;while(1){v[22708]=0;b=Q(191,d+80|0,15)|0;e=v[22708];v[22708]=0;_:{if((e|0)!=1){$:{if(b){v[22708]=0;R(527,d+80|0,d- -64|0);b=v[22708];v[22708]=0;aa:{if((b|0)!=1){b=d- -64|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>=x[a+480192>>1]){continue}f=d- -64|0;b=f;b=B(Ib(w[b|0]|w[b+1|0]<<8),104)+a|0;t[b+484524|0]=w[d+72|0];e=w[j|0];t[b+484523|0]=255;t[b+484525|0]=e;b=f;b=Ib(w[b|0]|w[b+1|0]<<8);e=f;e=Ib(w[e|0]|w[e+1|0]<<8);v[22708]=0;e=W(376,a|0,b+1&65535,e+1&65535)|0;b=v[22708];v[22708]=0;if((b|0)==1){break $}if(!e){continue}F=d,G=Ib(w[h|0]|w[h+1|0]<<8),u[F+144>>1]=G;v[22708]=0;u[d+40>>1]=4095;b=Pc(d+144|0,d+40|0);f=v[22708];v[22708]=0;if((f|0)==1){break $}v[e>>2]=x[b>>1];if(w[i|0]==255){continue}b=w[i|0];v[22708]=0;b=Q(190,d+208|0,B(b,34)+2|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}if(!b){continue}v[22708]=0;R(528,d+208|0,d+144|0);b=v[22708];v[22708]=0;if((b|0)==1){break $}t[e+60|0]=w[e+60|0]|1;b=Ib(w[d+144|0]|w[d+145|0]<<8);v[d+60>>2]=3;v[d+44>>2]=16;v[d+48>>2]=240;v[d+40>>2]=b;v[d+56>>2]=d+40;b=v[d+60>>2];v[d+8>>2]=v[d+56>>2];v[d+12>>2]=b;b=RX(d+8|0);v[22708]=0;f=e+48|0;R(446,f|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break $}b=0;if(Nb(f)){break aa}break _}break $}while(1){ba:{t[d+40|0]=64;l=(d+144|0)+(b<<1)|0;n=w[l+2|0];v[22708]=0;t[d+32|0]=n;n=ac(d+40|0,d+32|0);o=v[22708];v[22708]=0;if((o|0)==1){break ba}n=w[n|0];F=Lb(f,b),G=n,t[F+2|0]=G;l=w[l+3|0];F=Lb(f,b),G=l,u[F>>1]=G;b=b+1|0;if(Nb(f)>>>0>b>>>0){continue}break _}break}break $}xb(d+208|0);break w}}a=P()|0;O()|0;xb(d+208|0);break f}if(w[g|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[g|0];t[e+63|0]=b;t[e- -64|0]=b}if(cd(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Nb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}xb(d+80|0);v[22708]=0;U(529,d+208|0,d+232|0,1145131092);b=v[22708];v[22708]=0;if((b|0)==1){break j}b=d+208|0;F=d,G=Vb(b),v[F+32>>2]=G;F=d,G=Zb(b),v[F+24>>2]=G;if(Gb(d+32|0,d+24|0)){z=c&1;l=d+80|4;n=(k|0)!=841887798;A=(k|0)!=841887796;while(1){g=v[d+32>>2];v[22708]=0;Q(318,g|0,4)|0;b=v[22708];v[22708]=0;ca:{da:{ea:{if((b|0)!=1){v[22708]=0;f=T(416,g|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break l}v[22708]=0;h=T(416,g|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}h=n?h:(h>>>0)/y[a+480196>>2]|0;if(!z|f>>>0>255){break ca}v[22708]=0;b=W(331,p|0,f|0,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break m}if(!b){break ca}if(n){break da}v[22708]=0;Q(318,g|0,4)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}j=0;if(!x[a+480188>>1]){break ca}while(1){v[22708]=0;b=T(416,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ea}v[22708]=0;U(288,d+80|0,g|0,b+(b&1)&65535);b=v[22708];v[22708]=0;if((b|0)==1){break n}b=d+80|0;i=jc(d+144|0,b);xb(b);v[d+80>>2]=0;v[d+84>>2]=0;o=0;fa:{while(1){v[22708]=0;b=Q(191,d+144|0,6)|0;e=v[22708];v[22708]=0;if((e|0)==1){break o}if(!(b&y[d+80>>2]<h>>>0)){break fa}b=_b(p,f);v[22708]=0;b=Xc(b,v[d+80>>2],j&65535);e=v[22708];v[22708]=0;ga:{ha:{if((e|0)!=1){v[22708]=0;R(530,d+40|0,i|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}e=d+40|0;m=qd(e);C=Ve(e);D=ej(e);q=fc(e);E=e+5|0;e=t[e|0];if((e-1&255)>>>0>95){break ha}t[b|0]=e+13;if(!v[d+84>>2]){break ga}t[b+3|0]=19;v[22708]=0;v[d+64>>2]=15;e=pd(l,d- -64|0);s=v[22708];v[22708]=0;if((s|0)==1){break o}t[b+5|0]=w[e|0]|208;break ga}break o}if((e|0)>-1){break ga}if(v[d+84>>2]){t[b+3|0]=19;v[22708]=0;v[d+64>>2]=15;e=pd(l,d- -64|0);s=v[22708];v[22708]=0;if((s|0)!=1){t[b+5|0]=w[e|0]|192;break ga}break o}t[b|0]=254}if(w[m|0]){t[b+2|0]=1;v[22708]=0;t[d+64|0]=64;e=ac(m,d- -64|0);m=v[22708];v[22708]=0;if((m|0)==1){break o}t[b+4|0]=w[e|0]}e=w[C|0];if(e){t[b+1|0]=e}e=w[D|0];if(e|w[q|0]){t[b+3|0]=e;t[b+5|0]=w[q|0];v[22708]=0;Pf(b);b=v[22708];v[22708]=0;if((b|0)==1){break o}}b=w[E|0];if(b&128){v[22708]=0;e=T(374,i|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break o}b=e|b<<8&32512}e=v[a+480196>>2];v[22708]=0;o=b+o|0;kt(d- -64|0,o,e);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[d+68>>2];v[d+80>>2]=v[d+64>>2];v[d+84>>2]=b;continue}break}break o}xb(d+144|0);j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break}break ca}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}b=_b(p,f);v[22708]=0;b=Xc(b,0,0);e=v[22708];v[22708]=0;if((e|0)==1){break s}j=0;if(!h){break ca}while(1){i=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[22708]=0;R(531,d+144|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break ja}ka:{if(!A){v[d+80>>2]=v[d+144>>2];e=d+80|0;o=qd(e);m=Ve(e);q=ej(e);e=t[e|0];if((e|0)>=1){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}f=b;e=w[o|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[o|0]}t[f+1|0]=e<<4&48|w[m|0]>>>4;t[b+3|0]=w[m|0]&15;t[b+5|0]=w[q|0];break ka}e=v[d+144>>2];v[d+20>>2]=e;v[22708]=0;v[d+16>>2]=e;gr(d+16|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break ja}e=lc(d+144|0,0);t[b+1|0]=w[b+1|0]|w[e|0]&48}v[22708]=0;Pf(b);e=v[22708];v[22708]=0;if((e|0)==1){break ja}e=w[b+3|0];la:{if(e>>>0>11){break la}e=1<<e;ma:{if(!(e&2240)){if(!(e&12)){break la}if(!w[b+5|0]){break ma}break la}e=w[b+5|0];f=e&240;if(f){t[b+5|0]=f;break la}if(e){break la}}t[b+3|0]=0}b=b+6|0;i=i+1|0;if(x[a+480188>>1]>(i&65535)>>>0){continue}break ia}break}a=P()|0;O()|0;break k}j=j+1|0;if((j|0)!=(h|0)){continue}break}}b=d+32|0;Fh(b);if(Gb(b,d+24|0)){continue}break}}jd(d+208|0);v[22708]=0;U(520,d+144|0,d+232|0,1346458702);b=v[22708];v[22708]=0;if((b|0)==1){a=P()|0;O()|0;break b}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((e|0)!=1){if(b){e=Kb(d+80|0);b=0;Ba:{while(1){Ca:{v[22708]=0;f=Q(191,d+144|0,1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Ca}if(!f){break Ba}if(Te(p)>>>0<=b>>>0){break Ba}v[22708]=0;W(533,d+144|0,e|0,32)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Ca}f=_b(p,b);v[22708]=0;Q(428,f|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Ca}b=b+1|0;continue}break}a=P()|0;O()|0;vb(e);break Aa}vb(e)}b=d+144|0;xb(b);v[22708]=0;U(520,b|0,d+232|0,1414679374);b=v[22708];v[22708]=0;if((b|0)==1){break za}v[22708]=0;b=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break va}if(!b){break wa}e=Kb(d+80|0);b=0;while(1){v[22708]=0;f=Q(191,d+144|0,1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break ya}if(!f|x[a+480188>>1]<=b>>>0){break xa}v[22708]=0;W(533,d+144|0,e|0,32)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ya}v[22708]=0;Q(399,((b<<5)+a|0)+480289|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ya}b=b+1|0;continue}}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e);break ua}vb(e)}b=d+144|0;xb(b);v[22708]=0;U(529,b|0,d+232|0,1145129300);b=v[22708];v[22708]=0;if((b|0)==1){break ta}b=d+144|0;F=d,G=Vb(b),v[F+80>>2]=G;F=d,G=Zb(b),v[F+208>>2]=G;if(Gb(d+80|0,d+208|0)){e=c&2;while(1){b=v[d+80>>2];v[22708]=0;c=T(416,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Rc(d- -64|0,f&1?16:8,f&64?2:1,1,0);v[22708]=0;W(329,f|0,c+484484|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break p}}b=d+80|0;Fh(b);if(Gb(b,d+208|0)){continue}break}}jd(d+144|0);b=Kb(d+80|0);if((k|0)!=841887798){break ra}v[22708]=0;c=Q(2,d+144|0,6647)|0;e=v[22708];v[22708]=0;if((e|0)==1){break sa}Eb(b,c);vb(c);break qa}a=P()|0;O()|0}xb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break q}v[22708]=0;U(520,d+144|0,d+232|0,1447383635);c=v[22708];v[22708]=0;Da:{Ea:{Fa:{Ga:{Ha:{if((c|0)!=1){v[22708]=0;c=T(421,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break pa}if(!c){break Ea}v[22708]=0;c=T(426,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break Ha}v[22708]=0;R(411,d- -64|0,1401);e=v[22708];v[22708]=0;if((e|0)==1){break Ga}v[d+40>>2]=c>>>4;v[22708]=0;v[d+32>>2]=c&15;Y(534,d+208|0,d- -64|0,d+40|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break Fa}c=d+208|0;Eb(b,c);vb(c);Hb(d- -64|0);break Da}a=P()|0;O()|0;break q}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;Hb(d- -64|0);break r}v[22708]=0;c=Q(2,d+208|0,5656)|0;e=v[22708];v[22708]=0;if((e|0)==1){break t}Eb(b,c);vb(c)}xb(d+144|0)}v[22708]=0;c=Q(2,d+144|0,5656)|0;e=v[22708];v[22708]=0;if((e|0)==1){break oa}Eb(a+1298304|0,c);vb(c);v[22708]=0;c=Q(2,d+144|0,7403)|0;e=v[22708];v[22708]=0;if((e|0)==1){break na}Eb(a+1298316|0,c);vb(c);Eb(a+1298328|0,b);v[a+1298364>>2]=2;vb(b);i=1;break v}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}ke(d+232|0)}gb=d+272|0;return i|0}a=P()|0;O()|0;break r}a=P()|0;O()|0;break k}xb(d+144|0)}vb(b);break b}a=P()|0;O()|0;jd(d+144|0);break b}a=P()|0;O()|0;xb(d+144|0);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0}jd(d+208|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}xb(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(d+144|0);break b}a=P()|0;O()|0;xb(d+208|0)}ke(d+232|0)}S(a|0);L()}function uI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;x=gb-48|0;gb=x;a:{if(c>>>0<=2){c=c<<2;I=v[c+74780>>2];H=v[c+74768>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=md(b)}if(ym(c)){continue}break}m=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}m=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=md(b)}e:{f:{while(1){if(t[f+2048|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=md(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=x;h=gb-16|0;gb=h;g=(p(C(C(m|0)*C(N))),j(2));c=g&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;m=d<<25;d=c+1065353216|0;break h}m=g<<25;d=g>>>7|2147418112;if(c>>>0>=2139095040){break h}m=0;d=0;if(!c){break h}d=c;c=E(c);Mf(h,d,0,0,0,c+81|0);k=v[h>>2];l=v[h+4>>2];m=v[h+8>>2];d=v[h+12>>2]^65536|16265-c<<16}v[b>>2]=k;v[b+4>>2]=l;v[b+8>>2]=m;v[b+12>>2]=g&-2147483648|d;gb=h+16|0;k=v[x+8>>2];l=v[x+12>>2];h=v[x>>2];g=v[x+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+7248|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=md(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=md(b)}if((f&-33)==88){f=gb-432|0;gb=f;c=b;A=v[b+104>>2];b=v[b+4>>2];p:{if(A>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=md(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){J=1;v[c+4>>2]=b+1;b=w[b|0]}else{J=1;b=md(c)}continue}break}b=md(c)}G=1;if((b|0)!=48){break q}while(1){b=k;k=b-1|0;l=l-(b>>>0<1)|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=md(c)}if((b|0)==48){continue}break}J=1}A=1073676288;u:{while(1){v:{o=b|32;w:{x:{D=b-48|0;if(D>>>0<10){break x}if((b|0)!=46?o-97>>>0>=6:0){break u}if((b|0)!=46){break x}if(G){break v}G=1;k=h;l=g;break w}b=(b|0)>57?o-87|0:D;y:{if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){i=b+(i<<4)|0;break y}if((g|0)<0?1:(g|0)<=0?h>>>0<=28:0){Vg(f+48|0,b);Ed(f+32|0,r,z,F,A,0,0,0,1073414144);r=v[f+32>>2];z=v[f+36>>2];F=v[f+40>>2];A=v[f+44>>2];Ed(f+16|0,r,z,F,A,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);xg(f,q,e,s,u,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);s=v[f+8>>2];u=v[f+12>>2];q=v[f>>2];e=v[f+4>>2];break y}if(!b|n){break y}Ed(f+80|0,r,z,F,A,0,0,0,1073610752);xg(f- -64|0,q,e,s,u,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);s=v[f+72>>2];u=v[f+76>>2];n=1;q=v[f+64>>2];e=v[f+68>>2]}b=h+1|0;g=b>>>0<1?g+1|0:g;h=b;J=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=md(c)}continue}break}b=46}z:{A:{B:{if(!J){if(!v[c+104>>2]){if(d){break A}break B}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break B}v[c+4>>2]=b-2;if(!G){break A}v[c+4>>2]=b-3;break A}if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){F=h;A=g;while(1){i=i<<4;n=A;A=F+1|0;n=A>>>0<1?n+1|0:n;F=A;A=n;if((F|0)!=8|n){continue}break}}C:{D:{E:{if((b&-33)==80){F=tI(c,d);b=jb;A=b;if(F|(b|0)!=-2147483648){break C}if(d){if(v[c+104>>2]){break E}break D}q=0;e=0;zi(c,0,0);c=0;b=0;break z}if(!v[c+104>>2]){break D}}v[c+4>>2]=v[c+4>>2]-1}F=0;A=0}if(!i){uj(f+112|0,+(m|0)*0);q=v[f+112>>2];e=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break z}b=G?k:h;c=(G?l:g)<<2|b>>>30;b=F+(b<<2)|0;c=c+A|0;c=b>>>0<F>>>0?c+1|0:c;h=b-32|0;g=c-(b>>>0<32)|0;b=g;if((b|0)>0?1:(b|0)>=0?h>>>0>0-I>>>0:0){v[115189]=68;Vg(f+160|0,m);Ed(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Ed(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];e=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break z}b=I-226|0;c=h>>>0>=b>>>0;b=b>>31;if((b|0)<(g|0)?1:(g|0)>=(b|0)?c:0){if((i|0)>-1){while(1){xg(f+416|0,q,e,s,u,0,0,0,-1073807360);c=mB(q,e,s,u,1073610752);b=(c|0)<0;xg(f+400|0,q,e,s,u,b?q:v[f+416>>2],b?e:v[f+420>>2],b?s:v[f+424>>2],b?u:v[f+428>>2]);b=h;h=b-1|0;g=g-(b>>>0<1)|0;s=v[f+408>>2];u=v[f+412>>2];q=v[f+400>>2];e=v[f+404>>2];i=i<<1|(c|0)>-1;if((i|0)>-1){continue}break}}b=h;c=I;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=((c|0)<0?1:(c|0)<=0?b>>>0<H>>>0:0)?(b|0)>0?b:0:H;F:{if((c|0)>=113){Vg(f+384|0,m);k=v[f+392>>2];l=v[f+396>>2];r=v[f+384>>2];z=v[f+388>>2];g=0;b=0;break F}uj(f+352|0,ji(1,144-c|0));Vg(f+336|0,m);r=v[f+336>>2];z=v[f+340>>2];k=v[f+344>>2];l=v[f+348>>2];wI(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],r,z,k,l);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(i&1)&((rn(q,e,s,u,0,0,0,0)|0)!=0&(c|0)<32);Zn(f+320|0,c+i|0);Ed(f+304|0,r,z,k,l,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;xg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);b=c;Ed(f+288|0,b?0:q,b?0:e,b?0:s,b?0:u,r,z,k,l);xg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Ux(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];g=v[f+252>>2];if(!rn(b,c,d,g,0,0,0,0)){v[115189]=68}vI(f+224|0,b,c,d,g,h);q=v[f+224>>2];e=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break z}v[115189]=68;Vg(f+208|0,m);Ed(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Ed(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];e=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break z}zi(c,0,0)}uj(f+96|0,+(m|0)*0);q=v[f+96>>2];e=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[x+16>>2]=q;v[x+20>>2]=e;v[x+24>>2]=b;v[x+28>>2]=c;gb=f+432|0;k=v[x+24>>2];l=v[x+28>>2];h=v[x+16>>2];g=v[x+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}i=b;q=m;m=0;f=0;e=gb-8976|0;gb=e;J=H+I|0;O=0-J|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}b=v[i+4>>2];if(b>>>0>=y[i+104>>2]){break I}v[i+4>>2]=b+1;c=w[b|0];break H}}else{b=v[i+4>>2];if(b>>>0<y[i+104>>2]){m=1;v[i+4>>2]=b+1;c=w[b|0]}else{m=1;c=md(i)}continue}break}c=md(i)}o=1;if((c|0)!=48){break G}while(1){b=k;k=b-1|0;l=l-(b>>>0<1)|0;b=v[i+4>>2];J:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;c=w[b|0];break J}c=md(i)}if((c|0)==48){continue}break}m=1}v[e+784>>2]=0;K:{L:{b=(c|0)==46;n=c-48|0;M:{N:{O:{P:{if(n>>>0>9?b:1){while(1){Q:{if(b&1){if(!o){k=h;l=g;o=1;break Q}b=!m;break P}b=h+1|0;g=b>>>0<1?g+1|0:g;h=b;if((f|0)<=2044){G=(c|0)==48?G:h;b=(e+784|0)+(f<<2)|0;m=b;if(D){n=(B(v[b>>2],10)+c|0)-48|0}v[m>>2]=n;m=1;c=D+1|0;b=(c|0)==9;D=b?0:c;f=b+f|0;break Q}if((c|0)==48){break Q}v[e+8960>>2]=v[e+8960>>2]|1;G=18396}b=v[i+4>>2];R:{if(b>>>0<y[i+104>>2]){v[i+4>>2]=b+1;c=w[b|0];break R}c=md(i)}b=(c|0)==46;n=c-48|0;if(b|n>>>0<10){continue}break}}k=o?k:h;l=o?l:g;if(!(!m|(c&-33)!=69)){r=tI(i,d);b=jb;z=b;S:{if(r|(b|0)!=-2147483648){break S}if(!d){break M}r=0;z=0;if(!v[i+104>>2]){break S}v[i+4>>2]=v[i+4>>2]-1}if(!m){break N}n=l+z|0;b=k+r|0;n=b>>>0<r>>>0?n+1|0:n;k=b;l=n;break L}b=!m;if((c|0)<0){break O}}if(!v[i+104>>2]){break O}v[i+4>>2]=v[i+4>>2]-1}if(!b){break L}}v[115189]=28}h=0;g=0;zi(i,0,0);c=0;b=0;break K}b=v[e+784>>2];if(!b){uj(e,+(q|0)*0);h=v[e>>2];g=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break K}if(!((h|0)!=(k|0)|(g|0)!=(l|0)|((g|0)>0?1:(g|0)>=0?h>>>0>9:0)|(b>>>H|0?(H|0)<=30:0))){Vg(e+48|0,q);Zn(e+32|0,b);Ed(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);h=v[e+16>>2];g=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break K}if((l|0)>0?1:(l|0)>=0?k>>>0>(I|0)/-2>>>0:0){v[115189]=68;Vg(e+96|0,q);Ed(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Ed(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);h=v[e+64>>2];g=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break K}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if((b|0)>(l|0)?1:(l|0)<=(b|0)?c:0){v[115189]=68;Vg(e+144|0,q);Ed(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Ed(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);h=v[e+112>>2];g=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break K}if(D){if((D|0)<=8){b=(e+784|0)+(f<<2)|0;i=v[b>>2];while(1){i=B(i,10);D=D+1|0;if((D|0)!=9){continue}break}v[b>>2]=i}f=f+1|0}T:{o=k;if((G|0)>(k|0)|(G|0)>=9|(k|0)>17){break T}if((o|0)==9){Vg(e+192|0,q);Zn(e+176|0,v[e+784>>2]);Ed(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);h=v[e+160>>2];g=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break K}if((o|0)<=8){Vg(e+272|0,q);Zn(e+256|0,v[e+784>>2]);Ed(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Vg(e+224|0,v[(0-o<<2)+74768>>2]);_E(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);h=v[e+208>>2];g=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break K}b=(B(o,-3)+H|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break T}Vg(e+352|0,q);Zn(e+336|0,c);Ed(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Vg(e+304|0,v[(o<<2)+74696>>2]);Ed(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);h=v[e+288>>2];g=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break K}while(1){c=f;f=f-1|0;if(!v[(e+784|0)+(f<<2)>>2]){continue}break}D=0;b=(o|0)%9|0;U:{if(!b){b=0;break U}d=(o|0)>-1?b:b+9|0;V:{if(!c){b=0;c=0;break V}g=v[(0-d<<2)+74768>>2];h=1e9/(g|0)|0;n=0;i=0;b=0;while(1){k=n;l=(e+784|0)+(i<<2)|0;n=v[l>>2];m=(n>>>0)/(g>>>0)|0;k=k+m|0;v[l>>2]=k;k=!k&(b|0)==(i|0);b=k?b+1&2047:b;o=k?o-9|0:o;n=B(h,n-B(g,m)|0);i=i+1|0;if((i|0)!=(c|0)){continue}break}if(!n){break V}v[(e+784|0)+(c<<2)>>2]=n;c=c+1|0}o=(o-d|0)+9|0}while(1){h=(e+784|0)+(b<<2)|0;W:{while(1){if((o|0)!=36|y[h>>2]>10384592?(o|0)>=36:0){break W}m=c+2047|0;n=0;while(1){l=n;g=m&2047;m=(e+784|0)+(g<<2)|0;d=v[m>>2];n=d>>>3|0;k=d<<29;d=l+k|0;n=d>>>0<k>>>0?n+1|0:n;k=d;l=n;if(!l&k>>>0<1000000001){n=0}else{n=rqa(k,l,1e9,0);k=k-oqa(n,jb,1e9,0)|0}v[m>>2]=k;c=(g|0)!=(c-1&2047)?c:(b|0)==(g|0)?c:k?c:g;m=g-1|0;if((b|0)!=(g|0)){continue}break}D=D-29|0;if(!n){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;g=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[g>>2]=v[g>>2]|v[d+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=n;continue}break}X:{Y:while(1){d=c+1&2047;k=(e+784|0)+((c-1&2047)<<2)|0;while(1){g=(o|0)>45?9:1;Z:{while(1){m=b;i=0;_:{while(1){$:{b=i+m&2047;if((b|0)==(c|0)){break $}b=v[(e+784|0)+(b<<2)>>2];h=v[(i<<2)+74720>>2];if(b>>>0<h>>>0){break $}if(b>>>0>h>>>0){break _}i=i+1|0;if((i|0)!=4){continue}}break}if((o|0)!=36){break _}k=0;l=0;i=0;h=0;g=0;while(1){b=i+m&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Ed(e+768|0,k,l,h,g,0,0,1342177280,1075633366);Zn(e+752|0,v[(e+784|0)+(b<<2)>>2]);xg(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);h=v[e+744>>2];g=v[e+748>>2];k=v[e+736>>2];l=v[e+740>>2];i=i+1|0;if((i|0)!=4){continue}break}Vg(e+720|0,q);Ed(e+704|0,k,l,h,g,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);h=v[e+712>>2];g=v[e+716>>2];k=0;l=0;r=v[e+704>>2];z=v[e+708>>2];o=D+113|0;d=o-I|0;n=(d|0)<(H|0);b=n?(d|0)>0?d:0:H;if((b|0)<=112){break Z}break X}D=g+D|0;b=c;if((m|0)==(b|0)){continue}break}l=1e9>>>g|0;n=-1<<g^-1;i=0;b=m;while(1){h=i;f=(e+784|0)+(m<<2)|0;i=v[f>>2];h=h+(i>>>g|0)|0;v[f>>2]=h;h=!h&(b|0)==(m|0);b=h?b+1&2047:b;o=h?o-9|0:o;i=B(l,i&n);m=m+1&2047;if((m|0)!=(c|0)){continue}break}if(!i){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=i;c=d;continue Y}v[k>>2]=v[k>>2]|1;b=d;continue}break}break}uj(e+656|0,ji(1,225-b|0));wI(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],r,z,h,g);F=v[e+696>>2];A=v[e+700>>2];K=v[e+688>>2];L=v[e+692>>2];uj(e+640|0,ji(1,113-b|0));FE(e+672|0,r,z,h,g,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];l=v[e+676>>2];s=v[e+680>>2];u=v[e+684>>2];Ux(e+624|0,r,z,h,g,k,l,s,u);xg(e+608|0,K,L,F,A,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);h=v[e+616>>2];g=v[e+620>>2];r=v[e+608>>2];z=v[e+612>>2]}f=m+4&2047;aa:{if((f|0)==(c|0)){break aa}f=v[(e+784|0)+(f<<2)>>2];ba:{if(f>>>0<=499999999){if(!((m+5&2047)==(c|0)?f:1)){break ba}uj(e+496|0,+(q|0)*.25);xg(e+480|0,k,l,s,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);s=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];l=v[e+484>>2];break ba}if((f|0)!=5e8){uj(e+592|0,+(q|0)*.75);xg(e+576|0,k,l,s,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);s=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];l=v[e+580>>2];break ba}M=+(q|0);if((m+5&2047)==(c|0)){uj(e+528|0,M*.5);xg(e+512|0,k,l,s,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);s=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];l=v[e+516>>2];break ba}uj(e+560|0,M*.75);xg(e+544|0,k,l,s,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);s=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];l=v[e+548>>2]}if((b|0)>111){break aa}FE(e+464|0,k,l,s,u,0,0,0,1073676288);if(rn(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break aa}xg(e+448|0,k,l,s,u,0,0,0,1073676288);s=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];l=v[e+452>>2]}xg(e+432|0,r,z,h,g,k,l,s,u);Ux(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],K,L,F,A);h=v[e+424>>2];g=v[e+428>>2];r=v[e+416>>2];z=v[e+420>>2];ca:{if((-2-J|0)>=(o&2147483647)){break ca}v[e+408>>2]=h;v[e+412>>2]=g&2147483647;v[e+400>>2]=r;v[e+404>>2]=z;Ed(e+384|0,r,z,h,g,0,0,0,1073610752);A=v[e+400>>2];F=v[e+404>>2];f=v[e+408>>2];o=v[e+412>>2];c=mB(A,F,f,o,1081081856);m=(c|0)<0;i=m;h=i?h:v[e+392>>2];g=i?g:v[e+396>>2];r=i?r:v[e+384>>2];z=i?z:v[e+388>>2];D=((c|0)>-1)+D|0;if((D+110|0)<=(O|0)){if((((mB(A,F,f,o,1081081856)|0)<0?n:n&(b|0)!=(d|0))|0)!=1){break ca}if(!rn(k,l,s,u,0,0,0,0)){break ca}}v[115189]=68}vI(e+368|0,r,z,h,g,D);h=v[e+368>>2];g=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[x+32>>2]=h;v[x+36>>2]=g;v[x+40>>2]=b;v[x+44>>2]=c;gb=e+8976|0;k=v[x+40>>2];l=v[x+44>>2];h=v[x+32>>2];g=v[x+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}da:{c=v[b+4>>2];ea:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=md(b)}if((c|0)==40){f=1;break da}l=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];fa:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break fa}c=md(b)}if(c-97>>>0>=26?c-48>>>0<10|c-65>>>0<26|(c|0)==95:1){f=f+1|0;continue}break}l=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[115189]=28;zi(b,0,0)}l=0}v[a>>2]=h;v[a+4>>2]=g;v[a+8>>2]=k;v[a+12>>2]=l;gb=x+48|0}function Mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-416|0;gb=d;vc(b);e=d+408|0;g=Xv(b,e);if(!g){rW(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!g){break q}if(!CW(d+408|0)){break q}if(!c){p=1;break q}A=le(d+384|0,b);v[22708]=0;R(666,d+368|0,A|0);b=v[22708];v[22708]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((b|0)!=1){v[22708]=0;U(667,d+344|0,d+368|0,20041);b=v[22708];v[22708]=0;if((b|0)==1){break F}v[22708]=0;b=T(275,d+344|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}if(!b){break r}v[22708]=0;b=Q(668,d+344|0,d+248|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}if(!b){break r}v[22708]=0;R(367,a|0,16384);b=v[22708];v[22708]=0;if((b|0)==1){break w}v[a+480208>>2]=8;v[22708]=0;b=a+1074312|0;W(409,b|0,9,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}v[22708]=0;Q(410,b|0,21)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}v[22708]=0;Q(410,b|0,30)|0;b=v[22708];v[22708]=0;if((b|0)==1){break w}v[22708]=0;b=Q(2,d+208|0,5413)|0;e=v[22708];v[22708]=0;if((e|0)==1){break C}Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,d+208|0,8009)|0;e=v[22708];v[22708]=0;if((e|0)==1){break B}Eb(a+1298316|0,b);vb(b);v[22708]=0;b=Q(2,d+96|0,14600)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}e=w[d+412|0];switch(e-16|0){case 1:break z;case 0:break E;default:break D}}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[22708]=0;Q(2,d+232|0,12226)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break x}break e}if(!e){break y}v[22708]=0;Q(2,d+232|0,18720)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}break x}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[22708]=0;Q(2,d+232|0,12244)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break x}break e}v[22708]=0;Q(2,d+232|0,10601)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}}v[22708]=0;U(3,d+208|0,b|0,d+232|0);e=v[22708];v[22708]=0;if((e|0)==1){break f}e=d+208|0;Eb(a+1298328|0,e);vb(e);vb(d+232|0);vb(b);v[a+1298364>>2]=5;v[22708]=0;Ke(d+96|0,3,d+248|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;R(324,d+208|0,d+96|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}b=d+208|0;Eb(a+1298268|0,b);vb(b);v[22708]=0;Zj(d+232|0,3,d+280|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(324,d+96|0,d+232|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;U(13,d+208|0,5,d+96|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}b=d+208|0;Eb(a+1298280|0,b);vb(b);vb(d+96|0);v[a+480200>>2]=w[d+304|0]+1;H=a,I=Fd(w[d+305|0],1,255),v[H+480196>>2]=I;H=a,I=B(Fd(w[d+306|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Sb(b);g=w[d+300|0]|w[d+301|0]<<8;v[22708]=0;fa(521,e|0,d+344|0,g|0,65535,65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}bf(Sb(b),w[d+302|0]|w[d+303|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[22708]=0;e=(b<<5)+a|0;g=e+480280|0;We(g);f=v[22708];v[22708]=0;if((f|0)==1){break j}f=b+d|0;h=w[f+307|0]<<1&254;u[e+480284>>1]=(h|0)==254?256:h;G:{if(t[f+307|0]<=-1){v[g>>2]=v[g>>2]|1024;break G}u[a+480188>>1]=b+1}v[22708]=0;R(669,d+344|0,e+480289|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[22708]=0;U(667,d+208|0,d+368|0,17741);b=v[22708];v[22708]=0;if((b|0)==1){break k}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22708]=0;b=T(195,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}v[22708]=0;ca(509,a+1298292|0,d+344|0,b|0,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break w}v[22708]=0;U(667,d+208|0,d+368|0,21321);b=v[22708];v[22708]=0;if((b|0)==1){break l}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22708]=0;b=T(275,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}H:{if(b){v[22708]=0;U(667,d+208|0,d+368|0,16723);b=v[22708];v[22708]=0;if((b|0)==1){break m}v[22708]=0;k=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break n}I:{if(!k){break I}m=c&2;g=0;while(1){v[22708]=0;e=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break n}if(!e){break I}v[22708]=0;b=Q(191,d+344|0,56)|0;f=v[22708];v[22708]=0;if((f|0)==1){break n}if(!b){break I}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[22708]=0;b=B(e,104)+a|0;f=b+484380|0;R(424,f|0,0);h=v[22708];v[22708]=0;if((h|0)==1){break n}v[22708]=0;W(474,d+344|0,((e<<5)+a|0)+946304|0,32)|0;e=v[22708];v[22708]=0;if((e|0)==1){break n}v[22708]=0;W(477,d+344|0,b+484423|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break n}J:{if(w[d+412|0]<=15){v[22708]=0;e=T(287,d+344|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break J}break n}v[22708]=0;e=T(192,d+344|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}}v[b+484404>>2]=e<<1;v[22708]=0;e=T(192,d+344|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}v[f>>2]=e;v[22708]=0;h=T(192,d+344|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=h;v[22708]=0;h=T(192,d+344|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break n}j=b+484388|0;v[j>>2]=h;if(h){i=b+484414|0;u[i>>1]=x[i>>1]|2;v[j>>2]=h+v[e>>2]}v[22708]=0;h=T(374,d+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break H}if(w[d+412|0]<=15){u[b+484410>>1]=h}v[22708]=0;h=T(374,d+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}l=b+484414|0;b=x[l>>1];i=8;if(h&1){b=b|1;u[l>>1]=b;v[f>>2]=v[f>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[j>>2]=v[j>>2]>>>1;i=16}u[l>>1]=b&65531|h<<1&4;b=Rc(d+96|0,i,1,0,((h&12)!=0)<<3);K:{if(!m){break K}v[22708]=0;W(329,b|0,f|0,d+208|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break K}break n}g=g+1|0;if(k>>>0>(g&255)>>>0){continue}break}}xb(d+208|0)}v[22708]=0;U(667,d+208|0,d+368|0,18761);b=v[22708];v[22708]=0;if((b|0)==1){break p}b=d+344|0;e=d+208|0;Vc(b,e);xb(e);v[22708]=0;b=T(275,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}if(b){k=dd(d+96|0);i=dd(d+232|0);l=dd(d+192|0);v[22708]=0;U(667,d+168|0,d+368|0,17750);b=v[22708];v[22708]=0;if((b|0)==1){break o}e=v[d+180>>2];b=d- -64|0;v[b>>2]=v[d+176>>2];v[b+4>>2]=e;v[d+72>>2]=v[d+184>>2];v[22708]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(670,d+56|0,k|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[22708]=0;U(667,d+144|0,d+368|0,17744);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[22708]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(670,d+32|0,i|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[22708]=0;U(667,d+120|0,d+368|0,17734);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[22708]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(670,d+8|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}j=0;v[22708]=0;o=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}if(o){b=d+208|0;y=b|4;z=b|2;q=b|6;r=b|5;s=b|3;e=b|1;while(1){v[22708]=0;R(403,d+80|0,d+344|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=d+80|0;m=qd(b);L:{M:{N:{if(!w[b|0]){break N}g=w[m|0];v[22708]=0;g=Q(191,d+344|0,B(g,14)+32|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}if(!g){break N}b=w[b|0];v[22708]=0;h=W(376,a|0,b|0,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}if(h){break M}}b=w[m|0];v[22708]=0;Q(318,d+344|0,B(b,14)+32|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break L}break o}v[22708]=0;W(474,d+344|0,h+492|0,32)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}if(!w[m|0]){break L}C=h+88|0;D=h+68|0;E=h+48|0;F=h+236|0;f=0;b=0;while(1){v[22708]=0;R(671,d+344|0,d+208|0);g=v[22708];v[22708]=0;if((g|0)==1){break o}O:{if(!w[d+208|0]|x[a+480190>>1]<w[d+208|0]){break O}g=e;if(w[e|0]>128){t[g|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){g=w[d+208|0];H=wd(F,b&255),I=g,u[H>>1]=I;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}G=w[e|0];b=w[s|0];v[22708]=0;U(672,E|0,b|0,k|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=w[r|0];v[22708]=0;U(672,D|0,b|0,i|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=w[d+221|0];v[22708]=0;U(672,C|0,b|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[h>>2]=(w[q|0]|w[q+1|0]<<8)+1>>>1;b=w[d+208|0];P:{if(w[s|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break P}g=(B(b,104)+a|0)+484414|0;u[g>>1]=x[g>>1]|32768}u[d+118>>1]=w[y|0]<<1;v[22708]=0;u[d+116>>1]=254;n=Pc(d+118|0,d+116|0);g=v[22708];v[22708]=0;Q:{R:{if((g|0)!=1){g=B(b,104)+a|0;u[g+484408>>1]=x[n>>1];t[g+484418|0]=w[(w[d+219|0]&3)+28885|0];n=g+484419|0;t[n|0]=w[d+218|0];p=g+484420|0;t[p|0]=w[d+217|0]+3>>>2;t[g+484421|0]=w[d+216|0];b=w[n|0];if(b){break R}p=255;break Q}break o}p=dm(Qc((((w[p|0]<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0))}b=G+1|0;t[n|0]=p;if(!(w[r|0]&64)){break O}g=g+484414|0;u[g>>1]=x[g>>1]|32}f=f+1|0;if(w[m|0]>(f&255)>>>0){continue}break}}j=j+1|0;if(o>>>0>(j&255)>>>0){continue}break}}dp(l);dp(i);dp(k)}p=1;k=mc(d+232|0);if(!(c&1)){break s}v[22708]=0;U(667,d+208|0,d+368|0,21076);b=v[22708];v[22708]=0;S:{T:{U:{if((b|0)!=1){b=Vc(d+344|0,d+208|0);v[22708]=0;b=T(275,b|0)|0;c=v[22708];v[22708]=0;V:{W:{X:{Y:{Z:{_:{if((c|0)!=1){xb(d+208|0);$:{if(!b){break $}v[22708]=0;c=T(287,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break _}v[22708]=0;R(673,k|0,c+1|0);b=v[22708];v[22708]=0;if((b|0)==1){break _}if(!c){break $}b=1;while(1){v[22708]=0;e=T(287,d+344|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Z}v[22708]=0;U(288,d+96|0,d+344|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break Z}e=d+208|0;g=d+96|0;f=jc(e,g);Vc(Kg(k,b),f);f=(b|0)==(c|0);xb(e);xb(g);b=b+1|0;if(!f){continue}break}}v[22708]=0;U(667,d+208|0,d+368|0,16720);b=v[22708];v[22708]=0;if((b|0)==1){break Y}b=Vc(d+344|0,d+208|0);v[22708]=0;b=T(275,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break X}xb(d+208|0);if(!b){break V}f=0;v[22708]=0;l=T(374,d+344|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}if(l){while(1){m=32;aa:{if(w[d+412|0]>=16){v[22708]=0;R(674,d+344|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break U}if(!(w[d+208|0]>32|x[a+480188>>1]>=w[d+208|0])){u[a+480188>>1]=w[d+208|0]}m=w[d+208|0];if(!m){break aa}}b=0;while(1){v[22708]=0;e=T(287,d+344|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break T}c=b;b=b+1|0;ba:{if(!e){break ba}c=c&65535;if(c>>>0<x[a+480188>>1]|c>>>0>31){break ba}u[a+480188>>1]=b}if((b&65535)>>>0<m>>>0){continue}break}}f=f+1|0;if(l>>>0>(f&65535)>>>0){continue}break}}v[22708]=0;Q(190,d+344|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break W}break u}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}v[22708]=0;o=a+484344|0;R(330,o|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break u}if(!l){break V}b=d+208|0;C=b|2;D=b|1;g=0;while(1){q=Kb(d+96|0);r=64;s=32;if(w[d+412|0]>=16){v[22708]=0;R(674,d+344|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break v}s=w[d+208|0];b=w[D|0];v[22708]=0;BW(d+80|0,3,C);c=v[22708];v[22708]=0;if((c|0)==1){break v}v[22708]=0;R(324,d+192|0,d+80|0);c=v[22708];v[22708]=0;if((c|0)==1){break v}c=d+192|0;Eb(q,c);vb(c);r=b+1|0}v[22708]=0;b=W(331,o|0,g&65535,r|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}ca:{if(!b){v[22708]=0;Q(318,d+344|0,s<<1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ca}break v}b=_b(o,g);v[22708]=0;Q(428,b|0,q|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break v}j=0;if(!s){break ca}while(1){v[22708]=0;b=T(287,d+344|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}da:{if(!b){break da}if(Je(k)>>>0<=b>>>0){break da}n=j&65535;if(n>>>0>=x[a+480188>>1]){break da}h=Kg(k,b);vc(h);c=0;while(1){v[22708]=0;b=Q(191,h|0,1)|0;e=v[22708];v[22708]=0;ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){if(!b){break da}b=_b(o,g);v[22708]=0;b=Xc(b,c,n);e=v[22708];v[22708]=0;if((e|0)==1){break v}v[22708]=0;f=T(374,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break v}e=f>>>2|0;switch((f&3)-1|0){case 2:break ga;case 1:break ha;case 0:break ia;default:break ja}}break v}c=(c+e|0)+1|0;break ea}if(!c){c=0;break ea}f=_b(o,g);v[22708]=0;f=Xc(f,c-1|0,n);i=v[22708];v[22708]=0;if((i|0)!=1){while(1){i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;c=c+1|0;if(r>>>0<=c>>>0){break ea}b=B(x[a+480188>>1],6)+b|0;i=e&255;e=e-1|0;if(i){continue}break ea}}break v}if(c>>>0<=e>>>0){break fa}f=_b(o,g);v[22708]=0;e=Xc(f,e,n);f=v[22708];v[22708]=0;if((f|0)==1){break S}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break fa}if(e&1){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break S}t[b|0]=f>>>0>120?-1:f}if(e&2){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break S}t[b+1|0]=f}f=0;m=0;if(e&4){v[22708]=0;m=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break v}}y=0;if(e&8){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break v}y=f>>>4|0;f=f&15}i=0;z=0;if(e&16){v[22708]=0;z=T(374,h|0)|0;E=v[22708];v[22708]=0;if((E|0)==1){break v}}if(e&32){v[22708]=0;i=T(374,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break v}}v[22708]=0;AW(b,m,f,y,z,i);b=v[22708];v[22708]=0;if((b|0)==1){break v}}c=c+1|0}if(c>>>0<r>>>0){continue}break}}j=j+1|0;if((j&65535)>>>0<s>>>0){continue}break}}vb(q);g=g+1|0;if((l|0)!=(g|0)){continue}break}}v[22708]=0;U(667,d+208|0,d+368|0,20048);b=v[22708];v[22708]=0;ka:{la:{ma:{if((b|0)!=1){b=Vc(d+344|0,d+208|0);v[22708]=0;b=T(275,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ma}xb(d+208|0);if(!b){break s}a=a+484344|0;if(!Te(a)){break s}while(1){v[22708]=0;b=Q(191,d+344|0,16)|0;c=v[22708];v[22708]=0;if((c|0)==1){break la}if(!b){break s}v[22708]=0;R(677,d+344|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break ka}b=_b(a,0);v[22708]=0;R(678,b|0,d+208|0);b=v[22708];v[22708]=0;if((b|0)==1){break ka}if(Te(a)){continue}break}break s}e=P()|0;O()|0;break t}e=P()|0;O()|0;xb(d+208|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}break v}break n}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(q);break t}e=P()|0;O()|0}jd(k);break c}jd(k)}xb(d+344|0);ke(d+368|0);xb(A)}gb=d+416|0;return p|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;dp(l);dp(i);dp(k);break c}e=P()|0;O()|0;xb(d+208|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+96|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+232|0);break d}e=P()|0;O()|0}vb(b)}xb(d+344|0)}ke(d+368|0)}xb(A);S(e|0);L()}function hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-512|0;gb=d;vc(b);f=d+432|0;g=bW(b,f);if(!g){rC(f)}a:{if(!g){break a}if(!dT(d+432|0)){break a}if(!Pb(b,Qc(cT(d+432|0),jb))){break a}b:{if(!c){break b}Hd(a,4);Ag(a);t[a+1074368|0]=4;k=Kb(d+416|0);c:{d:{e:{f:{j=d+470|0;g:{if(!(sd(j,14886,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break g}v[22708]=0;f=xv(d+449|0,0,20);e=v[22708];v[22708]=0;if((e|0)==1){break d}e=f?1154:34;break e}if(!sd(j,14865,20)){e=1;break e}v[22708]=0;Zj(d+16|0,3,j);f=v[22708];v[22708]=0;h:{i:{j:{if((f|0)==1){break j}v[22708]=0;R(324,d+56|0,d+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}v[22708]=0;U(13,d+128|0,5,d+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}f=d+128|0;Eb(k,f);vb(f);vb(d+56|0);if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))!=1852141647|(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))!=542396493){break h}e=1048;break e}c=P()|0;O()|0;break c}c=P()|0;O()|0;vb(d+56|0);break c}if(!sd(j,14613,12)){e=16;if((x[d+482>>1]|x[d+484>>1]<<16)==538976288&(x[d+486>>1]|x[d+488>>1]<<16)==538976288){break e}t[a+1074368|0]=5;break e}if(sd(j,8911,20)){break f}}e=48;break e}if(!sd(j,33408,15)){v[22708]=0;f=a+1074312|0;Q(410,f|0,54)|0;e=v[22708];v[22708]=0;C=1;if((e|0)==1){break d}v[22708]=0;Q(410,f|0,51)|0;f=v[22708];v[22708]=0;e=16;if((f|0)==1){break d}break e}if(!sd(j,33424,14)){v[22708]=0;Q(410,a+1074312|0,57)|0;f=v[22708];v[22708]=0;e=16;if((f|0)!=1){break e}break d}e=sd(j,14701,11)?16:256}v[22708]=0;s=d+449|0;Zj(d+56|0,3,s);f=v[22708];v[22708]=0;k:{l:{m:{n:{o:{if((f|0)==1){break o}v[22708]=0;R(324,d+128|0,d+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break o}f=d+128|0;Eb(a+1298268|0,f);vb(f);v[a+480260>>2]=1;v[a+480264>>2]=31999;p=a+484360|0;bf(Sb(p),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;u[d+128>>1]=w[d+504|0]|w[d+505|0]<<8;v[22708]=0;u[d+56>>1]=255;f=Pc(f,d+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break n}u[a+480192>>1]=x[f>>1];if(w[d+508|0]|w[d+509|0]<<8){v[a+480196>>2]=w[d+508|0]|w[d+509|0]<<8}if(w[d+510|0]|w[d+511|0]<<8){F=a,G=Fd(B(w[d+510|0]|w[d+511|0]<<8,1e4),32e4,1e7),v[F+480204>>2]=G}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+506|0]|w[d+507|0]<<8)<<4&16;f=(w[d+506|0]|w[d+507|0]<<8)<<3&32768;v[a+480208>>2]=f|v[a+480208>>2]&-32769;g=Sb(p);m=w[d+496|0]|w[d+497|0]<<8;v[22708]=0;fa(521,g|0,b|0,m|0,65535,65535)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}g=f>>>15|0?(e|0)==34?146:e:e;if(!(g&1024|(w[d+496|0]|w[d+497|0]<<8))){f=Sb(p);v[22708]=0;U(956,f|0,1,0);f=v[22708];v[22708]=0;if((f|0)==1){break d}}f=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[22708]=0;Q(190,b|0,f+60|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[22708]=0;U(957,b|0,d+432|0,a|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}}t[d+415|0]=0;z=c&2;m=mc(d+400|0);f=-1;if(x[a+480192>>1]){break m}break l}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}D=d+74|0;E=d+161|0;e=1;n=1;while(1){p:{v[22708]=0;h=T(192,b|0)|0;i=v[22708];v[22708]=0;q:{r:{s:{t:{u:{v:{if((i|0)!=1){pg(b,4);v[22708]=0;U(958,b|0,d+128|0,(h?h:263)|0);h=v[22708];v[22708]=0;if((h|0)==1){break p}w:{if((g|0)==1){if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==245){v[a+1074308>>2]=16777381;v[22708]=0;g=Q(2,d+56|0,10688)|0;h=v[22708];v[22708]=0;if((h|0)!=1){Eb(k,g);vb(g);g=17;break w}c=P()|0;O()|0;break k}g=16;if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263){break w}v[a+1074308>>2]=16777395;v[22708]=0;g=Q(2,d+56|0,10612)|0;h=v[22708];v[22708]=0;if((h|0)!=1){Eb(k,g);vb(g);g=17;break w}c=P()|0;O()|0;break k}if(w[d+155|0]|w[d+156|0]<<8){break w}if(!(!(g&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263)){g=g|16;break w}if(!(!(g&256)|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==29)){g=g&-257;break w}if(!(g&160)){break w}g=(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==33?g:0}v[22708]=0;h=W(376,a|0,n&65535,0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break p}if(!h){break q}h=((e<<2)+a|0)+900380|0;e=v[h>>2];v[22708]=0;R(959,d+128|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break p}e=w[d+154|0];x:{if((f|0)==-1){f=e;break x}if(!(g&32)|(e|0)==(f|0)){break x}g=g&-161|128}if(!(w[d+155|0]|w[d+156|0]<<8)){break q}e=w[d+369|0];i=w[d+370|0];o=w[d+371|0]|w[d+372|0]<<8;l=w[d+375|0];q=w[d+155|0]|w[d+156|0]<<8;v[22708]=0;U(960,d+112|0,a|0,q|0);q=v[22708];v[22708]=0;if((q|0)==1){break v}g=l|(o|(e|i))?g&-4:g;e=12;while(1){i=x[wd(v[h>>2]+236|0,e)>>1];if(tc(d+112|0)>>>0>i>>>0){i=x[sc(d+112|0,x[wd(v[h>>2]+236|0,e)>>1])>>1];F=wd(v[h>>2]+236|0,e),G=i,u[F>>1]=G}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){Nb(m);cr(m);pw(m)}e=w[d+155|0]|w[d+156|0]<<8;v[22708]=0;h=Q(961,d+96|0,e|0)|0;e=v[22708];v[22708]=0;y:{if((e|0)!=1){e=0;if(w[d+155|0]|w[d+156|0]<<8){break y}break u}c=P()|0;O()|0;break s}z:{A:{B:{C:{while(1){v[22708]=0;Q(962,b|0,d+56|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break z}v[22708]=0;ON(d+16|0,d+56|0);i=v[22708];v[22708]=0;D:{if((i|0)==1){break D}v[22708]=0;R(964,m|0,d+16|0);i=v[22708];v[22708]=0;if((i|0)==1){break D}i=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);F=Lb(h,e),G=i,v[F>>2]=G;o=w[d+73|0];if(tc(d+112|0)>>>0>e>>>0){i=x[sc(d+112|0,e)>>1];v[22708]=0;l=(B(i,104)+a|0)+484380|0;R(965,d+56|0,l|0);q=v[22708];v[22708]=0;if((q|0)==1){break C}v[22708]=0;PN(E,l);l=v[22708];v[22708]=0;if((l|0)==1){break C}v[22708]=0;Qk(d+40|0,3,D);l=v[22708];v[22708]=0;if((l|0)==1){break B}v[22708]=0;R(324,d+16|0,d+40|0);l=v[22708];v[22708]=0;if((l|0)==1){break B}v[22708]=0;Q(301,((i<<5)+a|0)+946304|0,d+16|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break A}vb(d+16|0);g=(w[d+70|0]&3)==3?(g&2)>>>1|0?g|4:g:g}r=o|r;e=e+1|0;if(e>>>0>=(w[d+155|0]|w[d+156|0]<<8)>>>0){break u}continue}break}c=P()|0;O()|0;break t}c=P()|0;O()|0;break t}c=P()|0;O()|0;break t}c=P()|0;O()|0;vb(d+16|0);break t}c=P()|0;O()|0;break t}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break r}e=0;if(!(w[d+155|0]|w[d+156|0]<<8)){break r}E:{while(1){F:{o=w[Lb(m,e)+3|0];i=v[Lb(h,e)>>2];v[22708]=0;U(288,d+16|0,b|0,((o|0)==11?(i+1>>>1|0)+16|0:i)|0);i=v[22708];v[22708]=0;if((i|0)==1){break F}i=d+16|0;o=jc(d+56|0,i);xb(i);if(!(!z|tc(d+112|0)>>>0<=e>>>0)){l=x[sc(d+112|0,e)>>1];i=Lb(m,e);i=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);v[22708]=0;v[d+12>>2]=i;v[d+8>>2]=i;i=ca(967,(B(l,104)+a|0)+484380|0,d+8|0,o|0,d+415|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break E}A=i^1|A}xb(d+56|0);e=e+1|0;if(e>>>0<(w[d+155|0]|w[d+156|0]<<8)>>>0){continue}break r}break}c=P()|0;O()|0;break t}c=P()|0;O()|0;xb(d+56|0)}Lc(h)}Ye(d+112|0);break k}Lc(h);Ye(d+112|0)}n=n+1|0;e=n&65535;if(e>>>0<=x[a+480192>>1]){continue}break l}break}c=P()|0;O()|0;break k}G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if(!(!(g&2)|r&255)){v[22708]=0;e=xv(s,0,20);h=v[22708];v[22708]=0;if((h|0)==1){break X}g=e?g|16:g}Y:{if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break Y}if(c&3){v[22708]=0;U(957,b|0,d+432|0,a|0);c=v[22708];v[22708]=0;if((c|0)==1){break X}}if(!z|!x[a+480190>>1]){break Y}e=1;c=1;while(1){h=Lb(m,e-1|0);v[22708]=0;W(329,h|0,(B(e,104)+a|0)+484380|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break M}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(A&1){v[22708]=0;e=Q(2,d+128|0,13720)|0;c=v[22708];v[22708]=0;if((c|0)==1){break W}v[22708]=0;U(560,a|0,2,e|0);c=v[22708];v[22708]=0;if((c|0)==1){break V}vb(e)}v[22708]=0;c=Q(555,b|0,2650)|0;e=v[22708];v[22708]=0;if((e|0)==1){break X}if(c){v[22708]=0;c=T(192,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break X}v[22708]=0;ca(509,a+1298292|0,b|0,c|0,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break X}g=g|16}v[22708]=0;c=Q(555,b|0,11368)|0;e=v[22708];v[22708]=0;if((e|0)==1){break G}if(c){v[22708]=0;e=T(192,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break G}v[22708]=0;h=a+901404|0;U(968,b|0,h|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break G}v[22708]=0;Iu(h);e=v[22708];v[22708]=0;if((e|0)==1){break G}g=g|16}v[22708]=0;e=Q(555,b|0,11149)|0;h=v[22708];v[22708]=0;if((h|0)==1){break G}if(e){v[22708]=0;e=T(192,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break U}u[d+128>>1]=e>>>5;h=a+484344|0;e=Te(h);v[22708]=0;u[d+56>>1]=e;e=Pc(d+128|0,d+56|0);n=v[22708];v[22708]=0;if((n|0)==1){break T}n=x[e>>1];if(n){e=0;while(1){v[22708]=0;W(766,b|0,d+128|0,32)|0;i=v[22708];v[22708]=0;if((i|0)==1){break S}i=_b(h,e);v[22708]=0;Q(767,i|0,d+128|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break S}e=e+1|0;if((n|0)!=(e|0)){continue}break}}g=g|16}v[22708]=0;e=Q(555,b|0,11154)|0;h=v[22708];v[22708]=0;if((h|0)==1){break G}if(e){v[22708]=0;e=T(192,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break R}u[d+128>>1]=(e>>>0)/20;e=x[a+480188>>1];v[22708]=0;u[d+56>>1]=e;e=Pc(d+128|0,d+56|0);h=v[22708];v[22708]=0;if((h|0)==1){break Q}h=x[e>>1];if(h){e=0;while(1){v[22708]=0;W(571,b|0,((e<<5)+a|0)+480289|0,20)|0;n=v[22708];v[22708]=0;if((n|0)==1){break L}e=e+1|0;if((h|0)!=(e|0)){continue}break}}g=g|16}v[22708]=0;e=Q(191,b|0,8)|0;h=v[22708];v[22708]=0;if((h|0)==1){break G}if(e){e=v[b+8>>2];v[22708]=0;Q(572,a|0,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break K}g=(e|0)==v[b+8>>2]?g:g|16}if(!(g&16)){break N}if(!(g&4)){break O}v[a+1074308>>2]=17367040;v[22708]=0;e=Q(2,d+128|0,11890)|0;h=v[22708];v[22708]=0;if((h|0)==1){break P}Eb(k,e);vb(e);break N}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;vb(e);break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}if(!(g&2)){break N}v[a+1074308>>2]=18219008;v[22708]=0;e=Q(2,d+128|0,12047)|0;h=v[22708];v[22708]=0;if((h|0)==1){break J}Eb(k,e);vb(e)}Z:{_:{$:{aa:{ba:{ca:{da:{if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))==1852141647&(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))==542396493){v[22708]=0;e=Q(969,d+128|0,d+478|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break da}v[22708]=0;U(13,d+56|0,1,e|0);g=v[22708];v[22708]=0;if((g|0)==1){break ca}v[22708]=0;g=T(970,d+56|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break ba}v[a+1074308>>2]=g;vb(d+56|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;vb(e);g=24}if(!(!v[a+1074308>>2]|g&8)){t[a+1074368|0]=0;vv(a+1074312|0)}e=g&32;ea:{if(!e){break ea}t[a+1074368|0]=5;if(!c){v[22708]=0;Vo(a+901404|0);c=v[22708];v[22708]=0;if((c|0)==1){break G}}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break ea}v[22708]=0;W(409,a+1074312|0,4,1)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}}if(!gd(k)){break Z}if(!(g&256)|r&255|f+1>>>0>1){break _}v[22708]=0;c=Q(2,d+128|0,5425)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}Eb(k,c);vb(c);break Z}c=P()|0;O()|0;break k}c=P()|0;O()|0;break aa}c=P()|0;O()|0;vb(d+56|0)}vb(e);break k}c=P()|0;O()|0;break k}if(e){v[22708]=0;c=Q(2,d+128|0,9323)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Eb(k,c);vb(c);break Z}c=P()|0;O()|0;break k}v[22708]=0;c=Q(2,d+128|0,6892)|0;f=v[22708];v[22708]=0;if((f|0)==1){break I}Eb(k,c);vb(c)}t[d+40|0]=0;fa:{if(x[a+480192>>1]){v[22708]=0;c=Q(588,a|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break fa}t[d+40|0]=c}v[22708]=0;Y(589,a|0,b|0,1,d+40|0);b=v[22708];v[22708]=0;if((b|0)==1){break fa}c=a+1074308|0;e=v[c>>2];ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if(w[d+40|0]){if(e>>>0>18284543){break ua}v[a+1074308>>2]=18284544;break ua}if(e>>>0<18284544){break ta}}v[22708]=0;b=Q(2,d+56|0,14713)|0;f=v[22708];v[22708]=0;if((f|0)==1){break sa}v[22708]=0;R(971,d+16|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break ra}v[22708]=0;U(3,d+128|0,b|0,d+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break qa}f=d+128|0;Eb(k,f);vb(f);vb(d+16|0);vb(b);e=v[c>>2]}va:{if(e-1>>>0>19005952){break va}v[22708]=0;b=a+484344|0;c=me(b,254);f=v[22708];v[22708]=0;if((f|0)==1){break fa}if(!c){c=Sb(p);v[22708]=0;R(972,c|0,254);c=v[22708];v[22708]=0;if((c|0)==1){break fa}}v[22708]=0;b=me(b,255);c=v[22708];v[22708]=0;if((c|0)==1){break fa}if(b){break va}b=Sb(p);v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break fa}v[22708]=0;ev(b,255,65535);b=v[22708];v[22708]=0;if((b|0)==1){break fa}}v[22708]=0;R(974,d+56|0,1211);b=v[22708];v[22708]=0;if((b|0)==1){break oa}v[d+112>>2]=w[d+491|0];b=w[d+490|0];v[22708]=0;v[d+96>>2]=b;R(599,d+16|0,d+96|0);b=v[22708];v[22708]=0;if((b|0)==1){break na}v[22708]=0;Y(582,d+128|0,d+56|0,d+112|0,d+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break ma}b=a+1298304|0;c=d+128|0;Eb(b,c);vb(c);vb(d+16|0);Hb(d+56|0);Eb(a+1298328|0,k);v[a+1298364>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+415|0]){break ha}Eb(a+1298340|0,b);v[22708]=0;c=Q(2,d+128|0,12398)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ka}Eb(b,c);vb(c);v[22708]=0;b=Q(2,d+128|0,7371)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ja}Eb(a+1298316|0,b);vb(b);v[22708]=0;b=Q(2,d+128|0,7372)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ia}Eb(a+1298352|0,b);break ga}c=P()|0;O()|0;break k}c=P()|0;O()|0;break pa}c=P()|0;O()|0;vb(d+16|0)}vb(b);break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break la}c=P()|0;O()|0;vb(d+16|0)}Hb(d+56|0);break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}v[22708]=0;b=Q(2,d+128|0,7372)|0;c=v[22708];v[22708]=0;if((c|0)==1){break H}Eb(a+1298316|0,b)}vb(b);di(m);vb(k);break b}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0}di(m);break c}c=P()|0;O()|0}vb(k);S(c|0);L()}e=1}gb=d+512|0;return e|0}function lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-272|0;gb=d;vc(b);a:{b:{c:{if(!_u(b,d+176|0)){break c}if(!sU(d+176|0)){break c}if(!Pb(b,Qc(rU(d+176|0),jb))){break c}if(!c){s=1;break c}Hd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;l=Kb(d+160|0);i=d+216|0;if((w[i|0]|w[i+1|0]<<8)==20479){h=w[d+230|0]|w[d+231|0]<<8}else{h=(w[i|0]|w[i+1|0]<<8)-16464|0}d:{e:{f:{g:{h:{i:{j:{k:{switch(((w[i|0]|w[i+1|0]<<8)&61440)-4096>>>12|0){case 0:l:{if(w[d+238|0]|w[d+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[d+228|0]|w[d+208|0]&15)){break l}if((w[d+214|0]|w[d+215|0]<<8)&65455){break l}m:{if(t[d+227|0]<=-1){v[a+1074308>>2]=18219008;v[22708]=0;f=Q(2,d+32|0,11960)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break m}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[22708]=0;f=Q(2,d+32|0,10688)|0;g=v[22708];v[22708]=0;if((g|0)==1){break j}}Eb(l,f);vb(f);v[22708]=0;k=1;W(409,a+1074312|0,81,1)|0;g=v[22708];v[22708]=0;f=1;if((g|0)!=1){break d}break b}n:{if(w[d+238|0]|w[d+239|0]<<8|(w[i|0]|w[i+1|0]<<8)!=4896|(w[d+228|0]|(w[d+214|0]|w[d+215|0]<<8))){break n}if(w[d+229|0]){break n}v[22708]=0;f=Q(2,d+32|0,6633)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(l,f);break e}b=P()|0;O()|0;break a}v[22708]=0;e=Q(2,d+32|0,5641)|0;g=v[22708];v[22708]=0;s=1;if((g|0)!=1){Eb(l,e);vb(e);break f}b=P()|0;O()|0;break a;case 1:v[22708]=0;e=Q(2,d+32|0,3830)|0;g=v[22708];v[22708]=0;f=1;if((g|0)!=1){Eb(l,e);vb(e);break f}b=P()|0;O()|0;break a;case 2:o:{p:{q:{g=w[i|0]|w[i+1|0]<<8;r:{if(g>>>0<=12820){v[22708]=0;f=Q(2,d+32|0,5688)|0;j=v[22708];v[22708]=0;if((j|0)!=1){Eb(l,f);vb(f);break r}b=P()|0;O()|0;break a}v[22708]=0;R(597,d+144|0,1124);f=v[22708];v[22708]=0;if((f|0)==1){break q}f=w[i|0]|w[i+1|0]<<8;v[22708]=0;v[d+128>>2]=f-12820;U(598,d+32|0,d+144|0,d+128|0);f=v[22708];v[22708]=0;if((f|0)==1){break p}f=d+32|0;Eb(l,f);vb(f);Hb(d+144|0)}if((w[i|0]|w[i+1|0]<<8)>>>0<12807){break g}if(w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24)){break o}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hb(d+144|0);break a}f=w[i|0]|w[i+1|0]<<8;j=w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24);v[22708]=0;f=tw(f,j);j=v[22708];v[22708]=0;if((j|0)==1){break i}j=Er(d+32|0);v[j+44>>2]=f;v[22708]=0;R(601,a+1298368|0,j|0);f=v[22708];v[22708]=0;if((f|0)!=1){break g}b=P()|0;O()|0;break a;case 3:if((w[i|0]|w[i+1|0]<<8)==16640){v[22708]=0;e=Q(2,d+32|0,5473)|0;g=v[22708];v[22708]=0;f=1;if((g|0)!=1){Eb(l,e);vb(e);v[22708]=0;W(409,a+1074312|0,81,1)|0;g=v[22708];v[22708]=0;e=0;if((g|0)==1){break b}break d}b=P()|0;O()|0;break a}e=w[i|0]|w[i+1|0]<<8;f=w[d+230|0]|w[d+231|0]<<8;v[22708]=0;U(602,d+32|0,e|0,f|0);e=v[22708];v[22708]=0;s:{if((e|0)!=1){e=d+32|0;Eb(l,e);vb(e);v[a+480260>>2]=1;if((h|0)<4201){break s}v[22708]=0;W(409,a+1074312|0,7,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}break h}b=P()|0;O()|0;break a}if((h|0)>=2386){break h}f=1;e=1;break d;case 4:g=(w[i|0]|w[i+1|0]<<8)&4095;e=g<<16;f=a;if(g>>>0>=297){e=e|(w[d+230|0]|w[d+231|0]<<8)}v[f+1074308>>2]=e;v[22708]=0;f=Q(2,d+144|0,14713)|0;e=v[22708];v[22708]=0;t:{u:{v:{if((e|0)!=1){v[22708]=0;R(162,d+128|0,a+1074308|0);e=v[22708];v[22708]=0;if((e|0)==1){break v}v[22708]=0;U(3,d+32|0,f|0,d+128|0);e=v[22708];v[22708]=0;if((e|0)==1){break u}e=d+32|0;Eb(l,e);vb(e);vb(d+128|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break t}b=P()|0;O()|0;vb(d+128|0)}vb(f);break a;case 5:v[22708]=0;f=Q(2,d+32|0,5473)|0;g=v[22708];v[22708]=0;if((g|0)!=1){Eb(l,f);vb(f);v[22708]=0;W(409,a+1074312|0,81,1)|0;g=v[22708];v[22708]=0;f=0;if((g|0)==1){break b}break d}b=P()|0;O()|0;break a;case 6:v[22708]=0;f=Q(2,d+32|0,5499)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(l,f);break e}b=P()|0;O()|0;break a;default:break k}}if((w[i|0]|w[i+1|0]<<8)!=51712){break d}v[22708]=0;f=Q(2,d+32|0,6432)|0;e=v[22708];v[22708]=0;if((e|0)!=1){Eb(l,f);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[22708]=0;f=1;W(409,a+1074312|0,38,1)|0;g=v[22708];v[22708]=0;e=1;if((g|0)==1){break b}break d}v[22708]=0;f=a+1074312|0;W(409,f|0,7,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break b}v[22708]=0;W(409,f|0,23,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break b}v[22708]=0;W(409,f|0,38,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break b}v[22708]=0;W(409,f|0,107,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}f=1;v[a+480260>>2]=1;if(g>>>0>12820){break d}}v[22708]=0;_(882,d+144|0);e=v[22708];v[22708]=0;w:{x:{y:{if((e|0)!=1){v[d+16>>2]=w[i+1|0]&15;e=w[i|0];v[22708]=0;v[d>>2]=e;R(599,d+128|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break y}v[22708]=0;ha(883,d+32|0,d+144|0,l|0,d+16|0,d+128|0);e=v[22708];v[22708]=0;if((e|0)==1){break x}e=d+32|0;Eb(l,e);vb(e);vb(d+128|0);Hb(d+144|0);e=0;break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(d+128|0)}Hb(d+144|0);break a}vb(f);f=0;e=0}v[22708]=0;g=Q(2,d+32|0,12230)|0;j=v[22708];v[22708]=0;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((j|0)!=1){Eb(a+1298304|0,g);vb(g);v[22708]=0;g=Q(2,d+32|0,7744)|0;j=v[22708];v[22708]=0;if((j|0)==1){break M}Eb(a+1298316|0,g);vb(g);r=a+1298328|0;Eb(r,l);v[a+1298364>>2]=v[a+1074308>>2]?8:5;if(f){v[22708]=0;f=a+1074312|0;Q(410,f|0,77)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(410,f|0,78)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(410,f|0,79)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(410,f|0,80)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(410,f|0,82)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(410,f|0,96)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(410,f|0,113)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}}y=w[i|0]|w[i+1|0]<<8;f=y&61440;k=f>>>0<4097|(y>>>0<12820?(f|0)==12288:0)?k:1;v[22708]=0;f=a+901404|0;_(884,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break b}if(!k){v[22708]=0;Vo(f);f=v[22708];v[22708]=0;if((f|0)==1){break b}}v[22708]=0;Mk(d+144|0,1,d+176|0);f=v[22708];v[22708]=0;if((f|0)==1){break L}v[22708]=0;R(324,d+32|0,d+144|0);f=v[22708];v[22708]=0;if((f|0)==1){break L}f=d+32|0;Eb(a+1298268|0,f);vb(f);if(w[d+214|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+214|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+214|0]&64?0:(w[i|0]|w[i+1|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}f=w[d+225|0];v[a+480196>>2]=f;if(!(!s|(f|0)!=255?f:0)){v[a+480196>>2]=6}v[a+480204>>2]=B(w[d+226|0],1e4);if(w[d+226|0]<=32){v[a+480204>>2]=s?125e4:32e4}t[d+32|0]=w[d+224|0];v[22708]=0;t[d+144|0]=64;f=ac(d+32|0,d+144|0);g=v[22708];v[22708]=0;if((g|0)==1){break H}f=w[f|0];v[a+480200>>2]=f<<2;if(!((w[i|0]|w[i+1|0]<<8)>>>0>4895|f)){v[a+480200>>2]=256}if((w[d+218|0]|w[d+219|0]<<8)!=1|w[d+227|0]>7){break J}v[d+32>>2]=(w[d+227|0]<<4)+16;v[22708]=0;v[d+144>>2]=127;f=pd(d+32|0,d+144|0);g=v[22708];v[22708]=0;if((g|0)==1){break K}v[a+480228>>2]=v[f>>2];break I}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}if(!(w[d+227|0]!=18?w[d+227|0]!=2:0)){v[a+480228>>2]=32;break I}if(!(w[d+227|0]&127)){v[a+480228>>2]=48;break I}v[d+32>>2]=w[d+227|0]&127;v[22708]=0;v[d+144>>2]=16;f=If(d+32|0,d+144|0);g=v[22708];v[22708]=0;if((g|0)==1){break G}v[a+480228>>2]=v[f>>2]}j=v[a+1074308>>2]!=0|t[d+227|0]<0;if(!j){f=v[a+480228>>2];g=f>>>29|0;H=a,I=Qc(rqa(f<<3|5,g,11,0),jb),v[H+480228>>2]=I}u[a+480188>>1]=4;v[a+480232>>2]=e?(h|0)<3299?64:36:36;e=xr(d+120|0);f=0;while(1){v[22708]=0;h=(f<<5)+a|0;o=h+480280|0;We(o);g=v[22708];v[22708]=0;if((g|0)==1){break F}g=d+f|0;k=w[g+240|0];N:{if(w[g+240|0]==255){break N}u[a+480188>>1]=f+1;if(!j){break N}u[h+480284>>1]=k&8?204:51}if(t[g+240|0]<=-1){v[o>>2]=1024}if(((k&127)-16&255)>>>0<=13){u[h+480284>>1]=128;h=d+32|0;Al(h,e,f);Df(h,1)}f=f+1|0;if((f|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}h=Sb(a+484360|0);f=w[d+208|0]|w[d+209|0]<<8;v[22708]=0;fa(521,h|0,b|0,f|0,255,254)|0;h=v[22708];v[22708]=0;O:{P:{Q:{R:{S:{if((h|0)!=1){z=mc(d+144|0);h=w[d+210|0]|w[d+211|0]<<8;v[22708]=0;W(327,b|0,z|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break S}j=mc(d+128|0);h=w[d+212|0]|w[d+213|0]<<8;v[22708]=0;W(327,b|0,j|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break O}if(w[d+229|0]==252){f=0;v[22708]=0;R(885,b|0,d+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break R}while(1){g=(d+32|0)+f|0;h=w[g|0];T:{if(!(h&32)){break T}k=((f<<5)+a|0)+480284|0;if(s){h=d+16|0;Al(h,e,f);if(Cb(h)){break T}h=w[g|0]}u[k>>1]=(((h&15)<<8|8)>>>0)/15}f=f+1|0;if((f|0)!=32){continue}break}}u[d+32>>1]=w[d+210|0]|w[d+211|0]<<8;f=0;v[22708]=0;u[d+16>>1]=3999;h=Pc(d+32|0,d+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break Q}h=x[h>>1];u[a+480190>>1]=h;if(h){break P}k=0;g=0;break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break B}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}o=c&2;h=d+45|0;n=d+80|0;g=0;k=0;U:{V:{W:{while(1){e=sc(z,f);e=w[e|0]|w[e+1|0]<<8;v[22708]=0;e=Q(190,b|0,e<<4)|0;p=v[22708];v[22708]=0;if((p|0)==1){break E}X:{Y:{if(!e){break Y}v[22708]=0;e=Q(886,b|0,d+32|0)|0;p=v[22708];v[22708]=0;if((p|0)==1){break E}if(!e){break Y}v[22708]=0;e=f+1|0;p=(B(e,104)+a|0)+484380|0;U(887,d+32|0,p|0,s|0);m=v[22708];v[22708]=0;if((m|0)==1){break E}v[22708]=0;Mk(d,1,n);m=v[22708];v[22708]=0;if((m|0)==1){break X}v[22708]=0;R(324,d+16|0,d|0);m=v[22708];v[22708]=0;if((m|0)==1){break X}v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,d+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break W}vb(d+16|0);if(w[d+32|0]>1){break Y}m=w[d+46|0];A=w[d+47|0];e=h;Z:{if(!o|!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break Z}e=w[e|0];v[22708]=0;e=Q(190,b|0,A<<12|m<<4|e<<20)|0;m=v[22708];v[22708]=0;if((m|0)==1){break V}if(!e){break Z}e=w[d+218|0]|w[d+219|0]<<8;v[22708]=0;YQ(d+16|0,d+32|0,(e|0)==1);e=v[22708];v[22708]=0;if((e|0)==1){break U}v[22708]=0;W(329,d+16|0,p|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}k=1}g=w[d+72|0]|w[d+73|0]<<8|g}f=f+1|0;if(f>>>0>=x[a+480190>>1]){break D}continue}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;vb(d+16|0);break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break C}_:{$:{aa:{ba:{if(!s){break ba}if((w[i|0]|w[i+1|0]<<8)!=4864?!k|g&65535:1){v[22708]=0;h=a+1074312|0;e=g&65535;W(409,h|0,79,e>>>0>1|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break $}v[22708]=0;W(409,h|0,107,e>>>0<2|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break $}v[22708]=0;h=g&65535;Q(154,r|0,(h>>>0>1?14243:14250)|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break $}if(h>>>0<2){break ba}v[a+480228>>2]=48;break ba}v[22708]=0;h=Q(2,d+32|0,6892)|0;e=v[22708];v[22708]=0;if((e|0)==1){break aa}Eb(r,h);vb(h)}h=i;s=1;if(c&1){break _}break z}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}c=w[h|0]|w[h+1|0]<<8;u[d+32>>1]=w[d+212|0]|w[d+213|0]<<8;v[22708]=0;u[d+16>>1]=255;h=Pc(d+32|0,d+16|0);e=v[22708];v[22708]=0;ca:{da:{if((e|0)!=1){p=x[h>>1];v[22708]=0;h=a+484344|0;R(330,h|0,p|0);e=v[22708];v[22708]=0;if((e|0)==1){break da}m=c>>>0<4896;if(p){break ca}r=0;o=0;break A}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}c=d+32|0;D=c|5;E=c|3;A=c|4;F=c|2;G=c|1;f=0;o=0;r=0;ea:{fa:{while(1){ga:{v[22708]=0;c=W(331,h|0,f&65535,64)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ga}ha:{if(!c){break ha}c=sc(j,f);if(!(w[c|0]|w[c+1|0]<<8)){break ha}c=sc(j,f);c=w[c|0]|w[c+1|0]<<8;v[22708]=0;c=Q(190,b|0,c<<4)|0;e=v[22708];v[22708]=0;if((e|0)==1){break ga}if(!c){break ha}v[22708]=0;Q(318,b|0,2)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ga}g=0;c=_b(h,f);v[22708]=0;C=Uf(c,0);c=v[22708];v[22708]=0;if((c|0)==1){break fa}while(1){v[22708]=0;n=T(374,b|0)|0;c=v[22708];v[22708]=0;ia:{ja:{if((c|0)!=1){if(n){break ja}if(g>>>0>62){break ha}c=_b(h,f);v[22708]=0;g=g+1|0;C=Uf(c,g);c=v[22708];v[22708]=0;if((c|0)!=1){break ia}}b=P()|0;O()|0;break C}y=bj(d+32|0);e=n&31;c=e>>>0<x[a+480188>>1];k=B(e,6)+C|0;if(n&32){v[22708]=0;R(403,d+16|0,b|0);e=v[22708];v[22708]=0;ka:{la:{ma:{if((e|0)!=1){e=d+16|0;q=qd(e);e=w[e|0];if(e>>>0>239){break ma}e=(B(e>>>4|0,12)+(e&15)|0)+13|0;break la}b=P()|0;O()|0;break C}na:{switch(e-254|0){case 0:break la;case 1:break na;default:break ka}}e=0}t[(c?k:d+32|0)|0]=e}t[(c?k+1|0:G)|0]=w[q|0]}oa:{if(!(n&64)){break oa}v[22708]=0;e=T(374,b|0)|0;q=v[22708];v[22708]=0;pa:{if((q|0)!=1){q=c?k+2|0:F;t[d+16|0]=e;if(e<<24>>24>-1|e>>>0>192){break pa}t[q|0]=2;t[(c?k+4|0:A)|0]=w[d+16|0]^128;break oa}b=P()|0;O()|0;break C}t[q|0]=1;v[22708]=0;t[d|0]=64;e=ac(d+16|0,d);q=v[22708];v[22708]=0;if((q|0)==1){break ea}t[(c?k+4|0:A)|0]=w[e|0]}if(!(n&128)){break ia}v[22708]=0;R(403,d+16|0,b|0);e=v[22708];v[22708]=0;qa:{if((e|0)!=1){e=d+16|0;q=qd(e);n=c?k+3|0:E;t[n|0]=w[e|0];e=c?k+5|0:D;t[e|0]=w[q|0];Uu(c?k:y,0);ra:{c=w[n|0];if((c|0)==20){if((w[e|0]&240)!=160){break ia}if((w[i|0]|w[i+1|0]<<8)>>>0<4896){break ra}c=w[n|0]}if((c|0)!=31){break ia}c=w[e|0];if(c>>>0<=15){break qa}m=0;break ia}t[e|0]=w[e|0]&15^136;break ia}b=P()|0;O()|0;break C}if(c>>>0<=7){o=o+1|0;break ia}r=((c|0)!=8)+r|0}if(g>>>0<64){continue}break}}f=f+1|0;if((p|0)!=(f|0)){continue}break A}break}b=P()|0;O()|0;break C}b=P()|0;O()|0;break C}b=P()|0;O()|0}Pk(j)}Pk(z);break a}if(!m){break z}a=x[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(r-o|0)){break z}c=Te(h)-1&65535;a=0;e=0;if(Te(h)>>>0>c>>>0){while(1){if(ii(af(h,a))){b=Vb(af(h,a));i=Zb(af(h,a));a=gb-16|0;gb=a;v[a>>2]=i;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){i=a+8|0;b=v[i>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}ak(i);if(Gb(i,a)){continue}break}}gb=a+16|0}e=e+1|0;a=e&65535;if(c>>>0>=a>>>0){continue}break}}}Pk(j);Pk(z);vb(l)}gb=d+272|0;return s|0}b=P()|0;O()|0}vb(l);S(b|0);L()}function t6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=C(0),U=C(0),V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0);D=gb-17168|0;gb=D;v[D+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!fq(a+6152|0,b)){break c}k=ry(b,v[a+6148>>2])+eq(b)|0;v[D+17164>>2]=k;if((c|0)==(k|0)){k=c;break b}d:{if((k+4|0)<=(c|0)){if(fq(b,b+k|0)){break d}}v[D+17164>>2]=0;break c}if(k){break b}}g=b;p=Qb(a,0,6668)+6148|0;I=D+17164|0;f=c;e:{if((f|0)>=5){J=f-4|0;while(1){if(kJ(g)){y=ry(g,v[p>>2]);k=y+eq(g)|0;j=0;f:{g:{if(y){break g}l=4;q=h+4|0;while(1){if((J|0)<=((l<<1)+h|0)){break f}y=0;r=g+l|0;h:{if(!fq(g,r)){break h}s=l-eq(g)|0;G=eq(r)+s|0;if((f|0)<(G+(l+q|0)|0)){break h}if(!fq(g,r+G|0)){break h}v[p>>2]=s;y=s;k=l}j=!y;if(y){break g}s=l>>>0<2303;l=l+1|0;if(s){continue}break}}if((f|0)<(h+k|0)|j){break f}s=g;l=f-h|0;j=0;n=0;i:{while(1){G=j+s|0;j=(ry(G,y)+j|0)+eq(G)|0;q=(n|0)!=0;if((l|0)<(j+4|0)){break i}q=0;if(!fq(s,j+s|0)){break i}n=n+1|0;if((n|0)!=10){continue}break}q=1}if(q){break e}}if(!((f|0)!=(k|0)|h)){h=0;k=f;break e}v[p>>2]=0}g=g+1|0;h=h+1|0;if((J|0)!=(h|0)){continue}break}}k=0;h=f}v[I>>2]=k;n=h;k=v[D+17164>>2];if((h+k|0)<=(c|0)?k:0){break b}v[e>>2]=n;n=0;break a}G=b+n|0;v[a+6152>>2]=w[G|0]|w[G+1|0]<<8|(w[G+2|0]<<16|w[G+3|0]<<24);v[e+4>>2]=n;v[e>>2]=k+n;v[e+8>>2]=w[G+3|0]>191?1:2;ca=e,da=nJ(G),v[ca+12>>2]=da;v[e+16>>2]=4-(w[G+1|0]>>>1&3);ca=e,da=py(G),v[ca+20>>2]=da;if(!d){n=oy(G);break a}mJ(D+17152|0,G+4|0,k-4|0);if(!(t[G+1|0]&1)){$d(D+17152|0,16)}j:{if(v[e+16>>2]==3){n=0;r=D+17152|0;k=D+3740|0;h=0;c=G;g=w[c+1|0];b=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[c+2|0]>>>2&3)|0;f=b-((b|0)!=0)|0;l=w[c+3|0]>191?1:2;k:{if(g&8){j=$d(r,9);l=l<<1;h=$d(r,l+7|0);break k}j=$d(r,l|8)>>>l|0}b=B(f,40);I=b+62016|0;q=b+62336|0;s=B(f,23)+61824|0;A=-1;l:{while(1){g=w[c+3|0];f=$d(r,12);u[k+4>>1]=f;b=$d(r,9);u[k+6>>1]=b;if((b&65535)>>>0>288){break l}y=g>>>0>191?h<<4:h;ca=k,da=$d(r,8),t[ca+10|0]=da;b=$d(r,w[c+1|0]&8?4:9);t[k+13|0]=22;t[k+14|0]=0;v[k>>2]=s;u[k+8>>1]=b;m:{if($d(r,1)){b=$d(r,2);t[k+11|0]=b;if(!(b&255)){break l}h=$d(r,1);u[k+18>>1]=65287;t[k+12|0]=h;if(w[k+11|0]==2){b=k;n:{if(!(h&255)){v[k>>2]=I;t[k+18|0]=8;g=39;h=0;break n}v[k>>2]=q;g=30;h=w[c+1|0]&8?8:6}t[b+14|0]=g;t[k+13|0]=h;y=y&3855}b=$d(r,10);ca=k,da=$d(r,3),t[ca+21|0]=da;ca=k,da=$d(r,3),t[ca+22|0]=da;ca=k,da=$d(r,3),t[ca+23|0]=da;h=b<<5;break m}t[k+11|0]=0;t[k+12|0]=0;h=$d(r,15);ca=k,da=$d(r,4),t[ca+18|0]=da;b=$d(r,3);t[k+20|0]=255;t[k+19|0]=b}t[k+17|0]=h&31;t[k+15|0]=h>>>10;t[k+16|0]=h>>>5&31;i=(f&65535)+i|0;b=k;o:{if(w[c+1|0]&8){f=$d(r,1);break o}f=x[k+8>>1]>499}t[b+24|0]=f;ca=k,da=$d(r,1),t[ca+25|0]=da;b=$d(r,1);t[k+27|0]=y>>>12&15;t[k+26|0]=b;k=k+28|0;h=y<<4;l=l-1|0;if(l){continue}break}A=(v[r+4>>2]+i|0)>(v[r+8>>2]+(j<<3)|0)?-1:j}if(!((A|0)<0|v[D+17156>>2]>v[D+17160>>2])){s=D+17152|0;h=v[s+4>>2];k=v[s+8>>2];c=D+912|0;f=v[a+6144>>2];b=f-A|0;g=(f|0)>(A|0)?A:f;f=hc(c+12|0,(((b|0)>0?b:0)+a|0)+6156|0,g);b=(k-h|0)/8|0;hc(f+g|0,v[s>>2]+(v[s+4>>2]/8|0)|0,b);mJ(c,f,b+g|0);k=v[a+6144>>2]>=(A|0);if(k){Z=a+2304|0;n=v[e+8>>2];_=D+8620|0;$=D+3852|0;b=0;while(1){aa=Qb($,0,4608);s=D+912|0;y=(B(B(b,n),28)+D|0)+3740|0;l=0;r=a;J=r+6152|0;if((n|0)>=1){h=s+7548|0;while(1){f=B(l,28)+y|0;L=x[f+4>>1];M=v[s+4>>2];N=(s+B(l,39)|0)+16156|0;q=s;i=h;g=l;p=gb-48|0;gb=p;j=f;R=!w[f+13|0]+(w[f+14|0]!=0)|0;V=w[f+25|0];c=p;A=c+44|0;I=J;p:{if(w[J+1|0]&8){o=w[j+27|0];m=w[x[j+8>>1]+62752|0];g=m&3;t[p+47|0]=g;t[p+46|0]=g;g=m>>>2|0;t[p+45|0]=g;t[p+44|0]=g;g=B(R,28)+62656|0;break p}g=w[I+3|0]>>>4&(g|0)!=0;H=g?12:0;P=x[j+8>>1]>>>g|0;while(1){E=1;m=3;while(1){g=m;o=w[(g+H|0)+62768|0];t[g+(p+44|0)|0]=((P|0)/(E|0)|0)%(o|0);m=g-1|0;E=B(o,E);if(g){continue}break}H=H+4|0;P=P-E|0;if((P|0)>-1){continue}break}o=-16;g=(B(R,28)+H|0)+62656|0}E=0;while(1){O=w[g+E|0];if(O){q:{if(o&8){hc(c,N,O);break q}S=w[A+E|0];if(!S){Qb(c,0,O);Qb(N,0,O);break q}m=(o|0)>-1?-1:-1<<S^-1;H=0;while(1){R=$d(q,S);t[H+N|0]=(m|0)==(R|0)?-1:R;t[c+H|0]=R;H=H+1|0;if((O|0)!=(H|0)){continue}break}}o=o<<1;c=c+O|0;N=N+O|0;E=E+1|0;if((E|0)!=4){continue}}break}t[c+2|0]=0;t[c|0]=0;t[c+1|0]=0;m=w[j+14|0];r:{if(m){c=2-V|0;o=w[j+23|0]<<c;q=w[j+22|0]<<c;g=w[j+21|0]<<c;c=w[j+13|0];E=0;while(1){A=p+(c+E|0)|0;t[A|0]=g+w[A|0];t[A+1|0]=q+w[A+1|0];t[A+2|0]=o+w[A+2|0];E=E+3|0;if(m>>>0>E>>>0){continue}break}break r}if(!w[j+24|0]){break r}o=0;while(1){c=o+p|0;t[c+11|0]=w[c+11|0]+w[o+62792|0];o=o+1|0;if((o|0)!=10){continue}break}}T=ny(C(2048),((((w[I+3|0]&224)==96)<<1)-w[j+10|0]|0)+258|0);o=0;if((m|0)!=(0-w[j+13|0]|0)){c=V+1|0;while(1){ca=i+(o<<2)|0,ea=ny(T,w[o+p|0]<<c),z[ca>>2]=ea;o=o+1|0;if(o>>>0<w[j+14|0]+w[j+13|0]>>>0){continue}break}}gb=p+48|0;p=(s+B(l,2304)|0)+2940|0;c=h;R=L+M|0;F=C(0);Y=0;I=s;g=v[s+4>>2];q=v[s>>2]+((g|0)/8|0)|0;i=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);i=(i<<24|i<<8&16711680|(i>>>8&65280|i>>>24))<<(g&7);m=g|-8;K=q+4|0;q=f;E=v[f>>2];H=x[f+6>>1];s:{if(!H){H=0;break s}while(1){f=q+Y|0;g=w[f+15|0];X=(u[(g<<1)+67216>>1]<<1)+62832|0;N=w[f+18|0];t:{if(g>>>0>=16){L=w[g+67280|0];A=32-L|0;while(1){M=w[E|0]>>>1|0;o=(H|0)>(M|0)?M:H;F=z[c>>2];while(1){j=u[X+(i>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[X+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}O=j&65535;f=O>>>8|0;m=f+m|0;i=i<<f;P=1;while(1){ba=p;f=O&15;u:{if((f|0)==15){j=i<<L;f=(i>>>A|0)+15|0;m=m+L|0;if((m|0)>=0){while(1){j=w[K|0]<<m|j;i=(m|0)>7;m=m-8|0;K=K+1|0;if(i){continue}break}}W=F;i=f;v:{if((f|0)<=128){U=z[(i<<2)+67376>>2];break v}S=i<<3;g=i;i=(i|0)<1024;V=i?S:g;S=V<<1&64;Q=C(C((V&63)-S|0)/C(S+(V&-64)|0));U=C((i?C(16):C(256))*C(C(C(Q*C(C(Q*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(V+S>>6<<2)+67376>>2]))}W=C(C(W*U)*C(((j|0)>-1?1:-1)|0));break u}j=i;W=C(F*z[(((i>>>27&16|f)^16)<<2)+67312>>2])}z[ba>>2]=W;O=O>>>4|0;p=p+4|0;f=(f|0)!=0;m=f+m|0;i=j<<f;f=P&1;P=0;if(f){continue}break}if((m|0)>-1){while(1){i=w[K|0]<<m|i;f=(m|0)>7;m=m-8|0;K=K+1|0;if(f){continue}break}}o=o-1|0;if(o){continue}break}c=c+4|0;E=E+1|0;H=H-M|0;if((H|0)<1){break t}f=(N|0)>0;N=N-1|0;if(f){continue}break}break t}while(1){o=w[E|0]>>>1|0;P=(o|0)<(H|0)?o:H;F=z[c>>2];while(1){j=u[X+(i>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){i=i<<f;m=f+m|0;g=j&7;f=g;j=u[X+((i>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}j=j&65535;f=j>>>8|0;m=f+m|0;i=i<<f;f=1;while(1){g=j&15;z[p>>2]=F*z[(((g|i>>>27&16)^16)<<2)+67312>>2];j=j>>>4|0;p=p+4|0;g=(g|0)!=0;m=g+m|0;i=i<<g;g=f&1;f=0;if(g){continue}break}if((m|0)>-1){while(1){i=w[K|0]<<m|i;f=(m|0)>7;m=m-8|0;K=K+1|0;if(f){continue}break}}P=P-1|0;if(P){continue}break}c=c+4|0;E=E+1|0;H=H-o|0;if((H|0)<1){break t}f=(N|0)>0;N=N-1|0;if(f){continue}break}}Y=Y+1|0;if((H|0)>0){continue}break}}f=1-H|0;while(1){w:{g=w[q+26|0]?67200:67168;j=w[g+(i>>>28|0)|0];if(!(j&8)){j=w[g+((i<<4>>>32-(j&3))+(j>>>3)|0)|0]}g=j&7;m=g+m|0;if((R|0)<((m+(K-v[I>>2]<<3)|0)-24|0)){break w}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;F=z[c>>2];f=f>>>1|0;c=c+4|0}i=i<<g;if(j&128){z[p>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if(j&64){z[p+4>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break w}E=E+1|0;F=z[c>>2];f=f>>>1|0;c=c+4|0}if(j&32){z[p+8>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if(j&16){z[p+12>>2]=(i|0)<0?C(-F):F;m=m+1|0;i=i<<1}if((m|0)>=0){while(1){i=w[K|0]<<m|i;g=(m|0)>7;m=m-8|0;K=K+1|0;if(g){continue}break}}p=p+16|0;continue}break}v[I+4>>2]=R;l=l+1|0;if((n|0)!=(l|0)){continue}break}}c=w[r+6155|0];x:{if(c&16){j=0;L=gb-16|0;gb=L;o=s+2940|0;f=o+2304|0;i=y;m=v[i>>2];p=w[i+14|0];A=p+w[i+13|0]|0;I=A;M=L+4|0;v[M+8>>2]=-1;v[M>>2]=-1;v[M+4>>2]=-1;if(A>>>0>=1){while(1){c=0;q=j+m|0;g=w[q|0];h=0;y:{if(!g){break y}z:{while(1){l=c<<2;if(z[l+f>>2]!=C(0)|z[(l|4)+f>>2]!=C(0)){break z}c=c+2|0;if(g>>>0>c>>>0){continue}break}h=g;break y}v[M+((j>>>0)%3<<2)>>2]=j;h=w[q|0]}f=((h&255)<<2)+f|0;j=j+1|0;if((I|0)!=(j|0)){continue}break}}if(w[i+13|0]){f=v[L+12>>2];h=v[L+8>>2];c=v[L+4>>2];c=(c|0)<(h|0)?h:c;c=(c|0)<(f|0)?f:c;v[L+12>>2]=c;v[L+8>>2]=c;v[L+4>>2]=c}M=s+16195|0;g=p?3:1;f=A-g|0;j=0;while(1){h=f+j|0;c=h-g|0;if((c|0)<=v[(L+4|0)+(j<<2)>>2]){c=w[J+1|0]<<28>>31&3}else{c=w[c+M|0]}t[h+M|0]=c;j=j+1|0;if((g|0)!=(j|0)){continue}break}p=L+4|0;I=u[i+36>>1]&1;f=0;l=v[i>>2];c=w[l|0];if(c){q=w[J+1|0]&8?7:64;g=l;while(1){i=w[J+3|0]&32;A:{B:{if(v[p+((f>>>0)%3<<2)>>2]>=(f|0)){break B}j=w[f+M|0];if(j>>>0>=q>>>0){break B}h=o;U=i?C(1.4142135381698608):C(1);W=U;C:{if(w[J+1|0]&8){i=j<<3;F=z[i+67908>>2];Q=z[i+67904>>2];break C}T=ny(C(1),j+1>>>1<<I);i=j&1;F=i?C(1):T;Q=i?T:C(1)}Q=C(W*Q);T=C(U*F);m=0;while(1){i=h+(m<<2)|0;F=z[i>>2];z[i+2304>>2]=F*T;z[i>>2]=F*Q;m=m+1|0;if((m|0)!=(c|0)){continue}break}break A}if(!i){break A}jJ(o,c)}o=(w[g|0]<<2)+o|0;f=f+1|0;g=l+f|0;c=w[g|0];if(c){continue}break}}gb=L+16|0;break x}if((c&224)!=96){break x}jJ(s+2940|0,576)}if((n|0)>=1){c=s+7708|0;l=0;while(1){h=w[r+6153|0];J=(w[y+12|0]!=0)<<1<<((B((h>>>3&1)+(h>>>4&1)|0,3)+(w[r+6154|0]>>>2&3)|0)==2);q=(s+B(l,2304)|0)+2940|0;m=q;if(w[y+14|0]){g=((s+B(l,2304)|0)+B(J,72)|0)+2940|0;f=c;o=f;K=v[y>>2]+w[y+13|0]|0;A=w[K|0];if(A){h=g;while(1){I=A<<1;p=0;while(1){z[o>>2]=z[h>>2];z[o+4>>2]=z[(A<<2)+h>>2];i=I<<2;z[o+8>>2]=z[i+h>>2];h=h+4|0;o=o+12|0;p=p+1|0;if((p|0)!=(A|0)){continue}break}h=i+h|0;A=w[K+3|0];K=K+3|0;if(A){continue}break}}hc(g,f,o-f|0);i=J-1|0}else{i=31}if((i|0)>=1){while(1){h=0;while(1){g=h<<2;f=g+m|0;U=z[f+72>>2];I=f;Q=z[g+67968>>2];f=(17-h<<2)+m|0;F=z[f>>2];T=z[g+68e3>>2];z[I+72>>2]=C(U*Q)-C(F*T);z[f>>2]=C(F*Q)+C(U*T);h=h+1|0;if((h|0)!=8){continue}break}m=m+72|0;h=(i|0)>1;i=i-1|0;if(h){continue}break}}h=q;i=r+B(l,1152)|0;f=w[y+11|0];if(J){iJ(h,i,68032,J);i=B(J,36)+i|0;h=B(J,72)+h|0}D:{if((f|0)==2){j=gb-80|0;gb=j;g=32-J|0;if((g|0)>=1){p=j|8;J=j|4;while(1){I=hc(j,h,72);f=v[i+20>>2];v[h+16>>2]=v[i+16>>2];v[h+20>>2]=f;f=v[i+12>>2];v[h+8>>2]=v[i+8>>2];v[h+12>>2]=f;f=v[i+4>>2];v[h>>2]=v[i>>2];v[h+4>>2]=f;f=i+24|0;my(I,h+24|0,f);my(J,h+48|0,f);my(p,i,f);h=h+72|0;i=i+36|0;f=(g|0)>1;g=g-1|0;if(f){continue}break}}gb=j+80|0;break D}iJ(h,i,B((f|0)==3,72)+68032|0,32-J|0)}g=0;j=q+72|0;while(1){h=1;while(1){f=(h<<2)+j|0;z[f>>2]=-z[f>>2];f=h>>>0<16;h=h+2|0;if(f){continue}break}j=j+144|0;h=g>>>0<30;g=g+2|0;if(h){continue}break}y=y+28|0;l=l+1|0;if((n|0)!=(l|0)){continue}break}}lJ(Z,aa,18,v[e+8>>2],d,_);n=v[e+8>>2];d=B(n,1152)+d|0;b=b+1|0;if(b>>>0<(w[G+1|0]&8?2:1)>>>0){continue}break}}b=a;g=D+912|0;d=v[g+8>>2]>>>3|0;c=v[g+4>>2]+7>>>3|0;f=d-c|0;h=(f|0)>511;e=h?511:f;if((f|0)>=1){zh(b+6156|0,(g+(h?d-511|0:c)|0)+12|0,e)}v[b+6144>>2]=e;break j}st(a);break a}q=D+17152|0;n=0;k=0;y=0;b=D;s=b;h=0;E:{F:{G:{c=G;f=w[c+3|0];g=f>>>6|0;switch(g-1|0){case 2:break E;case 0:break G;default:break F}}h=(f>>>2&12)+4|0;break E}h=32}f=w[c+1|0];H:{if((f&6)==6){l=32;c=69436;break H}if(!(f&8)){l=30;c=69439;break H}f=w[c+2|0]>>>2&3;c=py(c)>>>((g|0)!=3)|0;c=c?c:192;if(c>>>0<=55){l=(f|0)==2?12:8;c=69460;break H}l=c>>>0>95?(f|0)!=1?30:27:27;c=69448}t[s+768|0]=l;t[s+769|0]=(h|0)>(l|0)?l:h;h=c;I:{if(!w[b+768|0]){break I}j=69344;while(1){if((n|0)==(y|0)){j=w[h|0]+69344|0;y=w[h+2|0]+y|0;k=w[h+1|0];h=h+3|0}c=n<<1;g=w[$d(q,k)+j|0];t[(c+b|0)+770|0]=g;i=w[b+769|0];if(n>>>0<i>>>0){g=w[$d(q,k)+j|0];i=w[b+769|0]}t[(b+(c|1)|0)+770|0]=i?g:0;g=w[b+768|0];n=n+1|0;if(g>>>0>n>>>0){continue}break}if(!g){k=g<<1;break I}n=0;while(1){c=b+n|0;J:{if(!w[c+770|0]){k=6;break J}k=2;if((w[G+1|0]&6)==6){break J}k=$d(q,2);g=w[b+768|0]}t[c+834|0]=k;k=g<<1&510;n=n+1|0;if(k>>>0>n>>>0){continue}break}}l=b+770|0;G=b+834|0;c=b;h=0;if((k|0)>=1){while(1){g=w[l|0];f=g?19>>>w[h+G|0]&3|4:0;l=l+1|0;s=B(g,3)-6|0;y=4;F=C(0);while(1){if(f&y){g=$d(q,6);i=(g|0)/3|0;F=C(z[(s+(g-B(i,3)|0)<<2)+69472>>2]*C(2097152>>>i|0))}z[c>>2]=F;c=c+4|0;g=y>>>0>1;y=y>>>1|0;if(g){continue}break}h=h+1|0;if((k|0)!=(h|0)){continue}break}}n=w[b+769|0];c=w[b+768|0];if(n>>>0<c>>>0){while(1){t[(b+(n<<1)|0)+771|0]=0;n=n+1|0;if((c|0)!=(n|0)){continue}break}}n=0;f=Qb(D+3852|0,0,4608);y=a+2304|0;G=D+8620|0;c=0;K:{while(1){s=((c<<2)+D|0)+3852|0;I=D+17152|0;r=v[e+16>>2]|1;i=0;h=D;l=w[h+768|0];b=576;while(1){L:{if(!(l&255)){l=0;break L}j=s+(B(i,r)<<2)|0;A=0;while(1){k=b;l=w[(h+A|0)+770|0];M:{if(!l){break M}if(l>>>0<=16){if((r|0)<1){break M}g=(-1<<l-1)+1|0;b=0;while(1){ca=(b<<2)+j|0,ea=C($d(I,l)+g|0),z[ca>>2]=ea;b=b+1|0;if((r|0)!=(b|0)){continue}break}break M}l=2<<l-17;b=$d(I,(l-(l>>>3|0)|0)+3|0);if((r|0)<1){break M}g=l>>>1|0;q=l|1;l=0;while(1){p=b;b=(b>>>0)/(q>>>0)|0;z[(l<<2)+j>>2]=(p-B(q,b)|0)-g|0;l=l+1|0;if((r|0)!=(l|0)){continue}break}}b=18-k|0;j=(k<<2)+j|0;A=A+1|0;l=w[h+768|0];if(A>>>0<l<<1>>>0){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){g=(n<<2)+D|0;b=f;c=D;h=w[c+769|0];k=f+B(h,72)|0;hc(k+2304|0,k,B(w[c+768|0]-h|0,72));if(w[c+768|0]){l=0;while(1){h=0;while(1){k=(h<<2)+b|0;z[k>>2]=z[g>>2]*z[k>>2];k=k+2304|0;z[k>>2]=z[g+12>>2]*z[k>>2];h=h+1|0;if((h|0)!=12){continue}break}g=g+24|0;b=b+72|0;l=l+1|0;if(l>>>0<w[c+768|0]){continue}break}}lJ(y,f,12,v[e+8>>2],d,G);Qb(f,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[D+17156>>2]<=v[D+17160>>2]){n=n+1|0;if((n|0)==3){break K}continue}break}st(a);n=0;break a}k=1}n=B(oy(a+6152|0),k)}gb=D+17168|0;return n|0}function oJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0,P=0;M=gb-144|0;gb=M;k=v[f>>2];N=g&4;K=N?-1:k+((d^-1)+e|0)|0;s=K+1|0;a:{if(d>>>0<=e>>>0?s&K:1){v[f>>2]=0;v[c>>2]=0;l=-3;break a}D=e+k|0;r=v[c>>2];z=r+b|0;E=v[a+60>>2];q=v[a+40>>2];k=v[a+36>>2];C=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];j=b;p=e;l=-1;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(v[a>>2]){case 37:v[a>>2]=37;break b;case 21:v[a>>2]=21;break b;case 17:v[a>>2]=17;break b;case 35:v[a>>2]=35;break b;case 10:v[a>>2]=10;break b;case 39:v[a>>2]=39;break b;case 36:v[a>>2]=36;break b;case 34:break g;case 42:break j;case 41:break k;case 53:break l;case 52:break m;case 51:break n;case 38:break o;case 27:break p;case 26:break q;case 25:break r;case 24:break s;case 23:break t;case 18:break u;case 16:break v;case 14:break w;case 11:break x;case 9:break y;case 7:break z;case 6:break A;case 3:break B;case 32:break C;case 5:break D;case 2:break F;case 1:break G;case 0:break H;default:break b}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;q=0;k=0;C=0;i=0;if(g&1){break G}break E}l=1;if((r|0)<1){break c}v[a+8>>2]=w[b|0];j=b+1|0}l=2;if(j>>>0>=z>>>0){break c}n=w[j|0];v[a+12>>2]=n;h=1;j=j+1|0;l=-1;A=36;k=v[a+8>>2];if(((n|k<<8)>>>0)%31|n&32){break d}n=k&15;if(!N){if((n|0)!=8){break d}n=256<<(k>>>4);if(n>>>0>32768){break d}k=0;if(n>>>0<=s>>>0){break E}break d}k=0;if((n|0)!=8){break d}}h=0;break i}if((r|0)<1){l=5;break c}O=i+8|0;j=b+1|0;m=w[b|0]<<i|m;h=2;break i}if((r|0)<1){l=32;break c}j=b+1|0;m=w[b|0]<<i|m;i=i+8|0;break h}h=1;break i}h=4;break i}h=3;break i}h=7;break i}h=9;break i}h=10;break i}h=11;break i}h=12;break i}h=13;break i}h=14;break i}h=15;break i}h=16;break i}h=17;break i}h=8;break i}h=5;break i}h=6;break i}h=18;break i}o=2;break e}o=1;break e}I:while(1){J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{switch(h|0){case 0:if(i>>>0>2){break wa}h=1;continue;case 17:break ea;case 16:break fa;case 15:break ga;case 14:break ha;case 13:break ia;case 12:break ja;case 11:break ka;case 10:break la;case 9:break ma;case 8:break oa;case 7:break pa;case 6:break qa;case 5:break ra;case 4:break ta;case 3:break ua;case 2:break va;case 1:break xa;default:break da}}l=3;while(1){if(j>>>0>=z>>>0){break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h}h=m&7;v[a+20>>2]=h;s=h>>>1|0;v[a+24>>2]=s;i=i-3|0;m=m>>>3|0;if(h>>>0>=2){break na}O=i;break ca}i=O&-8;m=m>>>(O&7)|0;k=0;h=0;break aa}if(j>>>0<z>>>0){break sa}l=7;break c}while(1){if(j>>>0>=z>>>0){l=6;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;h=1;break aa}t[(a+k|0)+10528|0]=w[j|0];j=j+1|0;h=2;break aa}while(1){if(j>>>0>=z>>>0){l=51;break c}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;break M}if(p>>>0>=D>>>0){l=2;A=52;h=k;break d}t[p|0]=C;k=k-1|0;p=p+1|0;break N}if(p>>>0<D>>>0){break ba}l=2;A=9;h=k;break d}if(j>>>0<z>>>0){n=D-p|0;h=z-j|0;h=h>>>0>n>>>0?n:h;h=h>>>0<k>>>0?h:k;k=k-h|0;p=hc(p,j,h)+h|0;j=h+j|0;break L}l=38;break c}l=-1;A=10;n=0;h=k;ya:{switch(s-1|0){case 0:break ya;case 2:break d;default:break $}}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Qb(a- -64|0,8,144);Qb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;F=1;break R}l=k+18701|0;while(1){if(j>>>0>=z>>>0){l=11;break c}m=w[j|0]<<i|m;n=j+1|0;j=n;h=i+8|0;i=h;G=t[l|0];if(h>>>0<G>>>0){continue}break}j=n;n=k;i=h;k=1;break T}while(1){if(j>>>0>=z>>>0){l=14;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h;h=1;break S}if(j>>>0>=z>>>0){l=16;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break _}break Z}while(1){if(j>>>0>=z>>>0){l=18;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}P=C-16|0;j=h;h=3;break Q}if(j>>>0>=z>>>0){l=23;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break Y}break X}if(p>>>0>=D>>>0){l=2;A=24;h=k;break d}t[p|0]=k;p=p+1|0;break P}while(1){if(j>>>0>=z>>>0){l=25;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=3;break O}if(j>>>0>=z>>>0){l=26;break c}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break W}break V}while(1){if(j>>>0>=z>>>0){l=27;break c}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=6;break O}if(p>>>0>=D>>>0){l=2;A=53;h=k;break d}t[p|0]=w[(E-C&K)+d|0];p=p+1|0;E=E+1|0;break U}h=2;continue}h=8;continue}while(1){za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:if(k>>>0>3){break Ca}if(!i){i=0;h=3;continue I}if(i>>>0>7){break Aa}h=4;continue I;case 1:t[(a+k|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break za;default:break Da}}k=k+1|0;break Ba}h=x[a+10528>>1];if((h|0)==(x[a+10530>>1]^65535)){k=h;break N}l=-1;A=39;break d}h=0;continue}h=1;continue}h=2;continue}}k=0;break T}h=1;break Q}h=2;break Q}h=0;break O}h=1;break O}h=4;break O}h=5;break O}h=7;break O}while(1){Ea:{Fa:{Ga:{if(!k){if(n>>>0>2){break Ga}k=n;G=t[k+18701|0];if(G>>>0<=i>>>0){break Ea}h=9;continue I}k=n<<2;v[(k+a|0)+44>>2]=v[k+61700>>2]+((-1<<G^-1)&m);n=n+1|0;i=i-G|0;m=m>>>G|0;break Fa}k=0;Qb(a+7040|0,0,288);h=0;break S}k=0;continue}k=1;continue}}while(1){Ha:{Ia:{Ja:{if(!h){if(y[a+52>>2]<=k>>>0){break Ja}if(i>>>0>2){break Ha}h=10;continue I}t[(w[k+61680|0]+a|0)+7040|0]=m&7;k=k+1|0;i=i-3|0;m=m>>>3|0;break Ia}v[a+52>>2]=19;F=v[a+24>>2];break R}h=0;continue}h=1;continue}}h=0}while(1){Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(h|0){case 0:h=0;if((F|0)<0){break P}H=Qb(M,0,64);l=B(F,3488)+a|0;Qb(l+352|0,0,3200);r=v[a+24>>2];s=v[((r<<2)+a|0)+44>>2];if(s){while(1){n=(w[(h+l|0)- -64|0]<<2)+H|0;v[n>>2]=v[n>>2]+1;h=h+1|0;if((s|0)!=(h|0)){continue}break}}v[H+64>>2]=0;v[H+68>>2]=0;n=0;A=0;h=1;while(1){l=h<<2;h=h+1|0;l=v[l+H>>2];n=l+n<<1;v[(H- -64|0)+(h<<2)>>2]=n;A=l+A|0;if((h|0)!=16){continue}break};if(!((n|0)==65536|A>>>0<=1)){l=-1;A=35;h=k;break d}if(s){l=-1;I=0;J=B(F,3488)+a|0;while(1){r=w[(I+J|0)- -64|0];Va:{if(!r){break Va}n=(H- -64|0)+(r<<2)|0;h=v[n>>2];v[n>>2]=h+1;n=0;A=r;while(1){s=n;n=h&1|n<<1;h=h>>>1|0;A=A-1|0;if(A){continue}break}if(r>>>0<=10){if(n>>>0>1023){break Va}s=1<<r;h=r<<9|I;while(1){u[((n<<1)+J|0)+352>>1]=h;n=n+s|0;if(n>>>0<1024){continue}break}break Va}n=((n&1023)<<1)+J|0;h=u[n+352>>1];Wa:{if(h){n=l;l=h;break Wa}u[n+352>>1]=l;n=l-2|0}h=s>>>8&8388607;if(r>>>0>=12){while(1){h=h>>>1|0;s=(((h&1)+(l^-1)<<1)+J|0)+2400|0;l=u[s>>1];if(!l){u[s>>1]=n;l=n;n=n-2|0}r=r-1|0;if(r>>>0>11){continue}break}}u[(((h>>>1&1)+(l^-1)<<1)+J|0)+2400>>1]=I;l=n}I=I+1|0;r=v[a+24>>2];if(I>>>0<y[((r<<2)+a|0)+44>>2]){continue}break}}h=0;if((r|0)!=2){break Na}break Ra;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];Xa:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break Xa}break Qa}if(i>>>0<11){break Xa}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break Qa}}h=11;continue I;case 2:l=u[(((m&1023)<<1)+a|0)+7328>>1];if((l|0)>=0){break Ta}h=10;while(1){n=m>>>h|0;h=h+1|0;l=u[(((n&1)+(l^-1)<<1)+a|0)+9376>>1];if((l|0)<0){continue}break};break Sa;default:break Ua}}l=t[P+14919|0]+((-1<<q^-1)&m)|0;i=i-q|0;m=m>>>q|0;n=a+k|0;Qb(n+10532|0,(C|0)==16?w[n+10531|0]:0,l);h=l+k|0;break Ra}h=l>>9;l=l&511}i=i-h|0;m=m>>>h|0;C=l;if(l>>>0>15){break Pa}t[(a+k|0)+10532|0]=C;h=k+1|0}n=v[a+48>>2];l=v[a+44>>2];k=n+l|0;if(k>>>0<=h>>>0){break Oa}if(i>>>0<=14){if((z-j|0)<=1){k=h;h=1;continue}m=w[j|0]<<i|m|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}k=h}h=2;continue}if(!((C|0)!=16|k)){l=-1;h=0;A=17;C=16;break d}q=t[C+18676|0];if(q>>>0>i>>>0){break Ma}P=C-16|0;break Ka}if((h|0)!=(k|0)){l=-1;A=21;break d}k=a+10532|0;hc(a- -64|0,k,l);hc(a+3552|0,l+k|0,n);r=v[a+24>>2];k=h}F=r-1|0;v[a+24>>2]=F;break La}h=12;continue I}h=0;continue}h=3;continue}}o=m;h=2}Ya:while(1){Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];mb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break mb}break Za}if(i>>>0<11){break mb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break Za}}h=13;continue I;case 1:l=u[(((m&1023)<<1)+a|0)+352>>1];if((l|0)>=0){break kb}h=10;while(1){k=m>>>h|0;h=h+1|0;l=u[(((k&1)+(l^-1)<<1)+a|0)+2400>>1];if((l|0)<0){continue}break};k=l;break jb;case 3:break ab;case 4:break bb;case 5:break fb;case 6:break gb;case 2:break lb;default:break hb}}while(1){h=z-j|0;if(!((D-p|0)>1?(h|0)>=4:0)){if(i>>>0>14){m=o;break Za}if((h|0)<=1){m=o;h=0;continue Ya}m=w[j|0]<<i|o|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0;break Za}nb:{if(i>>>0>14){m=i;h=j;break nb}m=i+16|0;o=(w[j|0]|w[j+1|0]<<8)<<i|o;h=j+2|0}k=u[(((o&1023)<<1)+a|0)+352>>1];ob:{if((k|0)<0){j=10;while(1){i=o>>>j|0;j=j+1|0;k=u[(((i&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break}break ob}j=k>>9}i=m-j|0;m=o>>>j|0;if(k&256){j=h;break ib}if(!(i>>>0>14)){m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;i=i+16|0}l=i;j=h;h=u[(((m&1023)<<1)+a|0)+352>>1];pb:{if((h|0)<0){o=10;while(1){i=m>>>o|0;o=o+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break pb}o=h>>9}t[p|0]=k;i=l-o|0;o=m>>>o|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=o;k=h;break ib}h=l>>9;k=l&511}i=i-h|0;m=m>>>h|0;if(k>>>0>255){break ib}h=14;continue I}l=k&511;k=256;if((l|0)==256){break K}q=0;h=m;n=l<<2;k=v[n+60140>>2];s=k;if(l-265>>>0>19){break $a}q=v[n+60268>>2];if(q>>>0>i>>>0){h=15;continue I}h=3;continue}if(!k){o=m;k=-1;break db}k=k-1|0;h=18;continue I}i=i-q|0;o=m>>>q|0;C=((-1<<q^-1)&m)+C|0;break eb}q=u[(((m&1023)<<1)+a|0)+3840>>1];qb:{if((q|0)<0){h=10;while(1){n=m>>>h|0;h=h+1|0;q=u[(((n&1)+(q^-1)<<1)+a|0)+5888>>1];if((q|0)<0){continue}break}n=q;break qb}h=q>>9;n=q&511}i=i-h|0;m=m>>>h|0;h=n<<2;C=v[h+61424>>2];q=0;if(n-4>>>0>25){o=m;break eb}q=v[h+61552>>2];if(q>>>0<=i>>>0){break cb}h=17;continue I}E=p-d|0;if(!(!N|E>>>0>=C>>>0)){l=-1;A=37;m=o;h=k;break d}h=(E-C&K)+d|0;if((h>>>0<p>>>0?p:h)+k>>>0>D>>>0){m=o;h=7;continue}if(k>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;k=k-3|0;if(k>>>0>2){continue}break}}if(!k){break db}t[p|0]=w[h|0];if((k|0)!=1){t[p+1|0]=w[h+1|0]}p=k+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];rb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break rb}break _a}if(i>>>0<11){break rb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break _a}}h=16;continue I}i=i-q|0;h=m>>>q|0;s=((-1<<q^-1)&m)+k|0}k=s;m=h;if(i>>>0>14){break _a}if((z-j|0)<=1){h=4;continue}m=m|w[j|0]<<i|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}h=5;continue}h=1;continue}}if(!k|!i){break L}if(i>>>0>7){break M}h=5;continue}i=i-8|0;C=m&255;m=m>>>8|0;h=6;continue}if(k){break J}k=0}if(t[a+20|0]&1){break h}h=0;continue}h=7;continue}}o=i&-8;sb:{if(!o|b>>>0>=j>>>0){break sb}while(1){o=o-8|0;j=j-1|0;if(j>>>0<=b>>>0){break sb}if(o){continue}break}}if(o){break f}m=(((o&63)>>>0>=32?0:-1<<o)^-1)&m>>>(i&7);h=0;n=0;i=0;if(!(g&1)){break g}o=0;break e}v[a>>2]=34;l=0;break b}aa(3896,10506,2787,3906);L()}while(1){tb:{ub:{vb:{wb:{xb:{yb:{switch(o|0){case 0:if(h>>>0>3){l=0;A=34;i=n;break d}if(n){break xb}i=0;k=h;o=1;continue;case 1:break yb;default:break wb}}if(j>>>0<z>>>0){break ub}l=42;break c}k=h;i=n;if(i>>>0>7){break vb}o=2;continue}while(1){if(j>>>0>=z>>>0){l=41;break c}m=w[j|0]<<i|m;h=i>>>0>4294967287;d=j+1|0;j=d;n=i+8|0;i=n;if(h){continue}break}j=d;h=k}o=m&255;m=m>>>8|0;n=n-8|0;break tb}o=w[j|0];j=j+1|0;h=k;n=i}v[a+16>>2]=v[a+16>>2]<<8|o;h=h+1|0;o=0;continue}}v[a>>2]=A;zb:{if(i>>>0<8|b>>>0>=j>>>0){break zb}while(1){i=i-8|0;j=j-1|0;if(j>>>0<=b>>>0){break zb}if(i>>>0>7){continue}break}}k=h;break b}v[a>>2]=l;l=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=E;v[a+40>>2]=q;v[a+36>>2]=k;v[a+32>>2]=C;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=j-b;c=p-e|0;v[f>>2]=c;if(!(g&9)|(l|0)<0){break a}b=v[a+28>>2];j=b>>>16|0;i=b&65535;if(c){o=(c>>>0)%5552|0;while(1){k=0;if(o>>>0>7){while(1){p=w[e|0]+i|0;n=p+w[e+1|0]|0;m=n+w[e+2|0]|0;h=m+w[e+3|0]|0;f=h+w[e+4|0]|0;d=f+w[e+5|0]|0;b=d+w[e+6|0]|0;i=b+w[e+7|0]|0;j=i+(b+(d+(f+(h+(m+(n+(j+p|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;k=k+8|0;if((k|7)>>>0<o>>>0){continue}break}k=o&8184}m=e;h=k;if(o>>>0>h>>>0){while(1){i=w[m|0]+i|0;j=j+i|0;m=m+1|0;h=h+1|0;if((o|0)!=(h|0)){continue}break}e=(o-k|0)+e|0}c=c-o|0;j=(j>>>0)%65521|0;i=(i>>>0)%65521|0;o=5552;if(c){continue}break}}b=j<<16|i;v[a+28>>2]=b;if(l){break a}l=0;if(!(g&1)){break a}l=(b|0)==v[a+16>>2]?0:-2}gb=M+144|0;return l}function cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Y=0;f=gb-400|0;gb=f;vc(b);j=gb-32|0;gb=j;e=j+24|0;i=f+192|0;bU(e,i);h=yb(e);e=v[j+28>>2];g=v[j+24>>2];v[j+8>>2]=g;v[j+12>>2]=e;v[j>>2]=g;v[j+4>>2]=e;g=j+16|0;e=b;cc(g,e,j);g=yb(g);if((g|0)==(h|0)){Rb(e,yb(j+24|0))}gb=j+32|0;e=(g|0)==(h|0);if(!e){aU(i)}a:{if(!e){break a}if(!jU(f+192|0)){break a}if(!c){d=1;break a}Hd(a,134217728);d=f+136|0;Ff(d,1084);v[22708]=0;n=f+192|4;U(891,f+8|0,d|0,n|0);d=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{if((d|0)!=1){d=f+8|0;Eb(a+1298304|0,d);vb(d);Hb(f+136|0);d=Tb(d,6105);Eb(a+1298316|0,d);vb(d);v[a+480188>>2]=4;v[a+1298364>>2]=2;X=a,Y=Ib(w[f+328|0]|w[f+329|0]<<8),v[X+480196>>2]=Y;d=Ib(w[f+332|0]|w[f+333|0]<<8);v[a+480260>>2]=56;v[a+480264>>2]=13696;X=a,Y=iU(d),v[X+480204>>2]=Y;Fr(Sb(a+484360|0),f+200|0,w[f+192|6]);r=a+480190|0;o=dd(f+176|0);q=mc(f+160|0);i:{j:{k:{l:{m:{n:{if(Ib(w[f+392|0]|w[f+393|0]<<8)){while(1){v[22708]=0;d=T(416,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}u[f+112>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=Ib(w[f+394|0]|w[f+395|0]<<8);if((Ib(w[n|0]|w[n+1|0]<<8)|0)==2){v[22708]=0;d=T(426,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}d=d-2|0}v[22708]=0;U(288,f+136|0,b|0,d|0);d=v[22708];v[22708]=0;o:{p:{q:{if((d|0)!=1){e=f+136|0;d=jc(f+8|0,e);xb(e);v[22708]=0;e=Le(r,f+112|0);j=v[22708];v[22708]=0;if((j|0)==1){break q}C=x[e>>1];u[a+480190>>1]=C;v[22708]=0;e=B(x[f+112>>1],104)+a|0;h=e+484380|0;R(424,h|0,1);j=v[22708];v[22708]=0;r:{if((j|0)==1){break r}if(Ib(w[n|0]|w[n+1|0]<<8)>>>0>1){break p}v[22708]=0;R(892,d|0,e+484423|0);j=v[22708];v[22708]=0;if((j|0)==1){break r}v[22708]=0;Q(318,f+8|0,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break r}v[22708]=0;W(503,d|0,((x[f+112>>1]<<5)+a|0)+946304|0,30)|0;j=v[22708];v[22708]=0;if((j|0)!=1){break o}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}j=Kb(f+136|0);v[22708]=0;W(533,d|0,j|0,257)|0;i=v[22708];v[22708]=0;s:{t:{if((i|0)==1){break t}v[22708]=0;Q(303,e+484423|0,j|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break t}v[22708]=0;Q(318,f+8|0,1)|0;i=v[22708];v[22708]=0;if((i|0)==1){break t}v[22708]=0;W(533,d|0,j|0,31)|0;i=v[22708];v[22708]=0;if((i|0)==1){break t}v[22708]=0;Q(301,((x[f+112>>1]<<5)+a|0)+946304|0,j|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break t}if(!(v[f+16>>2]&1)){break s}v[22708]=0;Q(318,f+8|0,1)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break s}}d=P()|0;O()|0;vb(j);break f}vb(j)}v[22708]=0;R(893,d|0,f+136|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}v[22708]=0;hU(f+136|0,h);d=v[22708];v[22708]=0;if((d|0)==1){break n}if((Ib(w[n|0]|w[n+1|0]<<8)|0)==2){t[e+484417|0]=w[f+154|0]<<3}u:{if(!Ib(w[n|0]|w[n+1|0]<<8)){break u}v[22708]=0;R(317,q|0,C|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}v[22708]=0;R(895,o|0,C|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}h=Ad(o,x[f+112>>1]-1|0);Od(h);v[22708]=0;j=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}v[22708]=0;d=Q(191,b|0,j<<3)|0;i=v[22708];v[22708]=0;if((i|0)==1){break j}if(!d){break l}v[22708]=0;R(896,h|0,j|0);d=v[22708];v[22708]=0;if((d|0)==1){break j}d=0;v[f+128>>2]=0;if(!j){if(!(w[e+484414|0]&2)){break u}d=v[e+484384>>2];v[f+120>>2]=d;e=v[e+484388>>2];v[22708]=0;v[f+124>>2]=e-d;R(897,h|0,f+120|0);d=v[22708];v[22708]=0;if((d|0)!=1){break u}d=P()|0;O()|0;break f}while(1){v[22708]=0;e=T(426,b|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}v[22708]=0;v[f+120>>2]=e;e=T(426,b|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}v[22708]=0;v[f+124>>2]=e;R(897,h|0,f+120|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}d=d+1|0;if(j>>>0>(d&65535)>>>0){continue}break}}xb(f+8|0);p=p+1|0;if(Ib(w[f+392|0]|w[f+393|0]<<8)>>>0>(p&65535)>>>0){continue}break}}D=128;if(Ib(w[n|0]|w[n+1|0]<<8)){break m}v[22708]=0;D=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break m}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=a+480188|0;E=w[f+192|7];u[f+118>>1]=4;v:{w:{if(Ib(w[n|0]|w[n+1|0]<<8)){p=v[b+8>>2];x:{if(!D){break x}g=0;while(1){v[22708]=0;e=T(416,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break w}if((e|0)==65535){break x}v[22708]=0;E=T(416,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}v[22708]=0;e=T(416,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break w}u[f+118>>1]=e;if(e>>>0>127){break c}v[22708]=0;e=Le(d,f+118|0);j=v[22708];v[22708]=0;if((j|0)==1){break w}u[d>>1]=x[e>>1];v[22708]=0;Q(318,b|0,B(x[f+118>>1],E)<<2)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}g=g+1|0;if((g&65535)>>>0<D>>>0){continue}break}}v[22708]=0;Q(190,b|0,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break v}}d=x[d>>1];v[22708]=0;G=Q(898,f+136|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){H=Ib(w[f+330|0]|w[f+331|0]<<8);y:{if(!D){break y}K=a+484344|0;V=c&1;j=0;p=0;while(1){z:{if(!Ib(w[n|0]|w[n+1|0]<<8)){d=x[f+118>>1];e=p;break z}v[22708]=0;e=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}if((e|0)==65535){break y}v[22708]=0;E=T(416,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;d=T(416,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break g}u[f+118>>1]=d}v[22708]=0;g=d&65535;F=E&65535;d=F<<2;h=Q(191,b|0,B(g,d)|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break g}if(!h){break y}A:{B:{C:{if(!V){break C}v[22708]=0;M=e&65535;e=W(331,K|0,M|0,F|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break g}if(!e){break C}s=0;if(F){break B}break A}v[22708]=0;Q(318,b|0,B(d,x[f+118>>1])|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break A}break g}while(1){d=_b(K,M);v[22708]=0;i=Uf(d,s);d=v[22708];v[22708]=0;D:{if((d|0)!=1){e=0;A=0;E:{F:{switch((H&3)-1|0){case 0:A=!(s&3);break E;case 1:A=!(s&1);break E;case 2:break F;default:break E}}A=(s&3)!=3}I=0;if(!x[f+118>>1]){break D}while(1){d=v[G>>2];v[22708]=0;R(531,f+120|0,b|0);h=v[22708];v[22708]=0;if((h|0)==1){break g}h=B(e,9)+d|0;d=f+120|0;g=qd(d);z=Ve(d);k=ej(d);l=i+B(e,6)|0;t[l+1|0]=w[d|0];d=w[g|0];t[l|0]=d;g=w[k|0];t[l+5|0]=g;k=l+5|0;if(d){t[l|0]=d+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[k|0]}m=g&255;z=w[z|0];G:{if(z>>>0>=240){d=m|(z&15)<<8;if(d){v[22708]=0;d=fn(+(iU(d)>>>0)/1e4);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=d;t[l+3|0]=17;break G}break g}t[l+3|0]=0;break G}J=m>>>4|0;N=m<<4;d=J|N;H:{switch(z|0){case 0:d=i+B(e,6)|0;if(g&255){t[d+3|0]=1;break G}t[d+3|0]=0;break G;case 1:t[(i+B(e,6)|0)+3|0]=2;break G;case 2:t[(i+B(e,6)|0)+3|0]=3;break G;case 3:v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[h|0]=w[d|0]|16;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(e,6)|0)+3|0]=0;break G}break g;case 4:v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[h|0]=w[d|0]|32;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(e,6)|0)+3|0]=0;break G}break g;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(i+B(e,6)|0)+3|0]=0;break G;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(i+B(e,6)|0)+3|0]=0;break G;case 7:t[(i+B(e,6)|0)+3|0]=23;j=0;break G;case 8:t[(i+B(e,6)|0)+3|0]=0;j=d;break G;case 9:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|16;break G}break g;case 10:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|32;break G}break g;case 11:t[h+3|0]=d;t[(i+B(e,6)|0)+3|0]=0;break G;case 12:d=i+B(e,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break G;case 13:z=i+B(e,6)|0;I:{J:{if(m&240){t[(i+B(e,6)|0)+2|0]=4;d=(g&240)>>>4|0;break J}if(!(m&15)){break I}t[(i+B(e,6)|0)+2|0]=3;d=g&15}t[z+4|0]=d}t[h+3|0]=0;t[(i+B(e,6)|0)+3|0]=0;break G;case 14:t[(i+B(e,6)|0)+3|0]=19;t[k|0]=!(g&255);break G;case 15:t[(i+B(e,6)|0)+3|0]=16;t[k|0]=(g&240)>>>4;H=g&15;break G;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(i+B(e,6)|0)+3|0]=0;break G;case 17:t[h+6|0]=m&15?g:0;t[(i+B(e,6)|0)+3|0]=0;break G;case 18:t[(i+B(e,6)|0)+3|0]=14;break G;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(i+B(e,6)|0)+3|0]=0;break G;case 20:t[(i+B(e,6)|0)+3|0]=12;break G;case 22:K:{d=w[l+1|0];L:{if(!d){break L}if(Ec(o)>>>0<d>>>0){break L}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;v[22708]=0;Q(900,f+8|0,0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break g}v[f+112>>2]=9;d=Ec(d);v[22708]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22708];v[22708]=0;if((m|0)==1){break K}if(y[d>>2]<=(g&255)>>>0){break L}d=i+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}t[(i+B(e,6)|0)+3|0]=0;break G}break g;case 23:d=w[l+1|0];M:{if(!d){break M}if(Ec(o)>>>0<d>>>0){break M}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;g=g&255;if(Ec(d)>>>0<=g>>>0){break M}N:{if(x[Ad(d,g)+8>>1]){break N}if(!fi(a)){g=w[k|0];break N}m=x[r>>1]+1|0;u[r>>1]=m;g=w[k|0];X=Ad(d,g),Y=m,u[X+8>>1]=Y}X=l,Y=w[Ad(d,g)+8|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break G;case 24:O:{d=w[l+1|0];P:{if(!d){break P}if(Ec(o)>>>0<d>>>0){break P}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;v[22708]=0;Q(900,f+8|0,0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break g}v[f+112>>2]=9;d=Ec(d);v[22708]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22708];v[22708]=0;if((m|0)==1){break O}if(y[d>>2]>(g&255)>>>0){d=i+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}Q:{if(x[sc(q,w[l+1|0]-1|0)>>1]){break Q}if(!fi(a)){break Q}d=x[r>>1]+1|0;u[r>>1]=d;X=sc(q,w[l+1|0]-1|0),Y=d,u[X>>1]=Y}X=l,Y=w[sc(q,w[l+1|0]-1|0)|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break G}break g;case 25:d=w[l+1|0];R:{if(!d){break R}if(Ec(o)>>>0<d>>>0){break R}d=Ad(o,d-1|0);g=g-1|0;t[k|0]=g;g=g&255;if(Ec(d)>>>0<=g>>>0){break R}S:{if(x[Ad(d,g)+10>>1]){break S}if(!fi(a)){g=w[k|0];break S}m=x[r>>1]+1|0;u[r>>1]=m;g=w[k|0];X=Ad(d,g),Y=m,u[X+10>>1]=Y}X=l,Y=w[Ad(d,g)+10|0],t[X+1|0]=Y}t[(i+B(e,6)|0)+3|0]=0;break G;case 29:t[(i+B(e,6)|0)+3|0]=11;t[k|0]=d;if(m&15){t[k|0]=N|15;break G}if((g&255)>>>0<16){break G}t[k|0]=J|240;break G;case 32:if(m&240){t[h+3|0]=J;t[(i+B(e,6)|0)+3|0]=0;break G}t[(i+B(e,6)|0)+3|0]=19;t[k|0]=g&15|192;break G;case 33:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|208;break G}break g;case 34:t[(i+B(e,6)|0)+3|0]=19;v[22708]=0;t[f+8|0]=15;d=ac(k,f+8|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[k|0]=w[d|0]|144;break G}break g;case 73:t[(i+B(e,6)|0)+3|0]=10;break G;case 78:if((g&112|128)==224){t[(i+B(e,6)|0)+3|0]=19;break G}t[(i+B(e,6)|0)+3|0]=0;break G;case 79:d=i+B(e,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;H=0;break G}t[d+3|0]=17;break G;default:break H}}t[(i+B(e,6)|0)+3|0]=0}m=0;g=w[h+3|0];if(!(w[l+2|0]|!g)){T:{if(g>>>0>=16){t[l+2|0]=5;g=g>>>4|0;break T}t[l+2|0]=6}t[l+4|0]=g;m=1}U:{if(w[l+3|0]){break U}d=w[h+1|0];V:{if(d){t[l+3|0]=2;break V}d=w[h+2|0];if(d){t[l+3|0]=3;break V}d=w[h|0];if(d){t[l+3|0]=19;break V}d=w[h+7|0];if(d){t[l+3|0]=4;t[h+8|0]=d;break V}d=w[h+4|0];if(d){t[l+3|0]=5;t[h+5|0]=d;break V}d=w[h+3|0];if(!(!d|m)){t[l+3|0]=11;t[k|0]=d;if(d&15){d=d|-16;break V}if(!(d&240)){break U}d=d|15;break V}d=w[h+6|0];if(d){t[l+3|0]=8;break V}if(A){t[l+3|0]=20;A=0;d=97;break V}A=0;if(I){break U}d=j&255;if(!d){break U}t[l+3|0]=24;t[k|0]=j;if(j&15){d=j|-16}else{if(!(d&240)){I=1;break U}d=j|15}I=1}t[k|0]=d}e=e+1|0;if(e>>>0<x[f+118>>1]){continue}break}break D}break g}s=s+1|0;if((F|0)!=(s|0)){continue}break}}p=p+1|0;if((p&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[22708]=0;yh(a,1);d=v[22708];v[22708]=0;if((d|0)==1){break g}if(Ib(w[n|0]|w[n+1|0]<<8)){W:{while(1){v[22708]=0;d=Q(191,b|0,2)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}if(!d){break W}v[22708]=0;d=T(416,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}if((d|0)==65535){break W}v[22708]=0;Q(318,b|0,2)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;d=T(426,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;Q(318,b|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}}break}break g}v[22708]=0;Q(318,b|0,34)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}}X:{if(!(!(c&2)|!C)){d=1;p=1;while(1){c=(B(d,104)+a|0)+484380|0;Y:{if(!v[c>>2]){break Y}e=Rc(f+8|0,8,1,0,0);v[22708]=0;W(329,e|0,c|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break X}if(Ec(o)>>>0<d>>>0){break Y}d=d-1|0;e=Ad(o,d);v[22708]=0;R(901,c|0,e|0);e=v[22708];v[22708]=0;Z:{if((e|0)!=1){if(!x[sc(q,d)>>1]){break Z}e=x[sc(q,d)>>1];j=v[c>>2];v[22708]=0;ha(902,c|0,(B(e,104)+a|0)+484380|0,0,j|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){break Z}}break g}d=Ad(o,d);X=f,Y=Vb(d),v[X+8>>2]=Y;X=f,Y=Zb(d),v[X+120>>2]=Y;if(!Gb(f+8|0,f+120|0)){break Y}while(1){d=v[f+8>>2];e=x[d+8>>1];if(e){j=v[d+4>>2];h=v[d>>2];v[22708]=0;ha(902,c|0,(B(e,104)+a|0)+484380|0,h|0,j|0,1);e=v[22708];v[22708]=0;if((e|0)==1){break g}}e=x[d+10>>1];if(e){j=v[d+4>>2];d=v[d>>2];v[22708]=0;ha(902,c|0,(B(e,104)+a|0)+484380|0,d|0,j|0,0);d=v[22708];v[22708]=0;if((d|0)==1){break g}}d=f+8|0;tr(d);if(Gb(d,f+120|0)){continue}break}}p=p+1|0;d=p&65535;if(C>>>0>=d>>>0){continue}break}}NB(G);d=1;break b}break g}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}xb(f+8|0);break c}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;Hb(f+136|0);break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;NB(G);break e}xb(f+8|0)}Ye(q);cU(o)}S(d|0);L()}d=0}Ye(q);cU(o)}gb=f+400|0;return d|0}function Cd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-16|0;gb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=v[116503];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=e>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;f=v[b+466060>>2];a=f+8|0;c=v[f+8>>2];b=b+466052|0;l:{if((c|0)==(b|0)){m=466012,n=sqa(-2,d)&e,v[m>>2]=n;break l}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[f+4>>2]=b|3;b=b+f|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116505];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+466060>>2];b=v[g+8>>2];a=a+466052|0;m:{if((b|0)==(a|0)){e=sqa(-2,c)&e;v[116503]=e;break m}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=h|3;d=g+h|0;b=c<<3;f=b-h|0;v[d+4>>2]=f|1;v[b+g>>2]=f;if(k){b=k>>>3|0;c=(b<<3)+466052|0;g=v[116508];b=1<<b;n:{if(!(b&e)){v[116503]=b|e;b=c;break n}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[116508]=d;v[116505]=f;break a}j=v[116504];if(!j){break k}b=(j&0-j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+466316>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;f=c>>>0<d>>>0;d=f?c:d;b=f?a:b;c=a;continue}break}i=v[b+24>>2];f=v[b+12>>2];if((f|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=f;v[f+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;f=a;c=a+20|0;a=v[c>>2];if(a){continue}c=f+16|0;a=v[f+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[116504];if(!j){break k}d=0-h|0;e=0;p:{if(h>>>0<256){break p}e=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;e=(a<<1|h>>>a+21&1)+28|0}c=v[(e<<2)+466316>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((e|0)==31?0:25-(e>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}f=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|f)){f=0;a=2<<e;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+466316>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;f=c?a:f;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!f|v[116505]-h>>>0<=d>>>0){break k}e=v[f+24>>2];b=v[f+12>>2];if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=f+20|0;a=v[c>>2];if(!a){a=v[f+16>>2];if(!a){break i}c=f+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116505];if(c>>>0>=h>>>0){d=v[116508];b=c-h|0;u:{if(b>>>0>=16){v[116505]=b;a=d+h|0;v[116508]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[116508]=0;v[116505]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[116506];if(i>>>0>h>>>0){b=i-h|0;v[116506]=b;c=v[116509];a=c+h|0;v[116509]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;b=j;if(v[116621]){c=v[116623]}else{v[116624]=-1;v[116625]=-1;v[116622]=4096;v[116623]=4096;v[116621]=l+12&-16^1431655768;v[116626]=0;v[116614]=0;c=4096}g=b+c|0;f=0-c|0;c=g&f;if(c>>>0<=h>>>0){break a}d=v[116613];if(d){b=v[116611];e=b+c|0;if(d>>>0<e>>>0|b>>>0>=e>>>0){break a}}if(w[466456]&4){break f}v:{w:{d=v[116509];if(d){a=466460;while(1){b=v[a>>2];if(d>>>0<b+v[a+4>>2]>>>0?b>>>0<=d>>>0:0){break w}a=v[a+8>>2];if(a){continue}break}}b=Up(0);if((b|0)==-1){break g}e=c;d=v[116622];a=d-1|0;if(a&b){e=(c-b|0)+(a+b&0-d)|0}if(e>>>0<=h>>>0|e>>>0>2147483646){break g}d=v[116613];if(d){a=v[116611];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=Up(e);if((b|0)!=(a|0)){break v}break e}e=f&g-i;if(e>>>0>2147483646){break g}b=Up(e);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=e>>>0)){b=v[116623];b=b+(j-e|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Up(b)|0)!=-1){e=b+e|0;b=a;break e}Up(0-e|0);break g}b=a;if((a|0)!=-1){break e}break g}f=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116614]=v[116614]|4}if(c>>>0>2147483646){break d}b=v[22706];c=c+3&-4;a=b+c|0;x:{y:{if(a>>>0<=b>>>0?c:0){break y}if($w()>>>0<a>>>0){if(!(va(a|0)|0)){break y}}v[22706]=a;break x}v[115189]=48;a=v[22706];b=-1}z:{if($w()>>>0>=a>>>0){break z}if(va(a|0)|0){break z}v[115189]=48;break d}v[22706]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}e=a-b|0;if(e>>>0<=h+40>>>0){break d}}a=v[116611]+e|0;v[116611]=a;if(a>>>0>y[116612]){v[116612]=a}A:{B:{C:{g=v[116509];if(g){a=466460;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break C}a=v[a+8>>2];if(a){continue}break}break B}a=v[116507];if(!(a>>>0<=b>>>0?a:0)){v[116507]=b}a=0;v[116616]=e;v[116615]=b;v[116511]=-1;v[116512]=v[116621];v[116618]=0;while(1){d=a<<3;c=d+466052|0;v[d+466060>>2]=c;v[d+466064>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116506]=c;a=a+b|0;v[116509]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116510]=v[116625];break A}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break B}v[a+4>>2]=c+e;a=g+8&7?-8-g&7:0;c=a+g|0;v[116509]=c;b=v[116506]+e|0;a=b-a|0;v[116506]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116510]=v[116625];break A}if(y[116507]>b>>>0){v[116507]=b}c=b+e|0;a=466460;D:{E:{F:{G:{H:{I:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break I}break}if(!(w[a+12|0]&8)){break H}}a=466460;while(1){c=v[a>>2];if(c>>>0<=g>>>0){f=c+v[a+4>>2]|0;if(f>>>0>g>>>0){break G}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+e;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=c+(c+8&7?-8-c&7:0)|0;i=h+j|0;c=e-i|0;if((e|0)==(g|0)){v[116509]=i;a=v[116506]+c|0;v[116506]=a;v[i+4>>2]=a|1;break E}if(v[116508]==(e|0)){v[116508]=i;a=v[116505]+c|0;v[116505]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break E}a=v[e+4>>2];if((a&3)==1){g=a&-8;J:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=466012,n=v[116503]&sqa(-2,a),v[m>>2]=n;break J}v[d+12>>2]=b;v[b+8>>2]=d;break J}h=v[e+24>>2];b=v[e+12>>2];K:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break K}L:{a=e+20|0;d=v[a>>2];if(d){break L}a=e+16|0;d=v[a>>2];if(d){break L}b=0;break K}while(1){f=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[f>>2]=0}if(!h){break J}d=v[e+28>>2];a=(d<<2)+466316|0;M:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break M}m=466016,n=v[116504]&sqa(-2,d),v[m>>2]=n;break J}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break J}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break J}v[b+20>>2]=a;v[a+24>>2]=b}e=e+g|0;c=c+g|0}v[e+4>>2]=v[e+4>>2]&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;N:{if(!(c&a)){v[116503]=a|c;a=b;break N}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break E}a=31;if(c>>>0<=16777215){a=c>>>8|0;f=a+1048320>>>16&8;a=a<<f;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|f))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;f=(a<<2)+466316|0;d=v[116504];b=1<<a;O:{if(!(d&b)){v[116504]=b|d;v[f>>2]=i;v[i+24>>2]=f;break O}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[f>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break F}b=a>>>29|0;a=a<<1;f=d+(b&4)|0;b=v[f+16>>2];if(b){continue}break}v[f+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break E}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116506]=c;a=a+b|0;v[116509]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116510]=v[116625];a=(f+(f-39&7?39-f&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116618];v[c+16>>2]=v[116617];v[c+20>>2]=a;a=v[116616];v[c+8>>2]=v[116615];v[c+12>>2]=a;v[116617]=c+8;v[116616]=e;v[116615]=b;v[116618]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((c|0)==(g|0)){break A}v[c+4>>2]=v[c+4>>2]&-2;f=c-g|0;v[g+4>>2]=f|1;v[c>>2]=f;if(f>>>0<=255){a=f>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;P:{if(!(c&a)){v[116503]=a|c;a=b;break P}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break A}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+466316|0;c=v[116504];b=1<<a;Q:{if(!(c&b)){v[116504]=b|c;v[d>>2]=g;v[g+24>>2]=d;break Q}a=f<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((f|0)==(v[b+4>>2]&-8)){break D}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break A}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[116506];if(a>>>0<=h>>>0){break d}b=a-h|0;v[116506]=b;c=v[116509];a=c+h|0;v[116509]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}v[115189]=48;a=0;break a}R:{if(!e){break R}c=v[f+28>>2];a=(c<<2)+466316|0;S:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break S}j=sqa(-2,c)&j;v[116504]=j;break R}v[e+(v[e+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break R}}v[b+24>>2]=e;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break R}v[b+20>>2]=a;v[a+24>>2]=b}T:{if(d>>>0<=15){a=d+h|0;v[f+4>>2]=a|3;a=a+f|0;v[a+4>>2]=v[a+4>>2]|1;break T}v[f+4>>2]=h|3;e=f+h|0;v[e+4>>2]=d|1;v[d+e>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;U:{if(!(c&a)){v[116503]=a|c;a=b;break U}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a;break T}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[e+28>>2]=a;v[e+16>>2]=0;v[e+20>>2]=0;b=(a<<2)+466316|0;V:{c=1<<a;W:{if(!(c&j)){v[116504]=c|j;v[b>>2]=e;break W}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break V}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=e}v[e+24>>2]=b;v[e+12>>2]=e;v[e+8>>2]=e;break T}a=v[b+8>>2];v[a+12>>2]=e;v[b+8>>2]=e;v[e+24>>2]=0;v[e+12>>2]=b;v[e+8>>2]=a}a=f+8|0;break a}X:{if(!i){break X}c=v[b+28>>2];a=(c<<2)+466316|0;Y:{if(v[a>>2]==(b|0)){v[a>>2]=f;if(f){break Y}m=466016,n=sqa(-2,c)&j,v[m>>2]=n;break X}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=f;if(!f){break X}}v[f+24>>2]=i;a=v[b+16>>2];if(a){v[f+16>>2]=a;v[a+24>>2]=f}a=v[b+20>>2];if(!a){break X}v[f+20>>2]=a;v[a+24>>2]=f}Z:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break Z}v[b+4>>2]=h|3;f=b+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+466052|0;g=v[116508];a=1<<a;_:{if(!(a&e)){v[116503]=a|e;a=c;break _}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[116508]=f;v[116505]=d}a=b+8|0}gb=l+16|0;return a|0}function k9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;a:{b:{c:{d:{e:{f:{if(qe(b,18720)){Kb(a);break f}if(qe(b,7151)){b=gb-96|0;gb=b;c=Kb(a);v[22708]=0;_(155,b- -64|0);a=v[22708];v[22708]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22708]=0;v[b+32>>2]=0;R(2037,b+48|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break p}v[22708]=0;Q(1167,c|0,b+48|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break o}vb(b+48|0);v[22708]=0;Q(1918,c|0,13839)|0;a=v[22708];v[22708]=0;q:{if((a|0)==1){break q}v[22708]=0;v[b+32>>2]=6;R(2037,b+48|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break n}v[22708]=0;Q(1167,c|0,b+48|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}vb(b+48|0);v[22708]=0;Q(1918,c|0,13839)|0;a=v[22708];v[22708]=0;if((a|0)==1){break q}v[22708]=0;v[b+32>>2]=0;R(2037,b+48|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;Q(1167,c|0,b+48|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break k}a=b+48|0;vb(a);v[22708]=0;a=Q(70,a|0,12139)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}e=Ab(a);vb(a);if(!e){break i}v[22708]=0;Q(1918,c|0,12139)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}e=mc(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[22708]=0;v[b+12>>2]=a;R(2037,b+16|0,b+12|0);a=v[22708];v[22708]=0;if((a|0)==1){break D}v[22708]=0;U(2038,b+32|0,6095,b+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break C}v[22708]=0;R(1423,e|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break B}vb(b+32|0);vb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[22708]=0;d=Q(70,b+32|0,10079)|0;a=v[22708];v[22708]=0;if((a|0)==1){break z}v[22708]=0;R(1423,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break y}vb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(!w[(b- -64|0)+17|0]){break w}v[22708]=0;d=Q(70,b+32|0,9779)|0;a=v[22708];v[22708]=0;if((a|0)==1){break v}v[22708]=0;R(1423,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break u}vb(d)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}v[22708]=0;d=Q(70,b+32|0,8321)|0;a=v[22708];v[22708]=0;E:{if((a|0)!=1){v[22708]=0;R(1423,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break E}vb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(cd(e)){break g}v[22708]=0;Q(1918,c|0,13869)|0;a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;d=Q(70,b+16|0,13839)|0;a=v[22708];v[22708]=0;F:{G:{H:{if((a|0)!=1){v[22708]=0;U(2039,b+32|0,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break H}v[22708]=0;Q(1167,c|0,b+32|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break G}vb(b+32|0);vb(d);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;vb(b+32|0)}vb(d);break r}a=P()|0;O()|0}yd(e)}Gf(b- -64|0);break c}yd(e);Gf(b- -64|0);gb=b+96|0;break f}if(qe(b,5265)){v[f>>2]=0;Mq(a,f);break f}if(qe(b,5243)){v[f>>2]=6;Mq(a,f);break f}if(qe(b,8086)){v[f>>2]=0;Mq(a,f);break f}if(qe(b,7883)){Tb(a,12139);break f}if(qe(b,8693)){b=Tb(f,12139);e=Ab(b);v[22708]=0;Q(70,a|0,(e?12902:12583)|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}vb(b);break f}if(qe(b,4456)){b=gb-48|0;gb=b;BG(b+16|0);v[22708]=0;_(173,b|0);e=v[22708];v[22708]=0;I:{J:{K:{L:{if((e|0)!=1){v[22708]=0;U(174,b+32|0,b+16|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break L}v[22708]=0;R(2040,a|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break K}vb(b+32|0);vb(b);vb(b+16|0);gb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b+32|0)}vb(b)}vb(b+16|0);break a}if(qe(b,7179)){b=gb-16|0;gb=b;i=gb-16|0;gb=i;v[i+8>>2]=101;e=b;d=gb-112|0;gb=d;h=mc(d+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{c=v[i+8>>2];if(c&1){v[22708]=0;v[d+48>>2]=19923024;R(162,d- -64|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break $}v[22708]=0;R(142,h|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break _}vb(d- -64|0);c=v[i+8>>2]}if(!(c&4)){break Y}v[22708]=0;c=ga(163)|0;g=v[22708];v[22708]=0;if((g|0)==1){break X}if(!c){break Z}break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}v[22708]=0;_(164,d- -64|0);c=v[22708];v[22708]=0;aa:{if((c|0)!=1){v[22708]=0;R(142,h|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break aa}vb(d- -64|0);break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}ba:{c=v[i+8>>2];if(!(c&32)){break ba}v[22708]=0;_(155,d- -64|0);c=v[22708];v[22708]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((c|0)!=1){v[22708]=0;R(165,d+48|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break da}c=d+48|0;g=gd(c);vb(c);if(!g){v[22708]=0;_(166,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break ua}v[22708]=0;R(165,d+16|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break ta}v[22708]=0;U(167,d+48|0,d+32|0,d+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break sa}v[22708]=0;R(142,h|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break ra}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}if(!gd(Xp(d- -64|0))){v[22708]=0;_(168,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break oa}c=Xp(d- -64|0);v[22708]=0;U(169,d+48|0,d+32|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break na}v[22708]=0;R(142,h|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break ma}vb(d+48|0);Hb(d+32|0)}v[22708]=0;R(170,d+48|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break ka}c=d+48|0;g=gd(c);vb(c);if(!g){v[22708]=0;_(166,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break ja}v[22708]=0;R(170,d+16|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break ia}v[22708]=0;U(167,d+48|0,d+32|0,d+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break ha}v[22708]=0;R(142,h|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break ga}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}Gf(d- -64|0);c=v[i+8>>2];break ba}c=P()|0;O()|0;break N}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break pa}c=P()|0;O()|0;break qa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break la}c=P()|0;O()|0;vb(d+48|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ea}c=P()|0;O()|0;break fa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0}Gf(d- -64|0);break N}va:{if(!(c&64)){break va}v[22708]=0;c=ga(163)|0;g=v[22708];v[22708]=0;if((g|0)==1){break X}if(c){break va}c=d- -64|0;Kb(c);v[22708]=0;R(142,h|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break O}vb(d- -64|0)}if(w[i+8|0]&128){v[22708]=0;_(171,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break W}v[22708]=0;R(142,h|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break V}vb(d- -64|0)}v[22708]=0;g=Q(2,d- -64|0,18720)|0;c=v[22708];v[22708]=0;if((c|0)==1){break U}v[22708]=0;U(172,d|0,h|0,g|0);c=v[22708];v[22708]=0;if((c|0)==1){break T}v[22708]=0;_(173,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break S}v[22708]=0;U(174,e|0,d|0,d+48|0);e=v[22708];v[22708]=0;if((e|0)==1){break R}vb(d+48|0);vb(d);vb(g);qm(h);gb=d+112|0;break M}c=P()|0;O()|0;break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;break P}c=P()|0;O()|0;break Q}c=P()|0;O()|0;vb(d+48|0)}vb(d)}vb(g);break N}c=P()|0;O()|0;vb(d- -64|0)}qm(h);S(c|0);L()}gb=i+16|0;v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7795)){b=gb-48|0;gb=b;Ls(b);v[22708]=0;R(165,b+32|0,b|0);e=v[22708];v[22708]=0;wa:{xa:{if((e|0)!=1){v[22708]=0;R(2040,a|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break xa}vb(b+32|0);Gf(b);gb=b+48|0;break f}a=P()|0;O()|0;break wa}a=P()|0;O()|0;vb(b+32|0)}Gf(b);break a}if(qe(b,8656)){b=gb-32|0;gb=b;Ls(b);e=Xp(b);v[22708]=0;R(2040,a|0,e|0);a=v[22708];v[22708]=0;if((a|0)!=1){Gf(b);gb=b+32|0;break f}a=P()|0;O()|0;Gf(b);break a}if(qe(b,7192)){b=gb-48|0;gb=b;Ls(b+16|0);ya:{if(v[b+28>>2]){e=v[b+28>>2];v[22708]=0;v[b+12>>2]=e;R(2037,a|0,b+12|0);a=v[22708];v[22708]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Gf(b+16|0);break a}Kb(a)}Gf(b+16|0);gb=b+48|0;break f}if(qe(b,10069)){Ls(f);b=w[f+16|0];v[22708]=0;Q(70,a|0,(b?12583:12902)|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Gf(f);break f}a=P()|0;O()|0;Gf(f);break a}if(qe(b,7208)){Ls(f);b=w[f+17|0];v[22708]=0;Q(70,a|0,(b?12583:12902)|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Gf(f);break f}a=P()|0;O()|0;Gf(f);break a}if(qe(b,9467)){Ls(f);b=w[f+18|0];v[22708]=0;Q(70,a|0,(b?12583:12902)|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Gf(f);break f}a=P()|0;O()|0;Gf(f);break a}if(qe(b,9753)){b=gb-16|0;gb=b;e=gb-32|0;gb=e;d=Kb(b);v[22708]=0;_(155,e|0);c=v[22708];v[22708]=0;za:{Aa:{Ba:{if((c|0)!=1){c=Xp(e);v[22708]=0;Q(156,d|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Ba}Gf(e);gb=e+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Gf(e)}vb(d);break a}v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,5386)){b=gb-16|0;gb=b;e=gb-48|0;gb=e;d=Kb(b);v[22708]=0;R(158,e+16|0,1244);c=v[22708];v[22708]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((c|0)!=1){v[e+12>>2]=14;v[e+8>>2]=0;v[22708]=0;v[e+4>>2]=0;ha(159,e+32|0,e+16|0,e+12|0,e+8|0,e+4|0);c=v[22708];v[22708]=0;if((c|0)==1){break Ga}v[22708]=0;Q(113,d|0,e+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Fa}vb(e+32|0);Hb(e+16|0);gb=e+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;vb(e+32|0)}Hb(e+16|0)}vb(d);S(a|0);L()}v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,3879)){b=gb-16|0;gb=b;ko(b,0,16666);v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,3512)){b=gb-48|0;gb=b;c=Tb(b+16|0,14750);v[22708]=0;R(2041,b|0,2);e=v[22708];v[22708]=0;Ha:{Ia:{Ja:{Ka:{if((e|0)!=1){v[22708]=0;U(3,b+32|0,c|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break Ka}v[22708]=0;R(2040,a|0,b+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break Ja}vb(b+32|0);vb(b);vb(c);gb=b+48|0;break f}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;vb(b+32|0)}vb(b)}break c}if(qe(b,8679)){b=gb-16|0;gb=b;ko(b,0,15066);v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7802)){b=gb-16|0;gb=b;xs(b,0);v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7777)){b=gb-16|0;gb=b;xs(b,2);v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(qe(b,7762)){b=gb-16|0;gb=b;xs(b,3);v[22708]=0;R(2040,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}Kb(a)}gb=f+32|0;break d}a=P()|0;O()|0;vb(b);break a}return}vb(c);break a}a=P()|0;O()|0;vb(b)}S(a|0);L()}function tZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-288|0;gb=e;vc(b);if(Tr(b,14907)){o=Kb(e+272|0);v[22708]=0;f=W(352,b|0,o|0,-1)|0;h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((h|0)!=1){if(!f){break a}v[22708]=0;f=Q(366,b|0,e+264|0)|0;h=v[22708];v[22708]=0;s:{if((h|0)==1){break s}if(!f){break a}if(!WD(e+264|0)){break a}f=Qc(VD(e+264|0),jb);v[22708]=0;f=Q(191,b|0,f|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break s}if(!f){break a}if(!c){break b}v[22708]=0;R(367,a|0,4096);d=v[22708];v[22708]=0;if((d|0)==1){break s}v[22708]=0;Q(368,a+1298268|0,o|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break s}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[22708]=0;yh(a,1);d=v[22708];v[22708]=0;if((d|0)==1){break s}v[22708]=0;d=Q(2,e+112|0,6633)|0;f=v[22708];v[22708]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{if((f|0)!=1){Eb(a+1298304|0,d);vb(d);v[22708]=0;d=Q(2,e+112|0,4107)|0;f=v[22708];v[22708]=0;if((f|0)==1){break B}Eb(a+1298316|0,d);vb(d);v[22708]=0;_(370,e+56|0);d=v[22708];v[22708]=0;if((d|0)==1){break A}t[e+232|0]=w[e+264|1];d=w[e+264|0];v[22708]=0;t[e+16|0]=d;R(371,e+248|0,e+16|0);d=v[22708];v[22708]=0;if((d|0)==1){break z}v[22708]=0;Y(372,e+112|0,e+56|0,e+232|0,e+248|0);d=v[22708];v[22708]=0;if((d|0)==1){break y}d=e+112|0;Eb(a+1298328|0,d);vb(d);vb(e+248|0);Hb(e+56|0);v[a+1298364>>2]=5;if(w[e+264|0]<2){break u}u[e+112>>1]=8192;v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break w}v[22708]=0;u[e+56>>1]=d;d=Le(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break w}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[22708]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break v}v[22708]=0;t[e+56|0]=d;d=pf(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break v}v[a+480196>>2]=w[d|0];v[22708]=0;Q(318,b|0,3)|0;d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break t}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break x}b=P()|0;O()|0;vb(e+248|0)}Hb(e+56|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+112|0]=32;v[22708]=0;d=T(374,b|0)|0;f=v[22708];v[22708]=0;C:{D:{if((f|0)==1){break D}v[22708]=0;t[e+56|0]=d;d=pf(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break D}v[a+480204>>2]=B(w[d|0],1e4);v[22708]=0;t[e+112|0]=1;d=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break C}v[22708]=0;t[e+56|0]=d;d=pf(e+112|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break C}v[a+480196>>2]=w[d|0];v[22708]=0;d=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=mc(e+248|0);m=mc(e+232|0);E:{F:{G:{H:{I:{J:{if(!x[a+480192>>1]){break J}i=1;h=e+88|1;p=e+112|12;while(1){v[22708]=0;f=W(376,a|0,i&65535,0)|0;d=v[22708];v[22708]=0;K:{L:{M:{if((d|0)==1){break M}if(!f){break J}v[22708]=0;d=W(353,b|0,f+492|0,-1)|0;k=v[22708];v[22708]=0;if((k|0)==1){break M}if(!d){break J}v[22708]=0;k=T(374,b|0)|0;d=v[22708];v[22708]=0;N:{O:{P:{Q:{R:{if((d|0)!=1){Qb(e+112|0,0,120);if(!k){break K}if(w[e+264|0]){v[22708]=0;d=Q(377,b|0,e+112|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break R}if(!d){break K}}if(!w[e+264|0]){d=vd(e+104|0,p,96);v[22708]=0;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;U(201,e+56|0,b|0,e+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break Q}if(!yb(e+56|0)){break K}}g=f+236|0;d=0;while(1){j=w[(e+112|0)+d|0];l=x[a+480190>>1];r=wd(g,d),s=(j+l|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[22708]=0;d=f+48|0;U(378,e+16|0,d|0,b|0);g=v[22708];v[22708]=0;if((g|0)==1){break P}v[22708]=0;g=f+68|0;U(378,e+40|0,g|0,b|0);j=v[22708];v[22708]=0;if((j|0)==1){break P}v[22708]=0;j=f+88|0;U(378,e+96|0,j|0,b|0);l=v[22708];v[22708]=0;if((l|0)==1){break P}v[22708]=0;R(379,b|0,e+88|0);l=v[22708];v[22708]=0;if((l|0)==1){break O}v[f>>2]=(w[h|0]|w[h+1|0]<<8)&4095;l=w[h|0]|w[h+1|0]<<8;f=e+88|0;_v(f,d,0);_v(f,g,1);_v(f,j,2);r=e,s=Vb(d),v[r+56>>2]=s;r=e,s=Zb(d),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){break N}break L}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){S:{d=v[e+56>>2];t[e+76|0]=64;f=w[d+2|0];v[22708]=0;t[e+79|0]=((f<<6)- -64>>>0)/127;f=ac(e+76|0,e+79|0);q=v[22708];v[22708]=0;if((q|0)==1){break S}t[d+2|0]=w[f|0];d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break L}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}r=e,s=Vb(g),v[r+56>>2]=s;r=e,s=Zb(g),v[r+80>>2]=s;T:{if(!Gb(e+56|0,e+80|0)){break T}while(1){U:{d=v[e+56>>2];t[e+76|0]=64;f=w[d+2|0];v[22708]=0;t[e+79|0]=((f<<6)+128>>>0)/255;f=ac(e+76|0,e+79|0);g=v[22708];v[22708]=0;if((g|0)==1){break U}t[d+2|0]=w[f|0];d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break T}break}b=P()|0;O()|0;break d}r=e,s=Vb(j),v[r+56>>2]=s;r=e,s=Zb(j),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){j=1<<(l>>>12&3);while(1){l=v[e+56>>2];d=t[l+2|0];d=oqa(d^-128,d>>31^-1,j,0);g=jb;f=g;V:{if((f|0)>-1?1:(f|0)>=-1?d>>>0>=4294967292:0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break V}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=l,s=Ac(d,f)^128,t[r+2|0]=s;d=e+56|0;Qe(d);if(Gb(d,e+80|0)){continue}break}}d=x[a+480190>>1]+1|0;u[e+76>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){d=0;f=0;while(1){v[22708]=0;W(353,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[22708];v[22708]=0;if((g|0)==1){break Z}v[22708]=0;R(381,b|0,e+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break Y}v[22708]=0;R(382,e+56|0,(B(x[e+76>>1]+f|0,104)+a|0)+484380|0);f=v[22708];v[22708]=0;if((f|0)==1){break Y}f=w[e+88|0];g=w[e+75|0];v[22708]=0;u[e+80>>1]=f|d<<8&32512|((g&3)!=0)<<15;R(383,m|0,e+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break X}d=d+1|0;f=d&65535;if(k>>>0<=f>>>0){break W}g=x[e+76>>1]+f|0;if(g>>>0<=3999){continue}break}}v[22708]=0;Q(318,b|0,20)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22708]=0;R(383,n|0,e+76|0);d=v[22708];v[22708]=0;if((d|0)==1){break I}v[e+56>>2]=3999;d=x[a+480190>>1];v[22708]=0;v[e+80>>2]=d+k;d=pd(e+56|0,e+80|0);f=v[22708];v[22708]=0;if((f|0)==1){break H}u[a+480190>>1]=v[d>>2]}i=i+1|0;if(x[a+480192>>1]>=(i&65535)>>>0){continue}break}}d=Kb(e+112|0);v[22708]=0;f=W(352,b|0,d|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}if(f){v[22708]=0;U(13,e+56|0,7,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break E}f=e+56|0;Eb(a+1298280|0,f);vb(f)}vb(d);d=0;while(1){v[22708]=0;f=(d<<5)+a|0;We(f+480280|0);h=v[22708];v[22708]=0;if((h|0)==1){break G}v[22708]=0;U(355,b|0,f+480289|0,-1);f=v[22708];v[22708]=0;if((f|0)==1){break G}d=d+1|0;if((d|0)!=32){continue}break}v[22708]=0;d=Q(385,b|0,e+40|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break l}if(!d){break i}if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))>>>0<12){break m}d=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);v[22708]=0;d=Q(191,b|0,d-11|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break l}if(d){break F}break m}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[e+96>>2]=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))-11;i=mc(e+112|0);v[22708]=0;W(358,b|0,i|0,v[e+96>>2])|0;d=v[22708];v[22708]=0;if((d|0)==1){break p}v[22708]=0;v[e+56>>2]=50529027;d=Fb(e+96|0,e+56|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}v[e+88>>2]=B(v[d>>2],85);h=Kb(e+56|0);d=e+40|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[22708]=0;v[e+16>>2]=d;d=Fb(e+88|0,e+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break r}d=v[d>>2];v[22708]=0;R(60,h|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break r}if(v[e+96>>2]){f=0;while(1){_:{k=w[kc(i,f)|0];d=f+1|0;if(!((k|0)!=255|v[e+96>>2]-d>>>0<2)){d=t[kc(i,d)|0];k=w[kc(i,f+2|0)|0];r=e,s=ef(h),v[r+16>>2]=s;Gd(e+32|0,e+16|0);v[22708]=0;ca(359,h|0,v[e+32>>2],k|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){d=f+3|0;break _}break r}v[22708]=0;R(61,h|0,k<<24>>24);f=v[22708];v[22708]=0;if((f|0)!=1){break _}break r}f=d;if(y[e+96>>2]>d>>>0){continue}break}}v[22708]=0;Y(360,e+16|0,5,7,h|0);d=v[22708];v[22708]=0;$:{if((d|0)!=1){d=e+16|0;Eb(h,d);vb(d);d=zb(Jb(h));f=Ab(h);v[22708]=0;fa(361,a+1298292|0,d|0,f|0,74,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break $}vb(h);gc(i);break m}break r}break r}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;vb(h);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}gc(i);break d}b=P()|0;O()|0;vb(d);break d}d=Sb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[22708]=0;fa(362,d|0,b|0,f|0,65535,65535)|0;d=v[22708];v[22708]=0;if((d|0)==1){break l}k=c&1;if(k){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[22708]=0;R(330,a+484344|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break l}}f=e+264|3;aa:{if(!(w[f|0]|w[f+1|0]<<8)){break aa}h=a+484344|0;d=0;while(1){v[22708]=0;i=Q(191,b|0,4)|0;g=v[22708];v[22708]=0;ba:{if((g|0)!=1){if(i){break ba}break aa}b=P()|0;O()|0;break d}v[22708]=0;i=T(192,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[22708]=0;U(288,e+56|0,b|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break g}g=e+56|0;i=jc(e+112|0,g);xb(g);ca:{if(!k){break ca}v[22708]=0;g=T(374,i|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}v[22708]=0;Q(318,e+112|0,1)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}v[22708]=0;g=W(331,h|0,d&65535,g+1|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}if(!g){break ca}v[22708]=0;U(356,i|0,e+56|0,-1);g=v[22708];v[22708]=0;if((g|0)==1){break e}g=_b(h,d);v[22708]=0;R(357,g|0,e+56|0);g=v[22708];v[22708]=0;if((g|0)==1){break e}g=_b(h,d);v[22708]=0;U(364,g|0,1,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break e}}xb(e+112|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break i}if(!x[a+480190>>1]){break j}d=0;while(1){if(w[sc(m,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=Rc(e+112|0,u[f+484414>>1]&1?16:8,1,0,u[sc(m,d)>>1]>-1?0:6);v[22708]=0;W(329,d|0,f+484380|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break k}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break j}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(!x[a+480190>>1]){break i}b=0;while(1){c=w[sc(m,b)|0];da:{if(!c){break da}c=c-1&65535;if(tc(n)>>>0<=c>>>0){break da}c=(w[sc(m,b)+1|0]&127)+x[sc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break da}f=B(c,104);d=(f+a|0)+484380|0;if(!Md(d)){break da}h=a+484380|0;c=h+B(b+1|0,104)|0;f=f+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[f+34>>1]&1;v[c>>2]=v[d>>2];v[22708]=0;h=T(386,c|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break h}if(!h){break da}hc(zb(v[c+20>>2]),zb(v[f+20>>2]),aj(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}Ye(m);Ye(n);break b}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;xb(e+112|0)}Ye(m);Ye(n)}vb(o);S(b|0);L()}d=1}vb(o)}gb=e+288|0;return d|0}function k8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=gb-48|0;gb=e;d=Tb(e+32|0,8890);f=ah(c,d);vb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){xl(a,v[b+24>>2]+1298316|0);break k}d=Tb(e+32|0,8238);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298304|0);break k}d=Tb(e+32|0,8720);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298352|0);break k}d=Tb(e+32|0,8230);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298340|0);break k}d=Tb(e+32|0,5376);f=ah(c,d);vb(d);if(f){d=e+32|0;c=d;f=v[v[b+24>>2]+480184>>2];b=39056;l:{while(1){if((f|0)==v[b>>2]){ko(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=39104){continue}break}Kb(c)}v[22708]=0;R(2040,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break j}vb(e+32|0);break k}d=Tb(e+32|0,8215);f=ah(c,d);vb(d);if(f){h=v[v[b+24>>2]+480184>>2];c=gb-48|0;gb=c;b=39056;g=Ik(c+32|0);j=e+32|0;d=Kb(j);while(1){if((h|0)==v[b>>2]){f=v[b+4>>2];v[22708]=0;f=Q(2,c+16|0,f|0)|0;i=v[22708];v[22708]=0;m:{n:{o:{p:{q:{r:{if((i|0)!=1){v[22708]=0;U(1414,c|0,g|0,f|0);i=v[22708];v[22708]=0;if((i|0)==1){break p}if(!w[c+4|0]){break m}if(!gd(d)){v[22708]=0;i=Q(2,c|0,14861)|0;k=v[22708];v[22708]=0;if((k|0)==1){break r}v[22708]=0;Q(113,d|0,i|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break q}vb(i)}v[22708]=0;Q(113,d|0,f|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break m}b=P()|0;O()|0;break o}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;vb(i);break o}b=P()|0;O()|0}vb(f)}vb(d);aO(g);S(b|0);L()}vb(f)}b=b+12|0;if((b|0)!=39104){continue}break}aO(g);gb=c+48|0;v[22708]=0;R(2040,a|0,j|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,5442);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298328|0);break k}d=Tb(e+32|0,2712);f=ah(c,d);vb(d);if(f){xl(a,v[b+24>>2]+1298280|0);break k}d=Tb(e+32|0,9258);f=ah(c,d);vb(d);if(f){c=e+32|0;gg(c,v[b+24>>2]+1298268|0);v[22708]=0;U(2093,a|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,8663);f=ah(c,d);vb(d);if(f){s:{if(!cd(Iy(v[b+24>>2]))){if(v[UK(Iy(v[b+24>>2]))+12>>2]){break s}}Kb(a);break k}p=e+32|0;q=p;b=UK(Iy(v[b+24>>2]));j=gb-192|0;gb=j;hc(j+144|0,b,44);g=v[b+44>>2];if(g){hc(j+44|0,b,44);c=gb-16|0;gb=c;b=iz(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-iz(1970,1,1)|0;b=oqa(b,b>>31,86400,0);d=B(v[j+52>>2],3600);f=d;b=b+d|0;d=jb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[j+48>>2],60);i=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<i>>>0?b+1|0:b;d=v[j+44>>2];i=d;f=d+f|0;d=(d>>31)+b|0;b=yN(c+8|0,f,f>>>0<i>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];gb=c+16|0;v[j+96>>2]=b;v[j+100>>2]=d;d=j+88|0;r=j+96|0;k=r;b=k;f=v[b>>2];i=v[b+4>>2];c=2147483647;n=ee(+(g>>>0)/18.2);b=-1;t:{if(n>=0x8000000000000000){break t}c=-2147483648;b=0;if(n<=-0x8000000000000000){break t}if(D(n)<0x8000000000000000){c=D(n)>=1?~~(n>0?F(H(n*2.3283064365386963e-10),4294967295):I((n-+(~~n>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~n>>>0;break t}b=0}l=d;d=c+i|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=yN(l,f,d);m=gb-16|0;gb=m;g=v[b>>2];o=v[b+4>>2];v[m+12>>2]=0;v[m+8>>2]=0;v[m+4>>2]=0;b=iz(1970,1,1)+pqa(g,o,86400,0)|0;h=b>>31;c=b;d=oqa(b,h,1e4,0)+14780|0;b=jb;i=d;b=d>>>0<14780?b+1|0:b;f=b;d=pqa(d,b,-14609700,-1);b=c;l=d+b|0;d=h+jb|0;d=b>>>0>l>>>0?d+1|0:d;b=l;l=pqa(i,f,365242500,0);b=b+l|0;d=jb+d|0;d=b>>>0<l>>>0?d+1|0:d;l=pqa(i,f,-146097e4,-1);b=l+b|0;d=jb+d|0;d=b>>>0<l>>>0?d+1|0:d;l=b;b=pqa(i,f,3652425,0);f=jb;s=f;i=l;l=oqa(b,f,-365,-1);i=i+l|0;f=jb+d|0;f=i>>>0<l>>>0?f+1|0:f;d=f;if(!((d|0)>0?1:(d|0)>=0)){d=s-(b>>>0<1)|0;b=b-1|0;f=oqa(b,d,-365,-1)+c|0;d=h+jb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;i=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<i>>>0?f+1|0:f;d=c;c=(b|0)/100|0;i=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<i>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;i=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<i>>>0?d+1|0:d;i=f}f=b;c=oqa(i,d,100,0)+52|0;b=jb;b=pqa(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[m+12>>2]=f+d;v[m+8>>2]=(c-B(d,12)|0)+1;b=oqa(b,jb,306,0)+5|0;d=jb;b=pqa(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[m+4>>2]=b+1;v[k+40>>2]=0;v[k+32>>2]=0;v[k+36>>2]=0;v[k+24>>2]=0;v[k+28>>2]=0;v[k+20>>2]=v[m+12>>2]-1900;v[k+16>>2]=v[m+8>>2]-1;b=v[m+4>>2];t=k,u=qqa(pqa(g,o,3600,0),jb,24),v[t+8>>2]=u;v[k+12>>2]=b;b=pqa(g,o,60,0);c=jb;t=k,u=qqa(b,c,60),v[t+4>>2]=u;t=k,u=g-oqa(b,c,60,0)|0,v[t>>2]=u;gb=m+16|0;hc(j+144|0,r,44)}i=hc(j,j+144|0,44);c=i;b=gb-112|0;gb=b;d=Kb(b+96|0);v[22708]=0;f=Q(2,b+80|0,10804)|0;g=v[22708];v[22708]=0;u:{v:{w:{x:{y:{if((g|0)!=1){g=v[c+20>>2];if(!g){break v}v[22708]=0;v[b+48>>2]=g+1900;R(112,b- -64|0,b+48|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;Q(113,d|0,b- -64|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break y}vb(b- -64|0);if(y[c+16>>2]>11){break v}v[22708]=0;g=Q(2,b+48|0,13867)|0;h=v[22708];v[22708]=0;z:{A:{B:{C:{D:{E:{if((h|0)!=1){h=v[c+16>>2];v[22708]=0;v[b+16>>2]=h+1;R(114,b+32|0,b+16|0);h=v[22708];v[22708]=0;if((h|0)==1){break E}v[22708]=0;U(3,b- -64|0,g|0,b+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break D}v[22708]=0;Q(113,d|0,b- -64|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break C}vb(b- -64|0);vb(b+32|0);vb(g);if(v[c+12>>2]-1>>>0<=30){break z}break v}a=P()|0;O()|0;break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}v[22708]=0;g=Q(2,b+48|0,13867)|0;h=v[22708];v[22708]=0;F:{G:{H:{I:{J:{K:{L:{M:{if((h|0)!=1){v[22708]=0;R(114,b+32|0,c+12|0);h=v[22708];v[22708]=0;if((h|0)==1){break M}v[22708]=0;U(3,b- -64|0,g|0,b+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break L}v[22708]=0;Q(113,d|0,b- -64|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break K}vb(b- -64|0);vb(b+32|0);vb(g);g=v[c+8>>2];if(g){break H}g=v[c+4>>2];if(g){break G}if(!v[c>>2]){break v}break F}a=P()|0;O()|0;break x}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}if(g>>>0>23){break v}g=v[c+4>>2]}if(g>>>0>59){break v}}v[22708]=0;g=Q(2,b- -64|0,10971)|0;h=v[22708];v[22708]=0;N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((h|0)!=1){v[22708]=0;Q(113,d|0,g|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break ea}vb(g);if(v[c+32>>2]>=1){v[22708]=0;g=Q(2,b- -64|0,12676)|0;h=v[22708];v[22708]=0;if((h|0)==1){break da}Eb(f,g);vb(g)}v[22708]=0;R(114,b+32|0,c+8|0);g=v[22708];v[22708]=0;if((g|0)==1){break ca}v[22708]=0;g=Q(2,b+16|0,11840)|0;h=v[22708];v[22708]=0;if((h|0)==1){break ba}v[22708]=0;U(3,b+48|0,b+32|0,g|0);h=v[22708];v[22708]=0;if((h|0)==1){break aa}v[22708]=0;R(114,b|0,c+4|0);h=v[22708];v[22708]=0;if((h|0)==1){break $}v[22708]=0;U(3,b- -64|0,b+48|0,b|0);h=v[22708];v[22708]=0;if((h|0)==1){break _}v[22708]=0;Q(113,d|0,b- -64|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break Z}vb(b- -64|0);vb(b);vb(b+48|0);vb(g);vb(b+32|0);if(y[c>>2]<62){break U}v[22708]=0;U(115,q|0,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break T}break u}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break V}a=P()|0;O()|0;break W}a=P()|0;O()|0;break X}a=P()|0;O()|0;break Y}a=P()|0;O()|0;vb(b- -64|0)}vb(b)}vb(b+48|0)}vb(g)}vb(b+32|0);break x}v[22708]=0;g=Q(2,b+48|0,11840)|0;h=v[22708];v[22708]=0;if((h|0)==1){break S}v[22708]=0;R(114,b+32|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break R}v[22708]=0;U(3,b- -64|0,g|0,b+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break Q}v[22708]=0;Q(113,d|0,b- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break P}vb(b- -64|0);vb(b+32|0);vb(g);v[22708]=0;Q(113,d|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break v}}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break N}a=P()|0;O()|0;break O}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(g);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break w}a=P()|0;O()|0;vb(b- -64|0)}vb(f)}vb(d);S(a|0);L()}Dc(q,d)}vb(f);vb(d);gb=b+112|0;gb=i+192|0;v[22708]=0;R(2040,a|0,p|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,9459);f=ah(c,d);vb(d);if(f){c=b;d=e+32|0;QS(d,v[b+24>>2]+1298292|0);fa:{ga:{ha:{if(!gd(d)){break ha}c=v[c+24>>2];v[22708]=0;c=HO(c);d=v[22708];v[22708]=0;if((d|0)==1){break fa}ia:{switch(c|0){case 0:v[22708]=0;R(2095,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break ha}c=P()|0;O()|0;break b;case 1:v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break ha}c=P()|0;O()|0;break b;case 2:if(gd(e+32|0)){v[22708]=0;R(2095,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}c=e+16|0;Eb(e+32|0,c);vb(c)}if(!gd(e+32|0)){break ha}v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break ha}c=P()|0;O()|0;break b;case 3:if(gd(e+32|0)){v[22708]=0;R(2096,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}c=e+16|0;Eb(e+32|0,c);vb(c)}if(!gd(e+32|0)){break ha}v[22708]=0;R(2095,e+16|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;Eb(e+32|0,c);vb(c);break ha}c=P()|0;O()|0;break b;case 4:v[22708]=0;R(2095,e+16|0,b|0);c=v[22708];v[22708]=0;ja:{ka:{if((c|0)!=1){v[22708]=0;R(2096,e|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break ja}if(gd(e+16|0)){break ka}v[22708]=0;Q(1167,e+32|0,e+16|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break ka}break d}c=P()|0;O()|0;break b}if(!gd(e)){v[22708]=0;Q(1167,e+32|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}}vb(e);vb(e+16|0);break ha}c=P()|0;O()|0;break c;case 5:break ia;default:break ha}}v[22708]=0;R(2095,e+16|0,b|0);c=v[22708];v[22708]=0;la:{if((c|0)!=1){v[22708]=0;R(2096,e|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break ga}if(gd(e)){break la}v[22708]=0;Q(1167,e+32|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break la}break f}c=P()|0;O()|0;break b}if(!gd(e+16|0)){v[22708]=0;Q(1167,e+32|0,e+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}}vb(e);vb(e+16|0)}v[22708]=0;U(2093,a|0,b|0,e+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break fa}vb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Tb(e+32|0,2564);f=ah(c,d);vb(d);if(f){c=e+32|0;QS(c,v[b+24>>2]+1298292|0);v[22708]=0;U(2093,a|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}i=c;c=Tb(e+32|0,4379);d=ah(i,c);vb(c);if(d){a=Kb(a);b=b+68|0;t=e,u=Vb(b),v[t+32>>2]=u;t=e,u=Zb(b),v[t+16>>2]=u;if(!Gb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[22708]=0;Q(1918,a|0,18690)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}}v[22708]=0;Q(1167,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}b=e+32|0;v[b>>2]=v[b>>2]+12;c=0;if(Gb(b,e+16|0)){continue}break}break k}Tb(a,18720)}gb=e+48|0;return}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;vb(a);break a}c=P()|0;O()|0;vb(e)}vb(e+16|0);break b}c=P()|0;O()|0;vb(e)}vb(e+16|0)}vb(e+32|0)}S(c|0);L()}function Apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=gb-352|0;gb=e;vc(b);f=e+328|0;g=ND(b,f);if(!g){Vv(f)}a:{b:{c:{d:{e:{f:{g:{if(!g){break g}if(!ZX(e+328|0)){break g}if(!Pb(b,Qc(72,0))){break g}if(!c){d=1;break g}Hd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;d=w[e+337|0];u[a+480190>>1]=63;u[a+480188>>1]=d;h:{if(d){d=0;while(1){du(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}if(!x[a+480190>>1]){break h}}d=1;f=1;while(1){g=(B(d,104)+a|0)+484380|0;ud(g,1);h=(e+256|0)+d|0;d=Be(b);t[h|0]=d;if(d<<24>>24>=0){C=g,D=WX(b)<<1,v[C>>2]=D}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}XD(b,a+1298268|0,-1);g=e+248|0;f=gb-32|0;gb=f;d=b;i:{if(!Pb(d,8)){t[f+16|0]=0;oi(g,8,f+16|0);break i}Gp(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;kd(f+16|0,d,f+8|0)}gb=f+32|0;m=mc(e+232|0);j:{if(w[e+338|0]|w[e+339|0]<<8){f=w[e+338|0]|w[e+339|0]<<8;g=w[e+337|0];d=0;v[22708]=0;f=W(498,b|0,m|0,B(f,g)<<1)|0;g=v[22708];v[22708]=0;if((g|0)==1){f=P()|0;O()|0;break a}if(!f){break j}}jn(e+224|0,v[m>>2],oc(m)>>>1|0);l=mc(e+208|0);k:{l:{m:{n:{o:{p:{if(!(w[e+340|0]|w[e+341|0]<<8)){break p}d=w[e+340|0]|w[e+341|0]<<8;f=0;v[22708]=0;R(499,l|0,d<<8);d=v[22708];v[22708]=0;if((d|0)==1){break o}if(!(w[e+340|0]|w[e+341|0]<<8)){break p}while(1){v[e+136>>2]=(w[e+340|0]|w[e+341|0]<<8)-f;v[22708]=0;v[e+160>>2]=2e3;d=pd(e+136|0,e+160|0);g=v[22708];v[22708]=0;q:{if((g|0)!=1){g=v[d>>2];d=mc(e+136|0);v[22708]=0;g=W(498,b|0,d|0,g<<8)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}if(g){break q}gc(d);d=0;break k}f=P()|0;O()|0;break b}C=e,D=Zb(l),v[C+160>>2]=D;Gd(e+200|0,e+160|0);g=Vb(d);h=Zb(d);v[22708]=0;Y(500,l|0,v[e+200>>2],g|0,h|0);g=v[22708];v[22708]=0;if((g|0)==1){break c}gc(d);f=f+2e3&65535;if(f>>>0<(w[e+340|0]|w[e+341|0]<<8)>>>0){continue}break}}v[22708]=0;Vd(e+184|0,l);d=v[22708];v[22708]=0;if((d|0)==1){break m}d=v[e+188>>2];v[e+64>>2]=v[e+184>>2];v[e+68>>2]=d;rh(e+192|0,e- -64|0);p=a+484360|0;d=Sb(p);f=w[e+338|0]|w[e+339|0]<<8;v[22708]=0;R(502,d|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}if(!(w[e+338|0]|w[e+339|0]<<8)){break l}q=a+484344|0;s=c&1;h=0;while(1){r:{C=sc(Sb(p),h),D=h,u[C>>1]=D;s:{if(!s){break s}v[22708]=0;r=h&65535;d=W(331,q|0,r|0,64)|0;f=v[22708];v[22708]=0;if((f|0)==1){break r}k=0;f=x[a+480188>>1];if(!(d&(f|0)!=0)){break s}while(1){d=sc(e+224|0,B(f&65535,h)+k|0);f=w[d|0]|w[d+1|0]<<8;t:{if(f>>>0>=(w[e+340|0]|w[e+341|0]<<8)>>>0){f=x[a+480188>>1];break t}d=_b(q,h);v[22708]=0;d=Xc(d,0,k&65535);g=v[22708];v[22708]=0;if((g|0)==1){break n}i=0;y=0-k|0;z=f<<8;while(1){f=e+136|0;vd(f,v[e+192>>2]+((i<<2)+z|0)|0,4);n=w[kc(f,0)|0]&63;t[d|0]=n?n+48|0:0;g=kc(f,0);C=d,D=w[kc(f,1)|0]<<2&60|w[g|0]>>>6,t[C+1|0]=D;g=w[kc(f,1)|0];o=w[kc(f,2)|0];A=kc(f,2);j=w[kc(f,3)|0];f=j<<4|w[A|0]>>>4;u[e+182>>1]=f;g=o<<2&60|g>>>6;u:{if(!(w[lc(e+248|0,g>>>3|0)|0]>>>(g&7)&1)|!(f?1:g)){break u}t[d+5|0]=f;t[d+3|0]=g;o=j>>>4|0;t[d+4|0]=o;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=g&15;v[22708]=0;Pf(d);f=v[22708];v[22708]=0;if((f|0)==1){break G}if(!w[d+4|0]){break u}t[d+2|0]=g>>>0<32?3:4;break u;case 3:case 4:case 5:case 6:case 7:case 12:v[22708]=0;Pf(d);f=v[22708];v[22708]=0;if((f|0)==1){break G}break u;case 9:t[d+3|0]=10;C=d,D=ei(f>>>1|0),t[C+5|0]=D;break u;case 50:break w;case 48:break x;case 43:break y;case 47:break z;case 17:case 18:case 26:case 27:break A;case 22:case 25:case 28:case 29:case 30:break B;case 16:case 19:case 20:case 21:case 23:case 31:break C;case 13:break D;case 11:case 15:break E;case 10:case 42:break H;default:break v}}if(f>>>0>254){break F}t[d+3|0]=g&15;v[22708]=0;Pf(d);f=v[22708];v[22708]=0;if((f|0)!=1){break u}}f=P()|0;O()|0;break b}t[d+3|0]=19;t[d+5|0]=o|(g>>>0<32?16:32);g=j&15;if(g){t[d+2|0]=3;t[d+4|0]=g;break u}t[d+2|0]=4;t[d+4|0]=f&15;break u}t[d+3|0]=(g|0)==11?12:16;C=d,D=Dv(f),t[C+5|0]=D;break u}t[d+3|0]=14;if((f&255)>>>0<64){break u}t[d+5|0]=0;break u}t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break u}t[d+3|0]=19;v[22708]=0;u[e+160>>1]=15;f=Pc(e+182|0,e+160|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[d+5|0]=w[f|0]|g<<4;break u}f=P()|0;O()|0;break b}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(j&240)){break u}t[d+2|0]=g>>>0>25?6:5;break u}t[d+5|0]=o|(g>>>0>25?-80:-96);break u}if(!f){break v}t[d+3|0]=17;v[e+160>>2]=8;v[22708]=0;v[e+176>>2]=f+4;f=If(e+160|0,e+176|0);g=v[22708];v[22708]=0;if((g|0)!=1){C=d,D=ei(v[f>>2]/8|0),t[C+5|0]=D;break u}f=P()|0;O()|0;break b}t[d+3|0]=14;g=x[a+480188>>1];if(!g){break u}n=B(y,6)+d|0;f=0;while(1){j=n+B(f,6)|0;if(!w[j+3|0]){t[j+3|0]=12;C=j,D=Dv(r),t[C+5|0]=D;g=x[a+480188>>1]}f=f+1|0;if(g>>>0>f>>>0){continue}break}break u}t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+28585|0];break u}g=f>>>4|0;if((g|0)==128){break v}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break u}t[d+5|0]=g^-1;break u}t[d+5|0]=0;t[d+3|0]=0;if(!n){t[d|0]=255;break u}t[d+3|0]=25;break u}t[d+3|0]=0}f=x[a+480188>>1];d=B(f,6)+d|0;i=i+1|0;if((i|0)!=64){continue}break}}k=k+1|0;if(k>>>0<(f&65535)>>>0){continue}break}}h=h+1|0;if(h>>>0<(w[e+338|0]|w[e+339|0]<<8)>>>0){continue}break l}break}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(x[a+480190>>1]){k=c&2;d=1;f=1;while(1){v[22708]=0;c=w[(e+256|0)+d|0];W(503,b|0,((d<<5)+a|0)+946304|0,c&63)|0;g=v[22708];v[22708]=0;I:{J:{K:{L:{M:{N:{if((g|0)!=1){if(c<<24>>24<=-1){break I}v[22708]=0;g=T(504,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}c=B(d,104)+a|0;d=c+484392|0;v[d>>2]=g<<1;v[22708]=0;g=T(504,b|0)|0;h=v[22708];v[22708]=0;O:{if((h|0)!=1){g=g<<1;if(g>>>0>=3){v[c+484396>>2]=g+v[d>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[22708]=0;d=T(374,b|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break O}break d}f=P()|0;O()|0;break b}u[c+484410>>1]=d<<2;v[22708]=0;d=T(374,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}t[c+484417|0]=d<<4;c=c+484380|0;if(!v[c>>2]){break I}v[22708]=0;h=T(374,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break L}d=0;P:{Q:{R:{S:{switch(h|0){case 0:if(!k){break Q}g=mc(e+160|0);h=v[c>>2];v[22708]=0;h=Q(191,b|0,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break N}if(!h){break R}d=v[c>>2];v[22708]=0;W(505,b|0,g|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break N}C=e,D=Vb(g),v[C+136>>2]=D;C=e,D=Zb(g),v[C+176>>2]=D;if(Gb(e+136|0,e+176|0)){break M}break K;case 1:g=mc(e+160|0);d=v[c>>2];v[22708]=0;U(506,e+136|0,b|0,d|0);d=v[22708];v[22708]=0;T:{U:{V:{W:{if((d|0)!=1){d=e+136|0;np(g,d);gc(d);if(!k){break V}v[22708]=0;Vd(e+112|0,g);d=v[22708];v[22708]=0;if((d|0)!=1){d=Ud(e+104|0);v[22708]=0;h=v[e+116>>2];v[e+40>>2]=v[e+112>>2];v[e+44>>2]=h;h=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=h;d=W(507,e+136|0,e+40|0,e+32|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break W}}f=P()|0;O()|0;break T}f=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break T}Z(f|0)|0;d=0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){break P}f=P()|0;O()|0;break T}h=Rc(e+176|0,8,1,0,2);v[22708]=0;W(329,h|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break U}xb(e+136|0)}gc(g);break I}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b;case 2:case 3:if(k){d=Rc(e+136|0,(h|0)==2?8:16,1,0,0);v[22708]=0;W(329,d|0,c|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break I}f=P()|0;O()|0;break b}c=v[c>>2];v[22708]=0;Q(318,b|0,B(c,h-1|0)|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break I}break L;case 4:case 5:break S;default:break k}}g=mc(e+160|0);d=v[c>>2];v[22708]=0;U(508,e+136|0,b|0,d|0);d=v[22708];v[22708]=0;X:{Y:{Z:{if((d|0)!=1){d=e+136|0;np(g,d);gc(d);if(k){_:{if((h|0)!=5){break _}C=e,D=Vb(g),v[C+136>>2]=D;C=e,D=Zb(g),v[C+176>>2]=D;if(!Gb(e+136|0,e+176|0)){break _}while(1){d=e+136|0;j=v[d>>2];i=zb(w[j|0]);C=j,D=zb((i^w[(i>>>7|0)+28593|0])&255),t[C|0]=D;Pe(d);if(Gb(d,e+176|0)){continue}break}}v[22708]=0;Vd(e+96|0,g);d=v[22708];v[22708]=0;if((d|0)==1){break Z}d=Ud(e+88|0);v[22708]=0;i=v[e+100>>2];v[e+56>>2]=v[e+96>>2];v[e+60>>2]=i;i=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=i;d=W(507,e+136|0,e+56|0,e+48|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break Z}h=(h|0)==5;h=Rc(e+176|0,h?16:8,1,0,h?17:1);v[22708]=0;W(329,h|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break Y}xb(e+136|0)}gc(g);break I}f=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break X}Z(f|0)|0;d=0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){f=P()|0;O()|0;break X}gc(g);break k}f=P()|0;O()|0;break X}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}gc(g);break k}c=v[c>>2];v[22708]=0;Q(318,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break L}break I}gc(g);break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break J}while(1){d=e+136|0;i=v[d>>2];h=zb(w[i|0]);C=i,D=zb((h<<7|(h^-1)<<24>>>25)&255),t[C|0]=D;Pe(d);if(Gb(d,e+176|0)){continue}break}break K}f=P()|0;O()|0;break b}v[22708]=0;Vd(e+128|0,g);d=v[22708];v[22708]=0;$:{aa:{if((d|0)==1){break aa}d=Ud(e+120|0);v[22708]=0;h=v[e+132>>2];v[e+24>>2]=v[e+128>>2];v[e+28>>2]=h;h=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=h;d=W(507,e+136|0,e+24|0,e+16|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break aa}h=Rc(e+176|0,16,1,0,17);v[22708]=0;W(329,h|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break $}xb(e+136|0);gc(g);break I}f=P()|0;O()|0;break J}f=P()|0;O()|0;xb(e+136|0)}gc(g);break b}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}ba:{ca:{da:{ea:{fa:{ga:{ha:{d=w[e+342|0]|w[e+343|0]<<8|w[e+344|0]<<16;if(d){c=mc(e+160|0);v[22708]=0;b=W(498,b|0,c|0,d|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}if(!b){break fa}v[22708]=0;Vd(e+80|0,c);b=v[22708];v[22708]=0;if((b|0)==1){break ha}b=Ud(e+72|0);v[22708]=0;f=v[e+84>>2];v[e+8>>2]=v[e+80>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;b=W(507,e+136|0,e+8|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ha}v[22708]=0;ca(509,a+1298292|0,b|0,d|0,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ga}xb(b);gc(c)}v[22708]=0;_(510,e+160|0);b=v[22708];v[22708]=0;if((b|0)==1){break ea}v[22708]=0;U(316,e+136|0,e+160|0,e+336|0);b=v[22708];v[22708]=0;if((b|0)==1){break da}b=e+136|0;Eb(a+1298304|0,b);vb(b);Hb(e+160|0);v[22708]=0;b=Q(2,b|0,7366)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ca}Eb(a+1298316|0,b);vb(b);v[22708]=0;b=Q(2,e+136|0,2197)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ba}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;d=1;break k}f=P()|0;O()|0;break e}f=P()|0;O()|0;xb(b);break e}gc(c);d=0;break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;Hb(e+160|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}gc(l)}gc(m)}gb=e+352|0;return d|0}f=P()|0;O()|0}gc(c);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;gc(d)}gc(l)}gc(m);S(f|0);L()}function f_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;p=Hh(b,11128);a:{if(!p){break a}if(!Pb(b,6)){break a}while(1){b:{l=sg(b);c:{if((l|0)==(zn(10978)|0)){break c}i=w[18696]|w[18697]<<8|(w[18698]<<16|w[18699]<<24);if(!(l&1616928864)|l&-2139062144){break c}if((i|0)!=(l|0)){break b}}pg(b,4);break a}m=1;r=Ng(b);if(x[a+480192>>1]){while(1){j=v[(((m&65535)<<2)+a|0)+900380>>2];if(j){d:{i=r;n=b;q=l;if((zn(13823)|0)==(l|0)){Rb(n,i);break d}e=q;c=i;d=n;g=0;h=gb-48|0;gb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+23|0]=z;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+18|0]=z;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=nw(d,c),v[s>>2]=z;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+21|0]=z;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break F}s=wd(e,d),z=f,u[s>>1]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+31|0]=z;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+34|0]=z;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+16|0]=z;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+24>>2]=240;s=h,z=wp(d,c),v[s>>2]=z;kh(f+68|0,v[Fb(h+24|0,h)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,1);f=v[22708];v[22708]=0;if((f|0)==1){break k}if(Nb(e)){while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break k}s=Lb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+82|0]=z;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+27|0]=z;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,1);f=v[22708];v[22708]=0;if((f|0)==1){break h}if(Nb(e)){while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break h}s=Lb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+83|0]=z;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}s=f,z=B(mw(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[s+40>>2]=z;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+36|0]=z;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,2);f=v[22708];v[22708]=0;if((f|0)==1){break l}if(Nb(e)){while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}s=Lb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,2);f=v[22708];v[22708]=0;if((f|0)==1){break i}if(Nb(e)){while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break i}s=Lb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+24|0]=z;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,0);f=v[22708];v[22708]=0;if((f|0)==1){break j}if(Nb(e)){while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break j}s=Lb(e,d),z=f,t[s+2|0]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+62|0]=z;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;v[22708]=0;e=ki(f,0);f=v[22708];v[22708]=0;if((f|0)==1){break g}if(Nb(e)){while(1){v[22708]=0;f=T(307,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break g}s=Lb(e,d),z=f,u[s>>1]=z;d=d+1|0;if(Nb(e)>>>0>d>>>0){continue}break}}xb(c);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+63|0]=z;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+15|0]=z;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}Td(h,d,c);k=jc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22708]=0;g=T(310,k|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break E}v[22708]=0;R(311,e|0,g|0);g=v[22708];v[22708]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22708]=0;Q(301,f+492|0,e|0)|0;c=v[22708];v[22708]=0;g=1;if((c|0)==1){break E}vb(e);xb(k);break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=nw(d,c),v[s+4>>2]=z;g=1;break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}s=f,z=nw(d,c),v[s+8>>2]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+61|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f- -64|0,z=xd(d,c),t[s|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+81|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+84|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+101|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+102|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+103|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+104|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+17|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+19|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+20|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+22|0]=z;g=1;break n}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=NE(d,c),u[s+28>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+30|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=ME(d,c),t[s+26|0]=z;g=1;break n}if(c>>>0>128){break n}e=f+108|0;Td(h,d,c);c=jc(h+24|0,h);xb(h);d=0;while(1){v[22708]=0;f=T(309,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break p}s=lc(e,d),z=f,t[s|0]=z;d=d+1|0;if(d>>>0<128){continue}break}xb(c);g=1;break n}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;vb(e);xb(k);break f}if(c>>>0>32){break n}Td(h,d,c);k=jc(h+24|0,h);xb(h);e=Kb(h);if(c){d=0;while(1){v[22708]=0;g=T(310,k|0)|0;o=v[22708];v[22708]=0;if((o|0)==1){break m}v[22708]=0;R(311,e|0,g|0);g=v[22708];v[22708]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22708]=0;Q(301,f+524|0,e|0)|0;c=v[22708];v[22708]=0;g=1;if((c|0)!=1){vb(e);xb(k);break n}break m}if(c>>>0>2){break n}if(!Pb(d,c)){break n}s=f,z=NE(d,c),u[s+12>>1]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+25|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+35|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+105|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+85|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+65|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+100|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+80|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=xd(d,c),t[s+60|0]=z;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}s=f,z=ME(d,c),t[s+33|0]=z;g=1;break n}g=1;c=wp(d,c);if(!up(c)){break n}t[f+14|0]=c;break n}v[h+24>>2]=240;s=h,z=wp(d,c),v[s>>2]=z;kh(f+48|0,v[Fb(h+24|0,h)>>2]);g=1;break n}v[h+24>>2]=240;s=h,z=wp(d,c),v[s>>2]=z;kh(f+88|0,v[Fb(h+24|0,h)>>2]);g=1;break n}d=P()|0;O()|0;xb(c);break f}c=mw(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}gb=h+48|0;break e}d=P()|0;O()|0;vb(e);xb(k);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c);break f}d=P()|0;O()|0;xb(c)}S(d|0);L()}if(!g){Rb(n,i);break d}if((zn(13828)|0)==(q|0)){i=w[j+15|0];t[j+15|0]=0;t[j+100|0]=w[j+100|0]&224|(i>>>5&4|i>>>6&1);t[j+60|0]=i>>>1&2|(i<<1&4|(w[j+60|0]&240|i&1));t[j+80|0]=w[j+80|0]&240|(i>>>4&2|(i>>>2&4|i>>>3&1))}}}m=m+1|0;if(x[a+480192>>1]>=(m&65535)>>>0){continue}break}}if(Pb(b,6)){continue}break}}return p|0}function ufa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;f=gb-48|0;gb=f;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Sf(a+1074312|0,0)}b=f+32|0;h=a+1074312|0;Db(b,h,0);if(Cb(b)){q=(v[a+480180>>2]&16777248)!=0}b=f+32|0;Db(b,h,0);if(Cb(b)){D=v[a+480180>>2]==4}l=a+1074308|0;b=v[l>>2];if(b>>>0<=18874367){c=1;e=!q;a:{if(!x[a+480192>>1]){break a}while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[f+32>>2]=B(w[b+20|0],100)>>>6;v[f+16>>2]=100;E=b,F=v[Fb(f+32|0,f+16|0)>>2],t[E+20|0]=F;if(!(e|y[l>>2]<18350080)){break b}j=t[b+26|0];t[b+26|0]=(((j|0)>-1?1:-1)+j|0)/2;if(!(e|y[l>>2]<18285314)){break b}HS(ki(b,2),4,v[a+480180>>2]);j=v[a+1074308>>2];if(j>>>0>=18284544){if(j>>>0>18285135){break b}c:{if(!w[b+34|0]){break c}if(!Ij(b)){break c}Ob(h,2,1)}if(y[l>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Ob(h,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}d:{if(!(v[a+480180>>2]&16777248)){break d}b=1;if(!(e|y[l>>2]<18285314)|!x[a+480190>>1]){break d}while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;d=TS(b);if((d|0)!=(b|0)){while(1){b=c;k=b+32|0;while(1){e=w[b|0];e:{f:{if((e-97&255)>>>0<=5){j=e-32|0;break f}j=99;g:{if(e>>>0<=106){if(e-88>>>0<2){break g}if((e|0)==75){break f}break e}if(e-120>>>0<2){break g}if((e|0)==107){break f}break e}j=122}t[b|0]=j}b=b+1|0;if((k|0)!=(b|0)){continue}break}c=c+32|0;if((d|0)!=(c|0)){continue}break}}b=v[a+1074308>>2]}h:{if(!x[a+480192>>1]|(!(v[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895))){break h}b=1;c=0;while(1){i:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break i}break h}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Ob(h,3,1)}b=v[l>>2];j:{if(!(v[a+480180>>2]&16777248)|(b>>>0>19006225|(b|0)==19005440)){break j}b=f+32|0;Db(b,h,0);if(!Cb(b)){b=f+16|0;Db(b,h,1);if(!Cb(b)){break j}}if(!x[a+480192>>1]){break j}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}k:{l:{m:{if(y[l>>2]<=19007232){c=a+946300|0;b=a+906300|0;while(1){e=f+16|0;j=b+80|0;NO(e,j);v[22708]=0;Y(360,f+32|0,0,8,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break l}vb(f+16|0);v[22708]=0;Jr(j,f+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break m}vb(f+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}n:{o:{p:{q:{if(v[a+480180>>2]!=4){break q}b=v[l>>2];if(b>>>0<19007257){break o}if(b>>>0>19071235){break p}if(w[a+1074368|0]!=4){break q}iA(a,5)}b=v[l>>2]}if((b|0)==19202048|b>>>0>19202054){break n}}if(!x[a+480192>>1]){break n}c=1;while(1){j=(((c&65535)<<2)+a|0)+900380|0;b=v[j>>2];r:{if(!b|!w[b+20|0]|!w[b+31|0]){break r}b=b+236|0;e=Ju(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break r}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[j>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}b=v[l>>2];if(b>>>0<=19267583){if(x[a+480192>>1]){b=1;e=!q;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];s:{if(!c){break s}j=t[c+26|0];t[c+26|0]=(((j|0)>-1?1:-1)+j|0)/2;if(!(e|y[l>>2]<18350080)){break s}t[c+19|0]=w[c+19|0]+3>>>2}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=v[l>>2]}t:{if(!x[a+480192>>1]|b>>>0>19398673){break t}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Ob(h,94,1);break t}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}u:{if(!x[a+480192>>1]|y[l>>2]>19399427){break u}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Ob(h,101,1);break u}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=gb-16|0;gb=b;u[f+12>>1]=0;v[f+8>>2]=a;c=b+8|0;Db(c,a+1074312|0,0);E=f,F=Cb(c),t[E+14|0]=F;gb=b+16|0;b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;c=gb-16|0;gb=c;o=a+484344|0;j=Te(o);b=v[f+4>>2];e=v[f>>2];v[c>>2]=e;v[c+4>>2]=b;v[c+8>>2]=e;v[c+12>>2]=b;b=c;e=gb-32|0;gb=e;C=j-1&65535;v:{if(Te(o)>>>0>C>>>0){r=v[b>>2];s=v[b+4>>2];while(1){b=z&65535;if(ii(af(o,b))){d=Vb(af(o,b));k=Zb(af(o,b));b=e;v[b+24>>2]=r;v[b+28>>2]=s;v[b+8>>2]=r;v[b+12>>2]=s;j=b+8|0;m=gb-16|0;gb=m;v[m>>2]=k;v[m+8>>2]=d;if(Gb(m+8|0,m)){while(1){A=m+8|0;d=v[A>>2];b=j;n=x[b+4>>1];k=n+1|0;u[b+4>>1]=k;if(x[v[b>>2]+480188>>1]<=(k&65535)>>>0){u[b+4>>1]=0}w:{if(Bg(d)){break w}g=v[b>>2];k=v[g+1074308>>2];x:{y:{z:{A:{B:{C:{D:{p=v[g+480180>>2];E:{F:{if((p|0)==2){if(k>>>0>18415615){break F}if(w[d+3|0]!=23){break E}zf(d+5|0,64);break E}G:{if(p&16777248){H:{I:{if(k>>>0>=18285314){if(w[b+6|0]){break I}g=0;i=0;if(k>>>0>18874367){break H}}J:{switch(w[d+3|0]-20|0){case 3:zf(d+5|0,128);break I;case 0:break J;default:break I}}g=w[d+5|0];if((g|0)!=208){if((g|0)!=192){break I}t[d|0]=254;t[d+3|0]=0;break I}t[d+3|0]=0}K:{L:{M:{if(k>>>0>=18350080){if(w[b+6|0]){break M}g=0;i=0;if(k>>>0>18874367){break H}}i=w[d+3|0];if(i>>>0>29){break L}g=1;if(!(1<<i&536873152)){break L}break K}g=0;i=0;if(k>>>0>18874367){break H}i=w[d+3|0]}g=0}i=(i|0)==24|(i|0)==22}N:{if(!(i?1:g)){break N}i=w[d+5|0];g=i&15;if(!g|(g|0)==15){break N}i=i&240;if(!i|(i|0)==240){break N}t[d+5|0]=w[d+3|0]==24?i:g}if(k>>>0>19005699){break z}if((k|0)==19005440){break D}g=x[v[b>>2]+480192>>1];if(w[b+6|0]|(!g|w[d+1|0]<=g>>>0)){break F}t[d+2|0]=1;i=d+4|0;break G}if((p|0)!=4){break F}O:{P:{Q:{R:{S:{if(k>>>0<18285314){break S}g=!w[b+6|0]&k>>>0<18874368;if(g){break S}if(k>>>0>19137025){break z}if(!(w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}if(!(g|k>>>0<18415616)){break R}}if(w[d+3|0]!=10|w[d+2|0]!=11){break Q}t[d+3|0]=0;break Q}if(k>>>0>18874639){break P}}if(w[d+2|0]!=11|w[d+3|0]!=4){break O}g=w[d+4|0];if(!(w[b+6|0]?1:g)){break O}i=w[d+5|0];if(!i){break O}t[d+2|0]=0;E=d,F=Dv(i+(g<<4)|0),t[E+5|0]=F;break O}if(k>>>0>19007240){break z}}if(w[d+5|0]|w[d+3|0]!=16){break F}i=d+3|0}t[i|0]=0}if(k>>>0>18874367){break z}}g=w[d+3|0];i=w[d+5|0]&240;if((g|0)!=28|(i|0)!=96){b=0}else{if(!w[b+6|0]|(p|0)!=4){break C}b=k>>>0<18350080}if(!(b|(g|0)==20&(i|0)==96)|!n){break A}break B}g=d+2|0;b=w[d+2|0];if((b|0)==8){break y}break x}if(!n){break z}}b=d+B(n,-6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}g=w[d+3|0]}if(!n|((g&255)!=20|(i|0)!=224)){break z}b=d+B(n,-6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}g=d+2|0;b=w[d+2|0];if((b|0)!=8){break x}if((k|0)==19333120|k>>>0>19333174){break w}}T:{U:{V:{W:{b=w[d+3|0];switch(b-5|0){case 2:break W;case 1:break w;case 0:break U;default:break V}}if(!w[d+4|0]){break T}t[d+3|0]=11;break w}if((b|0)!=26){break w}}k=w[d+5|0];if(!(k&15)){t[d+3|0]=5;t[d+5|0]=k|w[d+4|0]&15;break T}X:{switch(b-5|0){case 1:break w;case 0:case 2:break T;default:break X}}if((b|0)!=26){break w}}t[g|0]=0;break w}if(!(w[d+3|0]|((p|0)==16777216|(b|0)!=15))){t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break w}if(w[d+3|0]!=10|k>>>0>19922963|(b|0)!=15){break w}if(w[d+4|0]?w[d+5|0]:1){t[g|0]=0;break w}t[d+3|0]=0}ak(A);if(Gb(A,m)){continue}break}}b=v[j+4>>2];v[e+16>>2]=v[j>>2];v[e+20>>2]=b;gb=m+16|0}z=z+1|0;if((z&65535)>>>0<=C>>>0){continue}break}v[f+32>>2]=r;v[f+36>>2]=s;break v}j=v[b+4>>2];v[f+32>>2]=v[b>>2];v[f+36>>2]=j}gb=e+32|0;gb=c+16|0;b=v[a+1074308>>2];c=b>>>0<19267584;Y:{if(c&q){Ob(h,8,(b|0)==18284544|b>>>0>18285313);b=48232;while(1){c=v[l>>2];e=v[b+4>>2];Ob(h,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=48568){continue}break}break Y}if(!(c&D)){break Y}Ob(h,8,b>>>0>18285313);b=48584;while(1){Ob(h,v[b>>2],y[l>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=48816){continue}break}}Z:{if(v[a+480180>>2]&16777248){b=48816;while(1){c=v[l>>2];e=v[b+4>>2];j=e&-65536;if(!(c>>>0<=j>>>0|c>>>0>=e>>>0?c>>>0>=j>>>0:0)){Sf(h,v[b>>2])}b=b+8|0;if((b|0)!=48864){continue}break}break Z}if(v[a+480180>>2]==4){b=48864;while(1){if(y[l>>2]<y[b+4>>2]){Sf(h,v[b>>2])}b=b+8|0;if((b|0)!=48928){continue}break}break Z}if(v[a+480180>>2]!=2){break Z}b=48928;while(1){if(y[l>>2]<y[b+4>>2]){Sf(h,v[b>>2])}b=b+8|0;if((b|0)!=49016){continue}break}}_:{if(v[a+480180>>2]==4){b=v[l>>2];if(b>>>0>18415615){break _}Ob(h,98,1)}b=v[l>>2]}if(b-19333159>>>0<=33){b=0;while(1){c=f+32|0;e=b+77|0;Db(c,h,e);Ob(h,b+86|0,Cb(c));Sf(h,e);b=b+1|0;if((b|0)!=5){continue}break}b=v[l>>2]}c=8;$:{if(b>>>0>=18284544){if(b>>>0>18874627){break $}c=6;if((b|0)==18874368){break $}}Ob(h,c,1);b=v[l>>2]}aa:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Sf(h,7);break aa}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break aa}Ob(h,7,1);break aa}if((b|0)==19922944|b>>>0>19922997){break aa}Sf(h,7)}b=f+32|0;Db(b,h,31);ba:{if(!Cb(b)){break ba}b=v[l>>2];if(!x[a+480192>>1]|(b>>>0<19071234|b>>>0>19398722)){break ba}b=1;while(1){ca:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break ca}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break ca}Ob(h,97,1);break ba}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}da:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break da}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break da}break}ea:{fa:{ga:{if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216)){b=v[l>>2];if(b>>>0<19398688){break fa}if(b>>>0>19464277){break ga}Ob(h,109,1)}b=v[l>>2]}if((b|0)==19922944|b>>>0>19922996){break ea}}Sf(h,111)}if(!(v[a+480180>>2]!=2|y[a+1074308>>2]>19464191)){Ob(h,108,1);break da}if(v[a+480180>>2]==2){break da}Sf(h,108)}ha:{if(!(!(v[a+480180>>2]&16777252)|v[l>>2]-19333186>>>0>589827)){c=a+946300|0;a=a+906300|0;while(1){ia:{if((w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))!=1146637647|(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))!=-271958638){break ia}if((oc(a+4|0)|0)!=32){break ia}b=Tb(f+32|0,13920);v[22708]=0;Jr(a+80|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break ha}vb(b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}gb=f+48|0;return}a=P()|0;O()|0;vb(b);break k}a=P()|0;O()|0;vb(f+32|0);break k}a=P()|0;O()|0;vb(f+16|0)}S(a|0);L()}function gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-784|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{if(!Jh(b,d+776|0)){break K}if(!NN(d+776|0)){break K}if(!uC(b,d+768|0)){break K}if(!MN(d+768|0)){break K}e=1313423693;i=w[d+768|0]|w[d+769|0]<<8|(w[d+770|0]<<16|w[d+771|0]<<24);if((i|0)!=1179012417){e=1414090313;if((i|0)!=538987841){break K}}l=le(d+744|0,b);j=hh(d+728|0);L:{if(!c){v[22708]=0;Y(1451,d+144|0,l|0,((i|0)==1179012417?1:2)|0,e|0);b=v[22708];v[22708]=0;if((b|0)!=1){break L}b=P()|0;O()|0;break a}v[22708]=0;U(1452,d+144|0,l|0,((i|0)==1179012417?1:2)|0);b=v[22708];v[22708]=0;if((b|0)==1){break v}}b=d+144|0;NU(j,b);ke(b);v[22708]=0;U(1453,d+704|0,j|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break w}v[22708]=0;b=T(275,d+704|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}M:{if(!b){break M}v[22708]=0;b=Q(1454,d+704|0,d+624|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}if(!b|!w[d+689|0]){break M}b=w[d+689|0];v[22708]=0;g=Q(191,d+704|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}if(!g|!c){break M}v[22708]=0;R(367,a|0,8388608);b=v[22708];v[22708]=0;if((b|0)==1){break u}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+688|0]<<4^-1)&16;u[d+144>>1]=w[d+689|0];v[22708]=0;u[d+512>>1]=127;b=Pc(d+144|0,d+512|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[22708]=0;Q(157,a+1298304|0,((i|0)==1179012417?14038:14004)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}v[22708]=0;b=Q(2,d+144|0,10597)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;v[22708]=0;Hr(d+512|0,2,d+624|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;R(324,d+144|0,d+512|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=d+144|0;Eb(a+1298268|0,b);vb(b);if(x[a+480188>>1]){b=0;h=(i|0)==1179012417;while(1){v[22708]=0;g=(b<<5)+a|0;f=g+480280|0;We(f);e=v[22708];v[22708]=0;N:{O:{P:{Q:{R:{if((e|0)!=1){v[22708]=0;e=T(374,d+704|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break R}if(h){break Q}if(e>>>0<129){break P}break O}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}if(e<<24>>24<=-1){break O}v[d+144>>2]=e<<2;v[22708]=0;v[d+512>>2]=256;e=pd(d+144|0,d+512|0);f=v[22708];v[22708]=0;if((f|0)!=1){u[g+480284>>1]=v[e>>2];break N}b=P()|0;O()|0;break b}u[g+480284>>1]=e<<1;break N}v[f>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}g=gb-16|0;gb=g;e=Vb(j);h=Zb(j);b=gb-32|0;gb=b;v[b+16>>2]=h;v[b+24>>2]=e;v[b+8>>2]=1380209231;if(Gb(b+24|0,b+16|0)){while(1){if(!iD(b+8|0,v[b+24>>2])){e=b+24|0;on(e);if(Gb(e,b+16|0)){continue}}break}e=v[b+24>>2]}gb=b+32|0;v[g+8>>2]=e;m=g,n=Zb(j),v[m>>2]=n;b=Gb(g+8|0,g);gb=g+16|0;if(b){v[22708]=0;U(1453,d+144|0,j|0,1380209231);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;b=T(374,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}e=Sb(a+484360|0);v[22708]=0;fa(521,e|0,d+144|0,b+1&255,255,254)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}xb(d+144|0)}if(c&1){u[d+496>>1]=0;v[22708]=0;U(1456,d+576|0,j|0,1414807888);b=v[22708];v[22708]=0;if((b|0)==1){break h}b=Je(d+576|0);v[22708]=0;e=a+484344|0;R(330,e|0,b&65535);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=d+576|0;m=d,n=Vb(b),v[m+88>>2]=n;m=d,n=Zb(b),v[m+56>>2]=n;if(Gb(d+88|0,d+56|0)){g=(i|0)!=1179012417;while(1){b=le(d+144|0,v[d+88>>2]);v[22708]=0;h=T(374,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}v[22708]=0;u[d+128>>1]=h;b=T(192,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break l}v[22708]=0;U(288,d+512|0,d+144|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break m}b=jc(d+600|0,d+512|0);v[22708]=0;h=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[b+16>>2];h=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=h;Y(1457,d|0,x[d+128>>1],g|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break n}xb(d+512|0);v[22708]=0;b=Le(d+496|0,d+128|0);h=v[22708];v[22708]=0;if((h|0)==1){break l}u[d+496>>1]=x[b>>1];xb(d+144|0);b=d+88|0;Fh(b);if(Gb(b,d+56|0)){continue}break}}if(x[d+496>>1]){b=0;while(1){v[22708]=0;g=b&65535;h=me(e,g);f=v[22708];v[22708]=0;S:{if((f|0)!=1){if(h){break S}v[22708]=0;W(331,e|0,g|0,64)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break S}}b=P()|0;O()|0;break i}b=b+1|0;if(x[d+496>>1]>(b&65535)>>>0){continue}break}}jd(d+576|0)}T:{if((i|0)==1179012417){v[22708]=0;U(1456,d+88|0,j|0,1414745673);b=v[22708];v[22708]=0;if((b|0)==1){break I}b=d+88|0;m=d,n=Vb(b),v[m+128>>2]=n;m=d,n=Zb(b),v[m+40>>2]=n;U:{if(Gb(d+128|0,d+40|0)){i=c&2;g=d+520|0;h=d+144|1;while(1){c=le(d+576|0,v[d+128>>2]);v[22708]=0;b=Q(1458,c|0,d+144|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break U}V:{if(!b){break V}b=w[h|0];if((b|0)==255){break V}v[22708]=0;b=W(376,a|0,b+1|0,0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break H}if(!b){break V}e=x[a+480190>>1];v[22708]=0;U(1459,d+144|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break H}b=0;if(!w[d+174|0]){break V}while(1){W:{if(!fi(a)){break W}v[22708]=0;e=Q(1460,c|0,d+512|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break G}if(!e){break W}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;if((w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24))!=1347240275){break W}v[22708]=0;Mk(d+496|0,2,g);f=v[22708];v[22708]=0;X:{Y:{Z:{if((f|0)==1){break Z}v[22708]=0;R(324,d+56|0,d+496|0);f=v[22708];v[22708]=0;if((f|0)==1){break Z}v[22708]=0;e=e&65535;Q(301,((e<<5)+a|0)+946304|0,d+56|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break Y}vb(d+56|0);v[22708]=0;e=(B(e,104)+a|0)+484380|0;U(1461,d+512|0,d+144|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}if(!i){break X}f=d+56|0;k=d+550|0;Rc(f,(w[k|0]|w[k+1|0]<<8)&4?16:8,1,0,0);v[22708]=0;W(329,f|0,e|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break W}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;vb(d+56|0);break p}e=aj(e);v[22708]=0;Q(318,d+576|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}}b=b+1|0;if(b>>>0<w[d+174|0]){continue}break}}xb(d+576|0);b=d+128|0;Fh(b);if(Gb(b,d+40|0)){continue}break}}jd(d+88|0);break T}b=P()|0;O()|0;break p}v[22708]=0;U(1456,d+496|0,j|0,1179011410);b=v[22708];v[22708]=0;if((b|0)==1){break F}b=d+496|0;m=d,n=Vb(b),v[m+488>>2]=n;m=d,n=Zb(b),v[m+480>>2]=n;if(Gb(d+488|0,d+480|0)){i=c&2;g=d+512|4;b=d+80|4;h=d+144|5;while(1){c=le(d+576|0,v[d+488>>2]);v[22708]=0;e=T(192,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break E}_:{if((e|0)!=538986817){break _}v[22708]=0;e=Q(1462,c|0,d+472|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break D}if(!e|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24))!=1414745673){break _}v[22708]=0;e=Q(1463,c|0,d+144|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break C}if(!e){break _}e=w[h|0];if((e|0)==255){break _}v[22708]=0;e=W(376,a|0,e+1|0,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break B}if(!e){break _}f=x[a+480190>>1];v[22708]=0;U(1464,d+144|0,e|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break B}v[22708]=0;U(1452,d+512|0,c|0,2);c=v[22708];v[22708]=0;if((c|0)==1){break J}v[22708]=0;U(1456,d+128|0,d+512|0,1179011410);c=v[22708];v[22708]=0;if((c|0)==1){break A}ke(d+512|0);c=d+128|0;m=d,n=Vb(c),v[m+120>>2]=n;m=d,n=Zb(c),v[m+112>>2]=n;$:{if(!Gb(d+120|0,d+112|0)){break $}aa:{while(1){c=le(d+88|0,v[d+120>>2]);v[22708]=0;e=T(192,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break z}ba:{ca:{if((e|0)!=538989377){break ca}if(!fi(a)){break ca}e=w[d+468|0]|w[d+469|0]<<8;f=e-1|0;t[d+468|0]=f;t[d+469|0]=f>>>8;if(!e){xb(d+88|0);break $}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[22708]=0;c=Q(1462,c|0,d+80|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break y}da:{if(!(!c|(w[d+80|0]|w[d+81|0]<<8|(w[d+82|0]<<16|w[d+83|0]<<24))!=1347240275)){c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22708]=0;U(288,d+512|0,d+88|0,c|0);c=v[22708];v[22708]=0;ea:{if((c|0)!=1){c=d+512|0;e=jc(d+56|0,c);xb(c);v[22708]=0;c=Q(1465,e|0,c|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break ba}if(!c){break aa}v[22708]=0;Ke(d+24|0,2,g);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;R(324,d+40|0,d+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){break ea}}b=P()|0;O()|0;break t}b=P()|0;O()|0;break s}v[22708]=0;c=f&65535;Q(301,((c<<5)+a|0)+946304|0,d+40|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break x}vb(d+40|0);v[22708]=0;c=(B(c,104)+a|0)+484380|0;U(1466,d+512|0,d+144|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break ba}if(!i){break da}f=w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24);v[22708]=0;Q(190,d+56|0,f+4|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break ba}f=d+40|0;k=d+552|0;Rc(f,(w[k|0]|w[k+1|0]<<8)&4?16:8,1,0,0);v[22708]=0;W(329,f|0,c|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break da}b=P()|0;O()|0;break t}xb(d+88|0);break $}xb(d+56|0)}xb(d+88|0);c=d+120|0;Fh(c);if(Gb(c,d+112|0)){continue}break $}break}b=P()|0;O()|0;break t}xb(d+56|0);xb(d+88|0)}jd(d+128|0)}xb(d+576|0);c=d+488|0;Fh(c);if(Gb(c,d+480|0)){continue}break}}jd(d+496|0)}g=1}xb(d+704|0);ke(j);xb(l)}gb=d+784|0;return g|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;break b}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;ke(d+512|0);break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break s}b=P()|0;O()|0;vb(d+40|0);break t}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}xb(d+56|0)}xb(d+88|0);jd(d+128|0)}xb(d+576|0);jd(d+496|0);break b}b=P()|0;O()|0}xb(d+576|0);jd(d+88|0);break b}b=P()|0;O()|0;break i}b=P()|0;O()|0;xb(d+512|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0}xb(d+144|0)}jd(d+576|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;xb(d+144|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(d+704|0)}ke(j);xb(l);S(b|0);L()}function Qpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=gb+-64|0;gb=f;vc(a);a:{b:{if(b>>>0<=2){b=f+56|0;C=b,D=Be(a),t[C|0]=D;Rb(a,2);e=b|2;i=Ng(a);t[e|0]=i;t[e+1|0]=i>>>8;b=b|4;e=sg(a);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;break b}Dr(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{m=d+484344|0;b=f+56|2;r=Fd(w[b|0]|w[b+1|0]<<8,1,1024);l=jz(m,r,0);if((l|0)!=65535){i=Uf(_b(m,l),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];s=x[Pc(f,f+40|0)>>1];e=s+1|0;if(x[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){t[i+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Kv(f+40|0,e,f);if(r){b=(b|0)!=0;while(1){d:{e:{if(!w[kc(o,0)|0]){v[22708]=0;e=T(374,a|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}e=e<<24>>24;if((e|0)<=-1){v[22708]=0;i=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}C=kc(o,0),D=i,t[C|0]=D}y=0;t[f|0]=0;g=e&63;f:{g:{if(!g){break g}v[22708]=0;e=T(374,a|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break c}t[f|0]=e;i=0;h:{switch(g-1|0){case 0:t[c+12|0]=0;v[22708]=0;t[f+36|0]=1;b=pf(f+36|0,f);e=v[22708];v[22708]=0;if((e|0)!=1){t[c+14|0]=w[b|0];t[c+15|0]=0;b=1;break f}break c;case 1:if(!e){break f}t[c+15|0]=e;b=1;t[c+12|0]=1;i=w[c+13|0];if(!i){break g}t[c+14|0]=B(B(e,i),15);break g;case 2:t[c+13|0]=e>>>4;if(e>>>0>=16){b=w[c+12|0]!=0;break f}t[c+12|0]=0;break f;case 3:i=e;break f;case 5:if(!e){break f}i=(w[c+12|0]?15:14)+c|0;b=w[i|0];t[i|0]=b>>>0<256-e>>>0?b+e|0:-1;b=1;break g;case 6:break h;default:break f}}if(!e){break f}b=1;g=(w[c+12|0]?15:14)+c|0;i=w[g|0];t[g|0]=i>>>0>e+1>>>0?i-e|0:1}i=0}v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d}i=0;e=kc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;y=0;if(!(b&1)){break d}}b=w[c+12|0];e=w[c+13|0];if(e?0:b){break d}i:{if(b){v[f>>2]=1;b=w[c+15|0];v[22708]=0;v[f+28>>2]=B(b,e)<<1;b=If(f,f+28|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[b>>2];break i}e=B(w[c+14|0],30)+30|0}b=255;j:{while(1){g=B(b,e);if(g-1536>>>0<10752){e=g;break j}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(e|0)/48;Rd(f+32|0,32,255);v[22708]=0;v[f>>2]=1;b=If(f,f+36|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}t[c+16|0]=v[b>>2];y=1}b=_b(m,l);v[22708]=0;b=Xc(b,k,1);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(s){z=k-1|0;h=1;p=1;while(1){k:{l:{m:{n:{if(!w[kc(o,h)|0]){v[22708]=0;j=T(374,a|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(j&128){v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}C=kc(o,h),D=e,t[C|0]=D}A=1;if(j&64){v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[b+1|0]=e;A=!e}if(!(j&32)){e=w[b|0];break n}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[b|0]=e;if((e-1&255)>>>0<=107){e=nn(e+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C+1|0]=D;break n}if((e+127&255)>>>0<=107){e=nn((e&127)+24|0);t[b|0]=e;C=ad(c,h),D=e,t[C|0]=D;t[b|0]=0;break m}if((e|0)!=255){break n}t[b|0]=254;break l}e=kc(o,h);t[e|0]=w[e|0]-1;break k}if(e&255){break l}}if(!w[b+1|0]){break l}e=w[ad(c,h)+1|0];t[b+1|0]=0;t[b|0]=e}v[22708]=0;e=ce(b);g=v[22708];v[22708]=0;if((g|0)==1){break c}if(e){C=ad(c,h),D=0,t[C+5|0]=D}t[f+28|0]=0;t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;if(j&16){t[b+2|0]=1;v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[b+4|0]=e+2>>>2}o:{if(!(j&8)){break o}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[22708]=0;t[f+28|0]=e;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+25|0]=e;p:{q:{r:{s:{t:{u:{v:{w:{g=w[f+28|0];switch(g-1|0){case 0:break q;case 9:break r;case 5:case 6:case 7:case 8:break s;case 4:break t;case 3:break u;case 2:break v;case 1:break w;default:break p}}t[b|0]=255;break p}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break p}e=Jv(e,w[c+16|0]);t[f+25|0]=e;x:{if(e){t[f+28|0]=20;t[f+25|0]=e|208;break x}t[f+28|0]=0}if(w[b|0]){break o}C=b,D=w[ad(c,h)+1|0],t[C|0]=D;C=ad(c,h),D=0,t[C+5|0]=D;break o}t[f|0]=1;e=Jv(e,w[c+16|0]);v[22708]=0;t[f+22|0]=e;e=pf(f,f+22|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[f+25|0]=w[e|0];t[f+28|0]=15;C=ad(c,h),D=0,t[C+5|0]=D;break o}break c}y:{if(!k){break y}if((g|0)==w[ad(c,h)+4|0]){break y}e=_b(m,l);v[22708]=0;g=Ce(f,20,(w[f+28|0]+122|160)&255);n=v[22708];v[22708]=0;if((n|0)==1){break c}g=pp(op(Ue(g,z),p&65535));v[22708]=0;e=Q(431,e|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!e){break y}C=ad(c,h),D=w[f+28|0],t[C+4|0]=D}t[f+28|0]=10;if(!w[b|0]){C=b,D=w[ad(c,h)+1|0],t[C|0]=D}C=ad(c,h),D=0,t[C+5|0]=D;break o}t[f+28|0]=20;C=f,D=w[ad(c,h)+5|0]?-98:-97,t[C+25|0]=D;e=ad(c,h);t[e+5|0]=w[e+5|0]^1;break o}t[b|0]=254}t[f+28|0]=0}n=0;e=0;z:{if(!(j&4)){break z}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[22708]=0;t[f+27|0]=e;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+24|0]=e;g=f;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{q=w[f+27|0];switch(q-1|0){case 11:break C;case 10:break D;case 7:case 8:case 9:break E;case 6:break F;case 5:break G;case 3:case 4:break H;case 2:break I;case 1:break J;case 0:break K;default:break B}}v[22708]=0;kt(f,e<<24>>24<<3,128);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;e=ce(b);g=v[22708];v[22708]=0;if((g|0)==1){break c}if(e){C=b,D=nn(v[f>>2]+w[b|0]|0),t[C|0]=D}t[f+27|0]=35;t[f+24|0]=w[f+4|0]^128;e=0;break z}e=Jv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|208;e=1;break z}t[f+27|0]=0;e=1;break z}e=1;break A}g=w[c+16|0];v[22708]=0;e=nD(e,g,1);g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+24|0]=e;t[f+27|0]=w[f+27|0]==4?2:3;e=1;break z}if(!w[b|0]){C=b,D=w[ad(c,h)|0],t[C|0]=D;e=w[f+24|0]}g=w[c+16|0];v[22708]=0;e=nD(e&255,g,0);g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+27|0]=4;t[f+24|0]=e;e=1;break z}C=b,D=nn(e+25|0),t[C|0]=D;t[f+24|0]=255;t[f+27|0]=4;e=1;break z}L:{if(!k){break L}if((q|0)==w[ad(c,h)+2|0]){break L}e=_b(m,l);v[22708]=0;g=Ce(f,20,(w[f+27|0]-8|48)&255);q=v[22708];v[22708]=0;if((q|0)==1){break c}g=pp(op(Ue(g,z),p&65535));v[22708]=0;e=Q(431,e|0,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!e){break L}C=ad(c,h),D=w[f+27|0],t[C+2|0]=D}t[f+27|0]=5;e=w[c+16|0];v[22708]=0;e=Iv(w[f+24|0],e);g=v[22708];v[22708]=0;if((g|0)==1){break c}t[f+24|0]=e;e=1;break z}e=sY(e,w[c+16|0]);t[f+27|0]=18;t[f+24|0]=e;e=1;break z}e=Jv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|192;e=1;break z}t[f+27|0]=0;t[b|0]=254;e=1;break z}e=0}t[g+27|0]=e}M:{if(!(j&2)){break M}v[22708]=0;g=T(374,a|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}v[22708]=0;t[f+26|0]=g;g=T(374,a|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}t[f+23|0]=g;N:{O:{P:{Q:{R:{S:{T:{j=w[f+26|0];switch(j-1|0){case 9:break O;case 7:case 8:break P;case 6:break Q;case 3:case 4:case 5:break R;case 2:break S;case 0:case 1:break T;default:break N}}h=w[c+16|0];v[22708]=0;g=mD(g,h,(j|0)==1);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+26|0]=11;t[f+23|0]=g;n=1;break M}g=sY(g,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=g;n=1;break M}U:{if(!k){break U}if((j|0)==w[ad(c,h)+3|0]){break U}g=_b(m,l);v[22708]=0;j=Ce(f,20,(w[f+26|0]-4|64)&255);n=v[22708];v[22708]=0;if((n|0)==1){break c}j=pp(op(Ue(j,z),p&65535));v[22708]=0;g=Q(431,g|0,j|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}if(!g){break U}C=ad(c,h),D=w[f+26|0],t[C+3|0]=D}t[f+26|0]=8;g=w[c+16|0];v[22708]=0;g=Iv(w[f+23|0],g);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=9;break M}h=w[c+16|0];v[22708]=0;g=mD(g,h,(j|0)==8);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+26|0]=29;t[f+23|0]=g;n=1;break M}t[f+26|0]=27;h=w[c+16|0];v[22708]=0;g=Iv(g,h);h=v[22708];v[22708]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=0}if(e){rY(b,k,x[d+480188>>1],w[f+27|0],f+24|0)}if(n){rY(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}V:{if(!A){break V}v[22708]=0;e=ce(b);g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!e){break V}e=w[f+27|0];if(!e){t[f+24|0]=255;t[f+27|0]=4;break V}if(w[f+26|0]|(e|0)==4){break V}t[f+23|0]=255;t[f+26|0]=4}W:{if(w[b+2|0]!=1){break W}X:{if(!w[f+27|0]){t[f+27|0]=13;t[f+24|0]=w[b+4|0];break X}if(w[f+26|0]){break W}t[f+26|0]=13;t[f+23|0]=w[b+4|0]}t[b+2|0]=0}v[22708]=0;so(f,f+27|0,f+24|0,f+26|0,f+23|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}Y:{if(w[b+2|0]){break Y}e=w[f+27|0];if(!e){break Y}t[b+2|0]=e;t[b+4|0]=w[f+24|0]}Z:{if(w[f+28|0]){v[22708]=0;so(f,f+26|0,f+23|0,f+28|0,f+25|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}_:{if(w[b+2|0]){break _}e=w[f+26|0];if(!e){break _}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}h=f+25|0;e=w[f+28|0];break Z}h=f+23|0;e=w[f+26|0];if(!e){break k}}t[b+3|0]=e;t[b+5|0]=w[h|0]}b=b+6|0;p=p+1|0;h=p&65535;if(s>>>0>=h>>>0){continue}break}}$:{if(!y){break $}b=_b(m,l);v[22708]=0;e=Ce(f,17,w[f+32|0]);g=v[22708];v[22708]=0;if((g|0)==1){break c}e=Gh(op(Ue(e,k),0));v[22708]=0;Q(431,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=_b(m,l);v[22708]=0;e=Ce(f,16,w[f+36|0]);g=v[22708];v[22708]=0;if((g|0)!=1){e=Gh(Ue(e,k));v[22708]=0;Q(431,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break $}}break c}aa:{if(!(i&240)){break aa}b=_b(m,l);v[22708]=0;e=Ce(f,20,i>>>4|224);g=v[22708];v[22708]=0;if((g|0)!=1){e=qY(Ue(e,k));v[22708]=0;Q(431,b|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break aa}}break c}ba:{b=i&15;if(!b){break ba}e=w[c+16|0];i=_b(m,l);b=Fd((B(b,e)>>>0)/15&255,1,15);v[22708]=0;b=Ce(f,20,b|96);e=v[22708];v[22708]=0;if((e|0)!=1){b=qY(Ue(b,k));v[22708]=0;Q(431,i|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break ba}}break c}b=0;k=k+1|0;if((r|0)!=(k|0)){continue}break}}gc(o)}gb=f- -64|0;return l|0}a=P()|0;O()|0;gc(o);S(a|0);L()}function Hka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;i=gb-240|0;gb=i;a:{if(!Nu(a)){e=i+80|0;hc(e,a,128);f=i+208|0;of(f,e,128,2);e=i+224|0;Bc(e,f);v[22708]=0;Q(301,b+492|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}vb(i+224|0)}u[c+34>>1]=x[c+34>>1]&65489;o=i+224|0;l=o;e=c;h=gb-48|0;gb=h;f=a;b:{if(!(w[f+128|0]==4|w[f+128|0]==8)){v[h+44>>2]=0;v[h+40>>2]=0;break b}t[h+40|0]=w[f+129|0];t[h+36|0]=100;m=h+36|0;g=w[ac(h+40|0,m)|0];v[h+44>>2]=g;t[h+36|0]=w[f+130|0];t[h+32|0]=100;m=w[ac(m,h+32|0)|0];v[h+40>>2]=m;c:{if(w[f+140|0]&16){g=Ib(w[f+150|0]|w[f+151|0]<<8)|g<<16;v[h+44>>2]=g;f=Ib(w[f+152|0]|w[f+153|0]<<8)|m<<16;v[h+40>>2]=f;s=+y[e>>2]/6553600;g=hr(s*+(g>>>0));v[h+44>>2]=g;v[h+36>>2]=v[e>>2]-g;z=h,A=hr(s*+(f>>>0)),v[z+32>>2]=A;z=h,A=v[Fb(h+36|0,h+32|0)>>2],v[z+40>>2]=A;break c}if(!Md(e)){break c}f=v[e>>2];j=f>>>7|0;g=B(j,(g<<7>>>0)/100|0);v[h+44>>2]=g;v[h+36>>2]=f-g;v[h+32>>2]=B(j,(m<<7>>>0)/100|0);f=v[Fb(h+36|0,h+32|0)>>2];v[h+40>>2]=f;r=h;d:{if(t[e+34|0]&1){jn(h+24|0,v[e+20>>2],B(v[e>>2],fd(e)));j=fd(e);e=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=e;e=v[h+8>>2];e:{if(f){n=u[e+(B(g,j)<<1)>>1];e=e+(B(j,f+g|0)<<1)|0;p=0-j<<1;while(1){q=u[e>>1]-n|0;j=q>>31;g=f;if((j^j+q)>>>0<1536){break e}e=e+p|0;f=f-1|0;if(f){continue}break}}g=0}break d}bc(h+16|0,v[e+20>>2],B(v[e>>2],fd(e)));e=fd(e);j=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=j;j=v[h>>2];f:{if(f){n=0-e|0;p=t[j+B(e,g)|0];e=j+B(e,f+g|0)|0;while(1){q=t[e|0]-p|0;j=q>>31;g=f;if((j^j+q)>>>0<6){break f}e=e+n|0;f=f-1|0;if(f){continue}break}}g=0}}v[r+40>>2]=g}}v[l>>2]=v[h+44>>2];v[l+4>>2]=v[h+40>>2];gb=h+48|0;e=128;m=fc(o);if(!(!v[m>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[o>>2];v[c+8>>2]=v[m>>2]+v[o>>2]}f=i;if(!(!w[a+134|0]|w[a+134|0]>199)){t[i+80|0]=w[a+134|0];t[i+208|0]=100;e=(w[ac(i+80|0,i+208|0)|0]<<7>>>0)/100|0}t[f+79|0]=e;t[i+80|0]=64;e=i+79|0;f=i+80|0;z=c,A=w[pf(e,f)|0]>>>1|0,u[z+32>>1]=A;t[i+80|0]=64;z=b,A=w[ac(e,f)|0],v[z+4>>2]=A;v[c+24>>2]=40460;Oo(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){fm(b,127,1);em(b,0,1)}g:{if(!Md(c)){break g}if(t[a+140|0]&1){f=d;b=c;h:{if(!Md(b)){break h}e=v[b>>2];if(e>>>0<2){break h}i:{if((jj(b)|0)==4){h=v[b+20>>2];g=0;j=e>>>1|0;while(1){xc(h+(g<<2)|0,h+((g^-1)+e<<2)|0);g=g+1|0;if((j|0)!=(g|0)){continue}break}break i}if((jj(b)|0)==2){h=v[b+20>>2];g=0;j=e>>>1|0;while(1){Mz(h+(g<<1)|0,h+((g^-1)+e<<1)|0);g=g+1|0;if((j|0)!=(g|0)){continue}break}break i}if((jj(b)|0)!=1){break h}h=v[b+20>>2];g=0;j=e>>>1|0;while(1){l=h+g|0;n=w[l|0];r=l;l=h+((g^-1)+e|0)|0;t[r|0]=w[l|0];t[l|0]=n;g=g+1|0;if((j|0)!=(g|0)){continue}break}}_h(b,f,0)}}if(w[a+140|0]&4){f=d;b=c;j:{if(!Md(b)){break j}e=v[b>>2];fd(b);g=0;h=B(fd(b),e);k:{if((ij(b)|0)==2){j=v[b+20>>2]+(g<<1)|0;e=0;g=h-g|0;if(g){while(1){h=j+(e<<1)|0;u[h>>1]=x[h>>1]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}break k}if((ij(b)|0)!=1){break j}j=g+v[b+20>>2]|0;e=0;g=h-g|0;if(g){while(1){h=e+j|0;t[h|0]=w[h|0]^-1;e=e+1|0;if((g|0)!=(e|0)){continue}break}}}_h(b,f,0)}}if(!(!(w[a+141|0]?1:w[a+160|0]|w[a+170|0]==2)|t[c+34|0]&1)){e=Sq(v[c>>2],fd(c)<<1);if(!e){break g}b=e;g=B(v[c>>2],fd(c));f=v[c+20>>2];j=aj(c);h=gb-16|0;gb=h;v[h+12>>2]=g;qc(h+12|0,j);g=v[h+12>>2];if(g){while(1){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;g=g-1|0;if(g){continue}break}v[h+12>>2]=-1}gb=h+16|0;u[c+34>>1]=x[c+34>>1]|1;JN(c,e,v[c>>2],d)}l:{if(t[a+141|0]>-1){break l}jn(i+80|0,v[c+20>>2],B(v[c>>2],fd(c)));if(t[a+141|0]>=0){break l}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=id(u[b>>1]-id(e,1)|0,1);u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}k=k+1|0;if((k|0)<(0-t[a+141|0]|0)){continue}break}}m:{if(w[a+170|0]!=2){break m}e=i+80|0;jn(e,v[c+20>>2],B(v[c>>2],fd(c)));h=w[a+171|0];b=w[a+172|0];f=w[a+171|0];g=0-(b>>>0<f>>>0)|0;f=b-f|0;b=g<<24|f>>>8;g=f<<24;f=IB(e);k=(f|0)/2|0;j=k;g=g+j|0;b=(j>>31)+b|0;g=Ac(pqa(g,g>>>0<j>>>0?b+1|0:b,f,f>>31),jb);b=v[e>>2];j=v[e+4>>2];if((b|0)==(j|0)){break m}e=h<<24;h=e;f=e>>31;e=g;l=e>>31;while(1){g=u[b>>1];k=oqa(h,f,g,g>>31)+838860800|0;g=jb;z=b,A=Ac(pqa(k,k>>>0<838860800?g+1|0:g,1677721600,0),jb),u[z>>1]=A;f=f+l|0;h=e+h|0;f=h>>>0<e>>>0?f+1|0:f;b=b+2|0;if((j|0)!=(b|0)){continue}break}}n:{if(!w[a+160|0]){break n}jn(i+208|0,v[c+20>>2],B(v[c>>2],fd(c)));k=w[a+162|0];l=w[a+163|0];j=0;h=0;if(w[a+161|0]>=2){b=w[a+164|0];e=w[a+162|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;g=f<<23|b>>>9;f=b<<23;e=IB(i+208|0);b=(e|0)/2|0;h=b;f=f+b|0;b=(b>>31)+g|0;h=Ac(pqa(f,f>>>0<h>>>0?b+1|0:b,e,e>>31),jb)}if(w[a+161|0]>=2){b=w[a+165|0];e=w[a+163|0];f=0-(b>>>0<e>>>0)|0;b=b-e|0;g=f<<23|b>>>9;e=b<<23;b=IB(i+208|0);f=(b|0)/2|0;j=f;e=e+f|0;f=(f>>31)+g|0;j=Ac(pqa(e,e>>>0<j>>>0?f+1|0:f,b,b>>31),jb)}b=v[i+208>>2];n=v[i+212>>2];if((b|0)==(n|0)){break n}e=k<<23;f=l<<23;l=(i+80|0)+((w[a+160|0]&2)<<2)|0;k=0;g=0;while(1){p=(u[b>>1]>>1)-g|0;v[i+88>>2]=p;q=(e|0)/8388608|0;k=id(B(p,q),8)+k|0;v[i+84>>2]=k;g=id(B(k,q),6)+g|0;g=id(id(B(g,(f|0)/8388608|0),6)+g|0,2);v[i+80>>2]=g;z=b,A=Uc(v[l>>2]),u[z>>1]=A;f=f+j|0;e=e+h|0;b=b+2|0;if((n|0)!=(b|0)){continue}break}}o:{if(t[a+141|0]<1){break o}jn(i+80|0,v[c+20>>2],B(v[c>>2],fd(c)));k=0;if(t[a+141|0]<=0){break o}while(1){b=v[i+80>>2];f=v[i+84>>2];if((b|0)!=(f|0)){e=u[v[i+80>>2]>>1];while(1){e=((u[b>>1]<<1)+e|0)/3|0;u[b>>1]=e;b=b+2|0;if((f|0)!=(b|0)){continue}break}}k=k+1|0;if((k|0)<t[a+141|0]){continue}break}}p:{if(t[c+34|0]&1){jn(i- -64|0,v[c+20>>2],B(v[c>>2],fd(c)));b=v[i+68>>2];v[i+32>>2]=v[i+64>>2];v[i+36>>2]=b;j=gb-16|0;gb=j;l=v[i+36>>2];k=gb-16|0;gb=k;v[k+12>>2]=v[i+32>>2];n=j+8|0;b=k+12|0;f=Mu(n,b,b);e=v[k+12>>2];q:{if((e|0)==(l|0)){break q}b=e+2|0;v[k+12>>2]=b;if((b|0)==(l|0)){break q}z=(Nj(b,v[f>>2])?0:4)+f|0,A=b,v[z>>2]=A;e=e+4|0;if((l|0)==(e|0)){break q}g=f+4|0;while(1){h=b;b=b+4|0;v[k+12>>2]=b;if((b|0)==(l|0)){if(!Nj(e,v[f>>2])){f=g;if(Nj(e,v[f>>2])){break q}}v[f>>2]=e;break q}p=v[f>>2];r:{s:{if(Nj(b,e)){if(Nj(b,p)){v[f>>2]=b}if(!Nj(e,v[g>>2])){break s}break r}if(Nj(e,p)){v[f>>2]=e}e=b;if(Nj(b,v[g>>2])){break r}}v[g>>2]=e}e=h+6|0;v[k+12>>2]=e;if((e|0)!=(l|0)){continue}break}}gb=k+16|0;v[j+4>>2]=0-u[v[n>>2]>>1];z=j,A=u[v[fc(n)>>2]>>1],v[z>>2]=A;b=v[If(j+4|0,j)>>2];t:{if((b|0)>=32767|!b){break t}e=v[i+32>>2];f=v[i+36>>2];if((e|0)==(f|0)){break t}while(1){u[e>>1]=(B(u[e>>1],32767)|0)/(b|0);e=e+2|0;if((f|0)!=(e|0)){continue}break}}gb=j+16|0;break p}bc(i+56|0,v[c+20>>2],B(v[c>>2],fd(c)));b=v[i+60>>2];v[i+24>>2]=v[i+56>>2];v[i+28>>2]=b;k=gb-16|0;gb=k;j=v[i+28>>2];f=gb-16|0;gb=f;v[f+4>>2]=v[i+24>>2];l=k+8|0;b=f+4|0;b=Mu(l,b,b);e=v[f+4>>2];u:{if((e|0)==(j|0)){break u}e=e+1|0;v[f+4>>2]=e;if((e|0)==(j|0)){break u}e=(Mj(e,v[b>>2])?0:4)+b|0;h=v[f+4>>2];v[e>>2]=h;g=h+1|0;if((j|0)==(g|0)){break u}e=b+4|0;while(1){h=h+2|0;v[f+4>>2]=h;if((h|0)==(j|0)){if(!Mj(g,v[b>>2])){b=e;if(Mj(g,v[b>>2])){break u}}v[b>>2]=g;break u}v:{w:{if(Mj(h,g)){if(Mj(v[f+4>>2],v[b>>2])){v[b>>2]=v[f+4>>2]}if(!Mj(g,v[e>>2])){break w}break v}if(Mj(g,v[b>>2])){v[b>>2]=g}if(Mj(v[f+4>>2],v[e>>2])){break v}g=v[f+4>>2]}v[e>>2]=g}h=v[f+4>>2];g=h+1|0;v[f+4>>2]=g;if((g|0)!=(j|0)){continue}break}}gb=f+16|0;v[k+4>>2]=0-t[v[l>>2]];z=k,A=t[v[fc(l)>>2]],v[z>>2]=A;b=v[If(k+4|0,k)>>2];x:{if((b|0)>=127|!b){break x}e=v[i+24>>2];f=v[i+28>>2];if((e|0)==(f|0)){break x}while(1){t[e|0]=(B(t[e|0],127)|0)/(b|0);e=e+1|0;if((f|0)!=(e|0)){continue}break}}gb=k+16|0}y:{if(w[a+134|0]<101|w[a+134|0]>199){break y}b=B(v[c>>2],fd(c));if(t[c+34|0]&1){e=v[c+20>>2];b=td(i+48|0,e,e+(b<<1)|0);e=w[a+134|0];f=v[b+4>>2];v[i+16>>2]=v[b>>2];v[i+20>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+16>>2];k=v[i+20>>2];if((b|0)!=(k|0)){j=0-f|0;g=32768-f|0;while(1){e=b;h=u[b>>1];z:{if((h|0)>(f|0)){l=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break z}l=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(j|0)){break z}l=(B(h,g)|0)/(f|0)|0}z=e,A=Uc(l),u[z>>1]=A;b=b+2|0;if((k|0)!=(b|0)){continue}break}}break y}e=v[c+20>>2];b=td(i+40|0,e,b+e|0);e=w[a+134|0];f=v[b+4>>2];v[i+8>>2]=v[b>>2];v[i+12>>2]=f;f=(3276800-(e<<14)|0)/100|0;b=v[i+8>>2];k=v[i+12>>2];if((b|0)!=(k|0)){j=0-f|0;g=32768-f|0;while(1){e=b;h=t[b|0]<<8;A:{if((h|0)>(f|0)){l=g+((B(f,h-f|0)|0)/(g|0)|0)|0;break A}l=((B(f,f+h|0)|0)/(g|0)|0)-g|0;if((h|0)<(j|0)){break A}l=(B(h,g)|0)/(f|0)|0}z=e,A=HV((l|0)/256|0),t[z|0]=A;b=b+1|0;if((k|0)!=(b|0)){continue}break}}}if(!v[m>>2]|(!w[a+131|0]|w[a+128|0]!=8)){break g}v[c+12>>2]=v[o>>2];v[c+16>>2]=v[m>>2]+v[o>>2];if(y[m>>2]>268435456/w[a+131|0]>>>0|y[c>>2]>268435456-B(v[m>>2],w[a+131|0])>>>0){break g}b=jj(c);h=v[o>>2];k=v[m>>2];j=w[a+131|0];g=v[c>>2]+B(v[m>>2],w[a+131|0])|0;e=Sq(g,b);if(!e){break g}v[c>>2]=g;f=hc(e,zb(v[c+20>>2]),B(b,v[m>>2]+v[o>>2]|0));if(w[a+131|0]){e=0;while(1){e=e+1|0;hc(f+B(b,v[o>>2]+B(e,v[m>>2])|0)|0,zb(v[c+20>>2])+B(b,v[o>>2])|0,B(b,v[m>>2]));if(w[a+131|0]>e>>>0){continue}break}}a=h+B(k,j+1|0)|0;hc(f+B(a,b)|0,zb(v[c+20>>2])+B(b,v[m>>2]+v[o>>2]|0)|0,B(b,g-a|0));JN(c,f,v[c>>2],d)}gb=i+240|0;return}a=P()|0;O()|0;vb(i+224|0);S(a|0);L()}function qH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;d=gb-144|0;gb=d;D=Qb(d,0,144);v[D+76>>2]=-1;v[D+44>>2]=a;v[D+32>>2]=2449;v[D+84>>2]=a;E=c;c=0;j=gb-304|0;gb=j;e=D;d=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(ym(a&255)){while(1){a=d;d=d+1|0;if(ym(w[a+1|0])){continue}break}zi(e,0,0);while(1){b=v[e+4>>2];h:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break h}b=md(e)}if(ym(b)){continue}break}d=v[e+4>>2];if(v[e+104>>2]){d=d-1|0;v[e+4>>2]=d}b=d-v[e+8>>2]|0;f=b>>31;g=b;k=o+v[e+124>>2]|0;b=q+v[e+120>>2]|0;k=b>>>0<q>>>0?k+1|0:k;d=b;b=g+b|0;f=f+k|0;q=b;o=b>>>0<d>>>0?f+1|0:f;break g}i:{j:{k:{b=w[d|0];if((b|0)==37){a=w[d+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}zi(e,0,0);a=((b|0)==37)+d|0;b=v[e+4>>2];l:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break l}b=md(e)}if((b|0)!=w[a|0]){if(v[e+104>>2]){v[e+4>>2]=v[e+4>>2]-1}if((b|0)>-1){break a}s=0;if(F){break a}break c}b=q+1|0;o=b>>>0<1?o+1|0:o;q=b;break g}n=0;a=d+2|0;break i}if(!(!Rh(a)|w[d+2|0]!=36)){a=w[d+1|0]-48|0;b=gb-16|0;v[b+12>>2]=E;a=(a>>>0>1?(a<<2)-4|0:0)+E|0;v[b+8>>2]=a+4;n=v[a>>2];a=d+3|0;break i}n=v[E>>2];E=E+4|0;a=d+1|0}s=0;d=0;if(Rh(w[a|0])){while(1){d=(w[a|0]+B(d,10)|0)-48|0;b=w[a+1|0];a=a+1|0;if(Rh(b)){continue}break}}i=w[a|0];if((i|0)==109){c=0;s=(n|0)!=0;i=w[a+1|0];p=0;a=a+1|0}b=a;a=b+1|0;g=3;m:{n:{switch(i-65|0){case 39:f=b+2|0;b=w[b+1|0]==104;a=b?f:a;g=b?-2:-1;break m;case 43:f=b+2|0;b=w[b+1|0]==108;a=b?f:a;g=b?3:1;break m;case 51:case 57:g=1;break m;case 11:g=2;break m;case 41:break m;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break n;default:break d}}g=0;a=b}b=w[a|0];f=(b&47)==3;G=f?1:g;r=f?b|32:b;o:{if((r|0)==91){break o}p:{if((r|0)!=110){if((r|0)!=99){break p}d=(d|0)>1?d:1;break o}rH(n,G,q,o);break g}zi(e,0,0);while(1){b=v[e+4>>2];q:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break q}b=md(e)}if(ym(b)){continue}break}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}b=b-v[e+8>>2]|0;g=b>>31;l=b;b=o+v[e+124>>2]|0;f=q+v[e+120>>2]|0;b=f>>>0<q>>>0?b+1|0:b;i=f;o=l+f|0;f=b+g|0;q=o;o=i>>>0>o>>>0?f+1|0:f}l=d;m=d>>31;zi(e,d,m);b=v[e+104>>2];f=v[e+4>>2];r:{if(b>>>0>f>>>0){v[e+4>>2]=f+1;break r}if((md(e)|0)<0){break d}b=v[e+104>>2]}if(b){v[e+4>>2]=v[e+4>>2]-1}b=16;s:{t:{u:{v:{w:{x:{y:{switch(r-88|0){default:b=r-65|0;if(b>>>0>6|!(1<<b&113)){break s}case 9:case 13:case 14:case 15:uI(j+8|0,e,G,0);b=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-b|0)&v[e+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!n){break s}b=v[j+16>>2];d=v[j+20>>2];f=v[j+8>>2];g=v[j+12>>2];switch(G|0){case 2:break u;case 1:break v;case 0:break w;default:break s};case 3:case 11:case 27:if((r&239)==99){Qb(j+32|0,-1,257);t[j+32|0]=0;if((r|0)!=115){break t}t[j+65|0]=0;t[j+46|0]=0;u[j+42>>1]=0;u[j+44>>1]=0;break t}f=w[a+1|0];g=(f|0)==94;Qb(j+32|0,g,257);t[j+32|0]=0;b=g?a+2|0:a+1|0;z:{A:{B:{a=w[(g?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break B}g=(f|0)!=94;a=b;break z}g=(f|0)!=94;t[j+78|0]=g;break A}g=(f|0)!=94;t[j+126|0]=g}a=b+1|0}while(1){b=w[a|0];C:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break C}break t}b=45;f=w[a+1|0];if(!f|(f|0)==93){break C}i=a+1|0;a=w[a-1|0];D:{if(f>>>0<=a>>>0){b=f;break D}while(1){a=a+1|0;t[a+(j+32|0)|0]=g;b=w[i|0];if(b>>>0>a>>>0){continue}break}}a=i}t[(b+j|0)+33|0]=g;a=a+1|0;continue};case 23:b=8;break x;case 12:case 29:b=10;break x;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break s;case 0:case 24:case 32:break x;case 17:break y}}b=0}h=e;l=0;f=0;i=0;g=0;I=0;H=gb-16|0;gb=H;E:{F:{G:{H:{I:{J:{if(b>>>0<=36){while(1){d=v[h+4>>2];K:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break K}d=md(h)}if(ym(d)){continue}break}L:{M:{switch(d-43|0){case 0:case 2:break M;default:break L}}I=(d|0)==45?-1:0;d=v[h+4>>2];if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break L}d=md(h)}N:{if(!(b&-17|(d|0)!=48)){d=v[h+4>>2];O:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break O}d=md(h)}if((d&-33)==88){b=16;d=v[h+4>>2];P:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break P}d=md(h)}if(w[d+74449|0]<16){break I}if(!v[h+104>>2]){break F}v[h+4>>2]=v[h+4>>2]-1;break F}if(b){break N}b=8;break I}b=b?b:10;if(b>>>0>w[d+74449|0]){break N}if(v[h+104>>2]){v[h+4>>2]=v[h+4>>2]-1}zi(h,0,0);v[115189]=28;b=0;d=0;break E}if((b|0)!=10){break I}i=d-48|0;if(i>>>0<=9){b=0;while(1){b=B(b,10)+i|0;d=v[h+4>>2];Q:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break Q}d=md(h)}i=d-48|0;if(b>>>0<429496729?i>>>0<=9:0){continue}break}l=b}if(i>>>0>9){break J}k=oqa(l,0,10,0);m=jb;g=i;while(1){b=v[h+4>>2];R:{if(b>>>0<y[h+104>>2]){v[h+4>>2]=b+1;d=w[b|0];break R}d=md(h)}i=d-48|0;x=i>>>0>9;f=m;b=g+k|0;f=b>>>0<k>>>0?f+1|0:f;l=b;if((f|0)==429496729&b>>>0>=2576980378|f>>>0>429496729|x){break J}k=oqa(l,f,10,0);b=k;m=jb;g=i;if((m|0)==-1&(g^-1)>>>0>=b>>>0|(m|0)!=-1){continue}break}b=10;break H}v[115189]=28;b=0;d=0;break E}b=10;if(i>>>0<=9){break H}break G}if(b-1&b){g=w[d+74449|0];if(g>>>0<b>>>0){while(1){i=B(b,i)+g|0;d=v[h+4>>2];S:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break S}d=md(h)}g=w[d+74449|0];if(i>>>0<119304647?g>>>0<b>>>0:0){continue}break}l=i}if(b>>>0<=g>>>0){break H}i=b;k=oqa(l,0,b,0);m=jb;if((m|0)==-1&(g^-1)>>>0<k>>>0){break H}while(1){f=m;d=g+k|0;f=d>>>0<k>>>0?f+1|0:f;l=d;d=v[h+4>>2];T:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break T}d=md(h)}g=w[d+74449|0];if(g>>>0>=b>>>0){break H}qf(H,i,0,0,0,l,f,0,0);if(v[H+8>>2]|v[H+12>>2]){break H}k=oqa(l,f,i,0);m=jb;if((m|0)==-1&(g^-1)>>>0>=k>>>0|(m|0)!=-1){continue}break}break H}k=t[(B(b,23)>>>5&7)+74705|0];i=w[d+74449|0];if(i>>>0<b>>>0){while(1){g=g<<k|i;d=v[h+4>>2];U:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break U}d=md(h)}i=w[d+74449|0];if(g>>>0<134217728?i>>>0<b>>>0:0){continue}break}l=g}if(b>>>0<=i>>>0){break H}g=k;m=g&31;if((g&63)>>>0>=32){k=0;x=-1>>>m|0}else{x=-1>>>m|0;k=x;x=k|(1<<m)-1<<32-m}if(!k&l>>>0>x>>>0){break H}while(1){m=i&255;d=g;i=d&31;if((d&63)>>>0>=32){f=l<<i;d=0}else{f=(1<<i)-1&l>>>32-i|f<<i;d=l<<i}l=m|d;m=b;d=v[h+4>>2];V:{if(d>>>0<y[h+104>>2]){v[h+4>>2]=d+1;d=w[d|0];break V}d=md(h)}i=w[d+74449|0];if(m>>>0<=i>>>0){break H}if((f|0)==(k|0)&l>>>0<=x>>>0|f>>>0<k>>>0){continue}break}}if(w[d+74449|0]>=b>>>0){break G}while(1){f=v[h+4>>2];W:{if(f>>>0<y[h+104>>2]){v[h+4>>2]=f+1;d=w[f|0];break W}d=md(h)}if(w[d+74449|0]<b>>>0){continue}break}v[115189]=68;I=0;l=-1;f=-1}if(v[h+104>>2]){v[h+4>>2]=v[h+4>>2]-1}if((l|0)==-1&(f|0)==-1){if(!(I|1)){v[115189]=68;b=-2;d=-1;break E}}b=I;g=b^l;d=b;b=g-b|0;i=f;f=d>>31;d=(i^f)-((d>>>0>g>>>0)+f|0)|0;break E}zi(h,0,0);b=0;d=0}gb=H+16|0;f=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-f|0)&v[e+124>>2]==(0-((f>>31)+((f|0)!=0)|0)|0)){break b}if(!(!n|(r|0)!=112)){v[n>>2]=b;break s}rH(n,G,b,d);break s}J=n,K=sI(f,g,b,d),z[J>>2]=K;break s}J=n,L=cy(f,g,b,d),A[J>>3]=L;break s}v[n>>2]=f;v[n+4>>2]=g;v[n+8>>2]=b;v[n+12>>2]=d;break s}f=(r|0)==99;g=f?d+1|0:31;i=(G|0)!=1;X:{if(!i){b=n;if(s){b=Cd(g<<2);if(!b){break e}}v[j+296>>2]=0;v[j+300>>2]=0;d=0;c=s;while(1){p=b;Y:{while(1){b=v[e+4>>2];Z:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break Z}b=md(e)}if(!w[(b+j|0)+33|0]){break Y}t[j+27|0]=b;b=$p(j+28|0,j+27|0,1,j+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(p){v[(d<<2)+p>>2]=v[j+28>>2];d=d+1|0}if(!(c&(d|0)==(g|0))){continue}break}g=g<<1|1;b=Vp(p,g<<2);if(b){continue}break f}break}if(j+296|0?v[j+296>>2]:0){break f}c=0;break X}if(s){d=0;b=Cd(g);if(!b){break e}while(1){c=b;while(1){b=v[e+4>>2];_:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break _}b=md(e)}if(!w[(b+j|0)+33|0]){p=0;break X}t[c+d|0]=b;d=d+1|0;if((g|0)!=(d|0)){continue}break}p=0;g=g<<1|1;b=Vp(c,g);if(b){continue}break}break d}d=0;if(n){while(1){b=v[e+4>>2];$:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break $}b=md(e)}if(w[(b+j|0)+33|0]){t[d+n|0]=b;d=d+1|0;continue}else{p=0;c=n;break X}}}while(1){b=v[e+4>>2];aa:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break aa}b=md(e)}if(w[(b+j|0)+33|0]){continue}break}c=0;p=0}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}g=b-v[e+8>>2]|0;h=g;b=h+v[e+120>>2]|0;k=v[e+124>>2]+(h>>31)|0;k=b>>>0<h>>>0?k+1|0:k;if(!(k|b)|((b|0)!=(l|0)|(k|0)!=(m|0)?(r|0)==99:0)){break b}ba:{if(!s){break ba}if(!i){v[n>>2]=p;break ba}v[n>>2]=c}if(f){break s}if(p){v[(d<<2)+p>>2]=0}if(!c){c=0;break s}t[c+d|0]=0}b=v[e+4>>2]-v[e+8>>2]|0;f=b>>31;g=b;o=o+v[e+124>>2]|0;b=q+v[e+120>>2]|0;o=b>>>0<q>>>0?o+1|0:o;d=b;b=g+b|0;o=f+o|0;o=b>>>0<d>>>0?o+1|0:o;q=b;F=((n|0)!=0)+F|0}d=a+1|0;a=w[a+1|0];if(a){continue}break a}break}c=0;break d}c=0;p=0}if(F){break b}}F=-1}if(!s){break a}Xb(c);Xb(p)}gb=j+304|0;gb=D+144|0;return F}function iha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;j=gb-288|0;gb=j;h=gb-128|0;gb=h;g=j+104|0;i=le(g,c);v[22708]=0;n=T(215,g+20|0)|0;c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((c|0)!=1){v[22708]=0;p=T(215,g+40|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break A}v[22708]=0;q=T(215,g+60|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break z}v[22708]=0;r=T(215,g+80|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break y}v[22708]=0;o=T(215,g+100|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;k=T(215,g+120|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}m=Go(g+140|0);vc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[22708]=0;f=Q(1428,i|0,h+112|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}if(!f){break m}c=h+112|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1179011410){c=h+112|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1414744396){break m}}l=h+120|0;f=w[l+1|0]<<8;c=w[l+2|0]<<16|w[l+3|0]<<24;if((c|(f|w[l|0]))!=1702257015?(w[l|0]|f|c)!=1163280727:0){break m}c=h+112|0;t[g+176|0]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==1414744396;v[22708]=0;U(1429,h+96|0,i|0,2);c=v[22708];v[22708]=0;if((c|0)==1){break u}B:{if(_i(h+96|0)>>>0<4){break B}c=h+40|0;Zi(c,Zt(h+96|0,1));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break B}c=h- -64|0;Zi(c,Zt(h+96|0,1));if(!(bn(c)&1)){break B}c=h+24|0;Zi(c,Zt(h+96|0,2));if(bn(c)){break B}c=h+88|0;Zi(c,Zt(h+96|0,3));if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break B}v[22708]=0;Q(190,g|0,12)|0;c=v[22708];v[22708]=0;if((c|0)==1){break t}v[22708]=0;U(1429,h+40|0,i|0,1);c=v[22708];v[22708]=0;if((c|0)==1){break s}c=h+40|0;RN(h+96|0,c);tB(c)}v[22708]=0;U(1430,h- -64|0,h+96|0,544501094);c=v[22708];v[22708]=0;if((c|0)==1){break r}v[22708]=0;l=g+156|0;f=Q(1431,h- -64|0,l|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}if(!f){break n}if((w[l|0]|w[l+1|0]<<8)==1){v[22708]=0;f=T(467,h- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}if((f|0)==4){break q}}if((w[l|0]|w[l+1|0]<<8)!=65534){break o}v[22708]=0;f=Q(1432,h- -64|0,h+40|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break p}if(!f){break n}c=v[h+60>>2];v[h+16>>2]=v[h+56>>2];v[h+20>>2]=c;c=v[h+52>>2];v[h+8>>2]=v[h+48>>2];v[h+12>>2]=c;c=h+24|0;f=h+8|0;v[c>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);u[c+4>>1]=w[f+4|0]|w[f+5|0]<<8;u[c+6>>1]=w[f+6|0]|w[f+7|0]<<8;s=c,y=NC(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24)),v[s+8>>2]=y;v[c+12>>2]=jb;u[g+172>>1]=v[c>>2];break o}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}v[22708]=0;i=T(307,h- -64|0)|0;c=v[22708];v[22708]=0;C:{if((c|0)!=1){v[22708]=0;f=T(307,h- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break C}if((i|0)!=2|(f|0)!=1){break o}t[g+177|0]=1;break o}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22708]=0;U(1430,h+40|0,h+96|0,1635017060);c=v[22708];v[22708]=0;D:{E:{F:{G:{H:{I:{if((c|0)!=1){c=h+40|0;Vc(n,c);xb(c);v[22708]=0;f=T(275,n|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}if(!f){v[22708]=0;U(1430,h+40|0,h+96|0,544039792);c=v[22708];v[22708]=0;if((c|0)==1){break I}c=h+40|0;Vc(n,c);xb(c)}v[22708]=0;U(1430,h+40|0,h+96|0,1952670054);c=v[22708];v[22708]=0;if((c|0)==1){break H}v[22708]=0;f=T(192,h+40|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}v[g+152>>2]=f;xb(h+40|0);if(v[g+152>>2]?(w[l|0]|w[l+1|0]<<8)==17:0){break D}if(!zz(g)){break D}if(Ho(g)){if((Ho(g)>>>0)/(Lj(g)>>>0)>>>0<zz(g)<<1>>>0){break F}}v[22708]=0;c=T(195,n|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=zz(g);break E}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;xb(h+40|0);break j}v[22708]=0;c=T(195,n|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=Ho(g)}v[g+152>>2]=(c>>>0)/(f>>>0)}v[22708]=0;f=Q(1433,g|0,h+96|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}u[g+174>>1]=f;v[22708]=0;R(1434,g|0,h+96|0);c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;U(1430,h+40|0,h+96|0,1886221175);c=v[22708];v[22708]=0;if((c|0)==1){break l}c=h+40|0;Vc(o,c);xb(c)}xb(h- -64|0);tB(h+96|0)}gb=h+128|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0}xb(h- -64|0)}tB(h+96|0)}tB(m);xb(k)}xb(o)}xb(r)}xb(q)}xb(p)}xb(n)}xb(g);S(c|0);L()}v[22708]=0;f=T(1143,g|0)|0;c=v[22708];v[22708]=0;J:{K:{L:{M:{if((c|0)==1){break M}N:{O:{if(!f){break O}if(!Lj(g)){break O}if(Lj(g)>>>0>2){break O}if(!Ql(g)){v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break M}if((f|0)!=85){break O}}if(Ql(g)>>>0<=31){v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break M}if((f|0)==3){break O}}if(Ql(g)>>>0>64){break O}i=0;v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break L}v[j+80>>2]=f;c=v[j+80>>2];f=36544;P:{while(1){h=f;if((c|0)==v[f>>2]){break P}f=f+4|0;if((f|0)!=36568){continue}break}h=36568}if((h|0)==36568){break N}v[22708]=0;Q(1138,a|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break M}v[22708]=0;f=Q(70,j+80|0,18720)|0;c=v[22708];v[22708]=0;Q:{R:{S:{T:{U:{V:{if((c|0)!=1){v[22708]=0;i=((b<<5)+a|0)+946304|0;Q(301,i|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break V}vb(f);v[22708]=0;f=B(b,104)+a|0;k=f+484380|0;R(424,k|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break U}v[k>>2]=v[g+152>>2];v[f+484404>>2]=w[g+160|0]|w[g+161|0]<<8|(w[g+162|0]<<16|w[g+163|0]<<24);v[22708]=0;f=Jk(a);c=v[22708];v[22708]=0;if((c|0)==1){break U}v[22708]=0;Y(1145,g|0,k|0,f|0,i|0);c=v[22708];v[22708]=0;if((c|0)==1){break U}le(j+80|0,g+20|0);i=Rc(j+72|0,8,Lj(g)>>>0>1?2:1,0,0);v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break K}if((f|0)!=17){break T}if(Lj(g)>>>0>2){break T}qc(k,268435456);d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|1;c=Lj(g);u[d>>1]=x[d>>1]&65471|((c|0)==2)<<6;i=0;v[22708]=0;d=T(386,k|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break K}if(!d){break R}i=v[(B(b,104)+a|0)+484400>>2];f=v[k>>2];m=le(j+48|0,j+80|0);d=Ho(g);c=Lj(g);v[22708]=0;b=v[m+12>>2];v[j+8>>2]=v[m+8>>2];v[j+12>>2]=b;v[j+16>>2]=v[m+16>>2];b=v[m+4>>2];v[j>>2]=v[m>>2];v[j+4>>2]=b;ha(1146,i|0,f|0,j|0,d|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break K}v[22708]=0;_h(k,a,0);b=v[22708];v[22708]=0;if((b|0)==1){break K}break S}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(f);break J}a=P()|0;O()|0;break J}v[22708]=0;f=$h(g);c=v[22708];v[22708]=0;if((c|0)==1){break K}if((f|0)==85){v[22708]=0;c=fa(753,a|0,b|0,j+80|0,0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break Q}if(c){break S}i=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break Q}break R}W:{if(uB(g)|!w[g+177|0]){break W}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)!=1){break W}if((Ql(g)|0)!=32){break W}if((Ho(g)|0)!=Lj(g)<<2){break W}Yi(i,32);Cf(i,13);v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break S}break K}X:{if(uB(g)){break X}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)!=1){break X}if((Ql(g)|0)!=24){break X}if((Ho(g)|0)!=Lj(g)<<2){break X}Yi(i,32);Cf(i,14);v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break K}break S}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}Y:{if((c|0)!=6){v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)!=7){break Y}}Yi(i,16);v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}Cf(i,(c|0)==6?18:17);v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break K}break S}c=(Ql(g)-1>>>3|0)-1|0;b=c<<3;f=b&31;Yi(i,(c>>>0<7?(b&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255);if(Ql(g)>>>0<9){Cf(i,1)}v[22708]=0;c=$h(g);b=v[22708];v[22708]=0;if((b|0)==1){break K}if((c|0)==3){Cf(i,3)}if(d){WQ(i)}v[22708]=0;W(329,i|0,k|0,j+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break K}}if(e){b=j+24|0;le(b,g+100|0);Vc(e,b);xb(b)}b=v[a+480180>>2];v[22708]=0;U(1140,k|0,32,b|0);b=v[22708];v[22708]=0;i=1;if((b|0)==1){break K}v[22708]=0;_h(k,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break K}}xb(j+80|0);break N}break K}i=0}iT(g);gb=j+288|0;return i|0}a=P()|0;O()|0;break J}a=P()|0;O()|0;break J}a=P()|0;O()|0;xb(j+80|0)}iT(g);S(a|0);L()}function yK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-128|0;gb=h;v[h+124>>2]=c;a:{b:{if(g){He(h+112|0,f,32);v[22708]=0;W(716,h+96|0,f|0,32)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break b}f=P()|0;O()|0;break a}Kb(h+112|0);Kb(h+96|0)}u[h+80>>1]=0;u[h+64>>1]=65535;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(Et(h+124|0,h+80|0,h- -64|0)){i=b+24|0;b=v[i>>2];v[22708]=0;b=me(b+484344|0,c&65535);j=v[22708];v[22708]=0;if((j|0)==1){break t}if(b){break u}}v[22708]=0;U(2102,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)!=1){break p}f=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){v[22708]=0;U(2102,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)!=1){break p}break d}if(!(x[v[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){v[22708]=0;U(2102,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}break p}v[22708]=0;c=Xc(b,d,e&65535);b=v[22708];v[22708]=0;if((b|0)==1){break h}Se(h+112|0);Se(h+96|0);v[22708]=0;b=ce(c);d=v[22708];v[22708]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((d|0)!=1){H:{I:{if(!b){if(!Xt(c)){break I}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[22708]=0;Y(2104,h- -64|0,b|0,e|0,d|0);d=v[22708];v[22708]=0;b=1;if((d|0)==1){break G}v[22708]=0;R(2040,h+80|0,h- -64|0);d=v[22708];v[22708]=0;if((d|0)!=1){break H}f=P()|0;O()|0;break D}b=0;v[22708]=0;Q(70,h+80|0,13833)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}}v[22708]=0;Q(1167,h+112|0,h+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break E}vb(h+80|0);if(b){vb(h- -64|0)}v[22708]=0;b=ce(c);d=v[22708];v[22708]=0;if((d|0)==1){break e}J:{if(b){v[22708]=0;Q(70,h+80|0,7238)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}break J}if(Xt(c)){v[22708]=0;Q(70,h+80|0,7548)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break J}break e}v[22708]=0;Q(70,h+80|0,13833)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}}v[22708]=0;Q(1167,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break C}vb(h+80|0);j=f-1|0;if(j>>>0<5){break v}v[22708]=0;b=Q(70,h+80|0,14905)|0;d=v[22708];v[22708]=0;if((d|0)==1){break B}v[22708]=0;Q(1167,h+112|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break A}vb(b);v[22708]=0;b=Q(70,h+80|0,14905)|0;d=v[22708];v[22708]=0;if((d|0)==1){break z}v[22708]=0;Q(1167,h+96|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break y}vb(b);b=c+1|0;K:{if(w[c+1|0]){v[22708]=0;R(737,h+80|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){break K}break f}v[22708]=0;Q(70,h+80|0,13838)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}}v[22708]=0;Q(1167,h+112|0,h+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}vb(h+80|0);L:{if(w[b|0]){v[22708]=0;Q(70,h+80|0,8055)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break L}break g}v[22708]=0;Q(70,h+80|0,13838)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}}v[22708]=0;Q(1167,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break w}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}}vb(h- -64|0);break c}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;vb(h+80|0);break c}vb(h+80|0);if(j>>>0<8){break v}v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){T:{if(b){v[22708]=0;b=Q(70,h+48|0,14905)|0;d=v[22708];v[22708]=0;if((d|0)==1){break S}v[22708]=0;d=Hq(c);e=v[22708];v[22708]=0;if((e|0)==1){break R}e=0;v[22708]=0;v[h+16>>2]=d&255;R(735,h+32|0,h+16|0);k=v[22708];v[22708]=0;d=1;if((k|0)==1){break R}v[22708]=0;U(2059,h+80|0,b|0,h+32|0);b=v[22708];v[22708]=0;if((b|0)!=1){break T}f=P()|0;O()|0;break j}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[22708]=0;b=tz(b,d);d=v[22708];v[22708]=0;if((d|0)==1){break N}v[22708]=0;b=W(716,h+48|0,1,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break N}d=0;v[22708]=0;R(737,h+32|0,c+4|0);k=v[22708];v[22708]=0;e=1;if((k|0)==1){break Q}v[22708]=0;U(2059,h+80|0,b|0,h+32|0);b=v[22708];v[22708]=0;if((b|0)!=1){break T}f=P()|0;O()|0;vb(h+32|0);break l}d=0;v[22708]=0;Q(70,h+80|0,13837)|0;b=v[22708];v[22708]=0;e=0;if((b|0)==1){break O}}v[22708]=0;Q(1167,h+112|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break P}vb(h+80|0);if(e){vb(h+32|0);vb(h+48|0)}if(d){vb(h+32|0);vb(h+48|0)}v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;if((d|0)==1){break m}U:{if(b){v[22708]=0;Q(70,h+80|0,2580)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}break U}if(w[c+2|0]){v[22708]=0;Q(70,h+80|0,2576)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break U}break m}v[22708]=0;Q(70,h+80|0,13837)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}}v[22708]=0;Q(1167,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break M}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break i}f=P()|0;O()|0;break l}f=P()|0;O()|0;vb(h+80|0);if(!e){break k}vb(h+32|0);break l}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}vb(h+80|0);if(j>>>0<12){break v}v[22708]=0;b=Q(70,h+80|0,14905)|0;d=v[22708];v[22708]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){v[22708]=0;Q(1167,h+112|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break ba}vb(b);v[22708]=0;b=Q(70,h+80|0,14905)|0;d=v[22708];v[22708]=0;if((d|0)==1){break aa}v[22708]=0;Q(1167,h+96|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break $}vb(b);v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;if((d|0)==1){break _}ca:{if(b){b=0;v[22708]=0;d=Eo(c);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;v[h+28>>2]=d&4095;R(2106,h+80|0,h+28|0);d=v[22708];v[22708]=0;if((d|0)!=1){break ca}}f=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[22708]=0;b=sz(b,d);d=v[22708];v[22708]=0;if((d|0)==1){break Z}v[22708]=0;d=W(716,h+16|0,1,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break Z}v[22708]=0;R(737,h|0,c+5|0);e=v[22708];v[22708]=0;b=1;if((e|0)==1){break Y}v[22708]=0;U(2059,h+80|0,d|0,h|0);d=v[22708];v[22708]=0;if((d|0)!=1){break ca}f=P()|0;O()|0;vb(h);break n}b=0;v[22708]=0;Q(70,h+80|0,13833)|0;d=v[22708];v[22708]=0;if((d|0)==1){break W}}v[22708]=0;Q(1167,h+112|0,h+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break X}vb(h+80|0);if(b){vb(h);vb(h+16|0)}v[22708]=0;b=Bg(c);d=v[22708];v[22708]=0;if((d|0)==1){break o}da:{if(b){v[22708]=0;Q(70,h+80|0,8341)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}break da}if(w[c+3|0]){v[22708]=0;Q(70,h+80|0,8341)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break da}break o}v[22708]=0;Q(70,h+80|0,13833)|0;b=v[22708];v[22708]=0;if((b|0)==1){break o}}v[22708]=0;Q(1167,h+96|0,h+80|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break V}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break n}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}vb(h);break n}f=P()|0;O()|0;break c}vb(h+80|0);if(!f){break q}}ea:{fa:{if(Ab(h+112|0)>>>0>f>>>0){v[22708]=0;Y(151,h+80|0,h+112|0,0,f|0);b=v[22708];v[22708]=0;if((b|0)!=1){break fa}f=P()|0;O()|0;break c}if(g){b=Ab(h+112|0);v[22708]=0;b=W(716,h+80|0,f-b|0,32)|0;c=v[22708];v[22708]=0;if((c|0)==1){break s}v[22708]=0;Q(1167,h+112|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){f=P()|0;O()|0;vb(b);break c}vb(b);if(Ab(h+96|0)>>>0>f>>>0){break r}break ea}if(Ab(h+96|0)>>>0<=f>>>0){break q}break r}b=h+80|0;Eb(h+112|0,b);vb(b);if(Ab(h+96|0)>>>0>f>>>0){break r}if(!g){break q}}b=Ab(h+96|0);v[22708]=0;b=W(716,h+80|0,f-b|0,32)|0;c=v[22708];v[22708]=0;ga:{if((c|0)!=1){v[22708]=0;Q(1167,h+96|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break ga}vb(b);break q}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}v[22708]=0;Y(151,h+80|0,h+96|0,0,f|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=h+80|0;Eb(h+96|0,b);vb(b);break q}f=P()|0;O()|0;break c}v[22708]=0;U(2102,a|0,h+112|0,h+96|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}}vb(h+96|0);vb(h+112|0);gb=h+128|0;return}f=P()|0;O()|0;break c}vb(h+16|0);break c}f=P()|0;O()|0;break c}vb(h+48|0)}if(!d){break c}}vb(h+32|0)}vb(h+48|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}vb(h+96|0)}vb(h+112|0);S(f|0);L()}function ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-1344|0;gb=d;vc(b);h=gb-32|0;gb=h;f=h+24|0;_U(f,d+232|0);e=yb(f);f=v[h+28>>2];k=v[h+24>>2];v[h+8>>2]=k;v[h+12>>2]=f;v[h>>2]=k;v[h+4>>2]=f;f=b;k=h+16|0;cc(k,b,h);k=yb(k);if((k|0)==(e|0)){Rb(f,yb(h+24|0))}gb=h+32|0;a:{if((e|0)!=(k|0)){break a}if(!bV(d+232|0)){break a}if(!Pb(b,Qc(aV(d+232|0),jb))){break a}if(!c){p=1;break a}vc(b);b=le(d+232|0,b);v[22708]=0;R(817,d+216|0,b|0);f=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{if((f|0)!=1){xb(b);v[22708]=0;U(818,d+200|0,d+216|0,1196314451);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(818,d+184|0,d+216|0,1280331091);b=v[22708];v[22708]=0;if((b|0)!=1){if(cd(d+200|0)){break b}if(cd(d+184|0)){break b}v[22708]=0;R(367,a|0,1);b=v[22708];v[22708]=0;i:{if((b|0)==1){break i}v[22708]=0;Ag(a);b=v[22708];v[22708]=0;if((b|0)==1){break i}v[a+480188>>2]=4;v[a+480208>>2]=16842752;b=d+184|0;E=d,F=Vb(b),v[E+24>>2]=F;E=d,F=Zb(b),v[E+144>>2]=F;if(!Gb(d+24|0,d+144|0)){break h}k=c&2;j:{k:{while(1){h=v[d+24>>2];if(!fi(a)){break h}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[22708]=0;b=B(b&65535,104)+a|0;e=b+484380|0;R(424,e|0,1);f=v[22708];v[22708]=0;l:{m:{if((f|0)!=1){v[22708]=0;f=Q(819,h|0,d+232|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break m}if(!f){break c}if(bv(d+232|0)){break l}break c}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}v[22708]=0;f=Q(70,d+56|0,d+232|0)|0;m=v[22708];v[22708]=0;if((m|0)!=1){m=x[a+480190>>1];v[22708]=0;Q(301,((m<<5)+a|0)+946304|0,f|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break k}vb(f);f=w[d+268|0]|w[d+269|0]<<8|(w[d+270|0]<<16|w[d+271|0]<<24);v[e>>2]=f;v[b+484388>>2]=f;v[b+484384>>2]=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);u[b+484410>>1]=255;b=b+484414|0;u[b>>1]=x[b>>1]|2;if(k){b=Rc(d+56|0,8,1,0,0);v[22708]=0;W(329,b|0,e|0,h|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break j}}b=d+24|0;Fh(b);if(Gb(b,d+144|0)){continue}break h}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break f}a=P()|0;O()|0;break e}a=P()|0;O()|0;xb(b);break d}b=d+200|0;E=d,F=Vb(b),v[E+176>>2]=F;E=d,F=Zb(b),v[E+168>>2]=F;n=a+484360|0;n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!Gb(d+176|0,d+168|0)){break B}r=a+484344|0;p=1;y=c&1;k=d+1324|0;m=d+1328|0;o=d+1320|0;z=d+1318|0;A=a+484380|0;c=1;while(1){f=v[d+176>>2];if(!(c&1)){v[22708]=0;b=T(417,n|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}if(!b){break B}}$l(Sb(n));v[22708]=0;b=Q(820,f|0,d+232|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}if(!b|(w[z|0]|w[z+1|0]<<8)){break c}b=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);if(!b|b>>>0>4){break c}b=Sb(n);v[22708]=0;U(6,d+56|0,5,d+232|0);c=v[22708];v[22708]=0;if((c|0)==1){break n}v[22708]=0;R(418,b|0,d+56|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}vb(d+56|0);C:{if(y){b=m;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22708]=0;U(288,d+56|0,f|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break C}a=P()|0;O()|0;break g}v[22708]=0;T(215,d+120|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break p}Qw(d+56|0,d+120|0)}b=d+56|0;s=jc(d+144|0,b);xb(b);if(!y){xb(d+120|0)}Qb(d+56|0,0,64);j=1;C=1;D:{E:{while(1){v[22708]=0;b=(B(j,34)+d|0)+198|0;c=b+32|0;R(712,d+8|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break u}F:{if(!w[v[d+8>>2]]){break F}f=w[b- -64|0];if(f>>>0>15){break E}b=w[b+65|0];if(b>>>0>64){break E}if(!bv(c)){break E}if(!x[a+480190>>1]){break F}h=b<<2;e=f<<4;c=1;f=0;b=1;while(1){v[22708]=0;R(713,d+24|0,d+8|0);g=v[22708];v[22708]=0;G:{H:{if((g|0)!=1){v[22708]=0;g=Q(821,d+24|0,((c<<5)+a|0)+946304|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break H}vb(d+24|0);if(g){break G}E=wd(d+56|0,j),F=b,u[E>>1]=F;c=B(c,104)+a|0;g=c+484410|0;l=x[g>>1];if((l|0)!=255){f=b;if(w[c+484417|0]!=(e&255)|(h|0)!=(l|0)){break G}}t[c+484417|0]=e;u[g>>1]=h;break F}a=P()|0;O()|0;break q}a=P()|0;O()|0;vb(d+24|0);break q}b=b+1|0;c=b&65535;if(c>>>0<=x[a+480190>>1]){continue}break}c=f&65535;if(!c){break F}if(!fi(a)){break F}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;E=wd(d+56|0,j),F=b,u[E>>1]=F;b=x[a+480190>>1];v[22708]=0;f=B(b,104);b=f+A|0;Ol(b);g=v[22708];v[22708]=0;if((g|0)==1){break t}g=B(c,104)+A|0;$o(b,g);f=a+f|0;u[f+484410>>1]=h;t[f+484417|0]=e;v[22708]=0;Q(747,b|0,g|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break t}f=a+946304|0;b=f+(x[a+480190>>1]<<5)|0;c=f+(c<<5)|0;f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=f;f=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=f;f=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=f}C=j>>>0<31;j=j+1|0;if((j|0)!=32){continue}break}h=0;v[d+48>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;D=w[o|0]|w[o+1|0]<<8;c=64;l=65535;j=0;while(1){I:{if(!j){v[22708]=0;b=Q(191,d+144|0,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break A}if(!b){break I}}c=c+1|0;if(c>>>0>=64){v[22708]=0;l=W(544,r|0,64,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break A}if((l|0)==65535){break D}c=0;b=Sb(n);v[22708]=0;R(710,b|0,l|0);b=v[22708];v[22708]=0;if((b|0)==1){break A}}b=_b(r,l&65535);v[22708]=0;b=Xc(b,c,0);f=v[22708];v[22708]=0;if((f|0)==1){break s}if(!D){continue}e=0;f=0;while(1){g=(d+24|0)+B(e,7)|0;e=w[g+6|0];J:{if(e){t[g+6|0]=e-1;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;j=j-1|0;break J}v[22708]=0;e=Q(191,d+144|0,1)|0;i=v[22708];v[22708]=0;if((i|0)==1){break r}if(!e){break J}e=k;if(v[d+152>>2]==(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){h=Sb(n);e=Sb(n);v[22708]=0;e=T(468,e|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break r}bf(h,e);h=c}v[22708]=0;e=T(374,s|0)|0;i=v[22708];v[22708]=0;K:{if((i|0)!=1){e=e<<24>>24;if((e|0)>-1){break K}i=e&127;t[g+6|0]=i;e=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;e=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;j=j+i|0;break J}a=P()|0;O()|0;break q}if((e-1&255)>>>0<=35){t[b|0]=e+48}v[22708]=0;e=T(374,s|0)|0;i=v[22708];v[22708]=0;L:{M:{if((i|0)!=1){E=b,F=w[wd(d+56|0,e&31)|0],t[E+1|0]=F;if(!(e&128)){break M}t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];break L}a=P()|0;O()|0;break q}v[22708]=0;R(403,d+8|0,s|0);e=v[22708];v[22708]=0;N:{if((e|0)!=1){e=d+8|0;q=qd(e);i=w[e|0];if(i>>>0>19){break L}t[b+3|0]=w[(i<<1)+33264|0];q=w[q|0];t[b+5|0]=q;if((i|0)!=18|q>>>0<32){break N}t[b+3|0]=17;break L}a=P()|0;O()|0;break q}e=w[e|0];if(819137>>>e&1){break L}t[b+5|0]=w[(e<<1)+33265|0]|q&15}e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[g|0]=e;t[g+1|0]=e>>>8;t[g+2|0]=e>>>16;t[g+3|0]=e>>>24;e=w[b+4|0]|w[b+5|0]<<8;t[g+4|0]=e;t[g+5|0]=e>>>8}b=b+6|0;f=f+1|0;e=f&65535;if(D>>>0>e>>>0){continue}break}continue}break}if(!h&c>>>0>62){break D}b=l&65535;if((b|0)==65535){break D}b=_b(r,b);v[22708]=0;f=Ce(d+8|0,14,h&255);h=v[22708];v[22708]=0;if((h|0)!=1){c=Gh(Ue(f,c));v[22708]=0;Q(431,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break D}}a=P()|0;O()|0;break q}p=0}xb(d+144|0);if(C){break b}b=d+176|0;Fh(b);c=0;if(Gb(b,d+168|0)){continue}break}}v[22708]=0;Ri(n,0);b=v[22708];v[22708]=0;if((b|0)==1){break z}v[22708]=0;b=Q(2,d+232|0,3524)|0;c=v[22708];v[22708]=0;if((c|0)==1){break y}Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,d+232|0,3826)|0;c=v[22708];v[22708]=0;p=1;if((c|0)==1){break x}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;break b}a=P()|0;O()|0;break q}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0}xb(d+144|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(d+56|0);break g}a=P()|0;O()|0}jd(d+184|0)}jd(d+200|0)}ke(d+216|0)}S(a|0);L()}p=0}jd(d+184|0);jd(d+200|0);ke(d+216|0)}gb=d+1344|0;return p|0}function Mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-304|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!_u(b,d+208|0)){break j}if(!SU(d+208|0)){break j}if(!Pb(b,Qc(RU(d+208|0),jb))){break j}if(!c){n=1;break j}if(!Zc(b,w[d+208|4])){break j}Hd(a,268435456);Ag(a);v[a+480208>>2]=4;e=d+88|0;h=Tb(e,12448);Eb(a+1298304|0,h);vb(h);h=Tb(e,7552);Eb(a+1298316|0,h);vb(h);v[a+1298364>>2]=5;h=d+16|0;of(h,d+208|6,48,3);Bc(e,h);Eb(a+1298268|0,e);vb(e);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){e=0;while(1){u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;if(e>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;l=d+192|0;h=vh(l);k:{if(!e){break k}v[22708]=0;R(846,l|0,e|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;mr(l,e);e=v[22708];v[22708]=0;if((e|0)!=1){break k}}a=P()|0;O()|0;ci(h);S(a|0);L()}e=w[d+302|0]|w[d+303|0]<<8;v[22708]=0;U(838,b|0,l|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break i}s=mc(d+176|0);o=mc(d+160|0);e=w[d+301|0];v[22708]=0;W(564,b|0,s|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}h=w[d+300|0];e=0;v[22708]=0;W(564,b|0,o|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break f}if(w[d+300|0]){p=c&2;h=d+88|0;q=h|4;m=d+126|0;r=h|6;while(1){v[22708]=0;h=e;e=e+1|0;i=B(e,104)+a|0;g=i+484380|0;R(424,g|0,0);f=v[22708];v[22708]=0;l:{m:{if((f|0)!=1){f=Lb(o,h);if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break l}f=Lb(o,h);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22708]=0;f=Q(190,b|0,f|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(!f){break l}v[22708]=0;f=Q(839,b|0,d+88|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break c}if(!f){break l}v[22708]=0;Ke(d+72|0,2,r);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;R(324,d+16|0,d+72|0);f=v[22708];v[22708]=0;if((f|0)!=1){break m}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,d+16|0)|0;f=v[22708];v[22708]=0;n:{o:{p:{q:{r:{if((f|0)!=1){vb(d+16|0);v[22708]=0;Lk(d+72|0,2,m);f=v[22708];v[22708]=0;if((f|0)==1){break r}v[22708]=0;R(324,d+16|0,d+72|0);f=v[22708];v[22708]=0;if((f|0)==1){break r}v[22708]=0;Q(303,i+484423|0,d+16|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break q}vb(d+16|0);if(w[d+138|0]<=15){f=i+484414|0;u[f>>1]=x[f>>1]|32;u[i+484408>>1]=B(w[d+138|0],17)}t[d+16|0]=w[d+139|0];v[22708]=0;t[d+72|0]=64;f=ac(d+16|0,d+72|0);k=v[22708];v[22708]=0;if((k|0)==1){break p}u[i+484412>>1]=w[f|0];v[i+484404>>2]=w[d+141|0]|w[d+142|0]<<8;f=i+484384|0;v[f>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);k=i+484388|0;v[k>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[g>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break o}n=v[f>>2];f=v[k>>2];break n}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}n=v[f>>2]>>>1|0;v[f>>2]=n;f=v[k>>2]>>>1|0;v[k>>2]=f;v[g>>2]=v[g>>2]>>>1}s:{if(f>>>0<=n>>>0){break s}i=i+484414|0;u[i>>1]=x[i>>1]|2;if(!(w[d+140|0]&2)){break s}u[i>>1]=x[i>>1]|4}v[22708]=0;xk(g);i=v[22708];v[22708]=0;if((i|0)==1){break c}if(!p){break l}h=Lb(o,h);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);i=w[q|0];v[22708]=0;Q(190,b|0,h+i|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}h=Rc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[22708]=0;W(329,h|0,g|0,b|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){break l}e=P()|0;O()|0;break b}if(w[d+300|0]>e>>>0){continue}break}}n=1;t:{if(!(c&1)){break t}v[d+68>>2]=0;f=a+484360|0;$l(Sb(f));F=d,G=Vb(l),v[F+64>>2]=G;F=d,G=Zb(l),v[F+56>>2]=G;k=a+484344|0;if(Gb(d- -64|0,d+56|0)){c=d+88|0;r=c|5;p=c|4;while(1){h=v[d- -64>>2];c=h;u:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break u}c=Lb(s,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}if(!c){break u}v[22708]=0;R(842,b|0,d+88|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}if(!w[p|0]){break u}e=w[h|0]|w[h+1|0]<<8;c=e;t[d+16|0]=w[r|0];i=w[d+262|0];g=w[h+2|0];v[22708]=0;t[d+72|0]=i-g;i=ac(d+16|0,d+72|0);g=v[22708];v[22708]=0;if((g|0)==1){break d}q=w[i|0];i=w[h|0]|w[h+1|0]<<8;g=w[p|0];v[22708]=0;v[d+52>>2]=g+i;i=Mc(d+68|0,d+52|0);g=v[22708];v[22708]=0;if((g|0)==1){break e}v[d+68>>2]=v[i>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break u}y=c>>>6|0;e=e&63;A=0;while(1){v:{w:{x:{y:{z:{A:{B:{i=e>>>0>63;y=i+y|0;c=y&65535;if(tc(Sb(f))>>>0<=c>>>0){g=Sb(f);v[22708]=0;R(502,g|0,y+1&65535);g=v[22708];v[22708]=0;if((g|0)==1){break B}v[22708]=0;g=W(544,k|0,64,0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break B}F=sc(Sb(f),c),G=g,u[F>>1]=G}m=x[sc(Sb(f),c)>>1];v[22708]=0;c=me(k,m);g=v[22708];v[22708]=0;if((g|0)==1){break z}if(!c){break u}c=_b(k,m);g=w[h+2|0];v[22708]=0;z=i?0:e;e=Xc(c,z,g);c=v[22708];v[22708]=0;if((c|0)==1){break w}i=0;if(q){break A}break x}e=P()|0;O()|0;break b}while(1){v[22708]=0;R(844,d+72|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break y}c=d+72|0;g=qd(c);D=Ve(c);C=ej(c);E=fc(c);j=0;c=w[c|0];if((c-1&255)>>>0<=142){j=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+i|0]=j}t[e|0]=j;c=w[g|0];t[e+2|0]=1;t[e+1|0]=c;c=w[D|0];C:{if((c|0)!=255){t[e+4|0]=c;break C}t[e+2|0]=0}c=w[C|0];D:{if(c>>>0>22){break D}t[e+3|0]=w[c+33312|0];g=w[E|0];t[e+5|0]=g;c=e+5|0;E:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break D;case 4:t[c|0]=g&3|48;break D;case 7:if(Nb(l)>>>0<=g>>>0){break D}j=c;c=Lb(l,g);g=w[c|0]|w[c+1|0]<<8;t[j|0]=g>>>6;c=_b(k,m);j=x[a+480188>>1];v[22708]=0;c=Xc(c,z,j-1&65535);j=v[22708];v[22708]=0;if((j|0)!=1){t[c+3|0]=14;t[c+5|0]=g&63;break D}e=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(k,m);g=x[a+480188>>1];v[22708]=0;c=Xc(c,z,g-1&65535);g=v[22708];v[22708]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break D}e=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break D;case 12:v[22708]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[c|0]=w[g|0]|208;break D}e=P()|0;O()|0;break b;case 13:v[22708]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[c|0]=w[g|0]|192;break D}e=P()|0;O()|0;break b;case 14:v[22708]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22708];v[22708]=0;if((j|0)!=1){t[c|0]=w[g|0]|224;break D}e=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break D}j=g&240;if(!j|(j|0)==240){break D}t[c|0]=g|15;break D;case 9:case 18:break E;default:break D}}if(j&255){break D}t[e|0]=w[(d+16|0)+i|0]}e=e+6|0;i=i+1|0;if((q|0)!=(i|0)){continue}break}break x}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(q>>>0>=w[r|0]){break v}c=w[r|0];v[22708]=0;Q(318,b|0,B(c-q|0,5)|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break v}}e=P()|0;O()|0;break b}e=z+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}c=d- -64|0;Qe(c);if(Gb(c,d+56|0)){continue}break}}F:{a=v[d+68>>2];b=a&63;if(!b){break F}c=Sb(f);v[22708]=0;a=a>>>6|0;c=Q(472,c|0,a&65535)|0;e=v[22708];v[22708]=0;if((e|0)!=1){if(!c){break F}a=_b(k,x[sc(Sb(f),a&65535)>>1]);v[22708]=0;ca(845,a|0,b|0,0,1)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break F}}e=P()|0;O()|0;break b}a=Sb(f);F=d,G=Vb(a),v[F+88>>2]=G;F=d,G=Zb(a),v[F+16>>2]=G;if(!Gb(d+88|0,d+16|0)){break t}i=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){G:{if((i&65535)!=65535){break G}v[22708]=0;i=W(544,k|0,64,0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break G}e=P()|0;O()|0;break b}u[a>>1]=i}a=d+88|0;nf(a);if(Gb(a,d+16|0)){continue}break}}di(o);di(s);ci(l)}gb=d+304|0;return n|0}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}di(o);di(s)}ci(l);S(e|0);L()}function m$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=gb-1504|0;gb=e;vc(b);rs(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!Xw(b,e+1480|0)){break p}if(!cG(e+1480|0)){break p}if(!c){g=1;break p}E=e+1498|0;c=E;if(!qs(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break p}c=E;s=e+1492|0;if(!qs(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[s|0]|w[s+1|0]<<8)<<2)|0)){break p}Ww(a);G=e,H=Vw(),v[G+104>>2]=H;d=e+104|0;Uw(lj(a)+32|0,d);ps(d);n=v[lj(a)+32>>2];c=e+1494|0;v[e+1476>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);G=e,H=jm(b),v[G+1216>>2]=H;v[e+1176>>2]=214748364;c=e+1216|0;G=e,H=B(v[Fb(c,e+1176|0)>>2],20),v[G+104>>2]=H;Mt(n,v[Fb(e+1476|0,d)>>2]);Qb(c,0,256);C=dd(e+1200|0);q:{if(w[s|0]|w[s+1|0]<<8){k=e+1176|4;l=e+1192|0;D=e+1194|0;q=e+1190|0;i=e+1188|0;while(1){c=E;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;c=Q(190,b|0,c+(F<<2)|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}g=0;if(!c){break q}v[22708]=0;c=Q(191,b|0,4)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}if(!c){break q}v[22708]=0;d=T(192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break n}v[22708]=0;c=Q(190,b|0,d|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break n}if(!c){break q}v[22708]=0;c=Q(193,b|0,e+1176|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break m}if(!c){break q}c=w[i|0]|w[i+1|0]<<8;v[22708]=0;c=W(194,b|0,C|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break m}if(!c){break q}c=w[i|0]|w[i+1|0]<<8?v[C>>2]:0;f=w[i|0]|w[i+1|0]<<8;v[22708]=0;j=T(195,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break l}d=d+20|0;if(j>>>0<=d+(f<<3)>>>0){break q}j=d+((w[i|0]|w[i+1|0]<<8)<<3)|0;r:{if(!(t[q|0]&1)){f=0;if(!(w[i|0]|w[i+1|0]<<8)){break r}while(1){if(!c){break q}v[22708]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;h=v[22708];v[22708]=0;if((h|0)==1){break k}if(!d){break q}v[22708]=0;d=Q(190,b|0,j|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break k}if(!d){break q}d=c;h=d+4|0;h=vd(e+1168|0,kc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)),w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));v[22708]=0;m=v[h+4>>2];v[e+32>>2]=v[h>>2];v[e+36>>2]=m;U(197,e+104|0,b|0,e+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break j}if((yb(e+104|0)|0)!=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))){break q}c=c+8|0;f=f+1|0;if(f>>>0<(w[i|0]|w[i+1|0]<<8)>>>0){continue}break}break r}s:{t:{u:{v:{w:{if(w[q|0]&4){if(!c){break q}v[22708]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}if(!d){break q}u=kc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));r=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!r){break q}h=w[D|0]|w[D+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[22708]=0;d=Q(190,b|0,d+j|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}if(!d){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;d=Q(191,b|0,d-f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}if(!d){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;U(198,e+80|0,b|0,d-f|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;p=Lp(e+104|0,e+80|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}xb(e+80|0);m=0;y=0;j=0;x:{y:{z:{if(!(w[i|0]|w[i+1|0]<<8)){break z}while(1){A:{v[22708]=0;f=Q(200,p|0,h+1|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break A}d=h&15;o=x[(d<<1)+27376>>1];B:{C:{if(o>>>0<=f>>>0){v[22708]=0;d=w[d+27456|0];z=Q(200,p|0,d|0)|0;A=v[22708];v[22708]=0;if((A|0)==1){break A}d=z+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&15;break B}v[22708]=0;d=Q(200,p|0,4)|0;f=v[22708];v[22708]=0;if((f|0)==1){break A}if((d|0)==15){v[22708]=0;d=Q(200,p|0,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break A}f=65535;if(!d){break C}xb(e+104|0);break r}f=d+65520|0}if(f>>>0>65535){break B}}d=f&1?0-(f+1>>>1|0)|0:f>>>1|0;o=j+u|0;A=o;D:{if(w[q|0]&2){y=d+y|0;d=y;break D}d=w[q+1|0]&2?d:d^32768}f=d>>>8|0;z=(w[q|0]|w[q+1|0]<<8)&1024;t[A+1|0]=z?d:f;t[o|0]=z?f:d;j=j+2|0}if(j>>>0>=r>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break t}v[22708]=0;d=(m<<3)+c|0;f=W(196,d|0,n|0,v[e+1476>>2])|0;j=v[22708];v[22708]=0;if((j|0)==1){break A}if(!f){break v}r=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!r){break w}u=kc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break z}break}g=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break x}Z(g|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)==1){break y}}xb(e+104|0);break r}g=P()|0;O()|0}xb(e+104|0);break a}if(!c){break q}v[22708]=0;d=W(196,c|0,n|0,v[e+1476>>2])|0;f=v[22708];v[22708]=0;if((f|0)==1){break g}if(!d){break q}y=kc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));r=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[D|0]|w[D+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break q}v[22708]=0;d=Q(190,b|0,j|0)|0;f=v[22708];v[22708]=0;E:{F:{if((f|0)!=1){if(!d){break q}d=vd(e+72|0,e+1216|0,w[l|0]|w[l+1|0]<<8);v[22708]=0;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;U(201,e+104|0,b|0,e+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break F}if(yb(e+104|0)>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;d=Q(191,b|0,d-f|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break E}}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}if(!d){break q}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22708]=0;U(198,e+80|0,b|0,d-f|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;p=Lp(e+104|0,e+80|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}xb(e+80|0);u=0;j=0;m=0;G:{H:{I:{if(!(w[i|0]|w[i+1|0]<<8)){break I}while(1){J:{v[22708]=0;f=Q(200,p|0,h+1|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break J}d=h&7;o=w[d+27408|0];K:{L:{if(o>>>0<=f>>>0){v[22708]=0;d=w[d+27416|0];z=Q(200,p|0,d|0)|0;A=v[22708];v[22708]=0;if((A|0)==1){break J}d=z+(f-o<<d)|0;if((d|0)!=(h|0)){h=d&7;break K}v[22708]=0;d=Q(200,p|0,3)|0;f=v[22708];v[22708]=0;if((f|0)==1){break J}if((d|0)==7){v[22708]=0;d=Q(200,p|0,1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break J}f=255;if(!d){break L}xb(e+104|0);break r}f=d+248|0}if(f>>>0>255){break K}}d=w[(e+1216|0)+f|0];f=d+u|0;o=d;d=(w[q|0]|w[q+1|0]<<8)&2;t[j+y|0]=d?f:o;u=d?f:u;j=j+1|0}if(j>>>0>=r>>>0){m=m+1|0;if(m>>>0>=(w[i|0]|w[i+1|0]<<8)>>>0){break s}v[22708]=0;d=(m<<3)+c|0;f=W(196,d|0,n|0,v[e+1476>>2])|0;j=v[22708];v[22708]=0;if((j|0)==1){break J}if(!f){break u}r=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);y=kc(n,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));j=0}if((w[i|0]|w[i+1|0]<<8)>>>0>m>>>0){continue}break I}break}g=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break G}Z(g|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)==1){break H}}xb(e+104|0);break r}g=P()|0;O()|0}xb(e+104|0);break a}xb(e+104|0);break q}xb(e+104|0);break q}xb(e+104|0);break q}xb(e+104|0);break r}xb(e+104|0)}F=F+1|0;if(F>>>0<(w[s|0]|w[s+1|0]<<8)>>>0){continue}break}}v[22708]=0;Vd(e+56|0,n);b=v[22708];v[22708]=0;if((b|0)==1){break f}b=v[e+60>>2];v[e+24>>2]=v[e+56>>2];v[e+28>>2]=b;rh(e- -64|0,e+24|0);b=Ud(e+48|0);v[22708]=0;c=v[e+68>>2];v[e+16>>2]=v[e+64>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;b=W(203,e+104|0,e+16|0,e+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}Vc(lj(a)+12|0,b);xb(b);g=1}ms(C)}gb=e+1504|0;return g|0}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0;break a}g=P()|0;O()|0;xb(e+80|0);break a}g=P()|0;O()|0}ms(C);S(g|0);L()}function _E(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;k=gb-336|0;gb=k;m=h;n=i&65535;o=d;q=e&65535;t=(e^i)&-2147483648;B=i>>>16&32767;F=e>>>16&32767;a:{b:{if(B-1>>>0<32766?F-1>>>0<=32765:0){break b}u=e&2147483647;l=u;j=d;if(!(!j&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){G=d;t=e|32768;break a}u=i&2147483647;e=u;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){G=h;t=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;t=2147450880;break a}t=t|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){b=0;c=0;break a}if(!(b|j|(c|l))){b=!(d|f|(e|g));G=b?0:G;t=b?2147450880:t;b=0;c=0;break a}if(!(d|f|(e|g))){t=t|2147418112;b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){i=b;d=!(o|q);h=d<<6;j=E(d?b:o)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;Mf(k+320|0,i,c,o,q,b-15|0);p=16-b|0;o=v[k+328>>2];q=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(m|n);e=d<<6;h=E(d?f:m)+32|0;d=E(d?g:n);d=e+((d|0)==32?h:d)|0;Mf(k+304|0,f,g,m,n,d-15|0);p=(d+p|0)-16|0;m=v[k+312>>2];n=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=n|65536;D=e;u=m;d=m;j=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=j;i=1963258675-(j+((d|0)!=0)|0)|0;qf(k+288|0,d,j,0,0,h,i,0,0);j=v[k+296>>2];qf(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[k+280>>2];i=h<<1|v[k+276>>2]>>>31;h=v[k+284>>2]<<1|h>>>31;qf(k+256|0,i,h,0,0,d,e,0,0);j=h;h=v[k+264>>2];qf(k+240|0,i,j,0,0,0-h|0,0-(v[k+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+248>>2];l=v[k+252>>2]<<1|h>>>31;i=h<<1|v[k+244>>2]>>>31;h=l;qf(k+224|0,i,h,0,0,d,e,0,0);h=v[k+232>>2];qf(k+208|0,i,l,0,0,0-h|0,0-(v[k+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+216>>2];i=h<<1|v[k+212>>2]>>>31;h=v[k+220>>2]<<1|h>>>31;qf(k+192|0,i,h,0,0,d,e,0,0);j=h;h=v[k+200>>2];qf(k+176|0,i,j,0,0,0-h|0,0-(v[k+204>>2]+((h|0)!=0)|0)|0,0,0);j=d;h=v[k+184>>2];l=v[k+188>>2]<<1|h>>>31;d=h<<1|v[k+180>>2]>>>31;i=d-1|0;l=l-(d>>>0<1)|0;qf(k+160|0,j,e,0,0,i,l,0,0);e=f;qf(k+144|0,e<<15,g<<15|e>>>17,0,0,i,l,0,0);h=v[k+172>>2];n=v[k+160>>2];e=v[k+152>>2];d=n+e|0;m=v[k+164>>2];j=m+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(m|0)==(j|0)&n>>>0>e>>>0|j>>>0<m>>>0;m=n+v[k+168>>2]|0;j=h;j=m>>>0<n>>>0?j+1|0:j;h=m;m=!d&e>>>0>1|(d|0)!=0;h=h+m|0;j=h>>>0<m>>>0?j+1|0:j;qf(k+112|0,i,l,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);qf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,i,l,0,0);P=(F-B|0)+p|0;e=v[k+116>>2];z=e;d=v[k+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;e=j;i=v[k+140>>2];H=i;h=v[k+136>>2];j=i<<1|h>>>31;i=h<<1|v[k+132>>2]>>>31;d=i+m|0;l=e+j|0;l=d>>>0<i>>>0?l+1|0:l;i=d;d=l;e=i;j=d-(e>>>0<13927)|0;e=e-13927|0;l=j;I=j;h=0;p=h;j=q|65536;B=j;F=o;w=(j&2147483647)<<1|o>>>31;A=oqa(l,h,w,0);h=jb;r=A;s=h;h=c;L=(h&2147483647)<<1|b>>>31;J=L;x=0;l=(d|0)==(l|0)&e>>>0<i>>>0|d>>>0>l>>>0;m=(d|0)==(n|0)&i>>>0<m>>>0|d>>>0<n>>>0;d=v[k+120>>2];j=v[k+124>>2]<<1|d>>>31;i=H>>>31|0;d=i+(d<<1|z>>>31)|0;j=d>>>0<i>>>0?j+1|0:j;h=d;d=m+d|0;j=d>>>0<h>>>0?j+1|0:j;i=d;d=l+d|0;h=d>>>0<i>>>0?j+1|0:j;i=d-1|0;C=h-(d>>>0<1)|0;m=0;h=oqa(J,x,C,m);d=h+r|0;j=jb+s|0;j=d>>>0<h>>>0?j+1|0:j;h=j;r=(s|0)==(j|0)&d>>>0<r>>>0|j>>>0<s>>>0;j=0;A=j;z=j;R=0;j=o;Q=c>>>31|0;J=Q|j<<1;M=0;q=oqa(i,z,J,M);l=q+d|0;j=jb+h|0;j=l>>>0<q>>>0?j+1|0:j;n=l;q=j;j=(h|0)==(j|0)&d>>>0>l>>>0|h>>>0>j>>>0;d=j+r|0;h=0;h=d>>>0<j>>>0?1:h;l=oqa(w,K,C,m);d=l+d|0;j=jb+h|0;h=d>>>0<l>>>0?j+1|0:j;o=oqa(w,K,i,z);l=jb;s=d;z=oqa(C,m,J,M);d=z+o|0;j=jb+l|0;j=d>>>0<z>>>0?j+1|0:j;r=d;d=j;j=(l|0)==(j|0)&o>>>0>r>>>0|j>>>0<l>>>0;o=s+d|0;l=h+j|0;l=o>>>0<d>>>0?l+1|0:l;s=o;o=0;d=o+n|0;j=q+r|0;j=d>>>0<o>>>0?j+1|0:j;h=j;o=(q|0)==(j|0)&n>>>0>d>>>0|j>>>0<q>>>0;q=s+o|0;j=l;N=q;l=o>>>0>q>>>0?j+1|0:j;s=d;n=h;o=b<<1;q=c<<1|b>>>31;O=o&-2;r=oqa(i,A,O,0);h=jb;z=e;e=oqa(e,0,J,M);d=e+r|0;j=jb+h|0;j=d>>>0<e>>>0?j+1|0:j;r=(h|0)==(j|0)&d>>>0<r>>>0|h>>>0>j>>>0;h=d;e=j;S=r;H=oqa(I,p,L,x);d=H+d|0;j=jb+j|0;j=d>>>0<H>>>0?j+1|0:j;H=d;r=d;d=j;j=(j|0)==(e|0)&h>>>0>r>>>0|e>>>0>j>>>0;e=S+j|0;h=0;h=e>>>0<j>>>0?1:h;r=e;e=s+e|0;j=h+n|0;j=e>>>0<r>>>0?j+1|0:j;r=e;h=e;e=j;n=(j|0)==(n|0)&h>>>0<s>>>0|j>>>0<n>>>0;h=n+N|0;j=l;N=h;n=h>>>0<n>>>0?j+1|0:j;K=oqa(w,K,z,T);w=jb;l=oqa(C,m,O,U);h=l+K|0;j=jb+w|0;j=h>>>0<l>>>0?j+1|0:j;C=h;l=oqa(L,x,i,A);i=h+l|0;h=j;j=j+jb|0;j=i>>>0<l>>>0?j+1|0:j;m=i;A=oqa(I,p,J,M);i=i+A|0;l=j+jb|0;l=i>>>0<A>>>0?l+1|0:l;A=i;i=l;l=0;s=(i|0)==(j|0)&A>>>0<m>>>0|i>>>0<j>>>0;m=(h|0)==(j|0)&C>>>0>m>>>0|h>>>0>j>>>0;j=m+((h|0)==(w|0)&K>>>0>C>>>0|h>>>0<w>>>0)|0;h=0;m=s+j|0;j=m;h=r+i|0;j=(j|l)+e|0;j=h>>>0<i>>>0?j+1|0:j;s=h;m=j;h=(e|0)==(j|0)&h>>>0<r>>>0|e>>>0>j>>>0;e=h+N|0;j=n;C=e;n=e>>>0<h>>>0?j+1|0:j;r=s;w=H;I=oqa(I,p,O,U);p=jb;h=oqa(L,x,z,T);e=h+I|0;j=jb+p|0;j=e>>>0<h>>>0?j+1|0:j;l=j;j=0;h=(l|0)==(p|0)&e>>>0<I>>>0|l>>>0<p>>>0;e=l+w|0;j=(h|j)+d|0;j=e>>>0<l>>>0?j+1|0:j;h=e;s=(d|0)==(j|0)&h>>>0<w>>>0|d>>>0>j>>>0;l=j+A|0;p=0;i=p+h|0;d=i;l=d>>>0<p>>>0?l+1|0:l;e=(j|0)==(l|0)&d>>>0<h>>>0|j>>>0>l>>>0;d=s+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+r|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;i=(m|0)==(j|0)&d>>>0<r>>>0|j>>>0<m>>>0;h=i+C|0;l=n;l=h>>>0<i>>>0?l+1|0:l;i=l;c:{if((i|0)==131071|i>>>0<131071){j=F;l=B<<1|j>>>31;F=Q|j<<1;B=l|R;qf(k+80|0,d,e,h,i,f,g,u,D);l=b<<17;b=0;c=v[k+88>>2];m=b-c|0;j=v[k+80>>2];s=(j|0)!=0;n=v[k+84>>2];p=s|(n|0)!=0;x=m-p|0;p=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<p>>>0)|0;m=0-j|0;n=0-(n+s|0)|0;b=P+16382|0;break c}d=(e&1)<<31|d>>>1;j=h<<31|e>>>1;e=j;h=(i&1)<<31|h>>>1;i=i>>>1|0;qf(k+96|0,d,j,h,i,f,g,u,D);o=0;m=v[k+104>>2];n=o-m|0;j=v[k+96>>2];l=(j|0)!=0;q=v[k+100>>2];p=l|(q|0)!=0;x=n-p|0;p=((b<<16)-(v[k+108>>2]+(m>>>0>o>>>0)|0)|0)-(n>>>0<p>>>0)|0;m=0-j|0;n=0-(l+q|0)|0;o=b;q=c;b=P+16383|0}if((b|0)>=32767){t=t|2147418112;b=0;c=0;break a}d:{if((b|0)>=1){c=x;j=p<<1|c>>>31;x=c<<1|n>>>31;p=j;o=h;q=i&65535|b<<16;b=m;j=n<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}mm(k- -64|0,d,e,h,i,1-b|0);Mf(k+48|0,o,q,F,B,b+112|0);d=v[k+64>>2];e=v[k+68>>2];o=v[k+72>>2];q=v[k+76>>2];qf(k+32|0,f,g,u,D,d,e,o,q);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;m=v[k+36>>2];h=m;b=v[k+56>>2];m=h>>>31|i;i=b-m|0;l=v[k+60>>2]-((b>>>0<m>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;B=v[k+52>>2];j=B;b=v[k+48>>2];j=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;x=i-j|0;p=l-(i>>>0<j>>>0)|0;i=b;b=i-c|0;j=B-((c>>>0>i>>>0)+h|0)|0}qf(k+16|0,f,g,u,D,3,0,0,0);qf(k,f,g,u,D,5,0,0,0);i=d;c=e;l=f;f=g;r=o;m=0;h=j+m|0;n=d&1;d=b+n|0;h=d>>>0<b>>>0?h+1|0:h;o=d;g=h;l=(h|0)==(f|0)&d>>>0>l>>>0|f>>>0<h>>>0;d=(h|0)==(m|0)&n>>>0>d>>>0|h>>>0<m>>>0;b=d+x|0;j=p;j=b>>>0<d>>>0?j+1|0:j;h=b;f=j;d=(h|0)==(u|0)&(j|0)==(D|0)?l:(D|0)==(j|0)&h>>>0>u>>>0|j>>>0>D>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;e=(j|0)==(c|0)&d>>>0<i>>>0|c>>>0>j>>>0;c=r+e|0;j=q;i=c;j=i>>>0<e>>>0?j+1|0:j;c=j;e=d;l=i;d=v[k+20>>2];m=(d|0)==(g|0)&y[k+16>>2]<o>>>0|d>>>0<g>>>0;d=v[k+28>>2];i=v[k+24>>2];i=j>>>0<2147418112&((h|0)==(i|0)&(d|0)==(f|0)?m:(d|0)==(f|0)&i>>>0<h>>>0|d>>>0<f>>>0);d=e+i|0;j=b;j=d>>>0<i>>>0?j+1|0:j;i=d;d=j;e=(j|0)==(b|0)&e>>>0>i>>>0|b>>>0>j>>>0;b=l+e|0;j=c;j=b>>>0<e>>>0?j+1|0:j;e=j;l=b;b=v[k+4>>2];g=(b|0)==(g|0)&y[k>>2]<o>>>0|b>>>0<g>>>0;b=v[k+12>>2];c=v[k+8>>2];c=j>>>0<2147418112&((c|0)==(h|0)&(b|0)==(f|0)?g:(b|0)==(f|0)&c>>>0<h>>>0|b>>>0<f>>>0);b=c+i|0;j=d;j=b>>>0<c>>>0?j+1|0:j;c=j;f=(d|0)==(j|0)&b>>>0<i>>>0|d>>>0>j>>>0;d=l+f|0;j=e;G=d|G;t=t|(d>>>0<f>>>0?j+1|0:j)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=G;v[a+12>>2]=t;gb=k+336|0}function Xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-272|0;gb=e;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!xY(b,e+200|0)){break j}if(!yY(e+200|0)){break j}if(!c){d=1;break j}Hd(a,131072);d=gb-16|0;gb=d;i=e+104|0;f=Tb(d,1061);Dc(i,f);vb(f);gb=d+16|0;v[22708]=0;U(463,e+152|0,i|0,e+200|4);d=v[22708];v[22708]=0;if((d|0)==1){break i}d=e+152|0;Eb(a+1298304|0,d);vb(d);i=e+104|0;Hb(i);f=Tb(d,8333);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;Lr(i,3,e+213|0);Bc(d,i);Eb(a+1298268|0,d);vb(d);f=e+80|0;Zj(f,3,e+243|0);Bc(i,f);v[22708]=0;U(13,d|0,5,i|0);d=v[22708];v[22708]=0;k:{l:{m:{n:{o:{if((d|0)!=1){d=e+152|0;Eb(a+1298280|0,d);vb(d);vb(e+104|0);d=Er(d);m=d,n=Fd(w[e+263|0],1,31),v[m+12>>2]=n;m=d,n=Fd(w[e+264|0],1,12)-1|0,v[m+16>>2]=n;v[d+20>>2]=w[e+265|0];i=a+1298368|0;qD(i);vY(i,d);h=e+112|0;j=e+40|4;i=hh(e+136|0);while(1){v[22708]=0;d=Q(191,b|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}if(!d){break k}v[22708]=0;R(464,b|0,e+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);d=w[e+204|0];p:{if((d|0)==3){g=2;if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1431389523){break p}d=w[e+204|0]}if((d&255)==4){g=4;if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1431389523){break p}d=w[e+204|0]}g=0;if((d&255)>>>0>7){break p}f=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))==1146113363?-1:f}d=v[e+44>>2];v[e+104>>2]=v[e+40>>2];v[e+108>>2]=d;v[22708]=0;U(288,e+80|0,b|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}jc(h,e+80|0);v[22708]=0;R(465,i|0,e+104|0);d=v[22708];v[22708]=0;if((d|0)==1){break l}ed(e+104|0);xb(e+80|0);v[22708]=0;Q(318,b|0,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e+104|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(e+104|0);xb(e+80|0);break b}v[22708]=0;b=T(215,e+104|0)|0;d=v[22708];v[22708]=0;q:{r:{s:{if((d|0)!=1){v[22708]=0;U(466,e+80|0,i|0,1431389523);d=v[22708];v[22708]=0;if((d|0)==1){break s}d=e+80|0;Vc(b,d);xb(d);u[e+78>>1]=0;u[e+76>>1]=65534;if(w[e+204|0]<3){break q}v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break r}break d}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}u[e+78>>1]=d;if(w[e+204|0]<4){break q}v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}u[e+76>>1]=w[e+204|0]==4?d?d:-2:d}d=a+484360|0;f=Sb(d);v[22708]=0;g=T(467,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break d}v[22708]=0;fa(362,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}f=Sb(d);v[22708]=0;f=T(468,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}yg(e+78|0,f);f=Sb(d);v[22708]=0;f=T(468,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}yg(e+76|0,f);v[22708]=0;U(466,e+80|0,i|0,1414807888);f=v[22708];v[22708]=0;t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){f=e+80|0;Vc(b,f);xb(f);v[22708]=0;f=T(275,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}if(!f|!(c&1)){break t}v[22708]=0;R(469,b|0,e+72|0);f=v[22708];v[22708]=0;if((f|0)==1){break A}m=a,n=Fd(w[e+72|2],1,32)+1|0,u[m+480188>>1]=n;f=w[e+72|0]|w[e+73|0]<<8;v[22708]=0;f=Q(328,e|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break z}m=e,n=Vb(f),v[m+24>>2]=n;m=e,n=Zb(f),v[m+64>>2]=n;if(Gb(e+24|0,e- -64|0)){while(1){j=v[e+24>>2];v[22708]=0;g=w[e+204|0]<3?9:8;Q(318,b|0,g-4|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break y}v[22708]=0;h=T(192,b|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break x}pg(b,g);v[22708]=0;U(288,e+40|0,b|0,g+h|0);g=v[22708];v[22708]=0;if((g|0)==1){break w}h=j;g=e+80|0;j=e+40|0;Vc(h,jc(g,j));xb(g);xb(j);g=e+24|0;Fh(g);if(Gb(g,e- -64|0)){continue}break}}g=x[a+480188>>1];v[22708]=0;g=Q(470,e+80|0,g|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}h=Zl(Sb(d));v[22708]=0;j=a+484344|0;R(330,j|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break f}h=Sb(d);m=e,n=Vb(h),v[m+40>>2]=n;m=e,n=Zb(h),v[m+24>>2]=n;if(Gb(e+40|0,e+24|0)){while(1){h=v[e+40>>2];k=x[h>>1];if(Je(f)>>>0>k>>>0){k=Kg(f,x[h>>1]);v[22708]=0;k=ca(471,k|0,w[e+204|0],g|0,a|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break f}u[h>>1]=k}h=e+40|0;nf(h);if(Gb(h,e+24|0)){continue}break}}h=Sb(d);v[22708]=0;h=Q(472,h|0,x[e+76>>1])|0;k=v[22708];v[22708]=0;if((k|0)==1){break f}if(!h){break u}if(!x[e+78>>1]){h=x[e+76>>1];k=Sb(d);v[22708]=0;k=T(468,k|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break f}if(h>>>0>=k>>>0){break u}}d=x[sc(Sb(d),x[e+76>>1])>>1];h=_b(j,d);v[22708]=0;k=Ce(e+40|0,12,w[e+78|0]);l=v[22708];v[22708]=0;if((l|0)!=1){d=pp(Ue(k,v[_b(j,d)+12>>2]-1|0));v[22708]=0;Q(431,h|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break u}}break f}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}kD(g);jd(f)}v[22708]=0;U(466,e+80|0,i|0,1196641603);d=v[22708];v[22708]=0;if((d|0)==1){break h}d=e+80|0;Vc(b,d);xb(d);v[22708]=0;d=T(275,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}if(d){v[22708]=0;Q(318,b|0,1)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;d=T(467,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}v[22708]=0;fa(473,a+1298292|0,b|0,d|0,40,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}}v[22708]=0;U(466,e+80|0,i|0,1146113363);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;U(466,e+40|0,i|0,1229999443);d=v[22708];v[22708]=0;B:{C:{if((d|0)!=1){d=e+40|0;Vc(b,d);xb(d);v[22708]=0;f=T(374,b|0)|0;g=v[22708];v[22708]=0;d=1;D:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){j=c&2;g=1;while(1){f=30;E:{F:{G:{if(w[e+204|0]>=2){v[22708]=0;f=T(374,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}}v[22708]=0;W(474,b|0,((d<<5)+a|0)+946304|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break G}v[22708]=0;R(475,b|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break F}v[22708]=0;c=B(d,104)+a|0;f=c+484380|0;R(476,e+24|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break F}d=w[e+204|0];if(d>>>0>=8){v[22708]=0;W(477,b|0,c+484423|0,8)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}d=w[e+204|0]}v[22708]=0;Q(318,b|0,((d&255)>>>0>1?6:2)|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}v[22708]=0;d=T(192,e+80|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(288,e|0,e+80|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){break E}}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}d=e+40|0;h=jc(d,e);xb(e);v[22708]=0;d=T(275,d|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break D}H:{if(!d|!j){break H}c=Rc(e,u[c+484414>>1]&1?16:8,1,0,(w[e+39|0]&12)==4?7:0);v[22708]=0;W(329,c|0,f|0,h|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break H}break D}xb(e+40|0);g=g+1|0;d=g&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22708]=0;Ag(a);c=v[22708];v[22708]=0;d=1;if((c|0)!=1){break B}}a=P()|0;O()|0;break C}a=P()|0;O()|0;xb(e+40|0);break C}a=P()|0;O()|0}xb(e+80|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;xb(e+80|0);xb(b);ke(i)}gb=e+272|0;return d|0}a=P()|0;O()|0;Hb(e+104|0);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;kD(g)}jd(f);break c}a=P()|0;O()|0}xb(b)}ke(i)}S(a|0);L()}function Woa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=gb-272|0;gb=e;vc(b);f=gb-32|0;gb=f;d=f+24|0;l=e+112|0;AX(d,l);g=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(g|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(i|0);if(!d){zX(l)}a:{b:{c:{d:{if(!d){break d}if(!BX(e+112|0)){break d}if(!c){h=1;break d}Hd(a,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+28624>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=Tb(d,10441);Eb(a+1298304|0,f);vb(f);f=Tb(d,7583);Eb(a+1298316|0,f);vb(f);f=gb-16|0;gb=f;h=e+8|0;g=Tb(f,1498);Dc(h,g);vb(g);gb=f+16|0;v[22708]=0;Y(349,d|0,h|0,e+191|0,e+188|0);d=v[22708];v[22708]=0;e:{f:{if((d|0)!=1){d=e+48|0;Eb(a+1298328|0,d);vb(d);f=e+8|0;Hb(f);Wc(a+1298352|0,((w[e+228|0]|w[e+229|0]<<8)<<2)+28672|0);Wc(a+1298340|0,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+28720>>2]);v[a+1298364>>2]=5;Ke(f,2,e+112|4);Bc(d,f);Eb(a+1298268|0,d);vb(d);Ke(f,2,e+148|0);Bc(d,f);g:{if(yr(d,6892)){v[22708]=0;U(13,e+8|0,5,e+48|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}d=e+8|0;Eb(a+1298280|0,d);vb(d)}vb(e+48|0);u[a+480188>>1]=32;d=0;h:{while(1){h=(d<<5)+a|0;g=h+480280|0;We(g);i:{f=d+e|0;if(w[f+193|0]<=15){v[e+48>>2]=w[f+193|0]<<4|8;v[e+8>>2]=256;s=h+480284|0,y=v[pd(e+48|0,e+8|0)>>2],u[s>>1]=y;break i}if(w[f+193|0]==16){u[h+480284>>1]=128;v[g>>2]=256;break i}if(w[f+193|0]!=255){break i}u[a+480188>>1]=d;break h}d=d+1|0;if((d|0)!=32){continue}break}d=x[a+480188>>1]}h=0;if(!(d&65535)){break d}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;s=a,y=v[Fb(e+48|0,e+8|0)>>2],v[s+480200>>2]=y;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Zc(b,w[e+230|0]|w[e+231|0]<<8|(w[e+232|0]<<16|w[e+233|0]<<24))){jp(Sb(a+484360|0),b,w[e+234|0]+1|0,255,254)}if(!Zc(b,w[e+240|0]|w[e+241|0]<<8|(w[e+242|0]<<16|w[e+243|0]<<24))){break d}u[a+480190>>1]=w[e+248|0]+1;i=e+80|0;d=1;l=1;while(1){h=gb-32|0;gb=h;f=h+24|0;k=e+48|0;bc(f,k,62);g=yb(f);f=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=f;v[h>>2]=j;v[h+4>>2]=f;j=h+16|0;f=b;cc(j,f,h);j=yb(j);if((j|0)==(g|0)){Rb(f,yb(h+24|0))}gb=h+32|0;f=(g|0)==(j|0);if(!f){Qb(k,0,62)}if(f){f=B(d,104)+a|0;h=f+484380|0;ud(h,0);g=e+32|0;Ke(g,2,e+48|0);k=e+8|0;Bc(k,g);v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,k|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=e+8|0;vb(d);g=e+32|0;Lk(g,2,i);Bc(d,g);v[22708]=0;Q(303,f+484423|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}vb(e+8|0);d=f+484404|0;v[d>>2]=w[e+106|0]|w[e+107|0]<<8;j:{if(!hp(a)){break j}g=v[d>>2];d=0;while(1){if((g|0)==x[(d<<1)+28768>>1]){t[f+484417|0]=d<<4;break j}d=d+1|0;if((d|0)!=16){continue}break}}u[f+484412>>1]=64;v[h>>2]=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);if(w[e+105|0]&2){d=f+484414|0;u[d>>1]=x[d>>1]|1;v[h>>2]=v[h>>2]>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(t[e+105|0]&1){d=f+484414|0;u[d>>1]=x[d>>1]|2}k:{if(!(!(w[e+105|0]&4)|w[e+108|0]==255)){t[e+8|0]=w[e+108|0];t[e+32|0]=64;s=f+484410|0,y=w[ac(e+8|0,e+32|0)|0]<<2,u[s>>1]=y;break k}d=f+484414|0;u[d>>1]=x[d>>1]|32768}l:{if(!(w[e+105|0]&8)){u[f+484408>>1]=128;break l}d=f+484414|0;u[d>>1]=x[d>>1]|32;m=f+484408|0;if(w[e+109|0]<=15){f=w[e+109|0];v[e+32>>2]=256;v[e+8>>2]=f<<4|8;f=v[pd(e+8|0,e+32|0)>>2]}else{f=128}u[m>>1]=f;u[d>>1]=x[d>>1]&65279|(w[e+109|0]==16)<<8}l=l+1|0;d=l&65535;if(d>>>0<=x[a+480190>>1]){continue}}break}m:{if(!(c&2)){break m}if(!Zc(b,w[e+244|0]|w[e+245|0]<<8|(w[e+246|0]<<16|w[e+247|0]<<24))|!x[a+480190>>1]){break m}d=1;while(1){f=B(d&65535,104)+a|0;Cg(Rc(e+48|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}o=a+484344|0;zg(o,w[e+239|0]+1|0);f=zq(a);d=gb-16|0;gb=d;v[d+12>>2]=0;eu(d+12|0,f);i=v[d+12>>2];gb=d+16|0;Zc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));q=c&1;k=0;l=1;n:{while(1){o:{d=Ng(b);if(d>>>0>=3){c=e+8|0;Td(c,b,d-2|0);j=jc(e+48|0,c);xb(c);p:{if(!q){break p}v[22708]=0;c=T(275,e+48|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}if(!c){break p}v[22708]=0;c=W(331,o|0,k&65535,64)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}n=0;if(!c){break p}while(1){c=_b(o,k);v[22708]=0;r=Uf(c,n);c=v[22708];v[22708]=0;if((c|0)==1){break f}q:while(1){v[22708]=0;c=T(374,j|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}r:{if(!c){break r}d=c&31;if(d>>>0>=x[a+480188>>1]){break r}f=B(d,6)+r|0;if(c&32){v[22708]=0;R(403,e+8|0,j|0);d=v[22708];v[22708]=0;if((d|0)==1){break f}d=e+8|0;h=qd(d);g=w[d|0];if(g){m=d;d=(g&127)-1|0;t[m|0]=d;t[f|0]=(B((d&240)>>>4|0,12)+(d&15)|0)+13;v[22708]=0;d=yv(f);g=v[22708];v[22708]=0;if((g|0)==1){break f}l=d&l}t[f+1|0]=w[h|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;h=f+5|0;while(1){v[22708]=0;c=Q(191,e+48|0,2)|0;d=v[22708];v[22708]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((d|0)!=1){if(!c){continue q}p=w[h|0];c=w[f+3|0];v[22708]=0;R(403,e+8|0,j|0);d=v[22708];v[22708]=0;if((d|0)==1){break f}d=e+8|0;m=d;g=w[qd(d)|0];t[h|0]=g;d=w[(w[d|0]&31)+28800|0];t[f+3|0]=d;switch(d-2|0){case 4:case 5:break w;case 18:break x;case 13:break y;case 17:break z;case 11:break A;case 0:case 1:break B;default:break t}}break f}if(g>>>0<224){break u}d=223;if(v[a+480180>>2]!=1){break v}break u}v[22708]=0;t[e+32|0]=64;d=ac(h,e+32|0);g=v[22708];v[22708]=0;if((g|0)!=1){t[h|0]=w[d|0];v[22708]=0;d=uz(i,1);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(!d){break u}t[f+2|0]=1;t[f+4|0]=w[h|0];t[f+3|0]=c;t[h|0]=p;d=c;break t}break f}C:{switch(((g&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[h|0]=g&15|224;break s;case 1:t[f+3|0]=3;t[h|0]=g&15|224;break s;default:break C}}v[22708]=0;d=pq(i,19);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(d){break u}v[22708]=0;Yt(f);d=v[22708];v[22708]=0;if((d|0)!=1){break u}break f}v[22708]=0;d=pq(i,15);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(d){break u}v[22708]=0;d=pq(i,19);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(!d){break u}t[f+3|0]=19;t[h|0]=w[h|0]&15|144;break s}d=145;if((g|0)==1){break v}if((g&240)==128){v[22708]=0;d=pq(i,20);g=v[22708];v[22708]=0;if((g|0)==1){break f}if(d){break u}t[f+3|0]=19;break s}t[f+3|0]=0;break s}d=g&240;if(!d){break u}}t[h|0]=d}d=w[f+3|0]}if((d&255)!=20){break s}d=w[h|0];if(w[f+2|0]|(d&240)!=128){break s}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[h|0]=p}if(w[m|0]&32){continue}break}continue}break}n=n+1|0;if((n|0)!=64){continue}break}}xb(e+48|0)}c=w[e+239|0]>k>>>0;k=k+1|0;if(c){continue}break e}break}break f}break f}d=P()|0;O()|0;vb(e+48|0);break a}d=P()|0;O()|0;Hb(e+8|0);break a}d=P()|0;O()|0;xb(e+48|0);break a}c=a;if(v[a+480180>>2]!=1){d=v[a+480208>>2]&-8454145}else{d=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?l&1?8454144:0:0)}v[c+480208>>2]=d;h=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break d}if(!Zc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break d}oB(a+1298292|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4)}gb=e+272|0;return h|0}d=P()|0;O()|0;vb(e+8|0);break a}d=P()|0;O()|0;vb(e+8|0)}S(d|0);L()}function _Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=gb-224|0;gb=g;vc(b);a:{if(!uE(b,g+176|0)){break a}if(!vE(g+176|0)){break a}if(!c){h=1;break a}Hd(a,2048);Ag(a);d=gb-16|0;gb=d;f=g+8|0;e=Tb(d,1075);Dc(f,e);vb(e);gb=d+16|0;v[22708]=0;l=g+176|3;U(316,g+80|0,f|0,l|0);d=v[22708];v[22708]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){d=g+80|0;Eb(a+1298304|0,d);vb(d);f=g+8|0;Hb(f);e=Tb(d,8337);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;u[a+480188>>1]=w[g+216|0];u[a+480190>>1]=w[g+212|0];Ke(f,2,g+176|4);Bc(d,f);Eb(a+1298268|0,d);vb(d);if(w[l|0]<=8){u[a+480188>>1]=4;pg(b,1);yh(a,1)}d=w[l|0];n:{if(w[l|0]>=11){f=d>>>0>11?32:16;e=0;d=0;while(1){j=rE(b);o:{if((j|0)==100){v[((e<<5)+a|0)+480280>>2]=256;break o}v[g+80>>2]=(j<<1)+128;v[g+8>>2]=0;v[g+160>>2]=256;y=((e<<5)+a|0)+480284|0,z=v[dj(g+80|0,g+8|0,g+160|0)>>2],u[y>>1]=z}d=d+1|0;e=d&65535;if(f>>>0>e>>>0){continue}break}break n}if(d>>>0<9){break n}d=g+80|0;e=gb-32|0;gb=e;f=b;p:{if(!Pb(f,16)){f=gb-16|0;gb=f;j=d+16|0;while(1){Jf(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=f+16|0;break p}fw(e+24|0,d);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kd(e+16|0,f,e+8|0)}gb=e+32|0;e=0;while(1){u[((e<<5)+a|0)+480284>>1]=t[(g+80|0)+e|0]&1?64:192;e=e+1|0;if((e|0)!=16){continue}break}}q:{if(w[l|0]>=13){e=g+80|0;iw(e,b);j=qd(e);f=a;d=w[e|0];if(d>>>0<=31){t[e|0]=125;d=125}v[f+480204>>2]=B(d,1e4);v[a+480196>>2]=w[j|0];break q}v[a+480196>>2]=6;v[a+480204>>2]=125e4}d=a+484360|0;Bf(Sb(d),w[g+213|0]);n=mc(g+160|0);i=v[b+8>>2];r=w[l|0];r:{if(w[l|0]<14){break r}f=w[g+213|0];v[22708]=0;R(317,n|0,f|0);f=v[22708];v[22708]=0;if((f|0)!=1){break r}a=P()|0;O()|0;break e}s:{if(w[g+213|0]){e=0;while(1){y=sc(Sb(d),e),z=e,u[y>>1]=z;if(w[l|0]>=14){v[22708]=0;f=T(287,b|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break s}y=sc(n,e),z=f,u[y>>1]=z}f=x[a+480188>>1];v[22708]=0;Q(318,b|0,f<<1)|0;f=v[22708];v[22708]=0;if((f|0)==1){break s}e=e+1|0;if(e>>>0<w[g+213|0]){continue}break}}d=0;t:{u:{if(w[l|0]==10){j=v[b+8>>2];d=0;v:{if(!x[a+480190>>1]){break v}e=1;while(1){v[22708]=0;d=Q(319,b|0,g+80|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break u}w:{if(!d){break w}f=0;d=g+80|0;x:{if(w[d|0]>1|w[g+212|0]<(w[d+46|0]|w[d+47|0]<<8|(w[d+48|0]<<16|w[d+49|0]<<24))>>>0|((w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0>1048576|w[d+56|0]>64)){break x}if((w[d+57|0]|w[d+58|0]<<8|(w[d+59|0]<<16|w[d+60|0]<<24))>>>0>(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0){break x}f=(w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24))>>>0<=(w[d+50|0]|w[d+51|0]<<8|(w[d+52|0]<<16|w[d+53|0]<<24))>>>0}if(f){break w}d=1;break v}e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}d=0}v[22708]=0;Q(190,b|0,j|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break t}}f=x[a+480190>>1];v[22708]=0;v[g+80>>2]=0;q=W(320,g- -64|0,f|0,g+80|0)|0;f=v[22708];v[22708]=0;e=1;if((f|0)!=1){if(x[a+480190>>1]){o=d?59:65;j=g+80|1;f=1;while(1){y:{if(w[l|0]<=9){v[22708]=0;R(321,b|0,g+80|0);h=v[22708];v[22708]=0;z:{A:{B:{if((h|0)==1){break B}v[22708]=0;R(322,g+80|0,(B(e,104)+a|0)+484380|0);h=v[22708];v[22708]=0;if((h|0)==1){break B}v[22708]=0;Ke(g+48|0,2,j);h=v[22708];v[22708]=0;if((h|0)==1){break A}v[22708]=0;R(324,g+8|0,g+48|0);h=v[22708];v[22708]=0;if((h|0)==1){break A}v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,g+8|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break z}break y}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(g+8|0);break f}v[22708]=0;U(325,b|0,g+80|0,o|0);h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;U(326,g+80|0,(B(e,104)+a|0)+484380|0,d|0);h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;Ke(g+48|0,2,j);h=v[22708];v[22708]=0;if((h|0)==1){break h}v[22708]=0;R(324,g+8|0,g+48|0);h=v[22708];v[22708]=0;if((h|0)==1){break h}v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,g+8|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break i}}vb(g+8|0);h=w[g+126|0]|w[g+127|0]<<8|(w[g+128|0]<<16|w[g+129|0]<<24);y=Lb(q,e-1|0),z=h,v[y>>2]=z;f=f+1|0;e=f&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}j=mc(g+48|0);d=w[g+214|0]|w[g+215|0]<<8;v[22708]=0;h=W(327,b|0,j|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break m}if(!h){break b}d=0;if(!cd(j)){f=Vb(j);e=Zb(j);d=gb-32|0;gb=d;v[d+16>>2]=e;v[d+24>>2]=f;C:{if(!Gb(d+24|0,d+16|0)){break C}v[d>>2]=f;e=nf(d);if(!Gb(e,d+16|0)){break C}while(1){if(mE(v[d+24>>2],v[e>>2])){f=v[d>>2];v[d+24>>2]=f}if(Gb(nf(e),d+16|0)){continue}break}}gb=d+32|0;v[g+80>>2]=f;d=v[g+80>>2];d=w[d|0]|w[d+1|0]<<8}v[22708]=0;f=d;o=Q(328,g+32|0,d|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){D:{if(f){e=0;while(1){v[22708]=0;k=T(287,b|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break l}v[22708]=0;Q(318,b|0,1)|0;m=v[22708];v[22708]=0;if((m|0)==1){break l}if(k){m=w[l|0];v[22708]=0;U(288,g+8|0,b|0,B(k,3)+((m|0)==1?3:0)|0);k=v[22708];v[22708]=0;if((k|0)==1){break D}k=g+80|0;m=g+8|0;p=jc(k,m);Vc(Kg(o,e),p);xb(k);xb(m)}e=e+1|0;if((f|0)!=(e|0)){continue}break}}E:{if(!(c&2)){break E}f=1;m=Rc(g+80|0,8,1,0,1);if(!x[a+480190>>1]){break E}k=1;while(1){v[22708]=0;e=Q(191,b|0,1)|0;p=v[22708];v[22708]=0;F:{if((p|0)!=1){if(!e){break E}e=0;if(!x[a+480190>>1]){break F}p=v[b+8>>2];while(1){G:{H:{if(v[Lb(q,e)>>2]!=(f|0)){e=e+1|0;break H}v[22708]=0;Q(190,b|0,p|0)|0;s=v[22708];v[22708]=0;if((s|0)==1){break G}v[22708]=0;e=e+1|0;W(329,m|0,(B(e,104)+a|0)+484380|0,b|0)|0;s=v[22708];v[22708]=0;if((s|0)==1){break G}}if(x[a+480190>>1]>e>>>0){continue}break F}break}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}k=k+1|0;f=k&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}if(!(c&1)){break c}f=w[g+213|0];c=0;v[22708]=0;k=a+484344|0;R(330,k|0,f|0);f=v[22708];v[22708]=0;I:{if((f|0)!=1){if(!w[g+213|0]){break c}r=i+((r>>>0>13)<<1)|0;while(1){J:{e=64;if(tc(n)>>>0>c>>>0){e=x[sc(n,c)>>1]}v[22708]=0;f=W(331,k|0,c&65535,e&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break I}K:{if(f){f=x[a+480188>>1];e=w[l|0];v[22708]=0;Q(190,b|0,r+B(((e>>>0>13)<<1)+(f<<1)|0,c)|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break I}f=mc(g+80|0);e=x[a+480188>>1];v[22708]=0;e=W(327,b|0,f|0,e|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break K}L:{if(!e){break L}e=0;if(!x[a+480188>>1]){break L}while(1){M:{i=sc(f,e);if(!(w[i|0]|w[i+1|0]<<8)){break M}i=sc(f,e);if((w[i|0]|w[i+1|0]<<8)>>>0>(w[g+214|0]|w[g+215|0]<<8)>>>0){break M}i=sc(f,e);i=sc(j,(w[i|0]|w[i+1|0]<<8)-1|0);i=w[i|0]|w[i+1|0]<<8;if(!i|d>>>0<i>>>0){break M}m=_b(k,c);i=Kg(o,i-1&65535);v[22708]=0;U(332,m|0,e&65535,i|0);i=v[22708];v[22708]=0;if((i|0)!=1){break M}break J}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}Pk(f)}c=c+1|0;if(c>>>0>=w[g+213|0]){break c}continue}}break}a=P()|0;O()|0;Pk(f);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Hb(g+8|0);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0}jd(o)}Pk(j);break f}a=P()|0;O()|0;vb(g+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}Lc(q)}Ye(n)}S(a|0);L()}jd(o)}Pk(j);Lc(q);Ye(n)}gb=g+224|0;return h|0}function G2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2508;b=l+96|0;r=ge(l+136|0,l+144|0,b);k=v[r>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;u=Kb(b);m=Kb(l+80|0);n=Kb(l- -64|0);o=Kb(l+48|0);s=Kb(l+32|0);v[22708]=0;na(2517,c|0,d|0,l+120|0,l+116|0,l+112|0,u|0,m|0,n|0,o|0,l+28|0);b=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;p=v[l+28>>2];e=0;f:{while(1){v[22708]=0;b=Q(2486,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}g:{if(!b){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+q|0]){case 1:if((q|0)==3){break g}v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;b=W(2518,h|0,8192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(b){v[22708]=0;R(2519,l+16|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[l+16>>2];v[22708]=0;R(63,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((q|0)==3){break g}}while(1){v[22708]=0;b=Q(2486,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break h}v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;b=W(2518,h|0,8192,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break h}v[22708]=0;R(2519,l+16|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[l+16>>2];v[22708]=0;R(63,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(o)|0)){break h}r:{if(Ab(n)){if(Ab(o)){break r}}if(Ab(n)){v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)!=v[Jb(n)>>2]){break l}v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}e=Ab(n)>>>0>1?n:e;break h}v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)!=v[Jb(o)>>2]){break h}v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;e=Ab(o)>>>0>1?o:e;break h}v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)==v[Jb(n)>>2]){v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}e=Ab(n)>>>0>1?n:e;break h}v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)==v[Jb(o)>>2]){v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;e=Ab(o)>>>0>1?o:e;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(q>>>0<2|e|((q|0)==2&w[l+123|0]!=0|z))){e=0;break h}B=l,C=zd(m),v[B+8>>2]=C;b=Gd(l+16|0,l+8|0);s:{if(!q|w[(l+q|0)+119|0]>1){break s}B=l,C=vi(m),v[B+8>>2]=C;t:{if(!Gb(b,l+8|0)){break t}while(1){c=v[v[b>>2]>>2];v[22708]=0;c=W(2518,h|0,8192,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break k}if(!c){break t}Qe(b);B=l,C=vi(m),v[B+8>>2]=C;if(Gb(b,l+8|0)){continue}break}}B=l,C=zd(m),v[B+8>>2]=C;c=mv(b,l+8|0);if(Ab(s)>>>0>=c>>>0){B=l,C=vi(s),v[B+8>>2]=C;b=gb-16|0;gb=b;v[b+8>>2]=v[l+8>>2];v[b+8>>2]=v[b+8>>2]+(0-c<<2);c=v[b+8>>2];gb=b+16|0;d=vi(s);x=zd(m);b=gb-32|0;gb=b;v[b+16>>2]=d;v[b+24>>2]=c;v[b+8>>2]=x;c=1;u:{if(!Gb(b+24|0,b+16|0)){break u}while(1){c=Rj(v[b+24>>2],v[b+8>>2]);if(!c){break u}d=b+24|0;Qe(d);Qe(b+8|0);if(Gb(d,b+16|0)){continue}break}}gb=b+32|0;if(c){break s}}B=l,C=zd(m),v[B>>2]=C;Gd(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];B=l,C=vi(m),v[B>>2]=C;v:{w:{x:{if(!Gb(l+8|0,l)){break x}while(1){v[22708]=0;b=Q(2486,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}if(!b){break x}v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}if((b|0)!=v[v[l+8>>2]>>2]){break x}v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break v}b=l+8|0;Qe(b);B=l,C=vi(m),v[B>>2]=C;if(Gb(b,l)){continue}break}}if(!y){break h}B=l,C=vi(m),v[B>>2]=C;if(!Gb(l+8|0,l)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+28>>2]=p;break a}a=P()|0;O()|0;v[l+28>>2]=p;break a}d=0;x=v[l+112>>2];b=k;y:{while(1){z:{v[22708]=0;c=Q(2486,a|0,l+552|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break z}if(!c){break y}v[22708]=0;c=T(2488,a|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}v[22708]=0;k=W(2518,h|0,2048,c|0)|0;A=v[22708];v[22708]=0;if((A|0)==1){break e}A:{if(k){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22708]=0;U(2520,i|0,j|0,l+548|0);k=v[22708];v[22708]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+4;v[k>>2]=c;d=d+1|0;break A}if(!Ab(u)|!d|(c|0)!=(x|0)){break y}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2514,r|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22708]=0;T(2490,a|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[r>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2514,r|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break i}t[g|0]=1;break h}a=P()|0;O()|0;v[l+28>>2]=p;break a}k=b}B:{if((p|0)<1){break B}v[22708]=0;b=Q(2487,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}C:{if(!b){v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}if((b|0)==v[l+116>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}while(1){if((p|0)<1){p=0;break B}v[22708]=0;b=Q(2487,a|0,l+552|0)|0;c=v[22708];v[22708]=0;D:{if((c|0)==1){break D}E:{if(!b){v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break D}v[22708]=0;b=W(2518,h|0,2048,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break D}if(b){break E}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22708]=0;U(2520,i|0,j|0,l+548|0);b=v[22708];v[22708]=0;if((b|0)==1){break D}}v[22708]=0;b=T(2488,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break D}c=v[j>>2];v[j>>2]=c+4;v[c>>2]=b;v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;p=p-1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}q=q+1|0;if((q|0)!=4){continue}}break}v[l+28>>2]=p;F:{if(!e){break F}c=1;while(1){if(Ab(e)>>>0<=c>>>0){break F}v[22708]=0;b=Q(2487,a|0,l+552|0)|0;d=v[22708];v[22708]=0;G:{if((d|0)==1){break G}H:{if(!b){v[22708]=0;b=T(2488,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break G}if((b|0)==v[yk(e,c)>>2]){break H}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;c=c+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[r>>2]==(k|0)){break f}a=0;v[l+16>>2]=0;gf(u,v[r>>2],k,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}Ic(s);Ic(o);Ic(n);Ic(m);vb(u);Hc(r);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ic(s);Ic(o);Ic(n);Ic(m);vb(u);Hc(r);S(a|0);L()}function Cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=gb-320|0;gb=d;a:{if(!Zc(b,1080)){break a}if(!gp(b,d+316|0)){break a}Hd(a,1);n=EV(d+296|0);if(!DV(d+316|0,n)){break a}f=x[n+8>>1];if((f-1&65535)>>>0>126){break a}if(!c){h=1;break a}u[a+480188>>1]=f;o=w[n+12|0];H=w[n+11|0];e=w[n+10|0];D=1;if(!je(d+316|0,33192)){D=je(d+316|0,33197)}if(w[n+13|0]){Ob(a+1074312|0,5,1);f=x[a+480188>>1]}g=d+316|0;p=je(g,13813);j=1;if(!je(g,14590)){j=je(d+316|0,10888)}z=a+480188|0;y=(f&65535)==8&(H|0)!=0;Zc(b,0);RC(b,a+1298268|0,20);u[a+480190>>1]=31;l=(e|0)!=0;h=1;e=p;while(1){f=B(h,104)+a|0;g=f+484380|0;q=dC(b,d+160|0,g,((h<<5)+a|0)+946304|0,x[a+480188>>1]==4);g=v[g>>2];b:{if(j){t[f+484417|0]=0-(w[d+184|0]<<3);break b}l=g>>>0<65536&l}c:{d:{if(!Ib(w[d+182|0]|w[d+183|0]<<8)){break d}if(Ib(w[d+188|0]|w[d+189|0]<<8)){break d}$=1;break c}if(Ib(w[d+182|0]|w[d+183|0]<<8)){break c}I=w[d+185|0]==64|I}f=e&1;e=0;e:{if(!f){break e}k=(Ib(w[d+182|0]|w[d+183|0]<<8)<<1)+k|0;if(w[d+184|0]){break e}if(!Ib(w[d+182|0]|w[d+183|0]<<8)){e=1;break e}e=w[d+185|0]==64}E=q+E|0;i=g+i|0;h=h+1|0;if((h|0)!=32){continue}break}f:{g:{h:{i:{j:{k:{J=v[n+4>>2];if(J>>>0>=E>>>0){f=d+160|0;BV(b,f);Rb(b,4);q=f|1;h=w[q|0];g=128;j=a+484360|0;Fr(Sb(j),f|2,128);h=!h&e;k=h?k:0;e=w[f|0];l:{if(e>>>0>128){break l}g=e;if(e){break l}e=128;while(1){f=e-1|0;if(!x[sc(Sb(j),f)>>1]){g=1;e=f;if(e>>>0>1){continue}break l}break}g=e}F=(o|0)!=0;o=AV(b,Sb(j),g&65535,i,z,k,0);if(!(!h|x[a+480188>>1]!=8)){v[n>>2]=8553;F=1}m:{if(!y){break m}e=Sb(j);da=d,ea=Vb(e),v[da+144>>2]=ea;da=d,ea=Zb(e),v[da+128>>2]=ea;if(!Gb(d+144|0,d+128|0)){break m}while(1){e=d+144|0;i=v[e>>2];u[i>>1]=x[i>>1]>>>1;nf(e);if(Gb(e,d+128|0)){continue}break}}bf(Sb(j),w[q|0]);K=g-1&65535;n:{if(K>>>0>=w[q|0]){h=x[z>>1];if(w[q|0]!=120|(h|0)!=4){break n}}bf(Sb(j),0);h=x[z>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;e=Mb(256/((h&65535)>>>0)|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;yh(a,0);t[d+159|0]=0;h=1;k=0;M=1;if(!l){o:{if(!o){e=p;break o}s=d+144|5;e=p;l=0;j=0;while(1){g=0;i=0;while(1){f=bj(d+144|0);fv(b,f);r=yv(f);p:{q:{r:{f=w[d+147|0];if((f-7&255)>>>0<3){e=0;break r}e=r?e:0;s:{t:{u:{switch(f-13|0){case 2:if(w[d+149|0]>31){break t}break p;case 1:break s;case 0:break u;default:break r}}i=i+1|0;if((i&65535)>>>0<2){break p}}e=0;break p}f=w[d+149|0];e=f>>>0>1?0:e;break q}if((f|0)!=8){if((f|0)!=14){break p}f=w[d+149|0];break q}da=d,ea=w[pf(d+159|0,s)|0],t[da+159|0]=ea;f=t[d+149|0];if((f|0)>-1){j=1;break p}l=(f|0)!=-92&(f&255)>>>0>143|l;break p}if((f&240)!=128){break p}t[d+128|0]=f<<4;da=d,ea=w[pf(d+159|0,d+128|0)|0],t[da+159|0]=ea}h=h&r;g=g+1|0;if((g|0)!=256){continue}break}k=k+1|0;if(o>>>0>(k&65535)>>>0){continue}break}k=0;if((j^-1|l)&1){break o}k=w[d+159|0]>47}M=e&1}Zc(b,1084);e=x[a+480188>>1];r=a+484344|0;g=o+y|0;i=g&65535;zg(r,i);N=y?4:e;j=a+1074312|0;v:{if(!i){s=0;break v}aa=k^1;ba=c&1;Q=N&65535;T=g&65535;k=0;s=0;w:{while(1){x:{if(y){e=(k&65534)>>>1|0;g=k&1;if(!g){if(!wh(r,e,64)){break v}}l=Xc(_b(r,e),0,g<<2);break x}if(!wh(r,k&65535,64)){break v}l=Xc(_b(r,k),0,0)}if(!l|!ba){break v}e=x[a+480188>>1];t[d+128|0]=0;g=e;e=d+128|0;o=Kv(d+144|0,g,e);g=x[a+480188>>1];v[22708]=0;t[d+64|0]=0;C=W(780,e|0,g|0,d- -64|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){G=0;while(1){i=0;V=0;f=0;if(Q){while(1){v[22708]=0;e=B(f,6)+l|0;R(781,b|0,e|0);g=v[22708];v[22708]=0;y:{z:{if((g|0)!=1){g=w[e+3|0];A:{B:{C:{if(!g){if(w[e+5|0]){break C}break B}if(!H){break C}D:{switch(g-14|0){case 0:t[e+3|0]=0;t[e+5|0]=0;break C;case 1:break D;default:break C}}if(w[e+5|0]<32){break C}t[e+5|0]=31}Pf(e);g=1;E:{F:{G:{m=w[e+3|0];switch(m-14|0){case 2:break A;case 0:break F;case 3:break G;default:break E}}s=w[e+5|0]<100|s;V=1;break B}if(!M){break B}t[e+5|0]=0;break B}if(!((m|0)!=9|aa)){g=w[e+5|0];if((g|0)==164){t[e+3|0]=20;t[e+5|0]=145;break B}da=e,ea=ei(g<<1),t[da+5|0]=ea;break B}if((m|0)!=19){break B}g=w[e+5|0];if(g>>>0>15){break B}m=g&1;g=!m;ca=!m;m=X&1;X=(m|0)==(g|0)?X:ca;Y=((g|0)!=(m|0))+Y|0}g=i}if(w[e|0]){break z}if(!w[e+1|0]|y){break y}if(!w[kc(o,f)|0]){break y}if(w[kc(o,f)|0]==w[e+1|0]){break y}m=kc(C,f);i=w[m|0]+1|0;t[m|0]=i;if((i&255)>>>0<4){break y}v[22708]=0;W(409,j|0,85,1)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break y}}f=P()|0;O()|0;gc(C);break w}da=kc(C,f),ea=0,t[da|0]=ea}e=w[e+1|0];if(e){da=kc(o,f),ea=e,t[da|0]=ea}i=g;f=f+1|0;if((Q|0)!=(f|0)){continue}break}}Z=i&V|Z;l=B(x[z>>1],6)+l|0;G=G+1|0;if((G|0)!=64){continue}break}gc(C);gc(o);k=k+1|0;if((T|0)==(k|0)){break v}continue}break}f=P()|0;O()|0}gc(o);break f}H:{I:{J:{if((h^-1|$)&1){break J}K:{if(je(d+316|0,13813)){break K}if(je(d+316|0,14595)){break K}if(!je(d+316|0,10883)){break J}}v[a+480208>>2]=v[a+480208>>2]|2162688;Ob(j,85,1);Ob(j,91,1);Ob(j,92,1);L:{if(w[d+159|0]>47){break L}Ob(j,84,1);if(w[q|0]==127){break L}Ob(j,83,1)}if(!h){break H}break I}if(h){break I}if(p^1|w[q|0]!=127|w[q|0]+1>>>0<K>>>0){break H}v[n>>2]=5485;break H}if((Y|0)>6|F){break H}v[a+480208>>2]=v[a+480208>>2]|8388608}if((p|F)==1){Ob(j,89,1)}if(D){Ob(j,84,1)}if(c&2){Zc(b,(B(N&65535,T)<<8)+1084|0);g=(h&p^1|I)&1;h=1;while(1){i=B(h,104)+a|0;c=i+484380|0;if(v[c>>2]){f=d+144|0;if(D){e=2}else{e=zV(b,11143)?11:0}e=Rc(f,8,1,0,e);l=v[b+8>>2]+wv(e,v[c>>2])|0;if(!g){da=c,ea=v[Mc(c,i+484388|0)>>2],v[da>>2]=ea}Cg(e,c,b);Zc(b,l)}h=h+1|0;if((h|0)!=32){continue}break}}M:{if((p&s^-1|Z)&1){break M}b=yV(d+104|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;b=d+144|0;su(b,a,0,d+24|0);_=A[v[b>>2]>>3];dn(b);if(!(_>=600)){break M}Ob(j,5,1);b=xV(d+80|0,_);c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=d+144|0;su(b,a,0,d);c=w[v[b>>2]+26|0];dn(b);if(c){Sf(j,5);break M}v[n>>2]=14147}e=d+316|0;g=e;b=e;c=fc(e);p=c;if((c|0)!=(e|0)){while(1){i=w[e|0];t[b|0]=i>>>0>32?i:32;b=b+1|0;e=e+1|0;if((p|0)!=(e|0)){continue}break}}Ff(d+128|0,13900);v[22708]=0;b=W(782,d+48|0,g|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;U(13,d- -64|0,1,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[22708]=0;U(167,d+144|0,d+128|0,d- -64|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}c=d+144|0;Eb(a+1298304|0,c);vb(c);vb(d- -64|0);vb(b);Hb(d+128|0);b=Tb(c,9556);Eb(a+1298316|0,b);vb(b);b=v[n>>2];if(b){Wc(a+1298328|0,b)}v[a+1298364>>2]=2}h=E>>>0<=J>>>0;break a}f=P()|0;O()|0;break g}f=P()|0;O()|0;break h}f=P()|0;O()|0;vb(d- -64|0)}vb(b)}Hb(d+128|0)}S(f|0);L()}gb=d+320|0;return h|0}function wla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;e=f+24|0;j=d+120|0;AU(e,j);k=yb(e);e=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=e;v[f>>2]=h;v[f+4>>2]=e;h=f+16|0;e=b;cc(h,e,f);h=yb(h);if((h|0)==(k|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(h|0)==(k|0);if(!e){yU(j)}a:{b:{c:{d:{e:{if(!e){break e}if(!HU(d+120|0)){break e}if(!c){i=1;break e}Hd(a,4194304);e=d+32|0;f=Tb(e,14106);Eb(a+1298304|0,f);vb(f);f=Tb(e,7407);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;n=a,o=Fd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[n+480188>>1]=o;f=w[d+189|0];v[a+480228>>2]=(f|0)==255?48:f;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);f=d+96|0;of(f,d+120|4,59,3);Bc(e,f);Eb(a+1298268|0,e);vb(e);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Zc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!Hh(b,11465)){break f}jp(Sb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Zc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!Hh(b,11102)){break g}while(1){e=(i<<5)+a|0;We(e+480280|0);n=e+480284|0,o=((((Be(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;i=i+1|0;if((i|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Zc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!Hh(b,11378)){break h}f=d+32|0;Td(f,b,(w[d+196|0]|w[d+197|0]<<8)<<6);e=jc(d+96|0,f);xb(f);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}k=c&2;j=a+480190|0;h=d+45|0;while(1){v[22708]=0;f=Q(872,e|0,d+32|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!f){break i}f=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=f;j:{if((f-1&65535)>>>0>3998){break j}if(Md((B(f,104)+a|0)+484380|0)){break j}v[22708]=0;f=Le(j,d+30|0);i=v[22708];v[22708]=0;if((i|0)==1){break c}u[a+480190>>1]=x[f>>1];v[22708]=0;R(873,d+32|0,(B(x[d+30>>1],104)+a|0)+484380|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}of(d,h,24,1);v[22708]=0;R(324,d+16|0,d|0);f=v[22708];v[22708]=0;k:{if((f|0)!=1){v[22708]=0;Q(301,((x[d+30>>1]<<5)+a|0)+946304|0,d+16|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}vb(d+16|0);if(!k){break j}f=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[22708]=0;Q(190,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}i=1;g=d+16|0;f=d+79|0;l=Rc(g,w[f|0]&4?16:8,1,0,0);l:{m:{if(w[f|0]&8){break m}i=2;if(w[f|0]&16){break m}if(w[f|0]&127){break l}}Cf(l,i)}v[22708]=0;W(329,g|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break j}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+16|0);break b}m=m+1|0;if((m&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}xb(e)}i=1;if(!(c&1)){break e}n:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break n}if(!Zc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break n}if(!Hh(b,10968)){break n}h=a+484344|0;zg(h,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break n}k=d+16|2;m=0;while(1){if(!uC(b,d+16|0)){break n}if((w[d+16|0]|w[d+17|0]<<8)>>>0>3){c=d+96|0;Td(c,b,((w[d+16|0]|w[d+17|0]<<8)+15&131056)-4|0);f=jc(d+32|0,c);xb(c);c=w[k|0];v[22708]=0;c=W(331,h|0,m&65535,c|0)|0;e=v[22708];v[22708]=0;o:{if((e|0)!=1){p:{j=0;if(!c){break o}while(1){v[22708]=0;c=Q(191,d+32|0,1)|0;e=v[22708];v[22708]=0;q:{r:{s:{if((e|0)!=1){if(!c|w[k|0]<=j>>>0){break r}v[22708]=0;e=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break p}if(e){break s}j=j+1|0;continue}break p}c=_b(h,m);u[d+96>>1]=e&31;g=x[a+480188>>1];v[22708]=0;u[d>>1]=g-1;g=Pc(d+96|0,d);l=v[22708];v[22708]=0;if((l|0)==1){break p}g=x[g>>1];v[22708]=0;c=Xc(c,j,g);g=v[22708];v[22708]=0;if((g|0)==1){break p}if(e&128){v[22708]=0;R(403,d+96|0,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break p}g=d+96|0;l=qd(g);t[c|0]=w[g|0]+36;t[c+1|0]=w[l|0]}if(!(e&64)){break q}t[c+2|0]=1;v[22708]=0;g=T(374,f|0)|0;l=v[22708];v[22708]=0;t:{if((l|0)!=1){t[d+96|0]=g;v[22708]=0;t[d|0]=64;g=ac(d+96|0,d);l=v[22708];v[22708]=0;if((l|0)==1){break t}t[c+4|0]=w[g|0];break q}break p}break p}if(w[k|0]==64){break o}c=_b(h,m);v[22708]=0;e=Ce(d+96|0,14,0);f=v[22708];v[22708]=0;if((f|0)!=1){e=Gh(Ue(e,w[k|0]-1|0));v[22708]=0;Q(431,c|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break o}}break p}if(!(e&32)){continue}v[22708]=0;R(403,d+96|0,f|0);e=v[22708];v[22708]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((e|0)!=1){g=d+96|0;e=w[qd(g)|0];t[c+5|0]=e;switch(w[g|0]-1|0){case 71:break v;case 70:break w;case 69:break x;case 60:break y;case 59:break z;case 52:break A;case 51:break B;case 50:break C;case 49:break D;case 42:break E;case 41:break F;case 40:break G;case 39:break H;case 30:break I;case 29:break J;case 22:break K;case 21:break L;case 20:break M;case 19:break N;case 16:break O;case 15:break P;case 14:break Q;case 13:break R;case 12:break S;case 11:break T;case 10:break U;case 9:break V;case 3:break W;case 2:break X;case 1:break Y;case 0:break Z;default:break u}}break p}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[22708]=0;e=T(374,f|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){t[c+5|0]=e;v[22708]=0;Q(318,d+32|0,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break p}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;xb(d+32|0);break a}xb(d+32|0)}m=m+1|0;if(m>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Zc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));oB(a+1298292|0,b,Ng(b),4)}gb=d+272|0;return i|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}xb(e)}S(b|0);L()}function Toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;f=gb-1344|0;gb=f;vc(b);g=gb-32|0;gb=g;d=g+24|0;h=f+768|0;vX(d,h);k=yb(d);i=v[g+28>>2];d=v[g+24>>2];v[g+8>>2]=d;v[g+12>>2]=i;v[g>>2]=d;v[g+4>>2]=i;i=g+16|0;d=b;cc(i,d,g);i=yb(i);if((i|0)==(k|0)){Rb(d,yb(g+24|0))}gb=g+32|0;d=(i|0)==(k|0);if(!d){uX(h)}a:{b:{c:{if(!d){break c}if(!yX(f+768|0)){break c}if(!Pb(b,Qc(xX(f+768|0),jb))){break c}if(!c){e=1;break c}j=xr(f+760|0);A=1;d:{while(1){g=(e<<5)+a|0;k=g+480280|0;We(k);h=(f+768|0)+(e<<4)|0;u[g+480284>>1]=((w[h+78|0]<<8&65280)>>>0)/255;i=f+496|0;Lk(i,1,h- -64|0);d=f+112|0;Bc(d,i);v[22708]=0;Q(399,g+480289|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(f+112|0);e:{f:{switch(w[h+79|0]){case 0:o=e+1|0;break e;case 1:v[k>>2]=1024;o=m+1|0;break e;case 2:break f;default:break d}}v[k>>2]=1024;d=f+112|0;Al(d,j,e);Df(d,1)}A=e>>>0<31;m=m+1|0;e=e+1|0;if((e|0)!=32){continue}break}Hd(a,33554432);u[a+480188>>1]=o&255;d=f+112|0;e=Tb(d,3830);Eb(a+1298304|0,e);vb(e);e=Tb(d,8329);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;g:{if(w[f+847|0]){break g}m=1;while(1){if(w[((m<<4)+f|0)+847|0]!=1){break g}e=1;m=m+1|0;if((m|0)!=16){continue}break}while(1){d=((e<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}d=f+496|0;Ke(d,1,f+768|0);e=f+112|0;Bc(e,d);Eb(a+1298268|0,e);vb(e);v[a+480208>>2]=v[a+480208>>2]&-17|(w[f+806|0]|w[f+807|0]<<8)<<4&16;v[a+480196>>2]=w[f+816|0];v[a+480204>>2]=B(w[f+817|0],1e4);C=a,D=Fd(w[f+818|0],0,64)<<2,v[C+480200>>2]=D;C=a,D=Fd(w[f+819|0],4,127),v[C+480228>>2]=D;e=w[f+804|0]|w[f+805|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=e;jw(b,d);Ur(Sb(a+484360|0),d,w[f+800|0]|w[f+801|0]<<8,65535,255);n=c&1;if(n){zg(a+484344|0,w[f+802|0]|w[f+803|0]<<8)}if(w[f+802|0]|w[f+803|0]<<8){p=a+484344|0;while(1){e=Ng(b);z=Ng(b);d=f+48|0;Td(d,b,e-4|0);q=jc(f+112|0,d);xb(d);h:{if(!n){break h}v[22708]=0;d=W(331,p|0,r&65535,z|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){i:{if(!d){break h}s=0;i=bj(f+24|0);if(!z){break h}while(1){j:{v[22708]=0;m=T(374,q|0)|0;e=v[22708];v[22708]=0;k:{l:{if((e|0)!=1){if(m){break l}s=s+1|0;break k}break i}e=i;l=m&31;if(l>>>0<x[a+480188>>1]){e=_b(p,r);v[22708]=0;e=Xc(e,s,l);d=v[22708];v[22708]=0;if((d|0)==1){break i}}m:{if(!(m&32)){break m}v[22708]=0;R(403,f+48|0,q|0);h=v[22708];v[22708]=0;d=e;n:{o:{if((h|0)!=1){k=f+48|0;h=qd(k);k=w[k|0];t[e|0]=k;t[e+1|0]=w[h|0];if((k|0)!=160){break o}h=255;break n}break i}if((k|0)!=255){t[e|0]=(B(k>>>4|0,12)+(k&15)|0)+13;v[22708]=0;k=VC(e);h=v[22708];v[22708]=0;if((h|0)!=1){h=0;if(!k){break n}break m}break i}h=0}t[d|0]=h}d=m&192;p:{if(!d){break p}if((d|0)==192){v[22708]=0;R(531,f+48|0,q|0);d=v[22708];v[22708]=0;q:{r:{s:{if((d|0)!=1){d=f+48|0;h=d;k=qd(d);m=Ve(d);o=ej(d);g=w[d|0];if((g|0)!=12){break s}v[22708]=0;t[f|0]=64;h=ac(k,f);d=v[22708];v[22708]=0;if((d|0)==1){break i}t[e+4|0]=w[h|0];d=1;break r}break i}d=w[m|0];t:{if((d|0)==12){v[22708]=0;t[f|0]=64;m=ac(o,f);d=v[22708];v[22708]=0;if((d|0)!=1){t[e+4|0]=w[m|0];d=1;break t}break i}if((g|0)==10){t[e+4|0]=(w[k|0]<<6>>>0)/255;d=2;break r}if((d|0)!=10){break q}t[e+4|0]=(w[o|0]<<6>>>0)/255;d=2}m=h;o=k}t[e+2|0]=d;d=w[m|0]}t[e+3|0]=d;t[e+5|0]=w[o|0];break p}v[22708]=0;R(403,f+48|0,q|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}h=f+48|0;d=qd(h);t[e+3|0]=w[h|0];t[e+5|0]=w[d|0]}if(w[e+3|0]){v[22708]=0;_(553,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}}d=f+48|0;Al(d,j,l);if(!Cb(d)){break k}v[22708]=0;h=wX(e);d=v[22708];v[22708]=0;if((d|0)==1){break j}if(!h){break k}t[e+3|0]=0}if(s>>>0<z>>>0){continue}break h}break}}}e=P()|0;O()|0;xb(f+112|0);break a}xb(f+112|0);r=r+1|0;if(r>>>0<(w[f+802|0]|w[f+803|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break d}m=c&2;p=f- -64|0;o=1;d=0;while(1){d=d+1|0;k=d&65535;n=DO(a,k,0);g=gb-32|0;gb=g;c=g+24|0;i=f+112|0;bc(c,i,384);h=yb(c);e=v[g+28>>2];c=v[g+24>>2];v[g+8>>2]=c;v[g+12>>2]=e;v[g>>2]=c;v[g+4>>2]=e;e=g+16|0;c=b;cc(e,c,g);e=yb(e);if((e|0)==(h|0)){Rb(c,yb(g+24|0))}gb=g+32|0;c=(e|0)==(h|0);if(!c){Qb(i,0,384)}if(!(!c|!n)){i=o&65535;l=gb-32|0;gb=l;g=f+112|0;Ke(l,1,g);c=l+16|0;Bc(c,l);v[22708]=0;Q(301,n+492|0,c|0)|0;c=v[22708];v[22708]=0;u:{if((c|0)!=1){vb(l+16|0);v:{if(!(w[g+378|0]|w[g+379|0]<<8)){break v}v[l+16>>2]=120;v[l>>2]=116;if(!v[Fb(l+16|0,l)>>2]){break v}e=n+236|0;h=0;while(1){c=w[(g+h|0)+32|0];C=wd(e,h+12|0),D=c+i|0,u[C>>1]=D;v[l+16>>2]=120;v[l>>2]=116;h=h+1|0;if(h>>>0<y[Fb(l+16|0,l)>>2]){continue}break}}c=w[g+376|0]|w[g+377|0]<<8;t[n+33|0]=1;v[n>>2]=c;UC(g,n+48|0,0);UC(g,n+68|0,1);UC(g,n+88|0,2);c=w[n+100|0];if(c&1){t[n+100|0]=c|16}if(!(v[n>>2]|t[n+60|0]&1)){v[n>>2]=32767}gb=l+32|0;break u}a=P()|0;O()|0;vb(l+16|0);S(a|0);L()}e=0;w:{if(!(w[f+490|0]|w[f+491|0]<<8)){break w}while(1){x:{cY(b,f+48|0);y:{if((w[f+108|0]|w[f+109|0]<<8|(w[f+110|0]<<16|w[f+111|0]<<24))!=808538953){break y}c=e+o|0;l=c&65535;if(l>>>0>3999){break y}u[a+480190>>1]=c;i=gb-32|0;gb=i;n=B(l,104)+a|0;h=n+484380|0;g=h;ud(g,0);j=f+48|0;li(i,1,j);c=i+16|0;Bc(c,i);v[22708]=0;Q(303,g+43|0,c|0)|0;c=v[22708];v[22708]=0;z:{if((c|0)!=1){vb(i+16|0);v[g>>2]=w[j+16|0]|w[j+17|0]<<8|(w[j+18|0]<<16|w[j+19|0]<<24);v[g+4>>2]=w[j+20|0]|w[j+21|0]<<8|(w[j+22|0]<<16|w[j+23|0]<<24);v[g+8>>2]=w[j+24|0]|w[j+25|0]<<8|(w[j+26|0]<<16|w[j+27|0]<<24);v[g+24>>2]=w[j+28|0]|w[j+29|0]<<8|(w[j+30|0]<<16|w[j+31|0]<<24);u[g+30>>1]=w[j+32|0]<<2;u[g+28>>1]=w[j+33|0];if(t[j+48|0]&1){u[g+34>>1]=x[g+34>>1]|2}if(w[j+48|0]&2){u[g+34>>1]=x[g+34>>1]|4}if(w[j+48|0]&4){u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}if(w[j+48|0]&8){u[g+34>>1]=x[g+34>>1]|32}gb=i+32|0;break z}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}g=gb-16|0;gb=g;i=g+8|0;SE(i,n+484423|0);c=f+24|0;Zr(c,i);gb=g+16|0;v[22708]=0;Q(301,((l<<5)+a|0)+946304|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break x}vb(f+24|0);if(!(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))){break y}Td(f,b,w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24));i=jc(f+24|0,f);xb(f);A:{if(!m){break A}c=Rc(f,u[n+484414>>1]&1?16:8,1,0,0);v[22708]=0;W(329,c|0,h|0,i|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break A}e=P()|0;O()|0;xb(f+24|0);break a}xb(f+24|0)}e=e+1|0;if(e>>>0<(w[f+490|0]|w[f+491|0]<<8)>>>0){continue}break w}break}e=P()|0;O()|0;vb(f+24|0);break a}o=(w[f+490|0]|w[f+491|0]<<8)+o|0}if(k>>>0<x[a+480192>>1]){continue}break}}e=!A}gb=f+1344|0;return e&1}e=P()|0;O()|0;vb(f+112|0)}S(e|0);L()}function qu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-32|0;gb=h;v[h+28>>2]=c;a:{if((c|0)<1){break a}l=v[b+104>>2];j=v[b+656>>2];if(!(!j|v[a+480180>>2]!=16777216)){p=v[j+44>>2]!=0}b:{if(!(!j|(c|0)>128)){i=x[wd(j+236|0,c-1|0)>>1];c:{if((i-1&65535)>>>0<=3998){l=(B(i,104)+a|0)+484380|0;break c}i=h+16|0;Db(i,a+1074312|0,43);if(!Cb(i)){break c}if(!tk(b)){break a}}i=w[lc(j+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=i;break b}i=c}if((i|0)>=121){d:{if(!(v[a+480180>>2]&16777248?(i|0)!=255:0)){Bo(a,b);if(d){break d}c=h+16|0;Db(c,a+1074312|0,100);if(!Cb(c)|!(w[a+480208|0]&4)|!w[b+789|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}c=h+16|0;Db(c,a+1074312|0,50);if(Cb(c)){break g}}v[b+688>>2]=0}c=h+16|0;Db(c,a+1074312|0,50);if(Cb(c)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}c=h+16|0;Db(c,a+1074312|0,20);if(!Cb(c)){break a}t[b+797|0]=0;t[b+802|0]=0;break a}h:{i:{j:{if(p){if(d){n=w[b+797|0];if(n){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!l)){u[b+770>>1]=t[l+36|0];u[b+772>>1]=t[l+37|0]}if(l){d=h+16|0;Db(d,a+1074312|0,24);i=0;o=1;if(!Cb(d)){break h}v[b+704>>2]=v[l+24>>2];break h}i=0;break h}k=v[j+44>>2];u[h>>1]=n;u[h+14>>1]=i;v[h+16>>2]=0;i=(v[h+16>>2]+B(u[k+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+852>>2]|0;v[b+708>>2]=i;v[b+852>>2]=0-i}o=(l|0)!=0;i=1;if(Ni(b)){break h}i=h+16|0;k=a+1074312|0;Db(i,k,54);if(Cb(i)){v[b+700>>2]=0;break a}i=h+16|0;Db(i,k,39);i=(Cb(i)^-1)&d}k:{if(hp(a)){v[h+28>>2]=v[h+28>>2]+u[b+770>>1];Rd(h+28|0,12,131);break k}hV(h+28|0)}k=h+16|0;m=a+1074312|0;Db(k,m,34);d=b;l:{if(Cb(k)){c=nn(c);break l}c=v[h+28>>2]}t[d+797|0]=c;t[b+851|0]=w[b+851|0]&219|32;if(!(v[a+480180>>2]&16777250?0:i)){t[b+803|0]=0}n=_g(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;c=h+16|0;Db(c,m,48);if(Cb(c)){CP(a,b,j,l)}m:{if(e^1|i){break m}v[b+776>>2]=0;v[b+780>>2]=0;if(!j){break m}c=h+16|0;Db(c,m,29);if(Cb(c)){t[b+798|0]=w[j+16|0]}if(!(w[j+60|0]&8)){Gj(b+724|0)}if(!(w[j+80|0]&8)){Gj(b+732|0)}if(!(w[j+100|0]&8)){Gj(b+740|0)}if(w[j+20|0]){d=ou(Ao(a));c=w[j+20|0];k=h+16|0;Db(k,m,28);d=((B(c,d)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(k)){k=v[b+752>>2];break n}k=(v[b+688>>2]+1|0)/2|0}u[c+776>>1]=(B(k,d)|0)/199}o:{if(!w[j+19|0]){break o}q=b,r=(B(ou(Ao(a)),w[j+19|0])<<16>>16)/32|0,u[q+778>>1]=r;c=h+16|0;Db(c,m,28);if(Cb(c)|x[b+784>>1]){break o}u[b+784>>1]=x[b+692>>1]+1}k=w[j+23|0];if(k){d=ou(Ao(a));c=w[b+837|0];t[b+796|0]=c+1;u[b+780>>1]=(B(c,(B(k,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}k=w[j+24|0];if(!k){break m}d=ou(Ao(a));c=w[b+838|0];t[b+795|0]=c+1;u[b+782>>1]=(B(c,(B(k,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}o=0;p:{q:{if(!n){break q}r:{s:{t:{if(i){u:{if(!v[b+700>>2]){v[b+700>>2]=n;if(!p){break u}break t}if(p){break t}}v[b+708>>2]=n;t[b+851|0]=w[b+851|0]&247;break t}v[b+700>>2]=n;if(p){break s}c=h+16|0;Db(c,m,69);if(Cb(c)){break s}Db(h,m,46);if(Cb(h)|v[a+480180>>2]==1){break s}v[b+708>>2]=n;t[b+851|0]=w[b+851|0]&247;break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=l;c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){c=h+16|0;Db(c,m,96);if(!Cb(c)){break w}}if(w[b+789|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Fb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}c=x[l+34>>1];k=c&1023;d=k|v[b+88>>2]&-525056;v[b+88>>2]=d;x:{y:{if(c&8){v[b+80>>2]=v[l+12>>2];c=v[l+16>>2];v[b+88>>2]=(k&16?d|4:d&-524295)|2;v[b+84>>2]=c;if(y[b+76>>2]>c>>>0){break y}break x}if(!(k&2)){break x}v[b+80>>2]=v[l+4>>2];c=v[l+8>>2];v[b+84>>2]=c;if(y[b+76>>2]<=c>>>0){break x}}v[b+76>>2]=c}c=h+16|0;Db(c,m,83);if(!(!Cb(c)|v[b+80>>2])){c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];if(c&128){v[b+88>>2]=c|128;v[b+4>>2]=v[b+76>>2]-1}z:{if(w[b+822|0]>3){break z}d=h+16|0;Db(d,m,21);c=b;A:{if(!(Cb(d)|!(v[a+480180>>2]&16777248))){d=16;if(!(v[a+480208>>2]&4)){break A}}d=32;if(v[a+480180>>2]==16){break A}if(v[a+480180>>2]&67633152){break z}d=0}t[c+819|0]=d}c=h+16|0;Db(c,m,21);if(Cb(c)|w[b+825|0]>3){break r}t[b+820|0]=0}c=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=c;c=v[b+80>>2];v[b>>2]=d;v[b+4>>2]=c}if(!i){break q}o=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}if(!(w[a+480208|0]&8)|!w[b+789|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Lm(b);c=h+16|0;Db(c,m,21);if(!Cb(c)){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(w[b+789|0]|(!o|!(w[a+480208|0]&8)))){o=1;break p}if(w[b+789|0]?0:v[a+480180>>2]&1048580){break p}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}c=h+16|0;Db(c,m,40);B:{C:{D:{E:{if(Cb(c)){if(o){if(w[b+789|0]?w[a+480208|0]&8:0){break D}v[b+88>>2]=v[b+88>>2]&-4194305;break C}c=v[b+88>>2]&-4196353;break E}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;l=1;if(o){break B}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;c=h+16|0;Db(c,m,23);F:{if(Cb(c)){break F}Db(h,m,22);if(Cb(h)){break F}c=h+16|0;Db(c,m,52);if(Cb(c)){break F}Db(h,m,71);if(Cb(h)){break F}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;G:{if(j){H:{I:{if(!UE(j)){if(uw(j)){break I}c=!(c>>>13|0);if(c){break H}break G}q=b,r=VE(j),t[q+838|0]=r;if(!uw(j)){break H}}q=b,r=WE(j),t[q+837|0]=r}c=1;d=w[j+25|0];if((d|0)==255){break G}t[b+845|0]=d;break G}v[b+776>>2]=0;v[b+780>>2]=0;c=!c}J:{if(w[b+837|0]>=127){d=h+16|0;Db(d,m,36);if(!Cb(d)){break J}}if(!c){break J}if((Jq(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break J}c=a+1298260|0;if(!Dd(c)|(g|0)==65535){break J}Qq(v[c>>2],g,w[b+837|0]>>>1|0,1)}l=0;if(!(w[b+89|0]&2)){break B}d=a+1298260|0;if(!Dd(d)|(g|0)==65535){break B}c=h+16|0;Db(c,m,111);if(Cb(c)){vk(v[d>>2],g);break B}c=h+16|0;Db(c,m,110);if(!Cb(c)){break B}WA(v[d>>2],g,0,1,0);break B}v[b+88>>2]=v[b+88>>2]&-4196353}l=1}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}K:{L:{if(w[a+24618|0]&16?c&1024:0){break L}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break L}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break K}}if(f){break K}v[b+700>>2]=0}if(l){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}gb=h+32|0}function P2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2508;b=l+104|0;q=ge(l+136|0,l+144|0,b);k=v[q>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;u=Kb(b);m=Kb(l+88|0);n=Kb(l+72|0);p=Kb(l+56|0);s=Kb(l+40|0);v[22708]=0;na(2511,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,m|0,n|0,p|0,l+36|0);b=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;r=v[l+36>>2];e=0;f:{while(1){v[22708]=0;b=Q(2459,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}g:{if(!b){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(nh(h,8192,b)){v[22708]=0;R(2512,l+24|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=t[l+24|0];v[22708]=0;R(61,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break h}}if((e|0)==3){break g}}while(1){v[22708]=0;b=Q(2459,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break h}v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!nh(h,8192,b)){break h}v[22708]=0;R(2512,l+24|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=t[l+24|0];v[22708]=0;R(61,s|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(p)|0)){break h}q:{if(Ab(n)){if(Ab(p)){break q}}if(Ab(n)){v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(n,0)|0]!=(b&255)){break k}v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}o=Ab(n)>>>0>1?n:o;break h}v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(p,0)|0]!=(b&255)){break h}v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;o=Ab(p)>>>0>1?p:o;break h}v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(n,0)|0]==(b&255)){v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}o=Ab(n)>>>0>1?n:o;break h}v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if(w[pc(p,0)|0]==(b&255)){v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}t[g|0]=1;o=Ab(p)>>>0>1?p:o;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|o|((e|0)==2&w[l+123|0]!=0|z))){o=0;break h}A=l,B=zd(m),v[A+16>>2]=B;b=Gd(l+24|0,l+16|0);r:{if(!e|w[(e+l|0)+119|0]>1){break r}A=l,B=ef(m),v[A+16>>2]=B;s:{if(!Gb(b,l+16|0)){break s}while(1){if(!nh(h,8192,t[v[b>>2]])){break s}Pe(b);A=l,B=ef(m),v[A+16>>2]=B;if(Gb(b,l+16|0)){continue}break}}A=l,B=zd(m),v[A+16>>2]=B;b=bk(b,l+16|0);if(Ab(s)>>>0>=b>>>0){A=l,B=ef(s),v[A+16>>2]=B;c=xe(l+16|0,0-b|0);d=ef(s);x=zd(m);b=gb-32|0;gb=b;v[b+16>>2]=d;v[b+24>>2]=c;v[b+8>>2]=x;c=1;t:{if(!Gb(b+24|0,b+16|0)){break t}while(1){c=w[v[b+24>>2]]==w[v[b+8>>2]];if(!c){break t}d=b+24|0;Pe(d);Pe(b+8|0);if(Gb(d,b+16|0)){continue}break}}gb=b+32|0;if(c){break r}}A=l,B=zd(m),v[A+8>>2]=B;Gd(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];A=l,B=ef(m),v[A+8>>2]=B;u:{v:{w:{if(!Gb(l+16|0,l+8|0)){break w}while(1){v[22708]=0;b=Q(2459,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}if(!b){break w}v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}if(w[v[l+16>>2]]!=(b&255)){break w}v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break u}b=l+16|0;Pe(b);A=l,B=ef(m),v[A+8>>2]=B;if(Gb(b,l+8|0)){continue}break}}if(!y){break h}A=l,B=ef(m),v[A+8>>2]=B;if(!Gb(l+16|0,l+8|0)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+36>>2]=r;break a}a=P()|0;O()|0;v[l+36>>2]=r;break a}d=0;x=w[l+118|0];b=k;x:{while(1){y:{v[22708]=0;c=Q(2459,a|0,l+552|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break y}if(!c){break x}v[22708]=0;c=T(2461,a|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}z:{if(nh(h,2048,c)){k=v[j>>2];if((k|0)==v[l+548>>2]){v[22708]=0;U(2513,i|0,j|0,l+548|0);k=v[22708];v[22708]=0;if((k|0)==1){break e}k=v[j>>2]}v[j>>2]=k+1;t[k|0]=c;d=d+1|0;break z}if(!Ab(u)|!d|(x|0)!=(c&255)){break x}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2514,q|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=v[l+132>>2]}c=b+4|0;v[l+132>>2]=c;v[b>>2]=d;b=c;d=0}v[22708]=0;T(2463,a|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!d|v[q>>2]==(b|0)){break j}if(v[l+128>>2]==(b|0)){v[22708]=0;U(2514,q|0,l+132|0,l+128|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=v[l+132>>2]}k=b+4|0;v[l+132>>2]=k;v[b>>2]=d;break i}t[g|0]=1;break h}k=b}A:{if((r|0)<1){break A}v[22708]=0;b=Q(2460,a|0,l+552|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}B:{if(!b){v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}if(w[l+119|0]==(b&255)){break B}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}while(1){if((r|0)<1){r=0;break A}v[22708]=0;b=Q(2460,a|0,l+552|0)|0;c=v[22708];v[22708]=0;C:{if((c|0)==1){break C}D:{if(!b){v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break C}if(nh(h,2048,b)){break D}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22708]=0;U(2513,i|0,j|0,l+548|0);b=v[22708];v[22708]=0;if((b|0)==1){break C}}v[22708]=0;b=T(2461,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break C}c=v[j>>2];v[j>>2]=c+1;t[c|0]=b;v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;r=r-1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;if((e|0)!=4){continue}}break}v[l+36>>2]=r;E:{if(!o){break E}c=1;while(1){if(Ab(o)>>>0<=c>>>0){break E}v[22708]=0;b=Q(2460,a|0,l+552|0)|0;d=v[22708];v[22708]=0;F:{if((d|0)==1){break F}G:{if(!b){v[22708]=0;b=T(2461,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}if(w[pc(o,c)|0]==(b&255)){break G}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;c=c+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[q>>2]==(k|0)){break f}a=0;v[l+24>>2]=0;gf(u,v[q>>2],k,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}vb(s);vb(p);vb(n);vb(m);vb(u);Hc(q);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vb(s);vb(p);vb(n);vb(m);vb(u);Hc(q);S(a|0);L()}function gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-224|0;gb=e;vc(c);if(!(!Br(c,e+208|0)|v[e+208>>2]!=1297239878|((w[e+216|0]|w[e+217|0]<<8|(w[e+218|0]<<16|w[e+219|0]<<24))!=1128679745?v[e+216>>2]!=1179011393:0))){g=gb-32|0;gb=g;h=e+192|0;f=hh(h);a:{b:{c:{d:{e:{while(1){v[22708]=0;i=Q(191,c|0,8)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}if(!i){break d}v[22708]=0;R(1162,g|0,c|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;R(1163,f|0,g|0);i=v[22708];v[22708]=0;if((i|0)==1){break e}ed(g);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(g);break b}gb=g+32|0;break a}a=P()|0;O()|0}ke(f);S(a|0);L()}v[22708]=0;U(1147,e+168|0,h|0,1129270605);c=v[22708];v[22708]=0;f:{g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[22708]=0;c=Q(1148,e+168|0,e+144|0)|0;g=v[22708];v[22708]=0;n:{if((g|0)!=1){g=0;if(!c){break f}h=e+144|2;if(!Yb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))){break f}if(!Ib(w[e+144|0]|w[e+145|0]<<8)){break f}if(Ib(w[e+144|0]|w[e+145|0]<<8)>>>0>2){break f}f=e+144|6;if(!Ib(w[f|0]|w[f+1|0]<<8)){break f}if(Ib(w[f|0]|w[f+1|0]<<8)>>>0>64){break f}v[e+140>>2]=1162760014;c=1;if((w[e+216|0]|w[e+217|0]<<8|(w[e+218|0]<<16|w[e+219|0]<<24))==1128679745){v[22708]=0;c=Q(798,e+168|0,e+140|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}if(!c){break f}c=v[e+140>>2]!=1936684916}v[22708]=0;U(1147,e+120|0,e+192|0,1397968452);g=v[22708];v[22708]=0;o:{p:{if((g|0)!=1){v[22708]=0;g=Q(1149,e+120|0,e+112|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break o}if(g){break p}break g}g=P()|0;O()|0;break i}i=((Ib(w[f|0]|w[f+1|0]<<8)-1|0)/8|0)-1|0;j=i<<3;f=j&31;f=Rc(e+104|0,(i>>>0<7?(j&63)>>>0>=32?4196360>>>f|0:((1<<f)-1&4196360)<<32-f|136321040>>>f:8)&255,(Ib(w[e+144|0]|w[e+145|0]<<8)|0)==2?2:1,c,0);q:{c=v[e+140>>2];if((c|0)<=875981925){if((c|0)<=842230885){if((c|0)==544694642){break q}if((c|0)==842222662){break l}break k}if((c|0)==842230886){break l}if((c|0)!=875973702){break k}break l}if((c|0)<=1463897172){if((c|0)==875981926){break l}if((c|0)!=1463897153){break k}break m}if((c|0)!=1463897173){if((c|0)==2002873441){break m}if((c|0)!=2002873461){break k}}Cf(f,17);Yi(f,16);break k}Cf(f,1);break k}g=P()|0;O()|0;break j}g=P()|0;O()|0;break i}g=P()|0;O()|0;break i}g=P()|0;O()|0;break h}Cf(f,18);Yi(f,16);break k}Cf(f,3)}if(d){WQ(f)}c=Yb(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24));v[22708]=0;c=Q(191,e+120|0,c|0)|0;d=v[22708];v[22708]=0;r:{if((d|0)==1){break r}if(c){c=Yb(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24));v[22708]=0;Q(318,e+120|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}}v[22708]=0;Q(1138,a|0,b|0)|0;c=v[22708];v[22708]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)==1){break B}v[22708]=0;i=(B(b,104)+a|0)+484380|0;R(424,i|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break B}l=i,m=Yb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24)),v[l>>2]=m;d=e+144|0;c=w[d+13|0]|(w[d+11|0]<<16|w[d+10|0]<<24|w[d+12|0]<<8);h=30-w[d+9|0]|0;C:{if(!(h&255)){d=0;break C}while(1){d=c;c=c>>>1|0;h=h-1|0;if(h&255){continue}break}}v[(B(b,104)+a|0)+484404>>2]=(d&1)+c;v[22708]=0;W(329,f|0,i|0,e+120|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break B}v[22708]=0;U(1147,e+80|0,e+192|0,1296126539);c=v[22708];v[22708]=0;if((c|0)==1){break A}v[22708]=0;c=T(275,e+80|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break z}if(!c){break t}v[22708]=0;U(1147,e+32|0,e+192|0,1229869908);c=v[22708];v[22708]=0;if((c|0)==1){break y}v[22708]=0;c=Q(1150,e+32|0,e+56|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}xb(e+32|0);if(!c){break t}v[22708]=0;f=T(416,e+80|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}d=dd(e+32|0);v[22708]=0;R(1151,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)!=1){D:{if(!f){break D}h=e+8|6;c=0;while(1){v[22708]=0;j=Q(1152,e+80|0,e+8|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break v}if(!j){break D}v[22708]=0;R(1153,d|0,e+8|0);j=v[22708];v[22708]=0;if((j|0)==1){break v}j=w[h|0];k=w[h|0];v[22708]=0;Q(318,e+80|0,j+((k^-1)&1)|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break v}c=c+1|0;if((f|0)!=(c|0)){continue}break}}c=e- -64|0;if(Ib(w[c|0]|w[c+1|0]<<8)){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]|8;c=Ib(w[c|0]|w[c+1|0]<<8);u[f>>1]=x[f>>1]&65519|((c|0)==2)<<4}if(Ib(w[e+70|0]|w[e+71|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2;f=Ib(w[e+70|0]|w[e+71|0]<<8);u[c>>1]=x[c>>1]&65531|((f|0)==2)<<2}l=e,m=Vb(d),v[l+8>>2]=m;l=e,m=Zb(d),v[l+24>>2]=m;if(Gb(e+8|0,e+24|0)){c=B(b,104)+a|0;f=c+484388|0;h=c+484384|0;j=c+484396|0;k=c+484392|0;while(1){c=v[e+8>>2];if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+66|0]|w[e+67|0]<<8)|0)){l=k,m=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+68|0]|w[e+69|0]<<8)|0)){l=j,m=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+72|0]|w[e+73|0]<<8)|0)){l=h,m=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+74|0]|w[e+75|0]<<8)|0)){l=f,m=Yb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[l>>2]=m}c=e+8|0;v[c>>2]=v[c>>2]+7;if(Gb(c,e+24|0)){continue}break}}v[22708]=0;xk(i);c=v[22708];v[22708]=0;if((c|0)!=1){break u}}break v}g=P()|0;O()|0;break j}g=P()|0;O()|0;break j}g=P()|0;O()|0;break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;xb(e+32|0);break s}g=P()|0;O()|0;break s}g=P()|0;O()|0;SQ(d);break s}SQ(d)}v[22708]=0;U(1147,e+32|0,e+192|0,1312902469);c=v[22708];v[22708]=0;E:{F:{if((c|0)!=1){v[22708]=0;c=T(275,e+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}G:{H:{I:{J:{if(c){v[22708]=0;c=T(195,e+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break F}v[22708]=0;W(474,e+32|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break J}break F}v[22708]=0;c=Q(70,e+8|0,18720)|0;d=v[22708];v[22708]=0;if((d|0)==1){break I}v[22708]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break H}vb(c)}b=v[a+480180>>2];v[22708]=0;U(1140,i|0,32,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break G}v[22708]=0;_h(i,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break F}xb(e+32|0);xb(e+80|0);break g}g=P()|0;O()|0;break E}g=P()|0;O()|0;vb(c);break E}g=P()|0;O()|0;break E}g=P()|0;O()|0;break s}g=P()|0;O()|0}xb(e+32|0)}xb(e+80|0);break j}g=P()|0;O()|0}xb(e+120|0)}xb(e+168|0)}ke(e+192|0);S(g|0);L()}xb(e+120|0)}xb(e+168|0);ke(e+192|0)}gb=e+224|0;return g|0}function aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-208|0;gb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;XO(a+900380|0);v[22708]=0;lA(a+946304|0);d=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}d=g+48|0;Qb(d,0,160);d=_O(d);v[22708]=0;e=a+906300|0;U(1297,e|0,e+4e4|0,d|0);e=v[22708];v[22708]=0;f:{g:{h:{i:{if((e|0)!=1){Bq(d);v[22708]=0;d=T(275,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(!d){break f}i=dd(g+48|0);e=0;if(c&16){break h}v[22708]=0;h=(c|0)!=0;e=W(1298,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=4;j:{if(e){break j}v[22708]=0;e=W(1299,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=5;if(e){break j}v[22708]=0;e=W(1300,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=6;if(e){break j}e=0;v[22708]=0;h=W(1301,i|0,b|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}d=3;if(!h){break h}}if(c){break i}f=1;break b}a=P()|0;O()|0;Bq(d);break c}if(!cd(i)){Dw(b,v[i>>2]+12|0)}e=d}if(c&32){break b}d=37824;k:{l:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[22708]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){if(f){break k}d=d+12|0;if((d|0)==38328){break l}continue}break}break g}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break b}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}v[22708]=0;R(1122,a+1298224|0,1);d=v[22708];v[22708]=0;if((d|0)!=1){fA(i);break d}}a=P()|0;O()|0;fA(i);break c}v[22708]=0;R(367,a|0,0);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;R(1122,a+1298224|0,1);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[a+1074304>>2]=19923024;break d}a=P()|0;O()|0;break c}d=0;m:{n:{while(1){e=(d<<5)+a|0;yg(e+480286|0,64);f=e+480284|0;if(x[f>>1]>=257){u[f>>1]=128}e=e+480288|0;if(w[e|0]>=251){t[e|0]=0}v[22708]=0;_m((B(d,872)+a|0)+1074992|0,7,a,d&65535,134217728);e=v[22708];v[22708]=0;if((e|0)==1){break n}d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1298260|0;f=1;while(1){e=B(f&65535,104)+a|0;d=e+484380|0;o:{if(Md(d)){v[22708]=0;_h(d,a,0);d=v[22708];v[22708]=0;if((d|0)!=1){break o}break m}h=e+484414|0;j=x[h>>1];if(j&16384){break o}v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;u[h>>1]=j&65505}d=e+484412|0;if(x[d>>1]>=65){u[d>>1]=64}p:{if(!(w[e+484415|0]&2)){break p}if(!wk(i)){break p}v[22708]=0;_(1303,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;e=0;while(1){q:{f=v[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break q}e=v[a+480180>>2];v[22708]=0;CS(f,e);f=v[22708];v[22708]=0;e=d;if((f|0)!=1){break q}a=P()|0;O()|0;break c}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=e;d=a+480204|0;r:{if(y[a+480204>>2]<1e4){v[d>>2]=125e4;break r}qc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}d=a+480220|0;e=v[a+480216>>2];if(e>>>0>y[a+480220>>2]){v[d>>2]=e}e=a+480216|0;qc(e,65536);qc(d,65536);qc(a+480200|0,256);s:{d=a+480248|0;if(!cd(d)){e=v[e>>2];v[22708]=0;U(1305,d|0,e|0,16777216);d=v[22708];v[22708]=0;if((d|0)==1){break s}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];e=v[a+480220>>2];d=a+1074408|0;v[d>>2]=v[a+480216>>2];v[d+4>>2]=e;v[a+1074456>>2]=v[a+480200>>2];tA(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;u[a+480276>>1]=0;v[22708]=0;_(1306,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break s}d=a+484360|0;l=g,m=Vb(d),v[l+48>>2]=m;l=g,m=Zb(d),v[l+32>>2]=m;t:{if(Gb(g+48|0,g+32|0)){while(1){d=v[g+48>>2];v[22708]=0;_(1307,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break t}e=x[d+28>>1];if(tc(d)>>>0<=e>>>0){bf(d,0)}d=g+48|0;mS(d);if(Gb(d,g+32|0)){continue}break}}u:{v:{w:{x:{y:{z:{A:{B:{C:{k=v[a+480180>>2];if(k){eu(a+8|0,zq(a));if(v[a+1074308>>2]){v[22708]=0;_(1308,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break s}}f=dd(g+48|0);if((c&12)==12){d=0;while(1){j=B(d,160)+a|0;i=j+906300|0;e=i;c=e+16|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=e+20|0;D:{if(!(h|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)))){break D}v[22708]=0;Q(1309,i|0,a|0)|0;c=v[22708];v[22708]=0;E:{if((c|0)!=1){c=v[i>>2];if(!c){break E}e=v[j+906448>>2];i=v[v[c>>2]+56>>2];v[22708]=0;R(i|0,c|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break D}}a=P()|0;O()|0;break u}e=Vb(f);h=Zb(f);c=gb-32|0;gb=c;v[c+16>>2]=h;v[c+24>>2]=e;v[c+8>>2]=i;if(Gb(c+24|0,c+16|0)){while(1){e=v[v[c+24>>2]>>2];h=v[c+8>>2];if((w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24))==(w[h+20|0]|w[h+21|0]<<8|(w[h+22|0]<<16|w[h+23|0]<<24))){h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=v[c+8>>2];e=(h|0)==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{e=0}if(!e){e=c+24|0;Qe(e);if(Gb(e,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[g+32>>2]=e;l=g,m=Zb(f),v[l+16>>2]=m;if(Gb(g+32|0,g+16|0)){break D}v[22708]=0;v[g+32>>2]=j+906316;R(1310,f|0,g+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break C}v[22708]=0;c=Q(2,g+16|0,14790)|0;e=v[22708];v[22708]=0;if((e|0)==1){break B}v[22708]=0;R(1311,g|0,i|0);e=v[22708];v[22708]=0;if((e|0)==1){break A}v[22708]=0;U(3,g+32|0,c|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break z}v[22708]=0;U(560,a|0,2,g+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break y}vb(g+32|0);vb(g);vb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=w[a+1074368|0];v[22708]=0;R(1312,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break v}Gl(f)}f=(k|0)!=0;break a}a=P()|0;O()|0;break u}a=P()|0;O()|0;break u}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g+32|0)}vb(g)}vb(c);break u}a=P()|0;O()|0}Gl(f);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}xb(b);S(a|0);L()}fA(i)}xb(b);gb=g+208|0;return f|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=C(0),X=0,Y=0,Z=0,_=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];YL(a);if(g==z[a+4268>>2]){break a}Uy(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!ni(p)){break b}q=Nd(p,0);x=Nd(p,1);l=od(p,0);m=od(p,1);c:{if(!(w[a+4264|0]&2|(!w[a+5044|0]|!d))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;m=m+4|0;l=l+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}V=a+4960|0;F=a+4648|0;G=a+4672|0;R=a+4936|0;H=a+4696|0;I=a+4720|0;J=a+4744|0;K=a+4768|0;S=a+4840|0;E=a+4504|0;L=a+4528|0;T=a+4912|0;M=a+4552|0;N=a+4576|0;O=a+4600|0;P=a+4624|0;U=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){g=z[q>>2];g=C(g+C(C(z[a+5008>>2]-g)*z[a+4276>>2]));z[a+5008>>2]=g;Z=Cc(u,v[a+4880>>2]),_=g,z[Z>>2]=_;g=z[x>>2];g=C(g+C(C(z[a+5012>>2]-g)*z[a+4276>>2]));z[a+5012>>2]=g;Z=Cc(s,v[a+4904>>2]),_=g,z[Z>>2]=_;g=C(C(C(C(C(Th(u,v[a+4356>>2])*C(.6800000071525574))-C(Th(u,v[a+4360>>2])*C(.5)))-C(Th(u,v[a+4364>>2])*C(.6200000047683716)))-C(Th(u,v[a+4368>>2])*C(.5)))-C(Th(u,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){f=g;g=C(z[Cc(U,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));Z=Cc(U,v[a+4832>>2]),_=C(f-C(g*C(.6180340051651001))),z[Z>>2]=_}y=z[a+4280>>2];Z=a,_=C(Th(u,v[a+4352>>2])+z[a+5020>>2]),z[Z+5020>>2]=_;f=C(Th(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Cc(P,v[a+4644>>2])>>2])*z[a+4444>>2])+z[Cc(P,v[a+4644>>2])>>2]);z[a+4980>>2]=h;Q=C(h*z[a+4440>>2]);j=C(f*C(.7070000171661377));i=C(e*C(-.7070000171661377));e=C(j+i);h=z[a+4272>>2];f=C(Q+C(e*h));Z=Cc(P,v[a+4640>>2]),_=C(e-C(h*f)),z[Z>>2]=_;e=C(C(C(z[a+4976>>2]-z[Cc(O,v[a+4620>>2])>>2])*z[a+4436>>2])+z[Cc(O,v[a+4620>>2])>>2]);z[a+4976>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4432>>2])+C(f*h));Z=Cc(O,v[a+4616>>2]),_=C(f-C(h*e)),z[Z>>2]=_;A=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=C(C(C(z[a+4972>>2]-z[Cc(N,v[a+4596>>2])>>2])*z[a+4428>>2])+z[Cc(N,v[a+4596>>2])>>2]);z[a+4972>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4424>>2])+C(e*h));Z=Cc(N,v[a+4592>>2]),_=C(e-C(h*f)),z[Z>>2]=_;e=C(C(C(z[a+4968>>2]-z[Cc(M,v[a+4572>>2])>>2])*z[a+4420>>2])+z[Cc(M,v[a+4572>>2])>>2]);z[a+4968>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4416>>2])+C(f*h));Z=Cc(M,v[a+4568>>2]),_=C(f-C(h*e)),z[Z>>2]=_;A=C(C(A+C(f*C(.3499999940395355)))+C(e*C(-.3799999952316284)))}Z=Cc(T,v[a+4928>>2]),_=e,z[Z>>2]=_;f=C(z[Cc(T,v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=f+C(C(z[a+5028>>2]-f)*z[a+4500>>2]);f=C(C(C(z[a+4964>>2]-z[Cc(L,v[a+4548>>2])>>2])*z[a+4412>>2])+z[Cc(L,v[a+4548>>2])>>2]);z[a+4964>>2]=f;e=z[a+5028>>2];n=z[a+4272>>2];h=C(C(e*n)+C(f*z[a+4408>>2]));Z=Cc(L,v[a+4544>>2]),_=C(e-C(n*h)),z[Z>>2]=_;f=C(C(C(z[a+4960>>2]-z[Cc(E,v[a+4524>>2])>>2])*z[a+4404>>2])+z[Cc(E,v[a+4524>>2])>>2]);z[a+4960>>2]=f;e=C(f*z[a+4400>>2]);f=z[a+4272>>2];n=C(e+C(h*f));Z=Cc(E,v[a+4520>>2]),_=C(h-C(f*n)),z[Z>>2]=_;z[a+5020>>2]=n;f=C(C(C(C(C(Th(s,v[a+4380>>2])*C(.7070000171661377))-C(Th(s,v[a+4384>>2])*C(.6000000238418579)))-C(Th(s,v[a+4388>>2])*C(.5)))-C(Th(s,v[a+4392>>2])*C(.6000000238418579)))-C(Th(s,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){e=f;f=C(z[Cc(S,v[a+4860>>2])>>2]+C(f*C(.6180340051651001)));Z=Cc(S,v[a+4856>>2]),_=C(e-C(f*C(.6180340051651001))),z[Z>>2]=_}W=z[a+4280>>2];e=C(C(C(z[a+5004>>2]-z[Cc(K,v[a+4788>>2])>>2])*z[a+4492>>2])+z[Cc(K,v[a+4788>>2])>>2]);z[a+5004>>2]=e;Q=C(e*z[a+4488>>2]);e=C(i-j);i=z[a+4272>>2];j=C(Q+C(e*i));Z=Cc(K,v[a+4784>>2]),_=C(e-C(i*j)),z[Z>>2]=_;e=C(C(C(z[a+5e3>>2]-z[Cc(J,v[a+4764>>2])>>2])*z[a+4484>>2])+z[Cc(J,v[a+4764>>2])>>2]);z[a+5e3>>2]=e;i=z[a+4272>>2];e=C(C(e*z[a+4480>>2])+C(j*i));Z=Cc(J,v[a+4760>>2]),_=C(j-C(i*e)),z[Z>>2]=_;j=C(C(C(h*C(.3799999952316284))+C(j*C(-.15000000596046448)))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Cc(I,v[a+4740>>2])>>2])*z[a+4476>>2])+z[Cc(I,v[a+4740>>2])>>2]);z[a+4996>>2]=h;i=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(e*i));Z=Cc(I,v[a+4736>>2]),_=C(e-C(i*h)),z[Z>>2]=_;e=C(C(C(z[a+4992>>2]-z[Cc(H,v[a+4716>>2])>>2])*z[a+4468>>2])+z[Cc(H,v[a+4716>>2])>>2]);z[a+4992>>2]=e;i=z[a+4272>>2];e=C(C(e*z[a+4464>>2])+C(h*i));Z=Cc(H,v[a+4712>>2]),_=C(h-C(i*e)),z[Z>>2]=_;j=C(C(j+C(h*C(.3499999940395355)))+C(e*C(-.3799999952316284)))}X=x+4|0;Y=q+4|0;h=C(g*y);A=C(A-C(n*C(.3799999952316284)));n=C(f*W);Z=Cc(R,v[a+4952>>2]),_=e,z[Z>>2]=_;g=C(z[Cc(R,v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=g+C(C(z[a+5032>>2]-g)*z[a+4500>>2]);g=C(C(C(z[a+4988>>2]-z[Cc(G,v[a+4692>>2])>>2])*z[a+4460>>2])+z[Cc(G,v[a+4692>>2])>>2]);z[a+4988>>2]=g;f=z[a+5032>>2];e=z[a+4272>>2];g=C(C(f*e)+C(g*z[a+4456>>2]));Z=Cc(G,v[a+4688>>2]),_=C(f-C(e*g)),z[Z>>2]=_;e=z[a+4284>>2];f=C(C(C(z[a+4984>>2]-z[Cc(F,v[a+4668>>2])>>2])*z[a+4452>>2])+z[Cc(F,v[a+4668>>2])>>2]);z[a+4984>>2]=f;y=z[a+4272>>2];f=C(C(f*z[a+4448>>2])+C(g*y));Z=Cc(F,v[a+4664>>2]),_=C(g-C(y*f)),z[Z>>2]=_;z[a+5024>>2]=f;g=C(g*C(.3799999952316284));y=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((V|0)!=(k|0)){continue}break}g=C(h+C(C(A+g)*e));f=C(n+C(C(j+C(f*C(-.3799999952316284)))*y));e:{f:{if(w[a+4264|0]&2){q=Y;k=X;break f}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(f+z[a+5040>>2])*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;q=q+8|0;m=m+4|0;l=l+4|0;k=x+8|0}x=k;z[l>>2]=g;z[m>>2]=f;m=m+4|0;l=l+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}Fi(a,b,c,od(p,0),od(p,1),d)}}function xoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;f=gb-208|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(Hh(b,11133)){if(d){t[d|0]=1}j=a+1074312|0;vv(j);m=a+480216|0;n=a+480220|0;o=a+480224|0;k=a+1074368|0;p=a+480200|0;h:{if(!Pb(b,7)){break h}s=a+480228|0;z=a+480232|0;A=a+484360|0;l=a+480268|0;C=a+1298280|0;D=a+480248|0;while(1){d=sg(b);e=Ng(b);if((d|0)==(w[18696]|w[18697]<<8|(w[18698]<<16|w[18699]<<24))){pg(b,6);break h}if(!(d&1616928864)|d&-2139062144){break h}if(!Pb(b,e)){break h}h=f+24|0;Td(h,b,e);g=jc(f+184|0,h);xb(h);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break z}if((d|0)!=1129797166){break i}v[22708]=0;v[f+24>>2]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)==1){break w}v[a+1074304>>2]=v[f+24>>2];break i}if((d|0)==1130917459){break r}if((d|0)!=1145525806){break i}v[22708]=0;U(608,g|0,e|0,p|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}if((d|0)<=1213486400){if((d|0)==1146367534){break B}if((d|0)!=1196316499|e>>>0<3){break i}v[22708]=0;R(609,f+8|0,f+184|0);d=v[22708];v[22708]=0;if((d|0)==1){break p}v[22708]=0;R(610,f+168|0,f+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break o}v[22708]=0;e=W(100,f+24|0,f+168|0,8)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}vb(f+168|0);gc(f+8|0);v[22708]=0;d=T(195,f+184|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}v[22708]=0;U(611,f+24|0,D|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break l}vf(e);break i}if((d|0)==1213486401){break s}if((d|0)==1280530262){break v}if((d|0)!=1297303086){break i}vv(j);d=0;break k}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break x}if((d|0)!=1347244882){break i}v[22708]=0;U(612,g|0,e|0,l|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}if(up(w[l|0])){break i}t[l|0]=5;break i}if((d|0)==1380340804){break A}if((d|0)==1380986414){break t}if((d|0)!=1380991534){break i}v[22708]=0;U(608,g|0,e|0,m|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}if((d|0)<=1397768493){if((d|0)==1380994350){break j}if((d|0)!=1397052739|e>>>0<3){break i}v[22708]=0;d=T(287,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!d|d>>>0>x[a+480190>>1]){break i}d=(B(d,104)+a|0)+484448|0;e=nX(d);if((d|0)==(e|0)){break i}while(1){v[22708]=0;h=T(192,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}v[d>>2]=h;d=d+4|0;if((e|0)!=(d|0)){continue}break}break i}if((d|0)==1397768494){break u}if((d|0)==1414344238){break y}if((d|0)!=1448301654){break i}v[22708]=0;U(608,g|0,e|0,z|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}v[22708]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break i}v[22708]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break i}d=P()|0;O()|0;break a}if(c){break i}v[22708]=0;u[f+24>>1]=0;U(613,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)!=1){E=a,F=Fd(x[f+24>>1],x[a+480188>>1],127),u[E+480188>>1]=F;break i}d=P()|0;O()|0;break a}v[22708]=0;U(614,g|0,e|0,o|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}v[22708]=0;U(615,g|0,e|0,k|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}break i}d=P()|0;O()|0;break a}v[22708]=0;v[f+24>>2]=0;U(608,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)==1){break f}d=v[f+24>>2];if(!d){break i}v[a+1074308>>2]=d;break i}v[22708]=0;U(608,g|0,e|0,s|0);d=v[22708];v[22708]=0;if((d|0)!=1){break i}break b}if(v[a+480180>>2]==4){break i}v[22708]=0;U(613,g|0,e|0,f+24|0);d=v[22708];v[22708]=0;if((d|0)!=1){bf(Sb(A),x[f+24>>1]);break i}d=P()|0;O()|0;break a}e=Kb(f+24|0);v[22708]=0;d=T(195,f+184|0)|0;h=v[22708];v[22708]=0;C:{if((h|0)==1){break C}v[22708]=0;W(616,g|0,e|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break C}v[22708]=0;U(13,f+168|0,0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break C}d=f+168|0;Eb(C,d);vb(d);vb(e);break i}d=P()|0;O()|0;vb(e);break a}if(e&1|e>>>0>126){break i}u[f+24>>1]=(e>>>1|0)- -64;v[22708]=0;u[f+168>>1]=127;d=Pc(f+24|0,f+168|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}q=x[d>>1];if(q>>>0<65){break i}e=64;while(1){v[22708]=0;R(403,f+24|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}h=f+24|0;d=qd(h);D:{if(w[h|0]==255){break D}i=w[d|0];d=(e<<5)+a|0;r=d+480284|0;u[r>>1]=128;u[d+480286>>1]=i;i=d+480280|0;v[i>>2]=0;v[i>>2]=(w[h|0]&128)<<3;d=w[h|0]&127;t[h|0]=d;if(d>>>0<65){u[r>>1]=d<<2;d=w[h|0]}if((d&255)!=100){break D}v[i>>2]=v[i>>2]|256}e=e+1|0;if((q|0)!=(e|0)){continue}break}break i}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break m}d=P()|0;O()|0;vb(f+168|0)}gc(f+8|0);break a}d=P()|0;O()|0;vf(e);break a}E:{F:{G:while(1){v[22708]=0;e=Q(191,f+184|0,1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break F}if(!(e&d>>>0<114)){break i}v[22708]=0;h=T(374,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break E}e=0;while(1){H:{if(!(!(h>>>e&1)|d>>>0>113)){v[22708]=0;W(409,j|0,d|0,1)|0;i=v[22708];v[22708]=0;if((i|0)==1){break H}}d=d+1|0;e=e+1|0;if((e|0)!=8){continue}continue G}break}break}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[22708]=0;U(608,g|0,e|0,n|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}}xb(f+184|0);if(Pb(b,7)){continue}break}}Fp(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(w[a+480224|0]>=3){t[o|0]=0}if(w[k|0]>=6){t[k|0]=0}qc(p,256);qc(m,65536);qc(n,65536)}gb=f+208|0;return}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0}xb(f+184|0);S(d|0);L()}function Do(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;j=gb-16|0;gb=j;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;s=v[b+752>>2];h=w[b+802|0];a:{if(!h){i=j+8|0;Db(i,a+1074312|0,11);if(Cb(i)){break a}}b:{c:{if(!g){break c}if(!we(h)){break c}d:{i=g+236|0;h=h-1|0;if(x[wd(i,h)>>1]){break d}k=j+8|0;Db(k,a+1074312|0,43);if(!Cb(k)){break d}if(Ij(g)){break d}v[b+656>>2]=g;break a}if(w[lc(g+108|0,h)|0]>120){break a}h=x[wd(i,h)>>1];k=(h-1&65535)>>>0<3999?(B(h,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(h>>>0>250){break a}h=j+8|0;Db(h,a+1074312|0,43);if(Cb(h)){if(g){k=0;if(Ij(g)){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}k=0}h=v[b+104>>2];o=(h|0)!=0&(h|0)!=(k|0);i=v[b+656>>2];q=!g|v[a+480180>>2]!=16777216?q:v[g+44>>2]!=0;p=d^1;h=(g|0)!=(i|0);if((p|h|o)==1){u[b+774>>1]=0}r=!o;if(!(r?1:!(d&q)|v[b+656>>2]!=(g|0))){break a}e:{if(p|r){break e}l=j+8|0;m=a+1074312|0;Db(l,m,32);if(!(!Cb(l)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|h:1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Ni(b)){break f}}l=j+8|0;Db(l,m,79);if(!Cb(l)){break e}if(!Ni(b)){break e}}n=1}g:{if(!v[b+16>>2]|(!o|(h|!x[a+480192>>1]))){break g}l=j+8|0;Db(l,a+1074312|0,87);if(!Cb(l)){break g}n=ce(b+788|0)^1|n}h:{i:{j:{k:{l:{if(Ni(b)|!(v[a+480180>>2]&16777248)){break l}if(g){if(Ij(g)){break l}}l=1;break k}if(!(h|o)){break j}l=(g|0)!=(i|0)}if(!d){break i}h=j+8|0;Db(h,a+1074312|0,61);if(!Cb(h)){break i}i=v[b+656>>2];if(!i){m=0;i=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}l=0}v[b+656>>2]=g;m=l;h=k;i=g}m:{if(!e){break m}l=b;n:{o:{p:{if(v[a+480180>>2]&3){if(h){if(Md(h)){break p}}if(!tk(b)){break m}}if(!h){break o}}if(u[h+34>>1]<0){break m}g=x[h+30>>1];break n}g=0;if(!i|!w[i+34|0]){break n}g=b;k=v[b+656>>2];q:{if(k){g=v[k+4>>2]<<2;break q}g=v[g+688>>2]}}v[l+688>>2]=g}if(n){if(!((h|0)!=0&o)){break a}c=j+8|0;Db(c,a+1074312|0,85);if(Cb(c)){u[b+772>>1]=t[h+37|0]}if(v[a+480180>>2]!=2){break a}if(!Md(h)){break a}v[b+704>>2]=v[h+24>>2];break a}t[b+803|0]=0;r:{if(!i){break r}g=j+8|0;Db(g,a+1074312|0,29);if(z=0,A=(D=Cb(g),E=1,F=h,F?D:E),C=w[i+34|0]!=0|m,C?z:A){break r}t[b+798|0]=w[i+16|0]}g=i;n=64;k=b;v[b+752>>2]=64;l=h;if(h){n=x[l+32>>1];v[k+752>>2]=n}if(g){v[k+752>>2]=B(v[g+4>>2],n)>>>6}s:{if(!(v[a+480180>>2]&1048580?e:1)){break s}e=j+8|0;Db(e,a+1074312|0,48);if(Cb(e)){break s}CP(a,b,i,h)}t:{u:{v:{if(!f){break v}f=j+8|0;e=a+1074312|0;Db(f,e,19);w:{x:{y:{z:{A:{B:{C:{D:{if(Cb(f)){if(!v[b+76>>2]){g=1;break C}if(!(!c|p)){g=(w[a+480208|0]&8)>>>3|0;if(g){break C}break D}g=0;if(c){break D}break C}g=1;E:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break E}g=0;if(!(w[b+89|0]&16)){break E}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!i|m)){break A}if(!g){break z}g=v[b+88>>2];c=g&6144;break B}if(d){break C}if(!(w[b+89|0]&24)){g=0;break C}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break A}if(!g){break z}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!i){break w}if(c){break x}if(!(w[i+60|0]&8)){Gj(b+724|0)}if(!(w[i+80|0]&8)){Gj(b+732|0)}if(w[i+100|0]&8){break w}Gj(b+740|0);break w}if(g){break y}}if(i){if(t[i+60|0]&1){break v}c=j+8|0;Db(c,e,32);if(Cb(c)){Gj(b+724|0);break v}Lm(b);break v}g=0;if(!h){break u}break t}v[b+88>>2]=v[b+88>>2]|2097152;if(!i){break w}}Lm(b)}c=j+8|0;Db(c,e,21);if(Cb(c)){break v}t[b+818|0]=0;v[b+756>>2]=0}g=0;if(h){break t}if(!i){break u}g=1;if(Ij(i)){break t}}v[b+752>>2]=0;v[b+104>>2]=0;break a}c=b;F:{G:{H:{I:{J:{if(!(!d|!h|v[b+104>>2]!=(h|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break J}d=j+8|0;Db(d,a+1074312|0,40);if(!Cb(d)|w[b+789|0]){break J}d=v[b+88>>2];break I}v[b+88>>2]=v[b+88>>2]&-6145;e=j+8|0;f=a+1074312|0;Db(e,f,18);c=b;K:{if(z=Cb(e),A=1,C=v[a+480180>>2]&16777248,C?z:A){e=-640;if(!(v[b+104>>2]!=(h|0)|m)){break K}}e=-768}v[c+88>>2]=e&v[b+88>>2];L:{if(!i){break L}t[b+730|0]=w[i+60|0];t[b+738|0]=w[i+80|0];t[b+746|0]=w[i+100|0];M:{if((w[i+100|0]&17)!=17){break M}c=j+8|0;Db(c,f,36);if(Cb(c)|w[b+837|0]){break M}t[b+837|0]=127}if(uw(i)){z=b,A=WE(i),t[z+837|0]=A}if(!UE(i)){break L}z=b,A=VE(i),t[z+838|0]=A}if(g){break H}if(!d){break F}break G}d=v[b+88>>2]&-6145}v[c+88>>2]=d&-640;if(!g){break G}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break F}c=j+8|0;d=a+1074312|0;Db(c,d,54);if(!Cb(c)){Db(j,d,39);if(!Cb(j)){break F}}v[b+8>>2]=0;v[b+12>>2]=0}N:{if(w[b+788|0]!=255){break N}c=j+8|0;Db(c,a+1074312|0,100);if(!Cb(c)|(!(v[a+480208>>2]&4)|r)){break N}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}So(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];c=j+8|0;d=a+1074312|0;Db(c,d,83);if(!(!Cb(c)|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;c=j+8|0;Db(c,d,21);if(Cb(c)){t[b+818|0]=0;v[b+756>>2]=0}c=b;O:{P:{if(q){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|32;e=0;break P}if(!(v[a+480180>>2]&5?o|p:1)){break O}v[b+704>>2]=v[h+24>>2];e=t[h+37|0]}u[c+772>>1]=e}c=b;if(hp(a)){e=t[h+36|0]}else{e=0}u[c+770>>1]=e;c=j+8|0;Db(c,d,69);if(!(Cb(c)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}Q:{if(!(g&2)){g=v[b+76>>2];break Q}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break Q}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}gb=j+16|0}function l6(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;m=gb-560|0;gb=m;v[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<-1?1:(g|0)<=-1){A=1;C=2388;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){A=1;C=2391;break a}A=e&1;C=A?2394:2389;F=!A}b:{if((g&2146435072)==2146435072){i=A+3|0;cg(a,32,c,i,e&-65537);tf(a,C,A);d=f&32;tf(a,b!=b?d?7248:11107:d?8325:11416,3);break b}y=m+16|0;c:{d:{e:{b=MI(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;s=f|32;if((s|0)!=97){break e}break c}s=f|32;if((s|0)==97){break c}l=v[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;v[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}q=(l|0)<0?m+48|0:m+336|0;h=q;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<1){d=l;g=h;k=q;break f}k=q;d=l;while(1){p=(d|0)<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}d=p;i=0;while(1){u=g;G=i;x=v[g>>2];r=d&31;if((d&63)>>>0>=32){i=x<<r;x=0}else{i=(1<<r)-1&x>>>32-r;x=x<<r}r=G+x|0;i=i+H|0;i=r>>>0<x>>>0?i+1|0:i;i=rqa(r,i,1e9,0);x=u;u=oqa(i,jb,1e9,0);v[x>>2]=r-u;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-p|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25|0)/9|0;if((d|0)<=-1){p=h+1|0;E=(s|0)==102;while(1){d=0-d|0;i=(d|0)<9?d:9;h:{if(g>>>0>k>>>0){u=1e9>>>i|0;r=-1<<i^-1;d=0;h=k;while(1){x=d;d=v[h>>2];v[h>>2]=x+(d>>>i|0);d=B(u,d&r);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0;break h}h=v[k>>2]}d=i+v[m+44>>2]|0;v[m+44>>2]=d;k=(!h<<2)+k|0;h=E?q:k;g=(p|0)<g-h>>2?h+(p<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=k>>>0){break i}h=B(q-k>>2,9);d=10;i=v[k>>2];if(i>>>0<10){break i}while(1){h=h+1|0;d=B(d,10);if(i>>>0>=d>>>0){continue}break}}d=(n-((s|0)==102?0:h)|0)-((s|0)==103&(n|0)!=0)|0;if((d|0)<(B(g-q>>2,9)-9|0)){i=((l|0)<0?4:292)+m|0;l=d+9216|0;p=(l|0)/9|0;i=(i+(p<<2)|0)-4048|0;d=10;l=l-B(p,9)|0;if((l|0)<=7){while(1){d=B(d,10);l=l+1|0;if((l|0)!=8){continue}break}}p=v[i>>2];u=(p>>>0)/(d>>>0)|0;l=p-B(d,u)|0;r=i+4|0;j:{if(!((r|0)==(g|0)?l:1)){break j}b=(g|0)==(r|0)?1:1.5;r=d>>>1|0;z=l>>>0<r>>>0?.5:(r|0)==(l|0)?b:1.5;b=u&1?9007199254740994:9007199254740992;if(!(w[C|0]!=45|F)){z=-z;b=-b}l=p-l|0;v[i>>2]=l;if(b+z==b){break j}d=d+l|0;v[i>>2]=d;if(d>>>0>=1e9){while(1){v[i>>2]=0;i=i-4|0;if(i>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[i>>2]+1|0;v[i>>2]=d;if(d>>>0>999999999){continue}break}}h=B(q-k>>2,9);d=10;l=v[k>>2];if(l>>>0<10){break j}while(1){h=h+1|0;d=B(d,10);if(l>>>0>=d>>>0){continue}break}}d=i+4|0;g=d>>>0<g>>>0?d:g}while(1){l=g;d=g>>>0<=k>>>0;if(!d){g=l-4|0;if(!v[g>>2]){continue}}break}k:{if((s|0)!=103){s=e&8;break k}g=n?n:1;i=(g|0)>(h|0)&(h|0)>-5;n=(i?h^-1:-1)+g|0;f=(i?-1:-2)+f|0;s=e&8;if(s){break k}i=-9;l:{if(d){break l}p=v[l-4>>2];i=-9;if(!p){break l}d=10;g=0;i=0;if((p>>>0)%10|0){break l}while(1){i=g;g=g+1|0;d=B(d,10);if(!((p>>>0)%(d>>>0)|0)){continue}break}i=i^-1}d=B(l-q>>2,9)-9|0;if((f&-33)==70){s=0;d=d+i|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d;break k}s=0;d=i+(d+h|0)|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d}p=(n|s)!=0;d=a;x=c;u=f&-33;if((u|0)==70){f=(h|0)>0?h:0}else{g=h>>31;g=$n(g+h^g,0,y);if((y-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((y-g|0)<2){continue}break}}E=g-2|0;t[E|0]=f;t[g-1|0]=(h|0)<0?45:43;f=y-E|0}i=(f+(p+(n+A|0)|0)|0)+1|0;cg(d,32,x,i,e);tf(a,C,A);cg(a,48,c,i,e^65536);m:{n:{o:{if((u|0)==70){f=m+16|0;d=f|8;f=f|9;k=k>>>0>q>>>0?q:k;h=k;while(1){g=$n(v[h>>2],0,f);p:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break p}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break p}if((f|0)!=(g|0)){break p}t[m+24|0]=48;g=d}tf(a,g,f-g|0);h=h+4|0;if(q>>>0>=h>>>0){continue}break}g=0;if(!p){break n}tf(a,13839,1);if((n|0)<1|h>>>0>=l>>>0){break o}while(1){g=$n(v[h>>2],0,f);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}tf(a,g,(n|0)<9?n:9);g=n-9|0;h=h+4|0;if(l>>>0<=h>>>0){break n}d=(n|0)>9;n=g;if(d){continue}break}break n}q:{if((n|0)<0){break q}q=k>>>0<l>>>0?l:k+4|0;d=m+16|0;f=d|9;d=d|8;h=k;while(1){g=$n(v[h>>2],0,f);if((f|0)==(g|0)){t[m+24|0]=48;g=d}r:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}tf(a,g,1);g=g+1|0;if(s?0:(n|0)<=0){break r}tf(a,13839,1)}l=g;g=f-g|0;tf(a,l,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(q>>>0<=h>>>0){break q}if((n|0)>-1){continue}break}}cg(a,48,n+18|0,18,0);tf(a,E,y-E|0);break m}g=n}cg(a,48,g+9|0,9,0)}break b}n=(f<<26>>31&9)+C|0;s:{if(d>>>0>11){break s}g=12-d|0;if(!g){break s}z=8;while(1){z=z*16;g=g-1|0;if(g){continue}break}if(w[n|0]==45){b=-(z+(-b-z));break s}b=b+z-z}h=v[m+44>>2];g=h>>31;g=$n(g^g+h,0,y);if((y|0)==(g|0)){t[m+15|0]=48;g=m+15|0}q=A|2;l=f&32;h=v[m+44>>2];k=g-2|0;t[k|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;u=l;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=u|w[g+71216|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i?1:(d|0)>0|b!=0)|(h-(m+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}f=m+16|0;d=!d|((h-m|0)-18|0)>=(d|0)?(y-(f+k|0)|0)+h|0:((d+y|0)-k|0)+2|0;i=d+q|0;cg(a,32,c,i,e);tf(a,n,q);cg(a,48,c,i,e^65536);g=f;f=h-f|0;tf(a,g,f);g=d;d=y-k|0;cg(a,48,g-(d+f|0)|0,0,0);tf(a,k,d)}cg(a,32,c,i,e^8192);gb=m+560|0;return((c|0)>(i|0)?c:i)|0}function iP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=C(0),M=0,N=0,O=C(0),P=0;j=gb-48|0;gb=j;m=x[a+480192>>1]?v[(B(b,872)+a|0)+1075648>>2]:m;n=a+1074312|0;f=B(b,872)+a|0;q=f+1075791|0;A=f+1075680|0;D=f+1075768|0;r=f+1075744|0;y=f+1075740|0;E=f+1075712|0;F=f+1075684|0;G=f+1075676|0;H=f+1075656|0;I=f+1075778|0;J=f+1075080|0;g=e&127;K=C(g>>>0);s=f+1075842|0;L=C(w[s|0]);f=1;while(1){e=w[d+o|0];if(e){h=e-48|0;a:{b:{c:{if((h&255)>>>0<10){break c}if((e-65&255)>>>0<=5){h=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Jm(a,b,3,0);if(!e|e-251>>>0<5){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=fx(e,50352,50384);if(!e){break g}h=kb[v[v[e>>2]+188>>2]](e,b)|0;e=(h|0)!=255;h=e?h:0;if(e|!m){break c}break d}if(m){break d}h=0;break c;case 13:h=0;if(!we(w[q|0])){break e}h=w[q|0]-1|0;break e;case 21:e=j+8|0;Db(e,n,28);h:{if(!Cb(e)){Db(j,n,1);e=0;if(!Cb(j)){break h}}e=u[D>>1]}h=B(v[r>>2],v[y>>2]);e=B(v[a+1074456>>2],e+v[A>>2]|0);h=Mb((Ac(pqa(oqa(h,h>>31,e,e>>31),jb,1048576,0),jb)|0)/2|0,1,127);break e;case 23:v[j+8>>2]=v[F>>2]/2;v[j>>2]=127;h=v[pd(j+8|0,j)>>2];break e;case 24:v[j+8>>2]=v[G>>2]/2;v[j>>2]=127;h=v[pd(j+8|0,j)>>2];break e;case 0:h=0;if(!m){break e}e=x[m+28>>1];if(!e){break e}h=e-1>>>7&127;break e;case 1:h=0;if(!m){break e}e=x[m+28>>1];if(!e){break e}h=e-1&127;break e;case 14:h=v[H>>2]>>>8|0;break e;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[I|0]-1|0}h=e&127;break e;case 12:h=v[J>>2]>>>7&1;break e;case 15:h=0;if(!m){break e}e=w[m+30|0];if(!e){break e}h=e-1&127;break e;case 25:l=s;e=g;i:{if(!c){break i}e=g;if(t[s|0]<0){break i}j:{if(i>>>0<3){break j}k=(j+16|0)+i|0;if(w[k-3|0]!=240){break j}e=g;if(w[k-2|0]>239){break i}}p=Dq(a,L,K);if(p<C(4294967296)&p>=C(0)){e=~~p>>>0;break i}e=0}h=e;t[l|0]=h;break e;case 18:e=i;k:{if(!e){e=0;break k}while(1){e=e-1|0;if(w[e+(j+16|0)|0]==240){break k}if(e){continue}break}}if(w[(j+16|0)+e|0]!=240|i-e>>>0<5){break a}h=0;e=e+5|0;if((i|0)!=(e|0)){while(1){h=w[(j+16|0)+e|0]+h|0;e=e+1|0;if((i|0)!=(e|0)){continue}break}}h=0-h&127;break e;case 20:break f;default:break a}}e=B(v[r>>2],v[y>>2]);h=e;k=e>>31;e=B(v[a+1074456>>2],v[E>>2]);h=Mb((Ac(pqa(oqa(h,k,e,e>>31),jb,67108864,0),jb)|0)/2|0,1,127)}e=((f^-1)&1)+i|0;t[e+(j+16|0)|0]=h;i=e+1|0;f=1;break b}e=m;l=a;h=0;k=b;l:{if(k>>>0>=256){break l}if(w[e+31|0]==17){e=x[(l+B(k,872)|0)+1075778>>1];h=(e?e-1|0:k)&15;break l}if(!Ij(e)){break l}h=w[e+31|0]-1&15}}e=(j+16|0)+i|0;m:{if(f&1){t[e|0]=h;break m}t[e|0]=w[e|0]<<4|h;i=i+1|0}f=(f^-1)&1}}o=o+1|0;if((o|0)!=31){continue}}break}e=((f^-1)&1)+i|0;n:{if(!e){break n}h=0;f=0;while(1){l=(j+16|0)+f|0;d=t[l|0];o:{p:{q:{if((d|0)==-16){if(e-f>>>0>=4){o=4;if((w[(f+j|0)+17|0]&254)==240){break p}}o=f;r:{while(1){o=o+1|0;if(o>>>0>=e>>>0){break r}if(w[(j+16|0)+o|0]!=247){continue}break}d=o-f|0;o=d+1|0;if(o>>>0>=d>>>0){break p}}t[(j+16|0)+e|0]=247;e=e+1|0;o=e-f|0;break q}if((d|0)>=0){if(h&255){f=f-1|0;t[f+(j+16|0)|0]=h;break o}f=f+1|0;h=0;break o}M=j,N=VS(d&255),v[M+8>>2]=N;v[j>>2]=e-f;o=v[Fb(j+8|0,j)>>2]}if(!o){break n}d=w[l|0];h=d>>>0<240?d:h}s=f;d=a;g=b;m=c;k=gb-32|0;gb=k;i=o;v[k+28>>2]=i;f=w[l|0];n=f-250|0;if(!(n>>>0>5|!(1<<n&37))){if(x[d+480188>>1]){f=0;while(1){n=(d+B(f,872)|0)+1075829|0;t[n|0]=127;t[n+1|0]=0;f=f+1|0;if(f>>>0<x[d+480188>>1]){continue}break}}f=w[l|0]}s:{t:{if((f&255)!=240){break t}n=w[l+1|0];if((n&254)!=240){break t}f=i>>>0<4;i=0;if(f){break s}r=(d+B(g,872)|0)+1074992|0;q=w[l+2|0];f=t[l+3|0];if(!(q|(n|0)==241|(f|0)<0)){l=d+B(g,872)|0;i=l+1075829|0;n=i;if(m){f=ch(Dq(d,C(w[i|0]),C((f&255)>>>0)))}t[n|0]=f;t[l+1075788|0]=0;i=4;f=l+1075080|0;m=Jq(d,r,!(v[f>>2]&32768),256);if((m|0)<0|!(w[f+1|0]&2)){break s}d=d+1298260|0;if(!Dd(d)){break s}Qq(v[d>>2],g,m>>>2&255,1);break s}if(!((n|0)==241|(q|0)!=1|(f|0)<0)){g=d+B(g,872)|0;i=g+1075830|0;u:{if(!m){break u}p=Dq(d,C(w[i|0]),C((f&255)>>>0));if(p<C(4294967296)&p>=C(0)){f=~~p>>>0;break u}f=0}t[i|0]=f;t[g+1075787|0]=0;Jq(d,r,!(v[g+1075080>>2]&32768),256);i=4;break s}if(!((n|0)==241|(q|0)!=2)){i=4;if((f&255)>>>0>31){break s}g=d+B(g,872)|0;t[g+1075837|0]=(f&240)>>>4;Jq(d,r,!(v[g+1075080>>2]&32768),256);break s}if(!((n|0)==241|(q|0)!=3)){i=4;g=Jm(d,g,3,0);if((f|0)<0|(g+5&255)>>>0<6){break s}g=(d+B(g,160)|0)+906284|0;p=C(C(((f^-1)&127)>>>0)/C(127));if(!m){z[g>>2]=p;break s}M=g,O=Dq(d,z[g>>2],p),z[M>>2]=O;break s}if(!((n|0)!=241?q&128:1)){break s}i=4;g=Jm(d,g,3,0);if((g+5&255)>>>0<6){break s}g=v[(d+B(g,160)|0)+906140>>2];if(!g|(f|0)<0){break s}l=(n|0)==241?q+128|0:q&127;p=C(C((f&255)>>>0)/C(127));if(!m){kb[v[v[g>>2]+44>>2]](g,l,p);break s}N=g,P=l,O=Dq(d,C(kb[v[v[g>>2]+48>>2]](g,l)),p),M=v[v[g>>2]+44>>2],kb[M](N|0,P|0,C(O));break s}v:{if(g>>>0<x[d+480188>>1]){f=g+1|0;break v}f=x[(d+B(g,872)|0)+1075778>>1];if(!f){break s}}if(w[(d+B(g,872)|0)+1075083|0]&4|x[d+480188>>1]<(f&65535)>>>0){break s}f=Jm(d,g,3,0);if(!f|f-251>>>0<5){break s}d=v[(d+B(f,160)|0)+906140>>2];if(!d){break s}f=w[l|0];if((f|0)==240){bc(k+16|0,zb(l),i);f=v[v[d>>2]+72>>2];g=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=g;kb[f|0](d,k)|0;break s}M=k,P=VS(f),v[M+12>>2]=P;f=k+12|0;g=v[Fb(f,k+28|0)>>2];v[k+12>>2]=0;hc(f,l,g);kb[v[v[d>>2]+68>>2]](d,v[k+12>>2])|0;i=v[k+28>>2]}gb=k+32|0;f=(i?i:o)+s|0}if(e>>>0>f>>>0){continue}break}}gb=j+48|0}function hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-336|0;gb=e;Zc(b,60);j=15;a:{if(!Hh(b,11401)){Zc(b,124);j=31;if(!Hh(b,12499)){break a}}Hd(a,536870912);u[a+480190>>1]=j;vc(b);b:{if(x[a+480190>>1]){while(1){d=Kr(b);v[(e+208|0)+(f<<2)>>2]=d;if(d>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;yh(a,1);Rb(b,4);h=Mr(b);if(h>>>0<178){break a}d=a;p=1776930/+(h>>>0)*1e4;c:{if(p<4294967296&p>=0){h=~~p>>>0;break c}h=0}v[d+480204>>2]=h;Rb(b,14);d:{e:{f:{if(x[a+480190>>1]){i=e+62|0;k=1;j=0;m=1;while(1){f=e+40|0;wV(b,f);d=v[((k<<2)+e|0)+204>>2];n=gb-16|0;gb=n;g=(B(k,104)+a|0)+484380|0;ud(g,1);v[g>>2]=d;t[g+37|0]=w[f+24|0]<<4;t[n+15|0]=w[f+25|0];t[n+14|0]=64;q=g,r=w[ac(n+15|0,n+14|0)|0]<<2,u[q+30>>1]=r;d=f+26|0;l=Ib(w[d|0]|w[d+1|0]<<8);d=f+28|0;d=Ib(w[d|0]|w[d+1|0]<<8);h=v[g>>2];g:{if(!h){break g}v[g+4>>2]=l;d=(d<<1)+l|0;v[g+8>>2]=d;if(h>>>0<=l>>>0){l=h-1|0;v[g+4>>2]=l}if(d>>>0>h>>>0){v[g+8>>2]=h;d=h}if(!(d-l>>>0>3?!(d>>>0<l>>>0|d>>>0<4):0)){v[g+4>>2]=0;v[g+8>>2]=0;break g}if(d>>>0<=l>>>0){break g}u[g+34>>1]=x[g+34>>1]|2}gb=n+16|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;j=j+1|0}f=f+1|0;if((i|0)!=(f|0)){continue}break}if(j>>>0>127){break b}d=e+176|0;Qk(d,3,e+40|0);h=e+192|0;Bc(h,d);v[22708]=0;Q(301,((k<<5)+a|0)+946304|0,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}vb(e+192|0);m=m+1|0;k=m&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}d=Tb(e+40|0,11286);v[22708]=0;f=a+946336|0;h=Q(889,f|0,d|0)|0;g=v[22708];v[22708]=0;j=1;h:{i:{j:{k:{if((g|0)!=1){if(!h){v[22708]=0;h=Q(70,e+192|0,11297)|0;j=v[22708];v[22708]=0;if((j|0)==1){break k}v[22708]=0;j=Q(889,f|0,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}vb(h)}vb(d);f=0;d=e+40|0;h=pV(b,d);if(!h){XB(d)}if(!h){break a}if(!pU(e+40|0)){break a}if(c){break h}break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(h)}vb(d);break e}u[e+38>>1]=0;if(w[e+40|0]){while(1){u[e+192>>1]=w[(e+f|0)+42|0]+1;q=e,r=x[Le(e+38|0,e+192|0)>>1],u[q+38>>1]=r;f=f+1|0;if(f>>>0<w[e+40|0]){continue}break}}d=e+40|1;h=w[d|0];f=w[e+40|0];g=a+484360|0;bf(Sb(g),f>>>0>h>>>0?w[d|0]:0);Fr(Sb(g),e+40|2,w[e+40|0]);if(x[a+480190>>1]==31){Rb(b,4)}k=0;v[e+32>>2]=0;v[e+28>>2]=0;v[e+24>>2]=0;t[e+23|0]=0;l=c&1;if(l){zg(a+484344|0,x[e+38>>1])}if(x[e+38>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(wh(h,k&65535,64)){break m}}Rb(b,1024);break l}while(1){n=Xc(_b(h,k),m,0);f=0;while(1){g=e+192|0;vn(g,b);d=n+B(f,6)|0;n:{o:{p:{q:{if(w[lc(g,0)|0]!=255){break q}t[(e+32|0)+f|0]=0;t[(e+24|0)+f|0]=0;g=lc(e+192|0,1);i=w[g|0];if((i|0)==252&j){t[g|0]=254;break o}switch(i-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}g=v[e+192>>2];v[e+16>>2]=g;v[e+8>>2]=g;gr(e+8|0,d);g=w[d|0];r:{if(!g){break r}t[(e+24|0)+f|0]=0;t[(e+32|0)+f|0]=g;if(g>>>0>48){break r}t[e+176|0]=8;q=e,r=w[pf(e+23|0,e+176|0)|0],t[q+23|0]=r}s:{t:{u:{v:{w:{x:{switch(w[d+3|0]){case 1:t[d+3|0]=1;break n;case 2:g=w[d+5|0];if(g&240){t[d+3|0]=3;t[d+5|0]=g>>>4;break n}g=g&15;if(g){t[d+3|0]=2;t[d+5|0]=g;break n}t[d+5|0]=0;break t;case 3:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=0;break n;case 4:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=1;break n;case 5:if(!w[d+1|0]){break u}t[d+3|0]=13;t[e+176|0]=63;t[e+15|0]=w[d+5|0]+(x[(B(w[d+1|0],104)+a|0)+484410>>1]>>>2|0);q=d,r=w[ac(e+176|0,e+15|0)|0],t[q+5|0]=r;if(!w[(e+24|0)+f|0]){break w}t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+5|0]=0;break t;case 6:g=w[d+1|0];if(!g){break u}t[d+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;i=w[d+5|0];g=g>>>0<i>>>0?0:g-i|0;t[d+5|0]=g;if(!w[(e+24|0)+f|0]){break w}t[d+4|0]=g;t[d+2|0]=1;t[d+5|0]=0;break t;case 8:i=w[(e+32|0)+f|0];g=w[d+5|0];o=i+(g>>>4|0)|0;t[(e+28|0)+f|0]=o;t[d+3|0]=2;g=g&15;t[(e+24|0)+f|0]=g;q=d,r=nU(g,i,o&255),t[q+5|0]=r;break w;case 9:t[e+176|0]=8;q=e,r=w[pf(e+23|0,e+176|0)|0],t[q+23|0]=r;break t;case 0:break v;case 7:break x;default:break t}}g=w[(e+32|0)+f|0];i=w[d+5|0];o=g-(i>>>4|0)|0;t[(e+28|0)+f|0]=o;t[d+3|0]=3;i=i&15;t[(e+24|0)+f|0]=i;q=d,r=nU(i,o&255,g),t[q+5|0]=r}if(!w[d+3|0]){break s}break n}if(!w[d+5|0]){break s}break t}t[d+5|0]=0}t[d+3|0]=0}i=w[(e+24|0)+f|0];if(!i){break n}o=(e+28|0)+f|0;g=w[o|0];if(g){t[(e+32|0)+f|0]=g;t[d|0]=g;t[d+5|0]=i;t[o|0]=0}t[d+3|0]=4;break n}t[d+3|0]=14;t[e+23|0]=9;break n}t[d+3|0]=13}f=f+1|0;if((f|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}k=k+1|0;if(k>>>0<x[e+38>>1]){continue}break}}y:{z:{A:{B:{if(c&2){j=x[a+480190>>1];if(!j){break A}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){Cg(Rc(e+192|0,8,1,0,0),c,b);j=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(j&65535)>>>0){continue}break}break B}j=x[a+480190>>1]}if((j&65535)!=15){break A}b=gb-16|0;gb=b;c=e+176|0;d=Tb(b,1514);Dc(c,d);vb(d);gb=b+16|0;v[22708]=0;U(463,e+192|0,c|0,e+23|0);b=v[22708];v[22708]=0;f=1;if((b|0)!=1){break z}a=P()|0;O()|0;Hb(e+176|0);break e}f=0;v[22708]=0;Q(2,e+192|0,9560)|0;b=v[22708];v[22708]=0;if((b|0)==1){break y}}b=e+192|0;Eb(a+1298304|0,b);vb(b);if(f){Hb(e+176|0)}Wc(a+1298316|0,x[a+480190>>1]==15?2374:12313);v[a+1298364>>2]=2;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e+192|0)}S(a|0);L()}f=1;break a}f=0}gb=e+336|0;return f|0}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-144|0;gb=d;vc(c);a:{b:{c:{if(!(!Br(c,d+128|0)|v[d+128>>2]!=1297239878|!((w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))!=1146437965?v[d+136>>2]==1482052408|(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))==1448293937:1))){e=gb-32|0;gb=e;j=hh(d+112|0);d:{e:{f:{g:{h:{while(1){v[22708]=0;h=Q(191,c|0,8)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}if(!h){break g}v[22708]=0;R(1169,e|0,c|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;R(1170,j|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break h}ed(e);continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;ed(e);break e}gb=e+32|0;break d}a=P()|0;O()|0}ke(j);S(a|0);L()}v[22708]=0;j=T(215,d+88|0)|0;c=v[22708];v[22708]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((c|0)!=1){h=Rc(d+84|0,8,1,1,0);if((w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))!=1146437965){break n}v[22708]=0;U(1154,d- -64|0,d+112|0,1296581714);c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;U(1154,d+40|0,d+112|0,1296318804);c=v[22708];v[22708]=0;if((c|0)==1){break c}c=d+40|0;Vc(j,c);xb(c);c=0;v[22708]=0;g=T(1155,d- -64|0)|0;e=v[22708];v[22708]=0;f=1;if((e|0)==1){break c}e=0;if(!g){break o}v[22708]=0;g=T(275,j|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}e=0;if(!g){break o}v[22708]=0;e=T(426,d- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;l=T(416,d- -64|0)|0;c=v[22708];v[22708]=0;r:{if((c|0)==1){break r}v[22708]=0;Q(318,d- -64|0,2)|0;c=v[22708];v[22708]=0;if((c|0)==1){break r}v[22708]=0;c=T(426,d- -64|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break p}}break c}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}v[22708]=0;R(1156,d+40|0,d- -64|0);g=v[22708];v[22708]=0;f=1;if((g|0)==1){break c}if(!Ib(w[d+40|0]|w[d+41|0]<<8)){break o}f=d+40|0;g=fc(f);k=Ve(f);c=(c>>>0)/(Ib(w[d+40|0]|w[d+41|0]<<8)>>>0)|0;f=1;if((Ib(w[g|0]|w[g+1|0]<<8)|0)!=(Ib(w[k|0]|w[k+1|0]<<8)+1|0)){break o}if((Ib(w[g|0]|w[g+1|0]<<8)|0)==2){Ap(h,2)}s:{if((l|0)!=16){if((l|0)!=8){break o}if(!Ib(w[d+46|0]|w[d+47|0]<<8)){Cf(h,1);break s}if((Ib(w[d+46|0]|w[d+47|0]<<8)|0)==2){Cf(h,18);break s}if((Ib(w[d+46|0]|w[d+47|0]<<8)|0)!=3){break o}Cf(h,17);break s}if(Ib(w[d+46|0]|w[d+47|0]<<8)){break o}Yi(h,16)}f=0}xb(d- -64|0);l=0;if(!f){break m}f=0;break i}v[22708]=0;U(1154,d- -64|0,d+112|0,1447576658);c=v[22708];v[22708]=0;t:{u:{if((c|0)!=1){v[22708]=0;U(1154,d+40|0,d+112|0,1128808782);c=v[22708];v[22708]=0;if((c|0)==1){break u}v[22708]=0;U(1154,d+16|0,d+112|0,1112491097);c=v[22708];v[22708]=0;if((c|0)==1){break k}c=d+16|0;Vc(j,c);xb(c);v[22708]=0;i=T(275,j|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break t}c=0;e=0;v:{if(!i){break v}v[22708]=0;i=T(275,d- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break t}c=0;e=0;if(!i){break v}v[22708]=0;i=Q(1157,d- -64|0,d+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break t}c=0;e=0;if(!i){break v}c=w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24);v[22708]=0;e=T(426,d+40|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break k}g=(c|0)!=1482052408;if(g){Rc(d+12|0,16,1,0,0);v[d+84>>2]=v[d+12>>2]}if((e|0)==6){Ap(h,3)}c=d+16|0;k=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=c|4;i=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=Ib(w[d+28|0]|w[d+29|0]<<8);l=Yb(w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24));v[22708]=0;m=T(195,j|0)|0;n=v[22708];v[22708]=0;o=1;if((n|0)==1){break k}e=B((e|0)==6?2:1,g?2:1);g=(k>>>0)/(e>>>0)|0;k=(i>>>0)/(e>>>0)|0;e=(m>>>0)/(e>>>0)|0}xb(d+40|0);xb(d- -64|0);if(o){break l}break i}f=P()|0;O()|0;break b}f=P()|0;O()|0;break j}break k}k=0;g=0}v[22708]=0;Q(1138,a|0,b|0)|0;f=v[22708];v[22708]=0;w:{x:{y:{z:{if((f|0)!=1){v[22708]=0;i=B(b,104)+a|0;f=i+484380|0;R(424,f|0,0);m=v[22708];v[22708]=0;if((m|0)==1){break z}v[f>>2]=e;k=g+k|0;v[i+484388>>2]=k;v[i+484384>>2]=g;if(!(e>>>0<k>>>0|k>>>0<=g+4>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=l>>>8|0;u[e+484410>>1]=c&65535?(l&16776960)>>>0>65536?256:c:256;c=v[a+480180>>2];v[22708]=0;U(1140,f|0,32,c|0);c=v[22708];v[22708]=0;A:{B:{C:{D:{if((c|0)!=1){v[22708]=0;U(1154,d- -64|0,d+112|0,1312902469);c=v[22708];v[22708]=0;if((c|0)==1){break D}v[22708]=0;c=T(275,d- -64|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break x}if(!c){break C}v[22708]=0;c=T(195,d- -64|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break x}v[22708]=0;W(503,d- -64|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break B}break x}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}v[22708]=0;c=Q(70,d+40|0,18720)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}v[22708]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break y}vb(c)}v[22708]=0;W(329,h|0,f|0,j|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break x}v[22708]=0;_h(f,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break x}xb(d- -64|0);f=1;break i}f=P()|0;O()|0;break w}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;vb(c);break w}f=P()|0;O()|0}xb(d- -64|0);break b}f=P()|0;O()|0;xb(d+40|0)}xb(d- -64|0);break b}xb(j);ke(d+112|0)}gb=d+144|0;return f|0}f=P()|0;O()|0;xb(d- -64|0)}xb(j)}ke(d+112|0);S(f|0);L()}function Ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=gb-1824|0;gb=d;vc(b);g=gb-32|0;gb=g;e=g+24|0;k=d+1224|0;mV(e,k);i=yb(e);e=v[g+28>>2];j=v[g+24>>2];v[g+8>>2]=j;v[g+12>>2]=e;v[g>>2]=j;v[g+4>>2]=e;j=g+16|0;e=b;cc(j,e,g);j=yb(j);if((j|0)==(i|0)){Rb(e,yb(g+24|0))}gb=g+32|0;e=(i|0)==(j|0);if(!e){lV(k)}a:{if(!e){break a}if(!vV(d+1224|0)){break a}if(!cC(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;h=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=h;Hd(a,1);e=a+1074312|0;Sf(e,83);Ob(e,84,1);Ob(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Zc(b,20);j=a+480188|0;h=1;g=1;while(1){i=B(h,104)+a|0;k=i+484380|0;e=((h<<5)+a|0)+946304|0;dC(b,d+16|0,k,e,1);m=v[k>>2];b:{if(!w[lc(e,0)|0]){break b}c:{if(sd(e,13841,3)){if(sd(e,13845,3)){break c}}if(w[lc(e,5)|0]==58){break b}}g=0}if(Ib(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){z=i+484384|0,A=Ib(w[d+42|0]|w[d+43|0]<<8),v[z>>2]=A;z=i+484388|0,A=Ib(w[d+42|0]|w[d+43|0]<<8)+(Ib(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[z>>2]=A;xk(k)}d:{if(Ib(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break d}}v[d+1064>>2]=5;z=d,A=v[ap(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}f=f+m|0;h=h+1|0;if((h|0)!=16){continue}break}r=d+1064|0;e=r;BV(b,e);p=a+484360|0;Fr(Sb(p),e|2,128);h=0;m=AV(b,Sb(p),w[e|0],f,j,0,1);e=e|1;if(!(m>>>0<2?w[e|0]|w[r|0]:1)){break a}if(mf(b)+65536>>>0<(m<<10)+f>>>0){break a}if(!c){h=1;break a}if(!w[e|0]){t[e|0]=120}if(!sd(d+1200|0,12123,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;s=1773447.5/(+(240-w[e|0]|0)*122)*1e4;f:{if(s<4294967296&s>=0){e=~~s>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=g?4:5;z=d,A=v[ap(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A;break e}v[d+16>>2]=g?1:2;z=d,A=v[ap(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;e=d+1048|0;Zj(e,3,d+1200|0);f=d+16|0;Bc(f,e);Eb(a+1298268|0,f);vb(f);k=0;yh(a,0);y=v[b+8>>2];u[d+1046>>1]=0;g:{if(m){while(1){f=Sb(p);z=d,A=bC(Vb(f),Zb(f),d+1046|0),v[z+16>>2]=A;z=d,A=Zb(f),v[z+1048>>2]=A;f=d+16|0;e=Gb(f,d+1048|0);uV(b,f);if(e){k=aC(d+16|0,0)+k|0;if(k>>>0>512){break g}}j=0;f=0;o=0;while(1){r=tV(d+16|0,j);h=0;while(1){e=f;l=yf(r,h);q=w[lc(l,2)|0]&15;i=w[lc(l,3)|0];f=0;h:{if(!(e&255)|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}v[d+1196>>2]=6}i:{j:{k:{switch(q-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1?i>>>0>=32:0){break j}l=(q|0)!=1;if(!(l|!i|i>>>0>2)){v[d+1048>>2]=2;z=d,A=v[ap(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}if(l){break i}if((i|0)!=55){if((i|0)!=71){break i}if((e|0)<3){break j}break i}if((e|0)<=2){break j}break i;case 10:v[d+1196>>2]=6;break i;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[ap(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((q|0)!=13){break i}o=((i|j)!=0)+o|0;f=1;break i;case 14:break k;default:break i}}v[d+1048>>2]=3;z=d,A=v[ap(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}v[d+1196>>2]=g}h=h+1|0;if((h|0)!=4){continue}break}j=j+1|0;if((j|0)!=64){continue}break}if((o-1&255)>>>0<2){v[d+1196>>2]=6}n=(o&255)+n|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(m>>>0>(f&65535)>>>0){continue}break}}if(!(v[d+1196>>2]!=6|m+32>>>0>=n>>>0)){v[d+1196>>2]=5}Zc(b,y);o=c&1;if(o){zg(a+484344|0,m)}if(m){l=a+484344|0;j=0;while(1){uV(b,d+16|0);l:{if(!o){break l}if(!wh(l,j&65535,64)){break l}v[d+1048>>2]=0;n=0;while(1){q=Xc(_b(l,j),n,0);p=tV(d+16|0,n);i=0;while(1){f=yf(p,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=q+B(i,6)|0;gr(d+8|0,e);m:{n:{o:{p:{q:{r:{s:{t:{f=w[e+5|0];if(f){h=e+3|0;g=(d+1048|0)+i|0;k=w[e+3|0];if((k|0)!=14){break t}t[g|0]=0;break q}h=(d+1048|0)+i|0;t[h|0]=0;k=w[e+3|0];if(!k){break r}h=e+3|0;break s}g=w[g|0];if(!g){break s}u:{if(g>>>0>=16){t[e+2|0]=3;g=g>>>4|0;break u}t[e+2|0]=4}t[e+4|0]=g}v:{w:{switch(k-12|0){case 1:g=v[d+1196>>2];if((g|0)==6){break v}k=10;t[h|0]=10;break o;case 0:f=f&127;t[e+5|0]=f;k=12;break p;case 2:break q;case 3:break w;default:break p}}k=15;f=f&15;t[e+5|0]=f;break p}t[e+5|0]=0;break n}t[h|0]=0;break m}if(v[d+1196>>2]>3?f>>>0<=1:0){break n}k=10;t[h|0]=10;t[(d+1048|0)+i|0]=f}g=v[d+1196>>2]}if((g|0)>1){break n}x:{y:{z:{switch(k|0){case 0:if(f>>>0>2){break y}break;case 2:break x;case 1:break y;default:break z}}t[h|0]=0;break m}t[h|0]=1;break m}g=f&15;if(g){t[h|0]=2;t[e+5|0]=g;break m}if(f>>>0<16){break m}t[h|0]=3;t[e+5|0]=f>>>4;break m}Pf(e)}i=i+1|0;if((i|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}j=j+1|0;if((m|0)!=(j|0)){continue}break}}h=18720;f=v[d+1196>>2];if(f>>>0<7){h=v[(f<<2)+33208>>2]}f=d+16|0;e=Tb(f,5437);Eb(a+1298304|0,e);vb(e);f=Tb(f,8043);Eb(a+1298316|0,f);vb(f);Wc(a+1298328|0,h);v[a+1298364>>2]=2;h=1;if(!(c&2)){break a}i=1;while(1){c=B(i,104)+a|0;f=c+484384|0;Rb(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;c=d+16|0;Rc(c,8,1,1,0);Cg(c,f,b);i=i+1|0;if((i|0)!=16){continue}break}break a}h=0}gb=d+1824|0;return h|0}function zK(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-48|0;gb=g;v[g+44>>2]=c;u[g+32>>1]=0;u[g+16>>1]=65535;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Et(g+44|0,g+32|0,g+16|0)){if(me(v[b+24>>2]+484344|0,c&65535)){break j}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}c=_b(v[b+24>>2]+484344|0,c);if(!(v[c+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}if(!(x[v[b+24>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);Aj(c,a,b);vb(b);vb(a);break i}e=Xc(c,d,e&65535);k:{switch(f-1|0){default:l:{m:{n:{if(!ce(e)){if(!Xt(e)){break n}}c=g+16|0;IO(c,v[b+24>>2],w[e|0],w[e+1|0]);v[22708]=0;R(2040,g+32|0,c|0);c=v[22708];v[22708]=0;b=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[22708]=0;Q(70,g+32|0,13833)|0;c=v[22708];v[22708]=0;if((c|0)==1){break l}}v[22708]=0;c=ce(e);d=v[22708];v[22708]=0;if((d|0)==1){break c}o:{if(c){v[22708]=0;Q(70,g|0,7238)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}break o}if(Xt(e)){v[22708]=0;Q(70,g|0,7548)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break o}break c}v[22708]=0;Q(70,g|0,13833)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}}c=a;a=g+32|0;Aj(c,a,g);vb(g);vb(a);if(!b){break i}vb(g+16|0);break i}c=P()|0;O()|0;break a;case 0:b=e+1|0;p:{if(w[e+1|0]){hv(g+32|0,b);break p}Tb(g+32|0,13838)}q:{if(w[b|0]){v[22708]=0;Q(70,g+16|0,8055)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break q}break d}v[22708]=0;Q(70,g+16|0,13838)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 1:r:{if(Bg(e)){Tb(g+32|0,14905);break r}if(w[e+2|0]){He(g+32|0,1,tz(v[v[b+24>>2]+8>>2],w[e+2|0]));break r}Tb(g+32|0,14905)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break e}s:{if(b){v[22708]=0;Q(70,g+16|0,14905)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}break s}if(w[e+2|0]){v[22708]=0;Q(70,g+16|0,2597)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break s}break e}v[22708]=0;Q(70,g+16|0,14905)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 3:t:{if(Bg(e)){q=g,r=Hq(e)&255,v[q>>2]=r;iC(g+32|0,g);break t}if(w[e+2|0]){hv(g+32|0,e+4|0);break t}Tb(g+32|0,13838)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break f}u:{if(b){v[22708]=0;Q(70,g+16|0,2581)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}break u}if(w[e+2|0]){v[22708]=0;Q(70,g+16|0,2581)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break u}break f}v[22708]=0;Q(70,g+16|0,13838)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 2:v:{if(Bg(e)){q=g,r=(Eo(e)&3840)!=0,t[q|0]=r;i=gb-32|0;gb=i;t[i+24|0]=44;v[i+16>>2]=-1;v[i+20>>2]=0;v[i+8>>2]=1058;v[i+12>>2]=1;n=g+32|0;c=g;b=gb+-64|0;gb=b;d=b;k=i+8|0;l=v[k>>2]&2?16:10;j=gb-32|0;gb=j;f=He(j+16|0,1,0);w:{x:{y:{while(1){h=Jb(f);m=Jb(f);o=Ab(f);p=w[c|0];v[22708]=0;ha(91,j+8|0,h|0,m+o|0,p|0,l|0);h=v[22708];v[22708]=0;if((h|0)==1){break x}if(!v[j+12>>2]){break y}h=Ab(f);v[22708]=0;v[j+4>>2]=h;h=xf(j+4|0);m=v[22708];v[22708]=0;if((m|0)!=1){v[22708]=0;U(75,f|0,h|0,0);h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break x}c=v[j+8>>2];l=Jb(f);v[22708]=0;R(76,f|0,c-l|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;R(77,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break x}vb(f);gb=j+32|0;break w}}a=P()|0;O()|0;vb(f);S(a|0);L()}c=b+16|0;Ll(c,b,k);v[22708]=0;U(89,b+32|0,c|0,k|0);c=v[22708];v[22708]=0;z:{A:{B:{C:{D:{if((c|0)!=1){v[22708]=0;U(90,b+48|0,b+32|0,k|0);c=v[22708];v[22708]=0;if((c|0)==1){break D}v[22708]=0;R(72,n|0,b+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break C}vb(b+48|0);vb(b+32|0);vb(b+16|0);vb(b);gb=b- -64|0;break z}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b+48|0)}vb(b+32|0)}vb(b+16|0);vb(b);S(a|0);L()}gb=i+32|0;break v}if(w[e+3|0]){He(g+32|0,1,sz(v[v[b+24>>2]+8>>2],w[e+3|0]));break v}Tb(g+32|0,13839)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break g}E:{if(b){v[22708]=0;Q(70,g+16|0,9551)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}break E}if(w[e+3|0]){v[22708]=0;Q(70,g+16|0,9551)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break E}break g}v[22708]=0;Q(70,g+16|0,13839)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a);break i;case 4:break k}}F:{if(Bg(e)){q=g,r=Eo(e)&255,v[q>>2]=r;iC(g+32|0,g);break F}if(w[e+3|0]){hv(g+32|0,e+5|0);break F}Tb(g+32|0,13838)}v[22708]=0;b=Bg(e);c=v[22708];v[22708]=0;if((c|0)==1){break h}G:{if(b){v[22708]=0;Q(70,g+16|0,8342)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}break G}if(w[e+3|0]){v[22708]=0;Q(70,g+16|0,8342)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break G}break h}v[22708]=0;Q(70,g+16|0,13838)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}}c=a;a=g+32|0;b=g+16|0;Aj(c,a,b);vb(b);vb(a)}gb=g+48|0;return}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);if(!b){break a}}vb(g+16|0)}S(c|0);L()}function by(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0;h=gb-80|0;gb=h;v[h+76>>2]=b;z=h+55|0;x=h+56|0;b=0;a:{b:{c:while(1){d:{if((p|0)<0){break d}if((2147483647-p|0)<(b|0)){v[115189]=61;p=-1;break d}p=b+p|0}e:{f:{k=v[h+76>>2];b=k;i=w[b|0];if(i){while(1){g:{i=i&255;h:{if(!i){i=b;break h}if((i|0)!=37){break g}i=b;while(1){if(w[b+1|0]!=37){break h}j=b+2|0;v[h+76>>2]=j;i=i+1|0;m=w[b+2|0];b=j;if((m|0)==37){continue}break}}b=i-k|0;if(a){tf(a,k,b)}if(b){continue c}q=-1;i=1;j=h;r=!Rh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(!(r|w[b+2|0]!=36)){q=t[b+1|0]-48|0;y=1;i=3}b=i+b|0;v[j+76>>2]=b;s=0;l=t[b|0];j=l-32|0;i:{if(j>>>0>31){i=b;break i}i=b;j=1<<j;if(!(j&75913)){break i}while(1){i=b+1|0;v[h+76>>2]=i;s=j|s;l=t[b+1|0];j=l-32|0;if(j>>>0>=32){break i}b=i;j=1<<j;if(j&75913){continue}break}}j:{if((l|0)==42){j=h;k:{l:{if(!Rh(t[i+1|0])){break l}b=v[h+76>>2];if(w[b+2|0]!=36){break l}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;o=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break k}if(y){break b}y=0;o=0;if(a){b=v[c>>2];v[c>>2]=b+4;o=v[b>>2]}b=v[h+76>>2]+1|0}v[j+76>>2]=b;if((o|0)>-1){break j}o=0-o|0;s=s|8192;break j}o=SI(h+76|0);if((o|0)<0){break b}b=v[h+76>>2]}m=-1;m:{if(w[b|0]!=46){break m}if(w[b+1|0]==42){n:{if(!Rh(t[b+2|0])){break n}b=v[h+76>>2];if(w[b+3|0]!=36){break n}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;m=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break m}if(y){break b}if(a){b=v[c>>2];v[c>>2]=b+4;m=v[b>>2]}else{m=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break m}v[h+76>>2]=b+1;m=SI(h+76|0);b=v[h+76>>2]}i=0;while(1){r=i;n=-1;if(t[b|0]-65>>>0>57){break a}l=b+1|0;v[h+76>>2]=l;i=t[b|0];b=l;i=w[(i+B(r,58)|0)+70687|0];if(i-1>>>0<8){continue}break}o:{p:{if((i|0)!=19){if(!i){break a}if((q|0)>=0){v[(q<<2)+e>>2]=i;b=(q<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break p}if(!a){break e}RI(h- -64|0,i,c,g);l=v[h+76>>2];break o}if((q|0)>-1){break a}}b=0;if(!a){continue c}}j=s&-65537;i=s&8192?j:s;n=0;q=2378;s=x;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{b=t[l-1|0];b=r?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break q;case 9:case 13:case 14:case 15:break r;case 27:break w;case 12:case 17:break z;case 23:break A;case 0:case 32:break B;case 24:break C;case 22:break D;case 29:break E;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break f;default:break F}}G:{switch(b-65|0){case 0:case 4:case 5:case 6:break r;case 2:break u;case 1:case 3:break f;default:break G}}if((b|0)==83){break v}break f}l=v[h+64>>2];k=v[h+68>>2];q=2378;break y}b=0;H:{switch(r&255){case 0:v[v[h+64>>2]>>2]=p;continue c;case 1:v[v[h+64>>2]>>2]=p;continue c;case 2:i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c;case 3:u[v[h+64>>2]>>1]=p;continue c;case 4:t[v[h+64>>2]]=p;continue c;case 6:v[v[h+64>>2]>>2]=p;continue c;case 7:break H;default:continue c}}i=v[h+64>>2];v[i>>2]=p;v[i+4>>2]=p>>31;continue c}m=m>>>0>8?m:8;i=i|8;b=120}j=x;C=b&32;r=v[h+68>>2];k=r;l=v[h+64>>2];if(k|l){while(1){j=j-1|0;t[j|0]=C|w[(l&15)+71216|0];D=!k&l>>>0>15|(k|0)!=0;r=k;k=k>>>4|0;l=(r&15)<<28|l>>>4;if(D){continue}break}}k=j;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break x}q=(b>>>4|0)+2378|0;n=2;break x}b=x;j=v[h+68>>2];k=j;l=v[h+64>>2];if(j|l){while(1){b=b-1|0;t[b|0]=l&7|48;r=!k&l>>>0>7|(k|0)!=0;j=k;k=j>>>3|0;l=(j&7)<<29|l>>>3;if(r){continue}break}}k=b;if(!(i&8)){break x}b=x-k|0;m=(b|0)<(m|0)?m:b+1|0;break x}b=v[h+68>>2];k=b;l=v[h+64>>2];if((b|0)<-1?1:(b|0)<=-1){k=0-(k+((l|0)!=0)|0)|0;l=0-l|0;v[h+64>>2]=l;v[h+68>>2]=k;n=1;q=2378;break y}if(i&2048){n=1;q=2379;break y}n=i&1;q=n?2380:2378}k=$n(l,k,x)}i=(m|0)>-1?i&-65537:i;b=v[h+68>>2];j=b;l=v[h+64>>2];if(!((l|0)!=0|(b|0)!=0|m)){m=0;k=x;break f}b=!(j|l)+(x-k|0)|0;m=(b|0)<(m|0)?m:b;break f}b=v[h+64>>2];k=b?b:14140;b=mt(k,0,m);s=b?b:k+m|0;i=j;m=b?b-k|0:m;break f}if(m){b=v[h+64>>2];break t}b=0;cg(a,32,o,0,i);break s}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];b=h+8|0;v[h+64>>2]=b;m=-1}j=b;b=0;I:{while(1){k=v[j>>2];if(!k){break I}k=KI(h+4|0,k);l=(k|0)<0;if(!(l|k>>>0>m-b>>>0)){j=j+4|0;b=b+k|0;if(m>>>0>b>>>0){continue}break I}break}n=-1;if(l){break a}}cg(a,32,o,b,i);if(!b){b=0;break s}j=0;l=v[h+64>>2];while(1){k=v[l>>2];if(!k){break s}k=KI(h+4|0,k);j=k+j|0;if((j|0)>(b|0)){break s}tf(a,h+4|0,k);l=l+4|0;if(b>>>0>j>>>0){continue}break}}cg(a,32,o,b,i^8192);b=(b|0)<(o|0)?o:b;continue c}b=kb[f|0](a,A[h+64>>3],o,m,i,b)|0;continue c}t[h+55|0]=v[h+64>>2];m=1;k=z;i=j;break f}j=b+1|0;v[h+76>>2]=j;i=w[b+1|0];b=j;continue}}n=p;if(a){break a}if(!y){break e}b=1;while(1){a=v[(b<<2)+e>>2];if(a){RI((b<<3)+d|0,a,c,g);n=1;b=b+1|0;if((b|0)!=10){continue}break a}break}n=1;if(b>>>0>9){break a}while(1){n=1;b=b+1|0;if((b|0)==10){break a}n=-1;if(!v[(b<<2)+e>>2]){continue}break}break a}l=s-k|0;m=(l|0)>(m|0)?l:m;j=m+n|0;b=(j|0)>(o|0)?j:o;cg(a,32,b,j,i);tf(a,q,n);cg(a,48,b,j,i^65536);cg(a,48,m,l,0);tf(a,k,l);cg(a,32,b,j,i^8192);continue}break}n=0;break a}n=-1}gb=h+80|0;return n}function gL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-448|0;gb=e;a:{if(qk(b)){break a}f=w[ul(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}f=e+184|0;Ld(f);g=v[e+184>>2];Ld(e+416|0);h=tl(g,v[e+420>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=uc(e+432|0,18720);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){a=ba(8)|0;v[22708]=0;c=Q(2058,e+416|0,c|0)|0;b=v[22708];v[22708]=0;f:{g:{h:{if((b|0)!=1){v[22708]=0;U(2038,e+184|0,14722,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}rc(a,e+184|0);d=0;v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break g}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}if(!d){break e}d=ba(8)|0;v[22708]=0;f=Q(2058,e+384|0,b|0)|0;b=v[22708];v[22708]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22708]=0;U(2038,e+400|0,14758,f|0);a=v[22708];v[22708]=0;if((a|0)==1){break q}v[22708]=0;R(2055,e+416|0,e+400|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break p}v[22708]=0;c=Q(2058,e+368|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break o}v[22708]=0;U(2059,e+184|0,e+416|0,c|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break n}rc(d,e+184|0);v[22708]=0;U(186,d|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(c)}vb(e+416|0)}vb(e+400|0)}vb(f)}if(!a){break c}da(d|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=uc(e+352|0,18720);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Gc(e+176|0,e+168|0)){a=ba(8)|0;v[22708]=0;c=Q(2058,e+416|0,c|0)|0;b=v[22708];v[22708]=0;r:{s:{t:{if((b|0)!=1){v[22708]=0;U(2038,e+184|0,14722,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break t}rc(a,e+184|0);d=0;v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break s}b=P()|0;O()|0;break r}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=uc(e+336|0,9591);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Gc(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=uc(e+320|0,2693);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Gc(e- -64|0,e+56|0)){v[a+52>>2]=0;break e}v[e+312>>2]=d;v[e+316>>2]=b;f=uc(e+304|0,8575);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Gc(e+48|0,e+40|0)){v[a+52>>2]=1;break e}v[e+296>>2]=d;v[e+300>>2]=b;b=uc(e+288|0,6363);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Gc(e+32|0,e+24|0)){v[a+52>>2]=2;break e}a=ba(8)|0;v[22708]=0;c=Q(2058,e+416|0,c|0)|0;b=v[22708];v[22708]=0;u:{v:{w:{if((b|0)!=1){v[22708]=0;U(2038,e+184|0,11817,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break w}rc(a,e+184|0);d=0;v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break v}b=P()|0;O()|0;break u}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=uc(e+272|0,8812);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Gc(e+144|0,e+136|0)){break e}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=uc(e+256|0,12683);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;x:{if(Gc(e+128|0,e+120|0)){break x}v[e+248>>2]=c;v[e+252>>2]=d;b=uc(e+240|0,12688);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Gc(e+112|0,e+104|0)){break x}v[e+232>>2]=c;v[e+236>>2]=d;b=uc(e+224|0,9896);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Gc(e+96|0,e+88|0)){break x}v[e+216>>2]=c;v[e+220>>2]=d;b=uc(e+208|0,6427);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Gc(e+80|0,e+72|0)){break x}a=ba(8)|0;v[22708]=0;c=Q(70,e+184|0,8848)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break e}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=xK(v[a+56>>2]),v[i+204>>2]=j;if(!My(e+184|0,v[b>>2]+24648|0)){break e}Vz(v[b>>2],e+184|0)}gb=e+448|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function lJ(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=C(0),v=0,w=0,x=0,y=0,A=C(0),D=0,E=0,F=0,G=C(0),H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=0,P=0,Q=0,R=0;if((d|0)>=1){while(1){D=B(v,2304)+b|0;p=c;x=0;s=gb-128|0;while(1){m=D+(x<<2)|0;o=0;n=s;j=n;while(1){h=z[B(15-o|0,72)+m>>2];w=B(o,72)+m|0;i=z[w+1152>>2];l=C(h+i);k=z[w>>2];t=z[B(31-o|0,72)+m>>2];A=C(k+t);z[j>>2]=l+A;w=B(o,12);h=C(C(h-i)*z[w+68288>>2]);i=C(C(k-t)*z[w+68292>>2]);z[j+64>>2]=h+i;k=C(A-l);l=z[w+68296>>2];z[j+32>>2]=k*l;z[j+96>>2]=C(i-h)*l;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){l=z[n+8>>2];k=z[n+20>>2];i=C(l+k);t=z[n+4>>2];A=z[n+24>>2];G=C(t+A);h=C(i+G);H=z[n+12>>2];I=z[n+16>>2];J=C(H+I);K=z[n>>2];L=z[n+28>>2];M=C(K+L);N=C(J+M);z[n>>2]=h+N;z[n+16>>2]=C(N-h)*C(.7071067690849304);h=C(M-J);i=C(C(h+C(G-i))*C(.7071067690849304));z[n+24>>2]=C(h-i)*C(1.3065630197525024);z[n+8>>2]=C(h+i)*C(.5411961078643799);h=C(K-L);l=C(l-k);k=C(t-A);t=C(C(l+k)*C(.7071067690849304));i=C(h+t);k=C(k+h);l=C(C(C(H-I)+l)-C(k*C(.1989123672246933)));k=C(k+C(l*C(.3826834261417389)));z[n+28>>2]=C(i-k)*C(2.562915563583374);z[n+4>>2]=C(i+k)*C(.509795606136322);h=C(h-t);i=C(l-C(k*C(.1989123672246933)));z[n+20>>2]=C(h+i)*C(.8999761939048767);z[n+12>>2]=C(h-i)*C(.601344883441925);n=n+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;l=z[s+32>>2];h=z[s+96>>2];k=z[s+64>>2];while(1){z[m>>2]=z[s+(o<<2)>>2];n=m;o=o+1|0;m=s+(o<<2)|0;i=z[m+96>>2];z[n+72>>2]=C(h+k)+i;k=l;l=z[m+32>>2];z[n+144>>2]=k+l;k=z[m- -64>>2];z[n+216>>2]=i+C(h+k);m=n+288|0;h=i;if((o|0)!=7){continue}break}z[n+288>>2]=z[s+28>>2];h=z[s+124>>2];z[n+360>>2]=z[s+92>>2]+h;i=z[s+60>>2];z[n+504>>2]=h;z[n+432>>2]=i;x=x+1|0;if((p|0)!=(x|0)){continue}break}v=v+1|0;if((v|0)!=(d|0)){continue}break}}F=hc(f,a,3840);P=d<<5;v=0;while(1){m=gb-32|0;gb=m;o=(v<<8)+F|0;x=(v<<2)+b|0;z[o+4080>>2]=z[x+1152>>2];n=d;f=n-1|0;w=x+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[x>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[x+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[x+4>>2];z[o+4348>>2]=z[w+4>>2];D=(B(v,P)<<1)+e|0;E=D+(f<<1)|0;rt(E,n,o+244|0);f=n<<6;rt(f+E|0,n,o+500|0);rt(D,n,o+240|0);rt(f+D|0,n,o+496|0);O=o+3840|0;p=68384;f=14;while(1){s=f;q=f<<4;j=q+O|0;g=B(31-f|0,72);l=z[g+x>>2];z[j>>2]=l;z[j+4>>2]=z[g+w>>2];g=g|4;z[j+8>>2]=z[g+x>>2];z[j+12>>2]=z[g+w>>2];g=B(f,72);r=g+76|0;z[j+256>>2]=z[r+x>>2];z[j+260>>2]=z[r+w>>2];g=g+72|0;z[j-248>>2]=z[g+x>>2];z[j-244>>2]=z[g+w>>2];h=z[p>>2];i=z[p+4>>2];q=o+q|0;t=z[q>>2];k=C(C(l*h)-C(i*t));z[m+16>>2]=k;l=C(C(i*l)+C(h*t));z[m>>2]=l;r=f<<2;f=1;while(1){g=f<<2;t=z[g+j>>2];A=z[g+q>>2];z[g+(m+16|0)>>2]=C(h*t)-C(i*A);z[g+m>>2]=C(i*t)+C(h*A);f=f+1|0;if((f|0)!=4){continue}break}j=(r<<2)+O|0;q=j-3584|0;r=j-256|0;h=z[p+12>>2];i=z[p+8>>2];f=0;while(1){g=f<<2;t=z[g+q>>2];A=z[g+r>>2];z[g+(m+16|0)>>2]=C(C(h*t)-C(i*A))+k;z[g+m>>2]=l+C(C(h*A)+C(i*t));f=f+1|0;if((f|0)!=4){g=f<<2;k=z[g+(m+16|0)>>2];l=z[g+m>>2];continue}break}q=j-3328|0;r=j-512|0;h=z[p+20>>2];i=z[p+16>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-3072|0;r=j-768|0;h=z[p+28>>2];i=z[p+24>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(h*k)-C(i*l))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2816|0;r=j-1024|0;h=z[p+36>>2];i=z[p+32>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2560|0;r=j-1280|0;h=z[p+44>>2];i=z[p+40>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(h*k)-C(i*l))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2304|0;r=j-1536|0;h=z[p+52>>2];i=z[p+48>>2];f=0;while(1){g=f<<2;y=g+m|0;l=z[g+r>>2];k=z[g+q>>2];z[y>>2]=z[y>>2]+C(C(h*l)+C(i*k));g=g+(m+16|0)|0;z[g>>2]=C(C(i*l)-C(h*k))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=j-2048|0;q=j-1792|0;h=z[p+60>>2];i=z[p+56>>2];f=0;while(1){j=f<<2;r=j+m|0;l=z[j+q>>2];k=z[g+j>>2];z[r>>2]=z[r>>2]+C(C(h*l)+C(i*k));j=j+(m+16|0)|0;z[j>>2]=C(C(h*k)-C(i*l))+z[j>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(n,15-s|0)<<1;Q=f+E|0,R=zj(z[m+20>>2]),u[Q>>1]=R;j=B(n,s+17|0)<<1;Q=j+E|0,R=zj(z[m+4>>2]),u[Q>>1]=R;Q=f+D|0,R=zj(z[m+16>>2]),u[Q>>1]=R;Q=j+D|0,R=zj(z[m>>2]),u[Q>>1]=R;f=B(n,47-s|0)<<1;Q=f+E|0,R=zj(z[m+28>>2]),u[Q>>1]=R;j=B(n,s+49|0)<<1;Q=j+E|0,R=zj(z[m+12>>2]),u[Q>>1]=R;Q=f+D|0,R=zj(z[m+24>>2]),u[Q>>1]=R;Q=j+D|0,R=zj(z[m+8>>2]),u[Q>>1]=R;f=s-1|0;p=p- -64|0;if(s){continue}break}gb=m+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+F>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}hc(a,(b<<2)+F|0,3840)}}function pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=gb-752|0;gb=e;vc(b);f=gb-32|0;gb=f;d=f+24|0;j=e+144|0;vU(d,j);h=yb(d);d=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;g=f+16|0;d=b;cc(g,d,f);g=yb(g);if((g|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(g|0)==(h|0);if(!d){uU(j)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!d){break m}if(!xU(e+144|0)){break m}if(!Pb(b,Qc(wU(e+144|0),jb))){break m}if(!c){o=1;break m}Hd(a,262144);f=e+104|0;Mk(f,2,e+144|0);d=e+24|0;Bc(d,f);Eb(a+1298268|0,d);vb(d);h=Tb(d,5450);Eb(a+1298304|0,h);vb(h);d=Tb(d,7395);Eb(a+1298316|0,d);vb(d);d=gb-16|0;gb=d;g=f;f=Tb(d,1302);Dc(g,f);vb(f);gb=d+16|0;t[e+8|0]=w[e+174|0];d=w[e+173|0];v[22708]=0;t[e+127|0]=d;R(879,e+128|0,e+127|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;Y(372,e+24|0,e+104|0,e+8|0,e+128|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}d=e+24|0;Eb(a+1298328|0,d);vb(d);vb(e+128|0);f=e+104|0;Hb(f);v[a+480208>>2]=12;v[a+1298364>>2]=5;u[a+480188>>1]=w[e+182|0]|w[e+183|0]<<8;u[e+24>>1]=w[e+178|0]|w[e+179|0]<<8;u[e+104>>1]=3999;C=a,D=x[Pc(d,f)>>1],u[C+480190>>1]=D;LX(Sb(a+484360|0),e+240|0,w[e+176|0]|w[e+177|0]<<8);if(x[a+480188>>1]){d=0;while(1){f=(d<<5)+a|0;We(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}d=e+24|0;Td(d,b,B(w[e+178|0]|w[e+179|0]<<8,80));l=jc(e+104|0,d);xb(d);if(x[a+480190>>1]){h=c&2;j=e+72|0;d=0;while(1){v[22708]=0;R(880,l|0,e+24|0);f=v[22708];v[22708]=0;if((f|0)==1){break l}v[22708]=0;Mk(e+8|0,2,j);f=v[22708];v[22708]=0;n:{o:{p:{if((f|0)==1){break p}v[22708]=0;R(324,e+128|0,e+8|0);f=v[22708];v[22708]=0;if((f|0)==1){break p}v[22708]=0;d=d+1|0;Q(301,((d<<5)+a|0)+946304|0,e+128|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}f=e+128|0;vb(f);v[22708]=0;g=f;f=(B(d,104)+a|0)+484380|0;U(881,g|0,e+24|0,f|0);g=v[22708];v[22708]=0;q:{if((g|0)==1){break q}if(!h|!v[f>>2]){break n}g=w[e+42|0]|w[e+43|0]<<8|(w[e+44|0]<<16|w[e+45|0]<<24);v[22708]=0;g=Q(190,b|0,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break q}if(!g){break n}v[22708]=0;W(329,e+128|0,f|0,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break n}}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e+128|0);break e}if(x[a+480190>>1]>d>>>0){continue}break}}o=1;r:{if(!(c&1)){break r}c=w[e+180|0]|w[e+181|0]<<8;j=0;v[22708]=0;m=a+484344|0;R(330,m|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break k}if(!(w[e+180|0]|w[e+181|0]<<8)){break r}c=e+24|0;p=c|4;q=c|2;r=c|5;s=c|3;y=c|1;while(1){v[22708]=0;c=W(331,m|0,j&65535,64)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}s:{if(!c){break s}c=(j<<1)+e|0;d=c+496|0;if(!(w[d|0]|w[d+1|0]<<8)){break s}c=w[c+496|0]|w[c+497|0]<<8;v[22708]=0;c=Q(190,b|0,c<<4)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}if(!c){break s}n=0;c=_b(m,j);v[22708]=0;c=Xc(c,0,0);d=v[22708];v[22708]=0;if((d|0)==1){break f}while(1){v[22708]=0;d=Q(191,b|0,1)|0;f=v[22708];v[22708]=0;t:{u:{v:{if((f|0)!=1){if(!d){break s}v[22708]=0;g=T(374,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break v}if(g){break u}n=n+1|0;c=B(x[a+480188>>1],6)+c|0;break t}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}u[e+28>>1]=0;v[e+24>>2]=0;d=g&31;f=B(d,6)+c|0;z=bj(e+24|0);h=d>>>0<x[a+480188>>1];w:{if(!(g&32)){break w}v[22708]=0;R(403,e+128|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}d=e+128|0;i=qd(d);k=h?f:e+24|0;d=w[d|0];t[k|0]=d;t[(h?f+1|0:y)|0]=w[i|0];x:{if(d){if((d|0)==254){break x}if(d>>>0<121){break w}}d=0}t[k|0]=d}y:{if(!(g&64)){break y}v[22708]=0;R(403,e+128|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}d=e+128|0;A=qd(d);i=h?f+3|0:s;d=w[d|0];t[i|0]=d;k=h?f+5|0:r;t[k|0]=w[A|0];z:{A:{B:{if(d>>>0<=15){v[22708]=0;Pf(h?f:z);d=v[22708];v[22708]=0;if((d|0)!=1){break B}a=P()|0;O()|0;break e}if(d>>>0>23){break z}d=w[d+33319|0];t[i|0]=d;break A}d=w[i|0]}if((d|0)!=23){if((d|0)!=9){break y}t[i|0]=20;t[e+8|0]=w[k|0]>>>3;v[22708]=0;t[e+127|0]=1;d=pf(e+8|0,e+127|0);i=v[22708];v[22708]=0;if((i|0)!=1){t[k|0]=w[d|0]-1&15|128;break y}a=P()|0;O()|0;break e}v[22708]=0;t[e+8|0]=64;d=ac(k,e+8|0);i=v[22708];v[22708]=0;if((i|0)!=1){t[k|0]=w[d|0]<<1;break y}a=P()|0;O()|0;break e}t[i|0]=0}if(!(g&128)){break t}t[(h?f+2|0:q)|0]=1;v[22708]=0;d=T(374,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break g}t[(h?f+4|0:p)|0]=d}if(n>>>0<64){continue}break}}j=j+1|0;if(j>>>0<(w[e+180|0]|w[e+181|0]<<8)>>>0){continue}break}}xb(l)}gb=e+752|0;return o|0}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}xb(l);break a}a=P()|0;O()|0;vb(e+128|0);break b}a=P()|0;O()|0}Hb(e+104|0)}S(a|0);L()}function wma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-240|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!Br(b,d+224|0)){break h}if(!sV(d+224|0)){break h}j=Kh(d+200|0);k=Kb(d+184|0);gD(d+120|0);v[22708]=0;e=Q(783,b|0,d+112|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}i:{if(!e){break i}e=d+112|4;h=Yb(Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-4|0);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;h=0;while(1){f=Yb(Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-8|0);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;j:{if(c){break j}f=d+112|0;if((Yb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)!=1347699796){break j}h=1;break i}f=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22708]=0;U(288,d+88|0,b|0,f|0);f=v[22708];v[22708]=0;k:{l:{m:{n:{o:{if((f|0)!=1){g=d+8|0;i=d+88|0;f=jc(g,i);xb(i);v[22708]=0;g=T(275,g|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}if(g){break o}xb(d+8|0);break k}a=P()|0;O()|0;break a}g=d+112|0;g=Yb(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((g|0)<=1347699795){if((g|0)==1129139796){break m}if((g|0)!=1229866575){break l}v[22708]=0;l=Q(784,f|0,d+120|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break n}break l}if((g|0)!=1347699796){if((g|0)!=1447383635){break l}v[22708]=0;Q(318,d+8|0,4)|0;g=v[22708];v[22708]=0;if((g|0)==1){break n}v[22708]=0;g=T(785,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break n}if(!g){break l}if(Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0<7){break l}g=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[22708]=0;U(786,f|0,k|0,g-6|0);f=v[22708];v[22708]=0;if((f|0)==1){break n}break l}v[22708]=0;h=W(787,a|0,f|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break l}}a=P()|0;O()|0;xb(d+8|0);break a}Dw(j,f)}xb(d+8|0);v[22708]=0;f=Q(783,b|0,d+112|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(f){continue}}break}if(gd(k)){v[22708]=0;b=Q(2,d+8|0,12075)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}Eb(k,b);vb(b)}p:{if(!(h&l&1)){break p}b=d+162|0;b=Ib(w[b|0]|w[b+1|0]<<8);v[22708]=0;c=b&256;W(409,a+1074312|0,5,!c|0)|0;b=v[22708];v[22708]=0;q:{r:{if((b|0)!=1){b=d+158|0;if(Ib(w[b|0]|w[b+1|0]<<8)){u[d+8>>1]=64;b=Ib(w[b|0]|w[b+1|0]<<8);v[22708]=0;u[d+88>>1]=b;b=Pc(d+8|0,d+88|0);e=v[22708];v[22708]=0;if((e|0)==1){break r}v[a+480228>>2]=x[b>>1]}b=d+160|0;if(!(!Ib(w[b|0]|w[b+1|0]<<8)|!c)){m=a,n=B(Ib(w[b|0]|w[b+1|0]<<8),1e4),v[m+480204>>2]=n}if(w[d+120|0]){v[22708]=0;Ke(d+88|0,2,d+120|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;R(324,d+8|0,d+88|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}b=d+8|0;Eb(a+1298268|0,b);vb(b)}v[d+8>>2]=1;v[d+88>>2]=12;c=d+166|0;if(!fr(c,d+8|0,d+88|0)){break p}v[d+80>>2]=31;v[d+84>>2]=1;e=d+164|0;if(!fr(e,d+84|0,d+80|0)){break p}v[d+72>>2]=23;v[d+76>>2]=0;f=d+170|0;if(!fr(f,d+76|0,d+72|0)){break p}v[d+64>>2]=59;v[d+68>>2]=0;g=d+172|0;if(!fr(g,d+68|0,d- -64|0)){break p}v[d+56>>2]=59;v[d+60>>2]=0;i=d+174|0;if(!fr(i,d+60|0,d+56|0)){break p}b=Er(d+8|0);l=d+168|0;m=b,n=Ib(w[l|0]|w[l+1|0]<<8),v[m+20>>2]=n;m=b,n=Ib(w[c|0]|w[c+1|0]<<8)-1|0,v[m+16>>2]=n;m=b,n=Ib(w[e|0]|w[e+1|0]<<8),v[m+12>>2]=n;m=b,n=Ib(w[f|0]|w[f+1|0]<<8),v[m+8>>2]=n;m=b,n=Ib(w[g|0]|w[g+1|0]<<8),v[m+4>>2]=n;m=b,n=Ib(w[i|0]|w[i+1|0]<<8),v[m>>2]=n;v[22708]=0;R(601,a+1298368|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(h&1){v[22708]=0;b=T(275,j|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}if(b){b=Kb(d+8|0);v[22708]=0;W(413,j|0,b|0,32)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(yr(b,11057)){v[22708]=0;U(13,d+88|0,2,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=d+88|0;Eb(a+1298280|0,c);vb(c)}v[22708]=0;c=T(788,j|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!c){v[22708]=0;c=T(467,j|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}v[22708]=0;fa(473,a+1298292|0,j|0,c|0,40,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}}vb(b)}v[22708]=0;b=Q(2,d+88|0,14627)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;U(652,d+8|0,b|0,k|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}c=d+8|0;Eb(a+1298328|0,c);vb(c);vb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[22708]=0;a=a+1074312|0;W(409,a|0,84,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;W(409,a|0,83,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(410,a|0,85)|0;a=v[22708];v[22708]=0;if((a|0)==1){break d}}vb(k);xb(j)}gb=d+240|0;return h&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b)}vb(k);xb(j);S(a|0);L()}function Ed(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=gb-96|0;gb=l;p=c;u=(g&131071)<<15|f>>>17;j=i&65535;s=j;k=h;C=k<<15|g>>>17;n=(e^i)&-2147483648;o=e&65535;x=o;m=d;y=o;o=0;D=(j&131071)<<15|k>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){j=0;if(F-1>>>0<32766){break b}}q=e&2147483647;w=q;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;n=e|32768;break a}e=i&2147483647;q=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;n=i|32768;b=f;c=g;break a}if(!(b|j|(w^2147418112|c))){if(!(d|f|(g|q))){n=2147450880;b=0;c=0;break a}n=n|2147418112;b=0;c=0;break a}if(!(d|f|(q^2147418112|g))){d=b|j;e=c|w;b=0;c=0;if(!(d|e)){n=2147450880;break a}n=n|2147418112;break a}if(!(b|j|(c|w))){b=0;c=0;break a}if(!(d|f|(g|q))){b=0;c=0;break a}if((w|0)==65535|w>>>0<65535){h=b;i=c;d=!(m|x);e=d<<6;j=E(d?b:m)+32|0;b=E(d?c:x);b=e+((b|0)==32?j:b)|0;Mf(l+80|0,h,i,m,x,b-15|0);m=v[l+88>>2];p=v[l+84>>2];y=v[l+92>>2];t=16-b|0;b=v[l+80>>2]}j=t;if(q>>>0>65535){break b}c=!(k|s);d=c<<6;e=E(c?f:k)+32|0;c=E(c?g:s);c=d+((c|0)==32?e:c)|0;i=c;Mf(l- -64|0,f,g,k,s,c-15|0);e=v[l+76>>2];c=e;h=v[l+72>>2];d=h;d=d<<15;e=v[l+68>>2];C=e>>>17|d;d=0;f=v[l+64>>2];u=d|((e&131071)<<15|f>>>17);D=(c&131071)<<15|h>>>17;j=(t-i|0)+16|0}t=j;d=u;c=b;s=0;q=oqa(d,0,b,s);b=jb;G=b;e=f;A=e<<15&-32768;k=p;g=oqa(A,0,k,0);f=g+q|0;e=jb+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;j=f;i=0;g=oqa(c,s,A,B);f=i+g|0;b=j;j=j+jb|0;j=f>>>0<g>>>0?j+1|0:j;u=f;g=j;J=(b|0)==(j|0)&f>>>0<i>>>0|b>>>0>j>>>0;N=oqa(d,r,k,H);K=jb;p=m;f=oqa(A,B,m,0);b=f+N|0;j=jb+K|0;O=b;m=oqa(C,0,c,s);i=b+m|0;b=b>>>0<f>>>0?j+1|0:j;f=b+jb|0;w=i;f=i>>>0<m>>>0?f+1|0:f;x=f;j=f;f=(e|0)==(G|0)&h>>>0<q>>>0|e>>>0<G>>>0;h=e+w|0;j=f+j|0;q=h;j=h>>>0<e>>>0?j+1|0:j;m=j;e=h;h=j;Q=oqa(d,r,p,P);G=jb;f=A;I=y|65536;A=o;i=oqa(f,B,I,o);f=i+Q|0;j=jb+G|0;j=f>>>0<i>>>0?j+1|0:j;R=f;B=oqa(C,S,k,H);i=f+B|0;o=j;f=j+jb|0;f=i>>>0<B>>>0?f+1|0:f;L=i;D=D&2147483647|-2147483648;i=oqa(c,s,D,0);c=L+i|0;s=f;j=f+jb|0;B=c;c=c>>>0<i>>>0?j+1|0:j;y=J;i=0;f=i+e|0;j=h+B|0;J=f;h=f;e=y+f|0;y=f>>>0<i>>>0?j+1|0:j;f=y;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;t=(t+(F+M|0)|0)-16383|0;f=oqa(p,P,C,S);e=jb;r=oqa(d,r,I,A);d=r+f|0;j=jb+e|0;j=d>>>0<r>>>0?j+1|0:j;r=d;f=(e|0)==(j|0)&f>>>0>d>>>0|e>>>0>j>>>0;e=j;F=f;f=oqa(D,T,k,H);d=f+d|0;j=jb+j|0;j=d>>>0<f>>>0?j+1|0:j;f=d;d=j;k=(j|0)==(e|0)&f>>>0<r>>>0|e>>>0>j>>>0;j=F+k|0;e=0;e=j>>>0<k>>>0?1:e;r=f;k=d;F=j;f=(b|0)==(x|0)&w>>>0<O>>>0|b>>>0>x>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;j=0;j=b>>>0<f>>>0?1:j;f=b;b=r+f|0;j=d+j|0;j=b>>>0<f>>>0?j+1|0:j;H=b;d=j;j=(j|0)==(k|0)&b>>>0<r>>>0|j>>>0<k>>>0;b=F+j|0;f=e;f=b>>>0<j>>>0?f+1|0:f;e=oqa(D,T,I,A);b=e+b|0;j=jb+f|0;r=b;e=b>>>0<e>>>0?j+1|0:j;k=oqa(D,T,p,P);f=jb;p=oqa(C,S,I,A);b=p+k|0;j=jb+f|0;j=b>>>0<p>>>0?j+1|0:j;p=b;b=j;j=(f|0)==(j|0)&k>>>0>p>>>0|f>>>0>j>>>0;k=b+r|0;e=e+j|0;e=k>>>0<b>>>0?e+1|0:e;r=k;k=0;b=k+H|0;j=d+p|0;j=b>>>0<k>>>0?j+1|0:j;f=j;k=(d|0)==(j|0)&b>>>0<H>>>0|d>>>0>j>>>0;d=r+k|0;j=e;C=d;d=d>>>0<k>>>0?j+1|0:j;p=b;k=f;f=(o|0)==(s|0)&R>>>0>L>>>0|o>>>0>s>>>0;e=f+((o|0)==(G|0)&Q>>>0>R>>>0|o>>>0<G>>>0)|0;f=e;e=f+((c|0)==(s|0)&B>>>0<L>>>0|c>>>0<s>>>0)|0;f=e;b=c+b|0;e=f+k|0;e=b>>>0<c>>>0?e+1|0:e;o=b;c=b;b=e;e=(e|0)==(k|0)&c>>>0<p>>>0|e>>>0<k>>>0;c=e+C|0;j=d;j=c>>>0<e>>>0?j+1|0:j;d=c;k=d;e=(m|0)==(y|0)&q>>>0>J>>>0|m>>>0>y>>>0;d=e+((m|0)==(x|0)&q>>>0<w>>>0|m>>>0<x>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;m=d;d=d+o|0;e=b+f|0;e=d>>>0<m>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0;b=k+c|0;j=b>>>0<c>>>0?j+1|0:j;c=j;c:{if(j&65536){t=t+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;o=u;j=g<<1|o>>>31;u=o<<1;g=j;j=i<<1|h>>>31;h=h<<1|m;i=j}if((t|0)>=32767){n=n|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){f=1-t|0;if(f>>>0>=128){b=0;c=0;break a}j=t+127|0;Mf(l+48|0,u,g,h,i,j);Mf(l+32|0,d,e,b,c,j);mm(l+16|0,u,g,h,i,f);mm(l,d,e,b,c,f);u=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];h=v[l+40>>2]|v[l+24>>2];i=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];c=v[l+12>>2];b=v[l+8>>2];break d}c=c&65535|t<<16}z=b|z;n=c|n;if(!(!h&(i|0)==-2147483648?!(g|u):(i|0)>-1)){j=e;b=d+1|0;j=b>>>0<1?j+1|0:j;f=b;c=j;f=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=f+z|0;e=n;z=d;n=d>>>0<f>>>0?e+1|0:e;break a}if(h|u|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;e=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=e+z|0;j=n;z=d;n=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=n;gb=l+96|0}function pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;g=gb-208|0;gb=g;vc(b);a:{b:{c:{d:{e:{if(!YC(b,g+160|0)){break e}if(!oT(g+160|0)){break e}if(!c){i=1;break e}if(!Pb(b,Qc(nT(g+160|0),jb))){break e}Hd(a,128);e=g+144|0;Ke(e,2,g+175|0);d=g+72|0;Bc(d,e);Eb(a+1298268|0,d);vb(d);h=Tb(d,5600);Eb(a+1298304|0,h);vb(h);h=Tb(d,3148);Eb(a+1298316|0,h);vb(h);e=Tb(e,14639);v[22708]=0;U(951,d|0,e|0,v[(w[g+174|0]<<2)+33180>>2]);d=v[22708];v[22708]=0;i=1;if((d|0)==1){break b}d=g+72|0;Eb(a+1298328|0,d);vb(d);vb(e);v[a+480208>>2]=12;v[a+1298364>>2]=5;nB(a+1298292|0,b,w[g+207|0]<<5,32,0);z=a,A=Be(b),u[z+480190>>1]=A;if(x[a+480190>>1]){k=1;while(1){f:{if(w[g+174|0]>=52){d=g+72|0;if(!nY(b,d)){jD(d)}break f}e=gb-48|0;gb=e;v[e+44>>2]=64;v[e+24>>2]=66;d=b;h=v[Fb(e+44|0,e+24|0)>>2];if(!Pb(d,h)){h=mf(d)}f=e+24|0;j=g+72|0;Gv(f,j);m=vd(e+32|0,v[f>>2],h);n=v[m+4>>2];v[e+8>>2]=v[m>>2];v[e+12>>2]=n;cc(e+16|0,d,e+8|0);Gv(f,j);Qb(v[e+24>>2]+h|0,0,66-h|0);Rb(d,v[e+44>>2]);gb=e+48|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}h=gb-32|0;gb=h;e=(B(i,104)+a|0)+484380|0;ud(e,0);j=g+72|0;d=j;Lk(h,2,d+32|0);f=h+16|0;Bc(f,h);v[22708]=0;Q(303,e+43|0,f|0)|0;f=v[22708];v[22708]=0;g:{if((f|0)!=1){vb(h+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[h+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);z=e,A=v[Fb(h+16|0,e)>>2],v[z+16>>2]=A;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){Oo(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)/393216)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}gb=h+32|0;break g}a=P()|0;O()|0;vb(h+16|0);S(a|0);L()}d=g+56|0;Ke(d,2,j);e=g+144|0;Bc(e,d);v[22708]=0;Q(301,((i<<5)+a|0)+946304|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}vb(g+144|0);k=k+1|0;i=k&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}jp(Sb(a+484360|0),b,256,255,254);i=0;d=Be(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=Be(b);r=d+1|0;if(x[a+480188>>1]){while(1){e=(i<<5)+a|0;We(e+480280|0);h=e+480284|0;i:{if(w[g+174|0]>=51){e=(Be(b)<<4|8)&248;break i}e=i&1?192:64}u[h>>1]=e;i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}}m=a+484344|0;zg(m,r);i=0;k=0;while(1){e=k&65535;if(!wh(m,e,64)){break e}k=k+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){h=bj(g+72|0);n=0;while(1){if(Pb(b,5)){k=0;i=Xc(_b(m,n),0,p&65535);while(1){s=64-k|0;l=w[g+174|0];f=gb-16|0;gb=f;q=1;d=h;o=d;e=b;j=Be(e);if((j|0)==252){q=Be(e);j=Be(e)}t[o|0]=(j-1&255)>>>0<60?j+36|0:0;j=f+8|0;vn(j,e);e=qd(j);o=Ve(j);y=ej(j);t[d+1|0]=w[j|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[o|0];t[f+4|0]=w[y|0];lT(f+7|0,f+5|0,l);lT(f+6|0,f+4|0,l);j=w[f+7|0];l=(j|0)!=10;e=w[f+6|0];j:{if(!(l|(e|0)!=10)){t[f+7|0]=0;z=f,A=dm((w[f+4|0]|w[f+5|0]<<8)>>>6|0),t[z+5|0]=A;break j}k:{l:{m:{if(!l){z=f,A=dm(w[f+5|0]<<2),t[z+5|0]=A;break m}if((e|0)==10){z=f,A=dm(w[f+4|0]<<2),t[z+4|0]=A;break j}if((e|0)!=(j|0)){break m}t[f+6|0]=0;break l}if((e|0)==13){break k}if(e){break j}}if((j|0)==13){break j}}gi(f+7|0,f+6|0);gi(f+5|0,f+4|0)}e=f+6|0;j=f+4|0;l=f+7|0;o=f+5|0;pz(e,j,l,o);so(f,l,o,e,j);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0];gb=f+16|0;e=k+q|0;k=e>>>0>64?s:q;if(k){while(1){d=v[g+72>>2];t[i|0]=d;t[i+1|0]=d>>>8;t[i+2|0]=d>>>16;t[i+3|0]=d>>>24;d=x[g+76>>1];t[i+4|0]=d;t[i+5|0]=d>>>8;i=B(x[a+480188>>1],6)+i|0;k=k-1|0;if(k){continue}break}d=e>>>0<64;k=d?e:64;if(d){continue}}break}n=n+1|0;if((r|0)!=(n|0)){continue}}break}p=p+1|0;if(x[a+480188>>1]>(p&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;h=av(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[22708]=0;U(953,h|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){a=P()|0;O()|0;De(h);S(a|0);L()}v[22708]=0;U(952,g+32|0,m|0,d|0);e=v[22708];v[22708]=0;i=1;if((e|0)==1){break d}De(g+32|0);De(d);if(!(c&2)|!x[a+480190>>1]){break e}k=1;while(1){c=B(k&65535,104)+a|0;Cg(Rc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);k=k+1|0;if(x[a+480190>>1]>=(k&65535)>>>0){continue}break}}gb=g+208|0;return i|0}i=P()|0;O()|0;De(d);break a}i=P()|0;O()|0;vb(g+144|0);break a}i=P()|0;O()|0;vb(e)}S(i|0);L()}function GZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-128|0;gb=g;vc(b);a:{if(!Tr(b,9028)){break a}if(!bw(b,g+112|0)){break a}if(!ZD(g+112|0)){break a}if(!Pb(b,Qc(YD(g+112|0),jb))){break a}if(!Rb(b,w[g+121|0]|w[g+122|0]<<8)){break a}b:{if(!c){break b}Hd(a,4096);v[a+480208>>2]=12;d=1;h=g+112|0;u[a+480188>>1]=(w[h|2]&31)+1;i=h|3;u[a+480190>>1]=w[i|0];yh(a,1);j=g+32|0;e=Tb(j,5623);Eb(a+1298304|0,e);vb(e);e=Tb(j,4107);Eb(a+1298316|0,e);vb(e);e=gb-16|0;gb=e;f=g+8|0;k=Tb(e,1356);Dc(f,k);vb(k);gb=e+16|0;v[22708]=0;Y(349,j|0,f|0,h|1,h|0);h=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){h=g+32|0;Eb(a+1298328|0,h);vb(h);Hb(g+8|0);v[a+1298364>>2]=5;e=w[i|0];h=gb-16|0;gb=h;j=g+96|0;v[j>>2]=0;v[j+4>>2]=0;v[h+12>>2]=0;df(j+8|0,h+12|0,h+8|0);if(e){Yr(j,e);TE(j,e,0)}gb=h+16|0;k:{if(x[a+480190>>1]){h=1;while(1){v[22708]=0;R(350,b|0,g+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}v[22708]=0;R(351,g+32|0,(B(d,104)+a|0)+484380|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}e=w[g+48|0];i=g+8|0;re(i,j,d-1|0);Df(i,(e&3)!=0);h=h+1|0;d=h&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22708]=0;W(352,b|0,a+1298268|0,-1)|0;h=v[22708];v[22708]=0;d=1;l:{m:{if((h|0)!=1){if(x[a+480190>>1]){while(1){v[22708]=0;W(353,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;h=v[22708];v[22708]=0;if((h|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[22708]=0;h=(d<<5)+a|0;We(h+480280|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;U(355,b|0,h+480289|0,-1);h=v[22708];v[22708]=0;if((h|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}h=g+112|4;e=w[h|0]|w[h+1|0]<<8;d=0;v[22708]=0;i=a+484344|0;R(330,i|0,e|0);e=v[22708];v[22708]=0;if((e|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(w[h|0]|w[h+1|0]<<8){while(1){v[22708]=0;U(356,b|0,g+32|0,-1);e=v[22708];v[22708]=0;n:{o:{if((e|0)==1){break o}v[22708]=0;e=W(331,i|0,d&65535,64)|0;f=v[22708];v[22708]=0;if((f|0)==1){break o}if(!e){break n}e=_b(i,d);v[22708]=0;R(357,e|0,g+32|0);e=v[22708];v[22708]=0;if((e|0)!=1){break n}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}}v[22708]=0;f=T(287,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}p:{if(!f){break p}v[22708]=0;d=Q(191,b|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}if(!d){break p}e=mc(g+32|0);v[22708]=0;W(358,b|0,e|0,f|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break h}d=Kb(g+8|0);v[22708]=0;R(60,d|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}m=g,n=Vb(e),v[m+56>>2]=n;m=g,n=Zb(e),v[m+88>>2]=n;if(Gb(g+56|0,g+88|0)){while(1){q:{f=w[v[g+56>>2]];if(f&128){m=g,n=ef(d),v[m+72>>2]=n;Gd(g+80|0,g+72|0);v[22708]=0;ca(359,d|0,v[g+80>>2],f&127,32)|0;f=v[22708];v[22708]=0;if((f|0)!=1){break q}break i}v[22708]=0;R(61,d|0,f<<24>>24);f=v[22708];v[22708]=0;if((f|0)!=1){break q}break i}f=g+56|0;Pe(f);if(Gb(f,g+88|0)){continue}break}}v[22708]=0;Y(360,g+56|0,5,6,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}f=g+56|0;Eb(d,f);vb(f);f=zb(Jb(d));k=Ab(d);v[22708]=0;fa(361,a+1298292|0,f|0,k|0,76,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}vb(d);gc(e)}e=Sb(a+484360|0);d=g+112|6;f=w[d|0]|w[d+1|0]<<8;d=0;v[22708]=0;fa(362,e|0,b|0,f|0,65535,65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}r:{s:{t:{u:{if(!(w[h|0]|w[h+1|0]<<8)){break u}e=c&1;while(1){v[22708]=0;f=Q(191,b|0,4)|0;k=v[22708];v[22708]=0;v:{if((k|0)!=1){if(f){break v}break u}b=P()|0;O()|0;break d}v[22708]=0;f=T(192,b|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break s}v[22708]=0;U(288,g+8|0,b|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break r}f=g+8|0;k=jc(g+32|0,f);xb(f);w:{if(!e){break w}v[22708]=0;f=me(i,d&65535);l=v[22708];v[22708]=0;if((l|0)==1){break t}if(!f){break w}f=_b(i,d);v[22708]=0;U(364,f|0,0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break t}}xb(g+32|0);d=d+1|0;if(d>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){d=1;c=1;while(1){h=B(d,104)+a|0;e=x[h+484414>>1];i=g+32|0;re(i,j,d-1|0);d=Rc(g+8|0,e&1?16:8,1,0,Cb(i)?6:0);v[22708]=0;W(329,d|0,h+484380|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}De(j);break b}b=P()|0;O()|0;xb(g+32|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Hb(g+8|0);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(d);break g}b=P()|0;O()|0}gc(e);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}De(j)}S(b|0);L()}d=1}gb=g+128|0;return d|0}function gZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-3056|0;gb=g;vc(b);h=gb-32|0;gb=h;e=h+24|0;f=g+1096|0;CD(e,f);l=yb(e);e=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=e;j=h+16|0;e=b;cc(j,e,h);j=yb(j);if((j|0)==(l|0)){Rb(e,yb(h+24|0))}gb=h+32|0;e=(j|0)==(l|0);if(!e){BD(f)}a:{if(!e){break a}if(!FD(g+1096|0)){break a}if(!c){d=1;break a}if(!Pb(b,Qc(1024,0))){break a}ED(b,g+576|0);ED(b,g- -64|0);while(1){e=i<<2;h=e+(g+576|0)|0;if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0>16777215){break a}e=e+(g- -64|0)|0;f=w[e+1|0]<<8;j=w[e+2|0]<<16|w[e+3|0]<<24;if((w[e|0]|f|j)>>>0<3|(j|(f|w[e|0]))>>>0>4096){break a}if(!qs(b,((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0)+2978|0)){break a}i=i+1|0;if((i|0)!=128){continue}break}Hd(a,2);Ag(a);d=g+40|0;e=Tb(d,11138);Eb(a+1298304|0,e);vb(e);e=Tb(d,11956);Eb(a+1298316|0,e);vb(e);d=Tb(d,12601);Eb(a+1298328|0,d);vb(d);v[a+1298364>>2]=5;d=w[g+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;l=a+484360|0;bf(Sb(l),w[g+1097|0]);v[a+480188>>2]=4194317;Ob(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){e=d+1|0;i=B(e,104)+a|0;h=i+484380|0;ud(h,2);f=g+16|0;li(f,1,(B(d,13)+g|0)+1098|0);j=g+40|0;Bc(j,f);v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,j|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}vb(g+40|0);f=h;d=(g+1096|0)+(d<<4)|0;h=d+422|0;v[f>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[i+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[i+484414>>1]=2;v[i+484388>>2]=d}v[i+484404>>2]=8287;d=e;if((d|0)!=32){continue}break}i=0;while(1){d=i+33|0;h=(B(d,104)+a|0)+484380|0;ud(h,2);e=g+16|0;li(e,1,(B(i,13)+g|0)+2026|0);f=g+40|0;Bc(f,e);v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,f|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}d=g+40|0;vb(d);v[g+48>>2]=0;v[g+40>>2]=0;v[g+44>>2]=0;e=(g+1096|0)+B(i,11)|0;f=w[e+1347|0];p=lc(d,0),q=f,t[p|0]=q;f=w[e+1352|0];p=lc(d,1),q=f,t[p|0]=q;f=w[e+1348|0];p=lc(d,2),q=f,t[p|0]=q;f=w[e+1353|0];p=lc(d,3),q=f,t[p|0]=q;f=w[e+1349|0];p=lc(d,4),q=f,t[p|0]=q;f=w[e+1354|0];p=lc(d,5),q=f,t[p|0]=q;f=w[e+1350|0];p=lc(d,6),q=f,t[p|0]=q;f=w[e+1355|0];p=lc(d,7),q=f,t[p|0]=q;f=w[e+1351|0];p=lc(d,8),q=f,t[p|0]=q;f=w[e+1356|0];p=lc(d,9),q=f,t[p|0]=q;e=w[e+1346|0];p=lc(d,10),q=e,t[p|0]=q;v[g+8>>2]=v[g+48>>2];d=v[g+44>>2];v[g>>2]=v[g+40>>2];v[g+4>>2]=d;Qo(h,1,g);i=i+1|0;if((i|0)!=32){continue}break}Ur(Sb(l),g+2794|0,256,255,65535);j=a+484344|0;zg(j,128);o=c&1;i=0;f:{while(1){h=i<<2;d=h+(g+576|0)|0;Zc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);e=g+16|0;d=h+(g- -64|0)|0;Td(e,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));h=jc(g+40|0,e);xb(e);g:{if(!o){break g}v[22708]=0;d=W(331,j|0,i&65535,64)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!d){break g}d=0;l=_b(j,i);while(1){v[22708]=0;e=Q(191,g+40|0,1)|0;f=v[22708];v[22708]=0;h:{i:{if((f|0)!=1){if(!e){break g}v[22708]=0;e=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}if(e>>>0>12){break i}v[22708]=0;f=Xc(l,d,e);k=v[22708];v[22708]=0;if((k|0)==1){break c}v[22708]=0;R(403,g+16|0,h|0);k=v[22708];v[22708]=0;if((k|0)==1){break c}k=g+16|0;m=qd(k);n=w[k|0];e=e>>>0>3;t[f|0]=((n&15)+(e?13:37)|0)+B(n>>>4&7,12);t[f+1|0]=((w[m|0]>>>4|0)+(e?33:1)|0)+(w[k|0]>>>3&16);DD(f,w[m|0],e);break h}break c}f=e-32|0;if((f&255)>>>0<=12){v[22708]=0;f=Xc(l,d,f&65535);k=v[22708];v[22708]=0;if((k|0)==1){break c}v[22708]=0;k=T(374,h|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break c}DD(f,k,e>>>0>35);break h}if((e|0)!=64){if((e|0)!=96){break f}if(!d){break g}v[22708]=0;d=Xc(l,d-1|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}t[d+3|0]=14;break g}v[22708]=0;e=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}d=d+e|0}if(d>>>0<64){continue}break}}xb(g+40|0);i=i+1|0;if((i|0)!=128){continue}break}d=1;if(!(c&2)){break a}i=1;while(1){Cg(Rc(g+40|0,8,1,0,1),(B(i,104)+a|0)+484380|0,b);i=i+1|0;if((i|0)!=33){continue}break}break a}xb(g+40|0);d=0;break a}d=P()|0;O()|0;vb(g+40|0);break b}d=P()|0;O()|0;vb(g+40|0);break b}d=P()|0;O()|0;xb(g+40|0)}S(d|0);L()}gb=g+3056|0;return d|0}function Yoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=gb-320|0;gb=d;vc(b);g=gb-32|0;gb=g;f=g+24|0;CX(f,d+96|0);i=yb(f);f=v[g+28>>2];h=v[g+24>>2];v[g+8>>2]=h;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=f;h=g+16|0;f=b;cc(h,f,g);h=yb(h);if((h|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;a:{b:{c:{d:{if((i|0)!=(h|0)){break d}if(!GX(d+96|0)){break d}if(!Pb(b,Qc(FX(d+96|0),jb))){break d}if(!c){e=1;break d}Hd(a,2);Ag(a);v[a+480204>>2]=455e3;v[a+480188>>2]=524296;Ob(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;e=d- -64|0;Ke(e,2,d+127|0);f=d+80|0;Bc(f,e);Eb(a+1298268|0,f);vb(f);e=0;e:{f:{g:{h:{i:{while(1){g=d+80|0;f=(d+96|0)+B(e,19)|0;XC(g,f+63|0);i=d- -64|0;Bc(i,g);v[22708]=0;Q(399,((e<<5)+a|0)+480289|0,i|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break h}g=d- -64|0;vb(g);e=e+1|0;h=B(e,104)+a|0;j=h+484380|0;ud(j,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;i=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[g+7|0]=i;t[g+8|0]=i>>>8;t[g+9|0]=i>>>16;t[g+10|0]=i>>>24;i=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);t[g|0]=f;t[g+1|0]=f>>>8;t[g+2|0]=f>>>16;t[g+3|0]=f>>>24;t[g+4|0]=i;t[g+5|0]=i>>>8;t[g+6|0]=i>>>16;t[g+7|0]=i>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;Qo(j,1,d);v[h+484404>>2]=8215;f=d+48|0;Bc(f,d+80|0);v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}vb(d+48|0);if((e|0)!=8){continue}break}o=w[d+312|0];m=o+1|0;j=a+484360|0;jp(Sb(j),b,m,65535,65535);f=mc(d+80|0);v[22708]=0;W(358,b|0,f|0,m|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}z=d,A=Vb(f),v[z+64>>2]=A;z=d,A=Zb(f),v[z+48>>2]=A;if(Gb(d- -64|0,d+48|0)){while(1){if((w[v[d- -64>>2]]-1&255)>>>0>7){break f}e=d- -64|0;Pe(e);if(Gb(e,d+48|0)){continue}break}}z=a,A=w[kc(f,0)|0],v[z+480196>>2]=A;e=w[d+311|0];p=w[d+313|0];g=mc(d- -64|0);v[22708]=0;h=p+1|0;W(358,b|0,g|0,h|0)|0;i=v[22708];v[22708]=0;j:{if((i|0)==1){break j}v[22708]=0;i=a+484344|0;R(330,i|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break j}q=e+1|0;k:{l:{if(!(c&1)){break l}h=0;while(1){c=w[kc(g,h)|0];v[22708]=0;c=W(331,i|0,c|0,q|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break k}if(!c){break l}c=0;n=_b(i,w[kc(g,h)|0]);k=0;while(1){if(v[n+12>>2]){r=c+1|0;e=0;while(1){v[22708]=0;c=T(374,b|0)|0;l=v[22708];v[22708]=0;m:{n:{if((l|0)!=1){if(!(c&128)){break n}e=(c&127)+e|0;break m}e=P()|0;O()|0;break c}v[22708]=0;l=Xc(n,e,k&65535);s=v[22708];v[22708]=0;o:{if((s|0)!=1){p:{switch(c|0){case 0:break m;case 1:break p;default:break o}}t[l|0]=254;break m}e=P()|0;O()|0;break c}if(c>>>0>97){break m}t[l+1|0]=r;t[l|0]=c+12}e=e+1|0;if(e>>>0<y[n+12>>2]){continue}break}}e=k&65535;c=k+1|0;k=c;if(e>>>0<7){continue}break}c=(h|0)==(p|0);h=h+1|0;if(!c){continue}break}}c=0;e=0;q:{r:{s:{t:{u:{v:{w:{while(1){b=Sb(j);v[22708]=0;h=e&65535;b=Q(472,b|0,h|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break w}x:{if(!b){v[22708]=0;b=W(544,i|0,q|0,0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break v}if((b|0)==65535){break x}z=sc(Sb(j),c),A=b,u[z>>1]=A}z=d,A=Zb(_b(i,x[sc(Sb(j),c)>>1])),v[z+32>>2]=A;z=d,A=WC(d+32|0,1),v[z+48>>2]=A;b=w[kc(f,(c+1>>>0)%(m>>>0)|0)|0];if((b|0)==w[v[d+48>>2]+5|0]){break x}y:{if(w[v[d+48>>2]+3|0]!=16){break y}c=Sb(j);v[22708]=0;c=Q(545,c|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break q}if((c|0)==65535){break y}z=d,A=Zb(_b(i,c)),v[z+32>>2]=A;z=d,A=WC(d+32|0,1),v[z+48>>2]=A}t[v[d+48>>2]+3|0]=16;t[v[d+48>>2]+5|0]=b}e=e+1|0;c=e&65535;if(o>>>0>=c>>>0){continue}break}v[22708]=0;b=Q(2,d+48|0,5747)|0;c=v[22708];v[22708]=0;if((c|0)==1){break u}Eb(a+1298304|0,b);vb(b);v[22708]=0;b=Q(2,d+48|0,3141)|0;c=v[22708];v[22708]=0;if((c|0)==1){break t}Eb(a+1298316|0,b);vb(b);v[22708]=0;Zj(d+16|0,2,d+107|0);b=v[22708];v[22708]=0;if((b|0)==1){break s}v[22708]=0;R(324,d+32|0,d+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break s}v[22708]=0;U(13,d+48|0,5,d+32|0);b=v[22708];v[22708]=0;e=1;if((b|0)==1){break r}b=d+48|0;Eb(a+1298328|0,b);vb(b);vb(d+32|0);v[a+1298364>>2]=5;gc(g);break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+32|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+48|0);break a}e=P()|0;O()|0;vb(d- -64|0);break a}e=P()|0;O()|0;break b}e=0}gc(f)}gb=d+320|0;return e|0}gc(g)}gc(f)}S(e|0);L()}function Epa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-336|0;gb=d;vc(b);a:{if(!Br(b,d+320|0)){break a}if(!dY(d+320|0)){break a}if(v[d+320>>2]==1179472708){Rb(b,4)}if(!Jh(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}l=d+312|4;f=l;RD(b,d+120|0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Hd(a,8192);e=d+32|0;f=Tb(e,3596);Eb(a+1298304|0,f);vb(f);f=Tb(e,7411);Eb(a+1298316|0,f);vb(f);v[a+1298364>>2]=5;f=d+96|0;Mk(f,2,d+120|0);Bc(e,f);Eb(a+1298268|0,e);vb(e);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;q=a,r=x[Le(e,f)>>1],u[q+480188>>1]=r;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[ac(e,f)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+32>>2]=256/x[a+480188>>1];v[d+96>>2]=128;f=v[Fb(d+32|0,d+96|0)>>2];break b}f=w[d+165|0]&127}v[e+480228>>2]=f;e=0;while(1){f=(e<<5)+a|0;We(f+480280|0);h=d+e|0;if(w[h+168|0]<=128){u[f+480284>>1]=w[h+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}k=a+484360|0;g=Sb(k);i=d+184|0;e=gb-16|0;gb=e;v[e+12>>2]=w[d+156|0]|w[d+157|0]<<8;f=e+12|0;qc(f,128);qc(f,65535);j=x[e+12>>1];Bf(g,j);if(j){h=0;while(1){f=w[h+i|0];c:{if((f|0)==255){f=65535;break c}if((f|0)!=254){break c}f=65534}q=fj(g,h),r=f,u[q>>1]=r;h=h+1|0;if((j|0)!=(h|0)){continue}break}}gb=e+16|0;if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){bf(Sb(k),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Jh(b,d+312|0)){break a}n=c&2;k=a+484344|0;o=c&1;p=d+68|0;j=0;while(1){e=d+32|0;c=l;Td(e,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));h=jc(d+96|0,e);xb(e);d:{e:{f:{if(!(!o|v[d+312>>2]!=1414807888)){v[22708]=0;m=j&65535;c=W(331,k|0,m|0,64)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}if(!c){break d}v[22708]=0;Q(318,d+96|0,2)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}hi(d+32|0);f=0;g:{while(1){v[22708]=0;c=Q(191,d+96|0,1)|0;e=v[22708];v[22708]=0;h:{i:{if((e|0)!=1){if(!(c&f>>>0<64)){break g}v[22708]=0;e=T(374,h|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}if(e){break h}f=f+1|0;continue}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}c=d+32|0;j:{k:{l:{g=e&15;m:{if(g>>>0<x[a+480188>>1]){c=_b(k,m);v[22708]=0;c=Xc(c,f,g);g=v[22708];v[22708]=0;if((g|0)==1){break m}}n:{if(!(e&128)){break n}v[22708]=0;g=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break l}if(!g){break n}t[c|0]=g>>>0<109?g+12|0:g}if(!(e&64)){break j}v[22708]=0;g=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)!=1){break k}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}t[c+1|0]=g}o:{p:{q:{r:{s:{t:{u:{v:{if(e&32){t[c+2|0]=1;v[22708]=0;g=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break v}t[d+16|0]=g;v[22708]=0;t[d|0]=64;g=ac(d+16|0,d);i=v[22708];v[22708]=0;if((i|0)==1){break u}t[c+4|0]=w[g|0]}if(!(e&16)){continue}v[22708]=0;R(403,d+16|0,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break t}e=d+16|0;g=e;i=qd(e);e=w[e|0];switch(e-17|0){case 2:break r;case 0:case 1:break s;default:break q}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}e=e&15;break p}t[g|0]=33;t[i|0]=145;e=w[g|0];break o}if(e>>>0<17){break o}e=(e&240)==32?9:-1}t[g|0]=e}t[c+3|0]=e;t[c+5|0]=w[i|0];v[22708]=0;Pf(c);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break e}j=j+1|0;break d}if(v[d+312>>2]!=1414745673){break d}if(!fi(a)){break d}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22708]=0;R(495,h|0,d+32|0);e=v[22708];v[22708]=0;w:{x:{y:{if((e|0)==1){break y}v[22708]=0;g=(B(c&65535,104)+a|0)+484380|0;R(496,d+32|0,g|0);c=v[22708];v[22708]=0;if((c|0)==1){break y}v[22708]=0;Mk(d,2,p);c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;R(324,d+16|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break x}c=x[a+480190>>1];v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,d+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break w}vb(d+16|0);if(!n){break d}i=d+16|0;c=Rc(i,8,1,0,1);e=2;f=d+45|0;z:{if(!(w[f|0]&64)){e=0;if(!(w[f|0]&2)){break z}}Cf(c,e)}if(w[f|0]&4){Yi(c,16)}v[22708]=0;W(329,i|0,g|0,h|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(d+16|0);break e}b=P()|0;O()|0}xb(d+96|0);S(b|0);L()}xb(d+96|0);e=1;if(Jh(b,d+312|0)){continue}break}}gb=d+336|0;return e|0}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-176|0;gb=d;vc(b);a:{if(!YC(b,d+128|0)){break a}if(!lU(d+128|0)){break a}if(!Pb(b,Qc(kU(d+128|0),jb))){break a}b:{if(!c){break b}Hd(a,256);h=d+16|0;Zj(h,2,d+128|0);g=d+48|0;Bc(g,h);Eb(a+1298268|0,g);vb(g);e=Tb(g,12467);Eb(a+1298304|0,e);vb(e);e=Tb(g,7390);Eb(a+1298316|0,e);vb(e);Ff(h,1380);v[22708]=0;R(371,d+112|0,d+159|0);e=v[22708];v[22708]=0;c:{d:{e:{f:{g:{if((e|0)!=1){v[22708]=0;Y(890,d+48|0,d+16|0,d+158|0,d+112|0);e=v[22708];v[22708]=0;if((e|0)==1){break g}e=d+48|0;Eb(a+1298328|0,e);vb(e);vb(d+112|0);Hb(d+16|0);v[a+1298364>>2]=5;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+160|0];if(w[d+159|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}h=(f&255?f:96)&255;e=DP(h);v[a+480196>>2]=h>>>4;v[a+480204>>2]=e;if(w[d+159|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+112|0)}Hb(d+16|0);break c}t[d+48|0]=64;p=a,q=w[ac(d+162|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;We(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;h:{i:{while(1){cv(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break i}j=gb-32|0;gb=j;i=(B(f,104)+a|0)+484380|0;ud(i,0);g=d+16|0;k=g;Lk(j,2,g);e=j+16|0;Bc(e,j);v[22708]=0;Q(303,i+43|0,e|0)|0;e=v[22708];v[22708]=0;j:{k:{if((e|0)!=1){h=j+16|0;vb(h);e=k+24|0;v[i+24>>2]=w[e|0]|w[e+1|0]<<8;t[j+16|0]=w[k+22|0];t[j|0]=64;p=i,q=w[ac(h,j)|0]<<2,u[p+30>>1]=q;e=k+16|0;v[i>>2]=w[e|0]|w[e+1|0]<<8;e=k+18|0;v[i+4>>2]=w[e|0]|w[e+1|0]<<8;e=k+20|0;k=w[e|0]|w[e+1|0]<<8;v[i+8>>2]=k;h=v[i>>2];if(h>>>0>1){break k}v[i>>2]=0;break j}a=P()|0;O()|0;vb(j+16|0);S(a|0);L()}e=v[i+4>>2];if((k|0)==65535|h>>>0<=e>>>0|e>>>0>=k>>>0){break j}u[i+34>>1]=2;p=i,q=v[Fb(i+8|0,i)>>2],v[p+8>>2]=q}gb=j+32|0;Lk(d,2,g);e=d+112|0;Bc(e,d);v[22708]=0;Q(301,((f<<5)+a|0)+946304|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}vb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;jp(Sb(e),b,w[d+159|0]?128:64,65535,65535);e=Sb(e);p=d,q=Vb(e),v[p+16>>2]=q;p=d,q=Zb(e),v[p+112>>2]=q;if(Gb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];h=x[e>>1];l:{if(!((h|0)!=99?(h|0)!=255:0)){u[e>>1]=65535;break l}if(h>>>0>63){break i}}e=d+16|0;nf(e);if(Gb(e,d+112|0)){continue}break}}k=c&1;if(k){zg(a+484344|0,w[d+161|0])}if(w[d+161|0]){o=a+484344|0;while(1){m:{n:{if(k){if(wh(o,m&65535,64)){break n}}f=0;while(1){if((Be(b)+5&255)>>>0>=3){Rb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}p=d,q=Vb(_b(o,m)),v[p+112>>2]=q;v[d>>2]=63;l=65535;n=0;while(1){f=0;while(1){h=f;g=0;f=0;i=0;j=0;o:{p:{q:{r:{s:{t:{e=Be(b);switch(e-251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}t[v[d+112>>2]]=254;break o}g=d+16|0;Vr(g,b);f=w[lc(g,0)|0];i=w[lc(g,1)|0];j=w[lc(g,2)|0];g=254;if((e|0)==254){break q}g=e;if(e>>>0>95){break p}}g=(B(g>>>4|0,12)+(g&15)|0)+37|0}e=g;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=i>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(i&15)+33344|0];t[v[d+112>>2]+5|0]=j;u:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:g=v[d+112>>2];e=w[g+5|0];if(w[v[d+112>>2]+5|0]&15){t[g+5|0]=e&15;break o}t[g+5|0]=e&240;break o;case 3:e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=B(e&240,10)|e&15;v:{if((l|0)!=65535){if(w[v[d+112>>2]+5|0]){break v}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=l}l=65535}qc(d,n);break o;case 1:l=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break o;case 5:if(w[d+159|0]<=20){e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=(e>>>0)%10|(e>>>0)/10<<4}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0}ak(d+112|0);f=h+1|0;if((h&65535)>>>0<3){continue}break}n=n+1|0;if((n|0)!=64){continue}break}if((l|0)==65535){break m}Hm(_b(o,m),pp(Ue(Ce(d+16|0,12,l&255),v[d>>2])))}m=m+1|0;if(m>>>0<w[d+161|0]){continue}break}}f=1;if(!(c&2)){break a}h=Rc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;w:{if(!v[e>>2]|!x[c+484410>>1]){break w}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!Zc(b,c<<4)){break w}Cg(h,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;vb(d+112|0)}S(f|0);L()}f=1}gb=d+176|0;return f|0}function Vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-112|0;gb=f;vc(b);a:{b:{c:{d:{e:{if(ZU(b,11397)){i=mc(f+96|0);j=mc(f+80|0);l=av(f- -64|0);v[22708]=0;R(367,a|0,32768);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;d=Q(2,f+32|0,5302)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}Eb(a+1298304|0,d);vb(d);v[22708]=0;d=Q(2,f+32|0,3152)|0;g=v[22708];v[22708]=0;if((g|0)==1){break d}Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=2;m=a+484360|0;g=f+56|4;f:{g:{h:{i:{j:{while(1){v[22708]=0;d=Q(191,b|0,8)|0;h=v[22708];v[22708]=0;if((h|0)==1){break i}k:{l:{m:{n:{if(!d){break n}v[22708]=0;d=Q(827,b|0,f+56|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break m}if(!d){break n}d=g;d=Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[22708]=0;U(288,f+8|0,b|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break l}d=f+32|0;e=f+8|0;h=jc(d,e);xb(e);v[22708]=0;d=T(275,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(d){break k}xb(f+32|0)}if(x[a+480188>>1]){break j}g=0;break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=f+56|0;d=Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if(Je(i)>>>0>255){break p}v[22708]=0;R(828,i|0,h|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(x[a+480190>>1]|(d|0)!=1396788560){break p}v[22708]=0;U(829,h|0,l|0,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}v[22708]=0;d=T(195,f+32|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[22708]=0;d=T(416,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break e}p=a,q=Fd(d,1,255),v[p+480196>>2]=q;break p}if(x[a+480188>>1]){break p}v[22708]=0;e=T(195,f+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break e}d=0;if(e>>>0<8){break p}while(1){v[22708]=0;k=T(374,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break o}v[22708]=0;n=T(374,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}e=x[a+480188>>1];if(k|n){v[22708]=0;We(((e<<5)+a|0)+480280|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}k=x[a+480188>>1];e=k+1|0;u[a+480188>>1]=e;u[((k<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64}v[22708]=0;We((((e&65535)<<5)+a|0)+480280|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}e=x[a+480188>>1];u[a+480188>>1]=e+1;u[((e<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64;d=d+1|0;if((d|0)!=4){continue}break}if(c){break p}xb(f+32|0);break g}v[22708]=0;d=T(195,f+32|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[22708]=0;o=T(416,h|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break e}break p}d=Sb(m);v[22708]=0;e=T(195,f+32|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}v[22708]=0;fa(521,d|0,h|0,e|0,255,254)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break p}break e}if(Je(j)>>>0>3998){break p}v[22708]=0;d=T(195,f+32|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(!d){break p}v[22708]=0;R(828,j|0,h|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}}xb(f+32|0);continue}break}break e}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Sb(m);v[22708]=0;R(502,b|0,o&65535);b=v[22708];v[22708]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=Je(i);v[22708]=0;R(330,a+484344|0,b&65535);b=v[22708];v[22708]=0;if((b|0)==1){break b}if(!Je(i)){break u}b=0;while(1){d=Kg(i,d);v[22708]=0;U(830,d|0,b&65535,a|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if(Je(i)>>>0>d>>>0){continue}break}}b=1;if(x[a+480190>>1]<2){break g}h=c&2;d=0;v:{while(1){if(!h|Je(j)>>>0<=d>>>0){break g}w:{c=(B(b,104)+a|0)+484380|0;if(v[c>>2]){g=Kg(j,d);v[22708]=0;g=T(195,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}qc(c,g);g=f+32|0;re(g,l,b-1|0);g=Rc(f+8|0,8,1,1,Cb(g)?10:0);e=Kg(j,d);v[22708]=0;W(329,g|0,c|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break v}d=d+1|0}g=1;b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break f}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=1}De(l);jd(j);jd(i)}gb=f+112|0;return g|0}a=P()|0;O()|0;xb(f+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}De(l);jd(j);jd(i);S(a|0);L()}function Qoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=gb-736|0;gb=m;a:{b:{if(d>>>0<=511){d=0;a=gb-32|0;gb=a;e=a+24|0;g=m+56|0;bc(e,g,554);e=yb(e);k=v[a+28>>2];j=v[a+24>>2];v[a+8>>2]=j;v[a+12>>2]=k;v[a>>2]=j;v[a+4>>2]=k;k=a+16|0;cc(k,b,a);k=yb(k);if((k|0)==(e|0)){Rb(b,yb(a+24|0))}gb=a+32|0;a=(e|0)==(k|0);if(!a){Qb(g,0,554)}if(!a){break b}b=gb-32|0;gb=b;c:{d:{a=m+56|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}Cp(b,3,a+32|0);d=b+16|0;Bc(d,b);v[22708]=0;Q(301,c+492|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}d=b+16|0;vb(d);li(b,1,a+4|0);Bc(d,b);v[22708]=0;Q(301,c+524|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}vb(b+16|0);d=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=d<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];e=c+108|0;k=c+236|0;while(1){g=a+(h<<1)|0;d=w[g- -64|0];g=w[g+65|0];o=wd(k,h),p=g,u[o>>1]=p;o=lc(e,h),p=(d>>>0<120?d:h)+1|0,t[o|0]=p;h=h+1|0;if((h|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;k=c+61|0;t[k|0]=w[a+18|0];g=c+62|0;t[g|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];i=c- -64|0;t[i|0]=w[a+21|0];d=c+48|0;kh(d,25);h=0;while(1){f:{f=h<<1;e=w[(f+a|0)+504|0];o=Lb(d,h),p=e,u[o>>1]=p;if((e|0)==255){kh(d,h);break f}e=w[(a+(f|1)|0)+504|0];o=Lb(d,h),p=e,t[o+2|0]=p;h=h+1|0;if((h|0)!=25){continue}}break}a=w[pf(k,g)|0];if(Nb(d)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[pf(j,i)|0];if(Nb(d)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}gb=b+32|0;break c}a=P()|0;O()|0;vb(b+16|0);S(a|0);L()}d=554;break b}k=v[b+8>>2];h=m+56|0;i=h;g=gb-48|0;gb=g;v[g+44>>2]=674;v[g+24>>2]=674;d=b;j=v[Fb(g+44|0,g+24|0)>>2];if(!Pb(d,j)){j=mf(d)}f=g+24|0;WW(f,i);n=vd(g+32|0,v[f>>2],j);l=v[n+4>>2];v[g+8>>2]=v[n>>2];v[g+12>>2]=l;cc(g+16|0,d,g+8|0);WW(f,i);Qb(v[g+24>>2]+j|0,0,674-j|0);Rb(d,v[g+44>>2]);gb=g+48|0;g=b;j=c;d=c;n=v[a+480180>>2];i=gb-32|0;gb=i;g:{h:{a=h;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1229999433){Cp(i,3,a+32|0);f=i+16|0;Bc(f,i);v[22708]=0;Q(301,d+492|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}f=i+16|0;vb(f);li(i,1,a+4|0);Bc(f,i);v[22708]=0;Q(301,d+524|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}f=i+16|0;vb(f);v[d>>2]=(w[a+20|0]|w[a+21|0]<<8)<<5;v[d+4>>2]=w[a+24|0]>>>1;qc(d+4|0,64);l=w[a+25|0]&127;v[d+8>>2]=l>>>0>64?128:l<<2;t[d+15|0]=w[d+15|0]&254|((w[a+25|0]^-1)&128)>>>7;t[i+16|0]=w[a+26|0];t[i|0]=100;o=d,p=w[ac(f,i)|0],t[o+20|0]=p;t[i+16|0]=w[a+27|0];t[i|0]=64;o=d,p=w[ac(f,i)|0],t[o+19|0]=p;t[d+16|0]=w[a+17|0];t[d+17|0]=w[a+18|0];t[d+18|0]=w[a+19|0];t[d+26|0]=w[a+22|0];t[d+27|0]=w[a+23|0];fm(d,w[a+58|0]&127,w[a+58|0]>>>7|0);em(d,w[a+59|0]&127,w[a+59|0]>>>7|0);i:{j:{k:{f=w[a+28|0]|w[a+29|0]<<8;if(!((f|0)==514|(f|0)==529|(w[a+28|0]|w[a+29|0]<<8)==544)){if((w[a+28|0]|w[a+29|0]<<8)!=532){break k}}if(w[a+61|0]==255){break k}if(w[a+61|0]<=128){t[d+30|0]=w[a+61|0]}e=w[a+62|0]|w[a+63|0]<<8;if(e>>>0<129){break j}break i}if(t[a+61|0]>=0){t[d+30|0]=w[a+61|0]+1}e=t[a+62|0]>=0?w[a+62|0]+1|0:e;if(t[a+63|0]<0){break j}e=(w[a+63|0]<<7)+e|0}u[d+28>>1]=e}e=t[a+60|0];t[d+31|0]=e;if((e|0)<=-1){t[d+31|0]=0;t[d+34|0]=e^128}e=0;f=n&16777216?240:25;ww(a+304|0,d+48|0,0,f);ww(a+386|0,d+68|0,32,f);ww(a+468|0,d+88|0,32,f);t[d+100|0]=w[d+100|0]&239|w[a+468|0]>>>3&16;f=d+108|0;n=d+236|0;while(1){l=a+(e<<1)|0;d=w[l- -64|0];l=w[l+65|0];o=wd(n,e),p=l,u[o>>1]=p;o=lc(f,e),p=(d>>>0<120?d:e)+1|0,t[o|0]=p;e=e+1|0;if((e|0)!=120){continue}break}e=554}gb=i+32|0;a=e;break g}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}if(a){d=w[h+550|0]|w[h+551|0]<<8|(w[h+552|0]<<16|w[h+553|0]<<24);if(!((d|0)!=1297110104?(d|0)!=1481920589:0)){d=j+236|0;a=0;while(1){e=w[(a+h|0)+554|0];j=wd(d,a);u[j>>1]=x[j>>1]|e<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Zc(g,k+d|0);if(!Hh(b,11281)){break b}e=m+8|0;Td(e,b,sg(b));a=jc(m+32|0,e);xb(e);v[22708]=0;e=T(195,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;b=Q(555,a|0,11072)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}if(b){v[22708]=0;b=T(374,a|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}d=(d+e|0)+8|0;xb(a)}gb=m+736|0;return d|0}b=P()|0;O()|0;xb(a);S(b|0);L()}function kL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-416|0;gb=e;t[e+415|0]=c;a:{if(qk(b)){break a}f=w[ul(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+160|0,b,v[b+4>>2]-1|0);f=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=f}f=e+160|0;Ld(f);g=v[e+160>>2];Ld(e+376|0);h=tl(g,v[e+380>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+164>>2]){v[e+400>>2]=f;v[e+404>>2]=g;a=uc(e+392|0,18720);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Gc(e+8|0,e)){c=ba(8)|0;v[22708]=0;R(2057,e+376|0,e+415|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;U(2038,e+160|0,14722,e+376|0);a=v[22708];v[22708]=0;if((a|0)==1){break f}rc(c,e+160|0);a=0;v[22708]=0;U(186,c|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);break e}if(!d){break h}c=ba(8)|0;v[22708]=0;d=Q(2058,e+344|0,b|0)|0;b=v[22708];v[22708]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22708]=0;U(2038,e+360|0,14758,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break q}v[22708]=0;R(2055,e+376|0,e+360|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break p}v[22708]=0;R(2057,e+328|0,e+415|0);a=v[22708];v[22708]=0;if((a|0)==1){break o}v[22708]=0;U(2059,e+160|0,e+376|0,e+328|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break n}rc(c,e+160|0);v[22708]=0;U(186,c|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(e+328|0)}vb(e+376|0)}vb(e+360|0)}vb(d)}if(a){break d}break c}v[e+320>>2]=f;v[e+324>>2]=g;d=uc(e+312|0,18720);f=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=f;f=v[d+4>>2];v[e+144>>2]=v[d>>2];v[e+148>>2]=f;if(Gc(e+152|0,e+144|0)){c=ba(8)|0;v[22708]=0;R(2057,e+376|0,e+415|0);a=v[22708];v[22708]=0;r:{s:{if((a|0)!=1){v[22708]=0;U(2038,e+160|0,14722,e+376|0);a=v[22708];v[22708]=0;if((a|0)==1){break s}rc(c,e+160|0);a=0;v[22708]=0;U(186,c|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);break r}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}vb(e+376|0);if(a){break d}break c}d=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=d;d=uc(e+296|0,4506);f=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=f;f=v[d+4>>2];v[e+128>>2]=v[d>>2];v[e+132>>2]=f;t:{if(!Gc(e+136|0,e+128|0)){d=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=d;d=uc(e+280|0,4488);f=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=f;f=v[d+4>>2];v[e+112>>2]=v[d>>2];v[e+116>>2]=f;if(!Gc(e+120|0,e+112|0)){break t}}t[a+60|0]=c;break h}d=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=d;d=uc(e+264|0,3991);f=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=f;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;u:{if(!Gc(e+104|0,e+96|0)){d=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=d;d=uc(e+248|0,3972);f=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=f;f=v[d+4>>2];v[e+80>>2]=v[d>>2];v[e+84>>2]=f;if(!Gc(e+88|0,e+80|0)){break u}}t[a+61|0]=c;break h}d=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=d;d=uc(e+232|0,4075);f=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=f;f=v[d+4>>2];v[e+64>>2]=v[d>>2];v[e+68>>2]=f;if(Gc(e+72|0,e- -64|0)){t[a+62|0]=c;break h}d=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=d;d=uc(e+216|0,3156);f=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){t[a+63|0]=c;break h}d=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=d;d=uc(e+200|0,4555);f=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){t[a+64|0]=c;break h}d=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=d;b=uc(e+184|0,10714);d=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Gc(e+24|0,e+16|0)){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+176>>2]=v[f>>2];v[e+180>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+168>>2]=v[f>>2];v[e+172>>2]=g;f=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=f;b=e;if(c){a=xK(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!My(e+160|0,v[d>>2]+24648|0)){break h}Vz(v[d>>2],e+160|0)}gb=e+416|0;return}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}vb(e+376|0);if(!a){break c}}da(c|0)}S(b|0)}L()}function aka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-192|0;gb=e;a:{if(!Pb(c,8)){break a}Rb(c,4);while(1){n=rv(c);if(n){break a}p=gb-288|0;gb=p;f=OR(p);g=gb-384|0;gb=g;i=g+96|0;OR(i);j=hc(f,i,282);f=0;b:{c:{d:{e:{f:{g:{h:{h=c;if(Hh(h,10973)){pg(h,4);l=le(g+72|0,h);v[22708]=0;i=Q(1103,l|0,j|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}i:{if(!i){break i}i=w[j+26|0];v[22708]=0;i=Q(191,l|0,i|0)|0;k=v[22708];v[22708]=0;if((k|0)==1){break e}if(!i){break i}k=0;j:{k:{l:{if(w[j+26|0]){while(1){v[22708]=0;i=T(309,l|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break l}t[(j+k|0)+27|0]=i;f=f+i|0;k=k+1|0;if(k>>>0<w[j+26|0]){continue}break}k=f&65535}f=0;v[22708]=0;i=Q(191,l|0,k|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break d}if(!i){break i}v[22708]=0;Q(318,l|0,k|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}pg(l,PR(j));i=Vi(g- -64|0);f=g+96|0;VA(f);v[22708]=0;R(1104,l|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break k}u[g+118>>1]=0;u[g+120>>1]=0;NR(i,g+96|0,g+123|0);f=w[j+26|0];v[22708]=0;Q(318,l|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=j+27|0;NR(i,f,f+w[j+26|0]|0);v[22708]=0;U(288,g+16|0,l|0,k|0);f=v[22708];v[22708]=0;if((f|0)!=1){break j}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=g+16|0;k=jc(g+40|0,f);xb(f);v[22708]=0;R(757,f|0,k|0);f=v[22708];v[22708]=0;if((f|0)==1){break h}v[22708]=0;Uv(g+8|0,g+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break g}f=i;o=g+8|0;m=v[o>>2];o=v[o+4>>2];if((m|0)!=(o|0)){while(1){LR(f,zb(w[m|0]));m=m+1|0;if((o|0)!=(m|0)){continue}break}}zc(g+16|0);xb(k);f=0;if(v[i>>2]!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break i}f=PR(j);v[22708]=0;Q(318,h|0,f|0)|0;i=v[22708];v[22708]=0;f=1;if((i|0)==1){break d}}xb(l)}gb=g+384|0;break b}f=P()|0;O()|0;break f}f=P()|0;O()|0;zc(g+16|0)}xb(k);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}xb(l);S(f|0);L()}gb=p+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|n;vc(c);m:{n:{o:{p:{q:{r:{if(n){i=sg(c);d=e+144|0;Td(d,c,mf(c));f=jc(e+168|0,d);xb(d);u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=i>>>(b&1)>>>(b>>>6&1);v[e+140>>2]=0;v[e+136>>2]=0;v[22708]=0;R(757,d|0,f|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}v[22708]=0;b=Sd(e+144|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=v[e+144>>2];d=zb(b);i=Ui(c);v[22708]=0;i=fa(756,d|0,i|0,e+140|0,e+136|0,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}v[22708]=0;Q(318,f|0,v[e+140>>2])|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}if(!i){break p}h=v[e+140>>2];v[22708]=0;T(386,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break o}d=c-h|0;b=b+h|0;n=v[e+136>>2];c=0;while(1){s:{if(n){if(!d|(n|0)!=1){break q}if(y[a>>2]>c>>>0){break s}break q}if(y[a>>2]<=c>>>0){break q}}if(!Md(a)){break q}v[e+132>>2]=0;v[e+128>>2]=0;h=zb(b);g=Ui(d);v[22708]=0;h=la(758,i|0,h|0,g|0,e+132|0,e+124|0,e+128|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}v[22708]=0;v[e+140>>2]=h;Q(318,f|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}j=v[e+140>>2];ck(e+128|0,Ui(v[a>>2]-c|0));t:{if(v[e+128>>2]<1){break t}if(v[e+132>>2]!=(fd(a)|0)){break t}if(t[a+34|0]&1){h=mg(e+112|0,v[a+20>>2]+(B(fd(a),c)<<1)|0,fd(a),v[e+128>>2]);g=mg(e+96|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22708]=0;v[e+56>>2]=v[h+8>>2];l=v[h+4>>2];v[e+48>>2]=v[h>>2];v[e+52>>2]=l;v[e+40>>2]=v[g+8>>2];h=v[g+4>>2];v[e+32>>2]=v[g>>2];v[e+36>>2]=h;R(759,e+48|0,e+32|0);h=v[22708];v[22708]=0;if((h|0)!=1){break t}break o}h=mg(e+80|0,v[a+20>>2]+B(fd(a),c)|0,fd(a),v[e+128>>2]);g=mg(e- -64|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22708]=0;v[e+24>>2]=v[h+8>>2];l=v[h+4>>2];v[e+16>>2]=v[h>>2];v[e+20>>2]=l;v[e+8>>2]=v[g+8>>2];h=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=h;R(760,e+16|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break o}}v[22708]=0;h=v[e+128>>2];n=ky(i);g=v[22708];v[22708]=0;if((g|0)==1){break o}d=d-j|0;b=b+j|0;v[e+136>>2]=n;c=c+h|0;continue}}break o}Cg(b,a,c);a=1;break m}a=P()|0;O()|0;break n}v[22708]=0;ly(i);a=v[22708];v[22708]=0;if((a|0)!=1){break p}break o}a=(i|0)!=0;zc(e+144|0);xb(f);break m}a=P()|0;O()|0;zc(e+144|0)}xb(f);S(a|0);L()}gb=e+192|0;return a|0}function cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-256|0;gb=g;vc(b);a:{if(!xY(b,g+184|0)){break a}if(!dV(g+184|0)){break a}if(!Pb(b,Qc(cV(g+184|0),jb))){break a}b:{if(!c){break b}Hd(a,16);d=g+24|0;f=g+184|0;Zj(d,2,f|4);e=g+48|0;Bc(e,d);Eb(a+1298268|0,e);vb(e);u[a+480190>>1]=w[g+214|0];u[a+480188>>1]=w[g+217|0];i=Tb(e,5512);Eb(a+1298304|0,i);vb(i);i=Tb(e,7399);Eb(a+1298316|0,i);vb(i);Ff(d,1320);f=f|3;v[g>>2]=w[f|0]>>>4;f=w[f|0];v[22708]=0;v[g+180>>2]=f&15;Y(460,e|0,d|0,g|0,g+180|0);d=v[22708];v[22708]=0;e=1;c:{d:{e:{if((d|0)!=1){d=g+48|0;Eb(a+1298328|0,d);vb(d);Hb(g+24|0);v[a+1298364>>2]=5;if(x[a+480190>>1]){d=1;while(1){i=g+48|0;wE(b,i);j=gb-16|0;gb=j;h=(B(e,104)+a|0)+484380|0;ud(h,0);f=i;u[j+14>>1]=w[f+35|0]<<2;u[j+12>>1]=256;q=h,r=x[Pc(j+14|0,j+12|0)>>1],u[q+30>>1]=r;f:{if((w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24))>>>0<3){break f}v[h>>2]=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);v[h+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[j+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[j+4>>2]=1;q=h,r=v[Mc(j+8|0,j+4|0)>>2]-1|0,v[q+8>>2]=r;qc(h+8|0,v[h>>2]);g:{if(y[h+8>>2]<=v[h+4>>2]+4>>>0){v[h+4>>2]=0;v[h+8>>2]=0;break g}u[h+34>>1]=x[h+34>>1]|2}t[h+37|0]=w[f+34|0];q=h,r=Hu(0,t[f+34|0]<<4),v[q+24>>2]=r;if(!(t[f+36|0]&1)){break f}u[h+34>>1]=x[h+34>>1]|1;v[h>>2]=v[h>>2]>>>1;v[h+4>>2]=v[h+4>>2]>>>1;v[h+8>>2]=v[h+8>>2]>>>1}gb=j+16|0;Qk(g,2,i);f=g+24|0;Bc(f,g);v[22708]=0;Q(301,((e<<5)+a|0)+946304|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}vb(g+24|0);d=d+1|0;e=d&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){e=0;while(1){d=(e<<5)+a|0;We(d+480280|0);u[d+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}i=g+48|0;d=i;f=gb-32|0;gb=f;e=b;h:{if(!Pb(e,128)){e=gb-16|0;gb=e;h=d+128|0;while(1){Jf(d);d=d+1|0;if((h|0)!=(d|0)){continue}break}gb=e+16|0;break h}EW(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;kd(f+16|0,e,f+8|0)}gb=f+32|0;GE(Sb(a+484360|0),i,w[g+211|0]+1|0);h=w[g+216|0]?w[g+216|0]:64;Td(g,b,B(w[g+208|0]|w[g+209|0]<<8,192));l=jc(g+24|0,g);xb(g);e=c&1;if(e){d=w[g+210|0];v[22708]=0;R(330,a+484344|0,d+1|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}}i:{j:{if(!e){break j}p=a+484344|0;while(1){v[22708]=0;d=W(331,p|0,m&65535,h|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}e=0;if(!d){break j}while(1){v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break d}j=e;k:{if(!d|d>>>0>(w[g+208|0]|w[g+209|0]<<8)>>>0){break k}e=j&65535;if(e>>>0>=x[a+480188>>1]){break k}v[22708]=0;Q(190,l|0,B(d,192)-192|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}d=_b(p,m);v[22708]=0;e=Xc(d,0,e);d=v[22708];v[22708]=0;if((d|0)==1){break d}o=0;if(!h){break k}while(1){v[22708]=0;R(723,g|0,l|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}k=qd(g);n=Ve(g);f=e;i=g;d=w[g|0];if(d>>>0>=4){t[e|0]=(d>>>2|0)+37;d=w[i|0]}t[f+1|0]=d<<4&48|w[k|0]>>>4;d=w[n|0];f=0;i=0;l:{m:{n:{o:{p:{q:{k=w[k|0]&15;switch(k-8|0){case 0:break n;case 6:break p;case 2:break q;default:break o}}d=(d&240?-16:15)&d;k=10;break m}k=14;n=(d+16&240)>>>4|0;if(n>>>0>8){break m}if(1<<n&435){break n}break m}f=k;i=d}k=f;d=i;if(!((f|d)&255)){break l}}t[e+5|0]=d;t[e+3|0]=k;v[22708]=0;Pf(e);d=v[22708];v[22708]=0;if((d|0)!=1){break l}break d}e=B(x[a+480188>>1],6)+e|0;o=o+1|0;if((o|0)!=(h|0)){continue}break}}e=j+1|0;if((j&65535)>>>0<31){continue}break}e=w[g+210|0]>m>>>0;m=m+1|0;if(e){continue}break}}if(w[g+212|0]|w[g+213|0]<<8){e=w[g+212|0]|w[g+213|0]<<8;v[22708]=0;fa(473,a+1298292|0,b|0,e|0,39,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){e=1;while(1){c=B(e&65535,104)+a|0;d=Rc(g,u[c+484414>>1]&1?16:8,1,0,1);v[22708]=0;W(329,d|0,c+484380|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;xb(l);break b}break d}e=P()|0;O()|0;Hb(g+24|0);break c}e=P()|0;O()|0;vb(g+24|0);break c}e=P()|0;O()|0;xb(l)}S(e|0);L()}e=1}gb=g+256|0;return e|0}function AP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=gb-16|0;gb=i;a:{if(!we(d&255)){break a}j=(B(b,872)+a|0)+1074992|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(tk(j)){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1298260|0;if(!Dd(c)){break c}Pi(v[c>>2],b,0);break a}c=rA(a,b);if((c|0)==65535){break a}m=B(c,872);c=a+1074992|0;a=m+c|0;nu(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;_o(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;n=v[e+1075096>>2];c=x[a+480192>>1]<c>>>0?0:c;h=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!h){break d}f=d-1|0;c=x[wd(h+236|0,f)>>1];k=i+8|0;g=a+1074312|0;Db(k,g,104);e:{if(Cb(k)){Db(i,g,34);if(Cb(i)){break e}}d=w[lc(h+108|0,f)|0]}if((c-1&65535)>>>0<=3998){n=(B(c,104)+a|0)+484380|0;break d}c=i+8|0;Db(c,g,43);if(!Cb(c)){break d}if(!Ij(h)){break a}}if(w[e+1075081|0]&4){break a}g=a+1298260|0;k=a+1074312|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)?x[a+480188>>1]>c>>>0:0){break f}e=B(c,872)+a|0;if((b|0)!=(c|0)?x[e+1075778>>1]!=(q|0):0){break f}p=e+1075648|0;f=v[p>>2];if(!f){break f}l=e+1074992|0;g:{h:{i:{j:{k:{l:{m:{switch(w[f+17|0]-1|0){case 0:if(!d){break f}m=w[e+1075789|0]==(d|0)&(f|0)==(h|0);o=m;if(!h){break l}if(m){break i}break f;case 1:if(!n|v[e+1075096>>2]!=(n|0)){break f}if((f|0)==(h|0)){break g}f=i+8|0;Db(f,k,104);if(!Cb(f)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(h){break j}o=(f|0)==(h|0)}if(o){break g}break f}if(!h){break f}m=w[h+34|0];if(!m){break f}if((m|0)==w[f+34|0]){break h}break f}if((f|0)!=(h|0)){break f}}if(!w[h+34|0]){break g}}if(!w[e+1075789|0]|w[f+18|0]>2){break g}f=i+8|0;Db(f,k,34);Km(a,c&65535,JS(l,Cb(f))+255|0,0);t[e+1075792|0]=0}n:{o:{switch(w[v[p>>2]+18|0]){case 0:Bo(a,l);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break n}if(!Dd(g)){break n}Pi(v[g>>2],c&65535,1);break n;case 1:Bo(a,l);if(!(w[e+1075081|0]&2)){break n}if(!Dd(g)){break n}vk(v[g>>2],c&65535);break n;case 2:break o;default:break n}}l=e+1075080|0;f=v[l>>2];v[l>>2]=f|4096;if(!(f&512)){break n}if(!Dd(g)){break n}f=i+8|0;Db(f,k,105);if(Cb(f)){break n}vk(v[g>>2],c&65535)}if(v[e+1075680>>2]){break f}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}c=0;e=0;p:{if(!tk(j)){break p}if(!we(w[(B(b,872)+a|0)+1075789|0])){break p}q:{d=Jm(a,b,2,1);if(d-251>>>0<5){break q}if(!d){break p}e=v[(B(d,160)+a|0)+906140>>2];if(!e){break q}c=i+8|0;Db(c,k,34);c=(s=e,y=JS(j,Cb(c)),z=b,r=v[v[e>>2]+100>>2],kb[r](s|0,y|0,z|0)|0);break p}e=0}if(!(r=1,z=Ni(j),y=c,y?r:z)){break a}h=rA(a,b);if((h|0)==65535){break a}f=B(h,872)+a|0;d=f+1075080|0;n=f+1074992|0;r:{if(!(w[f+1075081|0]&2)){break r}if(!Dd(g)){break r}Pi(v[g>>2],h,1)}nu(n,j);v[d>>2]=v[d>>2]&-917505;t[f+1075823|0]=0;l=x[a+480188>>1];t[f+1075797|0]=0;u[f+1075778>>1]=b>>>0<l>>>0?b+1|0:0;s:{if(!((e|0)!=0&c)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}Km(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Bo(a,n);if(!(w[d+1|0]&2)){break t}if(!Dd(g)){break t}vk(v[g>>2],b);c=i+8|0;Db(c,k,105);if(!Cb(c)){break t}YA(v[g>>2],b,h);break t;case 0:v[(B(h,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Dd(g)){break t}Pi(v[g>>2],b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Dd(g)){break t}c=i+8|0;Db(c,k,105);e=Cb(c);c=v[g>>2];if(e){YA(c,b,h);break t}vk(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}if(!Dd(g)){break t}YA(v[g>>2],b,h)}if(!v[(B(h,872)+a|0)+1075680>>2]){v[(B(h,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}gb=i+16|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-112|0;gb=e;f=e+88|0;g=a+140|0;Rm(f,g,1296125513);v[22708]=0;f=T(275,f|0)|0;h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((h|0)!=1){if(f){f=Kb(e+32|0);v[22708]=0;h=T(195,e+88|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break o}v[22708]=0;U(1438,e+88|0,f|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break o}h=x[a+174>>1];v[22708]=0;Y(1439,e+72|0,h|0,8,f|0);h=v[22708];v[22708]=0;if((h|0)==1){break n}v[22708]=0;U(9,e+8|0,c|0,e+72|0);c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;Q(301,d|0,e+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break l}vb(e+8|0);vb(e+72|0);vb(f)}if(w[a+176|0]){v[22708]=0;R(1440,e+32|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;Q(303,b+43|0,e+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break h}vb(e+32|0)}v[22708]=0;U(1430,e+32|0,g|0,1413894985);c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;f=T(1441,e+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}g=e+32|0;xb(g);c=a+40|0;vc(c);v[22708]=0;g=Q(1442,c|0,g|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}if(!g){break d}if((w[e+60|0]|w[e+61|0]<<8|(w[e+62|0]<<16|w[e+63|0]<<24))>>>0<2){break e}v[22708]=0;g=Q(1443,c|0,e+8|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!g){break e}g=v[b>>2];v[22708]=0;yz(e+8|0,b+12|0,b+16|0,g,b+34|0,8,16,f);g=v[22708];v[22708]=0;if((g|0)!=1){break e}break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;vb(e+8|0)}vb(e+72|0)}vb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e+32|0);break a}v[22708]=0;c=Q(1443,c|0,e+8|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(c){c=v[b>>2];v[22708]=0;yz(e+8|0,b+4|0,b+8|0,c,b+34|0,2,4,f);c=v[22708];v[22708]=0;if((c|0)==1){break b}}c=w[e+44|0]|w[e+45|0]<<8|(w[e+46|0]<<16|w[e+47|0]<<24);t[b+42|0]=c&128?0:c+1|0;v[22708]=0;xk(b);c=v[22708];v[22708]=0;if((c|0)==1){break b}}p:{q:{if(w[b+42|0]){break q}v[22708]=0;c=a+60|0;f=Q(866,c|0,7)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!f){break q}vc(c);v[22708]=0;c=Q(1445,c|0,e+8|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break p}if(!c){break q}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[22708]=0;h=a+120|0;c=T(275,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}r:{if(!c){break r}c=0;v[22708]=0;f=T(192,h|0)|0;g=v[22708];v[22708]=0;s:{if((g|0)!=1){v[e+72>>2]=f;g=b+68|0;qc(e+72|0,9);if(v[e+72>>2]){f=e+8|4;while(1){v[22708]=0;R(1446,h|0,e+8|0);i=v[22708];v[22708]=0;if((i|0)==1){break s}i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=yf(g,c),k=i,v[j>>2]=k;c=c+1|0;if(c>>>0<y[e+72>>2]){continue}break}}c=v[e+72>>2];f=nX(g);v[22708]=0;RB(g+(c<<2)|0,f,36536);c=v[22708];v[22708]=0;if((c|0)!=1){break r}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=a+80|0;vc(a);v[22708]=0;c=Q(1448,a|0,e+8|0)|0;f=v[22708];v[22708]=0;t:{u:{v:{w:{x:{if((f|0)==1){break x}if(!c){break u}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|4;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22708]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22708];v[22708]=0;if((f|0)==1){break t}u[b+28>>1]=x[c>>1];c=e+8|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22708]=0;u[e+6>>1]=256;c=Pc(e+72|0,e+6|0);f=v[22708];v[22708]=0;if((f|0)==1){break w}u[b+30>>1]=x[c>>1];u[e+72>>1]=w[e+16|0]|w[e+17|0]<<8;v[22708]=0;u[e+6>>1]=64;c=Pc(e+72|0,e+6|0);f=v[22708];v[22708]=0;if((f|0)==1){break v}u[b+32>>1]=x[c>>1];t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[22708]=0;c=Q(191,a|0,32)|0;f=v[22708];v[22708]=0;if((f|0)==1){break x}if(!c){break u}v[22708]=0;W(1449,a|0,d|0,32)|0;c=v[22708];v[22708]=0;if((c|0)==1){break x}v[22708]=0;c=T(467,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}v[22708]=0;U(1450,a|0,b+43|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break u}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}xb(e+88|0);gb=e+112|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(e+88|0);S(a|0);L()}function IO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;a:{b:{if(!we(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break b}d=v[((d<<2)+b|0)+900380>>2];if(!d){break b}e=v[d+44>>2];if(!e){break b}u[i+14>>1]=c-61;d=gb-80|0;gb=d;c=u[e+28>>1];g=i+14|0;b=u[g>>1];f=e+4|0;Nb(f);c:{d:{if((b|0)>=(c|0)){if((b|0)<=(x[e+28>>1]+Nb(f)<<16)-65536>>16){break d}}Kb(a);break c}e:{b=x[e+30>>1];if(!b){b=e+52|0;k=d,l=hz(b,g),v[k+56>>2]=l;k=d,l=Eh(b),v[k+40>>2]=l;if(!og(d+56|0,d+40|0)){break e}gg(a,ve(d+56|0)+4|0);break c}c=qo(u[g>>1],b<<16>>16);u[d+78>>1]=c;b=Kb(a);a=e+52|0;k=d,l=hz(a,d+78|0),v[k+72>>2]=l;k=d,l=Eh(a),v[k+56>>2]=l;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(og(d+72|0,d+56|0)){a=ve(d+72|0);v[22708]=0;Q(156,b|0,a+4|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break v}a=u[e+30>>1];c=u[g>>1];v[22708]=0;k=d,l=gz(c,a)+5|0,v[k+40>>2]=l;R(153,d+56|0,d+40|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;Q(113,b|0,d+56|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(d+56|0);break c}a=P()|0;O()|0;vb(d+56|0);break f}if(u[e+30>>1]>26){break s}v[22708]=0;c=W(716,d+40|0,1,(c<<24)+1090519040>>24)|0;a=v[22708];v[22708]=0;if((a|0)==1){break u}v[22708]=0;U(13,d+56|0,0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break t}a=d+56|0;Eb(b,a);vb(a);vb(c);v[22708]=0;Q(154,b|0,11840)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break r}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22708]=0;a=(c<<16>>16)/16|0;v[d+36>>2]=c-(a<<4)<<16>>16;R(1504,d+40|0,d+36|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}v[22708]=0;v[d+20>>2]=(a<<16>>16)%16;R(1504,d+24|0,d+20|0);a=v[22708];v[22708]=0;if((a|0)==1){break p}v[22708]=0;U(3,d+56|0,d+40|0,d+24|0);a=v[22708];v[22708]=0;if((a|0)==1){break o}a=d+56|0;Eb(b,a);vb(a);vb(d+24|0);vb(d+40|0);if(c<<16>>16<256){break r}v[22708]=0;U(9,d+8|0,0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;YS(d+40|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;U(13,d+56|0,0,d+40|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}a=d+56|0;Eb(b,a);vb(a);vb(d+40|0);vb(d+8|0)}a=u[e+30>>1];c=u[g>>1];v[22708]=0;k=d,l=gz(c,a)+5|0,v[k+40>>2]=l;R(153,d+56|0,d+40|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;Q(113,b|0,d+56|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break h}vb(d+56|0);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(d+24|0)}vb(d+40|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+40|0)}vb(d+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+56|0);break f}a=P()|0;O()|0}vb(b);S(a|0);L()}b=a;a=gb-16|0;gb=a;c=a;f=gb-32|0;gb=f;e=He(f+16|0,1,0);PP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);w:{x:{if(v[f+12>>2]){while(1){h=Ab(e);v[22708]=0;v[f+4>>2]=h;h=xf(f+4|0);j=v[22708];v[22708]=0;if((j|0)==1){break x}v[22708]=0;U(75,e|0,h|0,0);h=v[22708];v[22708]=0;if((h|0)==1){break x}PP(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);if(v[f+12>>2]){continue}break}}g=v[f+8>>2];h=Jb(e);v[22708]=0;R(76,e|0,g-h|0);g=v[22708];v[22708]=0;if((g|0)==1){break x}v[22708]=0;R(86,c|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break w}}a=P()|0;O()|0;vb(e);S(a|0);L()}vb(e);gb=f+32|0;v[22708]=0;R(85,b|0,a|0);b=v[22708];v[22708]=0;y:{if((b|0)!=1){vb(a);gb=a+16|0;break y}b=P()|0;O()|0;vb(a);S(b|0);L()}}gb=d+80|0;break a}e=v[b>>2];b=gb-32|0;gb=b;d=gb-16|0;gb=d;t[d+15|0]=c;t[d+14|0]=251;t[d+13|0]=255;f=Hv(d+15|0,d+14|0,d+13|0);gb=d+16|0;z:{if(f){v[b+16>>2]=v[9588];d=v[9587];v[b+8>>2]=v[9586];v[b+12>>2]=d;d=v[9585];v[b>>2]=v[9584];v[b+4>>2]=d;Tb(a,(b+(c<<2)|0)-1004|0);break z}if(we(c)){d=Kb(b);v[22708]=0;f=c-1|0;c=(f<<16>>16)/12|0;e=Q(1322,d|0,e+(f-B(c,12)<<16>>16<<2)|0)|0;f=v[22708];v[22708]=0;A:{if((f|0)==1){break A}v[22708]=0;c=Q(1323,e|0,c+48&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break A}v[22708]=0;Q(4,a|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break A}vb(d);break z}a=P()|0;O()|0;vb(d);S(a|0);L()}if(!c){Tb(a,13833);break z}Tb(a,11811)}gb=b+32|0}gb=i+16|0}function oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-144|0;gb=e;d=-1;a:{b:{c:{d:{if(!El(v[v[b>>2]-12>>2]+b|0)){b=Fm(e+40|0,b);v[22708]=0;d=Q(620,e+24|0,11251)|0;f=v[22708];v[22708]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)!=1){v[22708]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(621,b|0,d|0,e+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break E}Hb(d);t[e+15|0]=0;v[22708]=0;d=Q(620,e+24|0,11939)|0;f=v[22708];v[22708]=0;if((f|0)==1){break D}v[22708]=0;W(622,b|0,e+15|0,d|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break C}Hb(d);v[22708]=0;f=w[e+15|0];d=Q(620,e+24|0,12902)|0;g=v[22708];v[22708]=0;if((g|0)==1){break B}v[22708]=0;f=f?0:c;Y(1507,b|0,a+40|0,d|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break A}Hb(d);u[e+12>>1]=65535;v[22708]=0;c=Q(620,e+24|0,12583)|0;d=v[22708];v[22708]=0;if((d|0)==1){break z}v[22708]=0;W(1092,b|0,e+12|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break y}Hb(c);u[e+10>>1]=0;v[22708]=0;c=Q(620,e+24|0,12482)|0;d=v[22708];v[22708]=0;if((d|0)==1){break x}v[22708]=0;W(1092,b|0,e+10|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break w}Hb(c);u[a>>1]=x[e+10>>1];v[22708]=0;c=Q(620,e+24|0,12244)|0;d=v[22708];v[22708]=0;if((d|0)==1){break v}v[22708]=0;Y(1508,b|0,a+52|0,c|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break u}Hb(c);v[22708]=0;c=Q(620,e+24|0,12193)|0;d=v[22708];v[22708]=0;if((d|0)==1){break t}v[22708]=0;W(1480,b|0,a+36|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break s}Hb(c);v[22708]=0;c=Q(620,e+24|0,12585)|0;d=v[22708];v[22708]=0;if((d|0)==1){break r}v[22708]=0;f=a+4|0;U(1509,b|0,f|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break q}Hb(c);v[22708]=0;c=Q(620,e+24|0,12484)|0;d=v[22708];v[22708]=0;if((d|0)==1){break p}v[22708]=0;g=a+28|0;U(1510,b|0,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break o}Hb(c);v[22708]=0;c=Q(620,e+24|0,12345)|0;d=v[22708];v[22708]=0;if((d|0)==1){break n}v[22708]=0;U(1510,b|0,a+30|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break m}Hb(c);v[22708]=0;c=Q(620,e+24|0,12217)|0;d=v[22708];v[22708]=0;if((d|0)==1){break l}v[22708]=0;U(1511,b|0,a+32|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break k}Hb(c);u[e+8>>1]=0;v[22708]=0;c=Q(620,e+24|0,12172)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;W(1092,b|0,e+8|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break j}Hb(c);d=-1;if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>=601){break e}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break e}i=e,j=Ui(v[a+36>>2]),v[i+24>>2]=j;v[22708]=0;v[e+16>>2]=0;c=dj(e+24|0,e+16|0,49656);h=v[22708];v[22708]=0;if((h|0)==1){break c}v[a+36>>2]=v[c>>2];if(Nb(f)>>>0>32767){break e}switch(x[a>>1]-1|0){case 2:break i;case 0:break h;default:break g}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;Hb(c);break a}c=u[e+8>>1];if((c|0)<1){break e}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];f=x[a+28>>1];u[e+16>>1]=f;v[22708]=0;u[e+18>>1]=(c+f|0)-1;a=ca(1512,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}c=u[e+8>>1];if((c|0)<1){break e}z[e+24>>2]=z[a+32>>2];h=x[a+28>>1];u[e+16>>1]=h;v[22708]=0;u[e+18>>1]=(c+h|0)-1;a=fa(1513,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}v[22708]=0;_(1514,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}}d=1}gh(b)}gb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}gh(b);S(a|0);L()}function IL(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;l=gb-48|0;gb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Xb(k);v[j>>2]=0}v[22708]=0;X(2028);k=v[22708];v[22708]=0;b:{c:{if((k|0)==1){m=Ta(89104,54720,54776,54936,89280,89384,89332,89224,89212,89528,89496,89464,89452,89080,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(89104)|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=277;if((j|0)==1){break e}break b}if((ea(54720)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(54776)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(54936)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89280)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89384)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89332)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89224)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89212)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89528)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89496)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89464)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}if((ea(89452)|0)==(n|0)){k=Z(m|0)|0;v[22708]=0;R(2029,j|0,k|0);j=v[22708];v[22708]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break d}o=ea(89080)|0;k=257;m=Z(m|0)|0;if((n|0)!=(o|0)){break b}v[22708]=0;R(2029,j|0,m|0);j=v[22708];v[22708]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}$()}o=!g;if(d){j=kb[d|0](k,e)|0}else{j=3}if(!(o|!(j&2))){v[g+16>>2]=k;m=v[l+44>>2];f:{if(m){o=ie(m);break f}o=ie(18720)}v[g+20>>2]=o}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];g:{if(g){g=ie(g);break g}g=ie(18720)}v[i>>2]=g}g=v[l+44>>2];if(g){Xb(g);v[l+44>>2]=0}h:{if(!(j&1)){break h}v[22708]=0;R(1913,l+32|0,a|0);g=v[22708];v[22708]=0;i:{j:{if((g|0)!=1){k:{if(f){v[22708]=0;R(1914,f|0,l+32|0);g=v[22708];v[22708]=0;if((g|0)!=1){break k}break j}g=Jb(l+32|0);if(b){v[22708]=0;R(b|0,g|0,c|0);g=v[22708];v[22708]=0;if((g|0)==1){break j}break k}Kt(g,l)}vb(l+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;vb(l+32|0)}Z(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:18720;v[l+4>>2]=250;v[l>>2]=6331;UI(14936,l);lt(90144);$()}gb=l+48|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=gb-128|0;gb=d;i=-1;a:{b:{c:{d:{if(!_f(v[v[b>>2]-12>>2]+b|0)){break d}te(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];h=d+104|0;hm(h);kl(b,h,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=sh(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;kk(b,d+8|0);break d}u[d+86>>1]=0;ag(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}e=d+78|0;hm(e);kl(b,e,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;ag(b,d+76|0);e=u[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Kb(d+112|0);v[22708]=0;f=W(653,b|0,e|0,65535)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!f){break j}v[22708]=0;U(13,d- -64|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)!=1){break k}break b}e=Kb(d+112|0);v[22708]=0;f=W(655,b|0,e|0,255)|0;h=v[22708];v[22708]=0;if((h|0)==1){break c}if(!f){break i}v[22708]=0;U(13,d- -64|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}}f=d- -64|0;Eb(a+40|0,f);vb(f);vb(e);u[d+62>>1]=0;ag(b,d+62|0);u[d+60>>1]=0;ag(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Hk(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=Lv(e);u[d+58>>1]=e;break l}ag(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){h=a+52|0;f=0;while(1){e=Kb(d+112|0);v[22708]=0;u[d+40>>1]=0;Q(1515,b|0,d+40|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[22708]=0;g=W(653,b|0,e|0,65535)|0;j=v[22708];v[22708]=0;if((j|0)==1){break g}if(g){break q}break e}v[22708]=0;g=W(655,b|0,e|0,255)|0;j=v[22708];v[22708]=0;if((j|0)==1){break g}if(!g){break e}}v[22708]=0;U(13,d- -64|0,c|0,e|0);g=v[22708];v[22708]=0;if((g|0)==1){break p}v[22708]=0;g=Q(1516,h|0,d+40|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break o}j=g;g=d- -64|0;Eb(j,g);vb(g);vb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}c=d- -64|0;hm(c);kl(b,c,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(iN(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(d- -64|0);break f}if(!hN(b,c)){break d}}e=a+16|0;r:{if(u[d+86>>1]<=2){if(iN(b,e)){break r}break d}if(!hN(b,e)){break d}}l=a,m=Nb(e),v[l+36>>2]=m;u[d+56>>1]=0;ag(b,d+56|0);e=x[d+56>>1];u[a+28>>1]=e;if((e+200&65535)>>>0>400){break d}u[d+54>>1]=0;ag(b,d+54|0);e=u[d+54>>1];u[a+30>>1]=e;if((e|0)<0){break d}v[d+48>>2]=0;mq(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}e=d+40|0;hm(e);kl(b,e,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}if(Nb(c)>>>0>32767){break d}b=x[a>>1];if(!(b?!(z[a+32>>2]<=C(0))&u[a+30>>1]>0:1)){break d}s:{switch(b-1|0){case 0:case 2:if(Nb(c)>>>0<u[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=Ui(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[dj(d+112|0,d+32|0,49656)>>2],v[l+36>>2]=m;nq(a);i=1;if(x[a>>1]!=3){break d}if((nN(Nb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=mc(d+112|0);b=0;if(u[a+30>>1]>0){while(1){i=Lb(c,b-u[a+28>>1]|0);v[22708]=0;R(1517,e|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break h}b=b+1|0;if((b|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;l=d,m=(Nb(c)+b|0)-1|0,u[l+34>>1]=m;v[22708]=0;u[d+30>>1]=0;fa(1513,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=v[22708];v[22708]=0;i=1;if((a|0)!=1){Lc(e);break d}break h}vb(e);break d}vb(e);break d}b=P()|0;O()|0;Lc(e);break a}b=P()|0;O()|0}vb(e);break a}vb(e)}gb=d+128|0;return i|0}b=P()|0;O()|0;vb(e);break a}b=P()|0;O()|0;vb(e)}S(b|0);L()}function LI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=gb-560|0;gb=h;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+B(s,-24)|0;n=v[(e<<2)+71248>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=s-j|0;while(1){A[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+v[(c<<2)+71264>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=l-24|0;i=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;while(1){f=A[(g<<3)+h>>3];c=0;i=g;o=(g|0)<1;if(!o){while(1){k=(h+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;a:{if(D(f)<2147483648){j=~~f;break a}j=-2147483648}f=+(j|0);m=m+f*-16777216;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}v[k>>2]=j;i=i-1|0;f=A[(i<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=ji(f,q);f=f+H(f*.125)*-8;c:{if(D(f)<2147483648){k=~~f;break c}k=-2147483648}f=f-+(k|0);d:{e:{f:{u=(q|0)<1;g:{if(!u){i=(g<<2)+h|0;j=v[i+476>>2];c=j>>t;r=i;i=j-(c<<t)|0;v[r+476>>2]=i;k=c+k|0;j=i>>y;break g}if(q){break f}j=v[((g<<2)+h|0)+476>>2]>>23}if((j|0)<1){break d}break e}j=2;if(f>=.5){break e}j=0;break d}c=0;i=0;if(!o){while(1){r=(h+480|0)+(c<<2)|0;o=v[r>>2];w=16777215;h:{i:{if(i){break i}w=16777216;if(o){break i}i=0;break h}v[r>>2]=w-o;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}j:{if(u){break j}c=8388607;k:{switch(z|0){case 1:c=4194303;break;case 0:break k;default:break j}}o=(g<<2)+h|0;v[o+476>>2]=v[o+476>>2]&c}k=k+1|0;if((j|0)!=2){break d}f=1-f;j=2;if(!i){break d}f=f-ji(1,q)}l:{m:{if(f==0){i=0;c=g;if((n|0)>=(c|0)){break l}while(1){c=c-1|0;i=v[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break l}l=q;while(1){l=l-24|0;g=g-1|0;if(!v[(h+480|0)+(g<<2)>>2]){continue}break}break m}f=ji(f,24-l|0);n:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=q}v[(h+480|0)+(g<<2)>>2]=c}f=ji(1,l);if((g|0)>=0){c=g;while(1){A[(c<<3)+h>>3]=f*+v[(h+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){q:{f=f+A[(c<<3)+74032>>3]*A[(a+c<<3)+h>>3];if((c|0)>=(n|0)){break q}i=c>>>0<d>>>0;c=c+1|0;if(i){continue}}break}A[(h+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<1){break u}d=(h+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=h+160|0;a=c-1|0;i=e+(a<<3)|0;x=A[i>>3];f=f+x;A[e+(c<<3)>>3]=m+(x-f);A[i>>3]=f;e=(c|0)>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=f+p;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[h+160>>3];if(j){break s}A[b>>3]=f;f=A[h+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){f=f+A[(h+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){c=g;while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;f=A[h+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[h+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}gb=h+560|0;return k&7}c=1;while(1){i=c;c=c+1|0;if(!v[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;A[(h+320|0)+(j<<3)>>3]=v[(s+g<<2)+71264>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}}function _oa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-976|0;gb=g;vc(b);f=gb-32|0;gb=f;d=f+24|0;j=g+872|0;KX(d,j);h=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){JX(j)}a:{if(!d){break a}if(!NX(g+872|0)){break a}if(!Pb(b,Qc(MX(g+872|0),jb))){break a}b:{if(!c){break b}Hd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[g+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Ob(a+1074312|0,7,1);d=g+96|0;e=Tb(d,5357);Eb(a+1298304|0,e);vb(e);e=Tb(d,6043);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;e=g+16|0;ZC(e,2,g+872|4);Bc(d,e);Eb(a+1298268|0,d);vb(d);e=0;while(1){d=(e<<5)+a|0;f=d+480280|0;We(f);h=f;f=(g+872|0)+e|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;e=e+1|0;if((e|0)!=16){continue}break}if(w[g+968|0]|w[g+969|0]<<8){nB(a+1298292|0,b,w[g+968|0]|w[g+969|0]<<8,132,0)}e=0;f=gb-32|0;gb=f;d=f+24|0;j=g+96|0;bc(d,j,771);h=yb(d);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;i=f+16|0;d=b;cc(i,d,f);i=yb(i);if((i|0)==(h|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){Qb(j,0,771)}if(!d){break a}d=a+484360|0;LX(Sb(d),g+96|0,w[g+353|0]);bf(Sb(d),w[g+354|0]);Zc(b,w[g+919|0]|w[g+920|0]<<8);i=a+484344|0;r=c&1;f=0;c:{d:{while(1){d=(f<<1)+g|0;if(w[d+355|0]|w[d+356|0]<<8){e=g+72|0;Td(e,b,w[d+355|0]|w[d+356|0]<<8);p=jc(g+16|0,e);xb(e);d=w[d+355|0]|w[d+356|0]<<8;j=(d-2|0)/64|0;e:{if(!r){break e}v[22708]=0;e=W(331,i|0,f&65535,j|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!e){break e}v[22708]=0;m=T(374,p|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(318,g+16|0,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0>=66){s=j>>>0>1?j:1;k=0;while(1){d=_b(i,f);v[22708]=0;n=Uf(d,k);d=v[22708];v[22708]=0;e=0;if((d|0)==1){break d}f:{while(1){g:{v[22708]=0;R(531,g+72|0,p|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}d=g+72|0;l=qd(d);h=Ve(d);o=ej(d);d=w[d|0];if((d-1&255)>>>0<=71){q=B(e,6)+n|0;t[q|0]=d+36;t[q+1|0]=w[l|0]+1}if((w[h|0]-1&255)>>>0<=15){d=B(e,6)+n|0;t[d+2|0]=1;t[d+4|0]=((w[h|0]<<6)+-64>>>0)/15}d=B(e,6)+n|0;l=w[o|0];h=l&15;t[d+5|0]=h;h:{i:{switch((w[o|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=l|240;break h;case 2:t[d+5|0]=h<<2;break h;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=h<<3;break h;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=h|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[o|0]>>>4|0)+28608|0];e=e+1|0;if((e|0)!=16){continue}break f}break}break d}k=k+1|0;if((s|0)!=(k|0)){continue}break}}d=_b(i,f);v[22708]=0;e=Ce(g+72|0,14,0);h=v[22708];v[22708]=0;if((h|0)==1){break d}e=Gh(Ue(e,m?j-2>>>0>m>>>0?m+1|0:-1:-1));v[22708]=0;Q(431,d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}}xb(g+16|0)}f=f+1|0;if((f|0)!=256){continue}break}e=1;if(!(c&2)){break a}SY(b,g- -64|0);e=0;while(1){j:{k:{if(!(w[g- -64+(e>>>3)|0]>>>(e&7)&1)){e=e+1|0;break k}if(!YC(b,g+16|0)){break b}e=e+1|0;u[a+480190>>1]=e;Ke(g,1,g+16|0);c=g+72|0;Bc(c,g);d=x[a+480190>>1];v[22708]=0;Q(301,((d<<5)+a|0)+946304|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break j}f=g+72|0;vb(f);h=(B(e,104)+a|0)+484380|0;c=h;ud(c,0);j=g+16|0;d=j;v[c>>2]=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);v[c+4>>2]=w[d+38|0]|w[d+39|0]<<8|(w[d+40|0]<<16|w[d+41|0]<<24);i=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=i;u[c+30>>1]=w[d+37|0]<<4;if(t[d+46|0]&1){v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}if(!(!(w[d+47|0]&8)|y[c+8>>2]<=y[c+4>>2])){u[c+34>>1]=x[c+34>>1]|2}Rc(f,t[j+46|0]&1?16:8,1,0,0);Cg(f,h,b)}if((e|0)!=64){continue}break b}break}e=P()|0;O()|0;vb(g+72|0);break c}e=P()|0;O()|0;xb(g+16|0)}S(e|0);L()}e=1}gb=g+976|0;return e|0}function U2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb+-64|0;gb=h;v[h+56>>2]=b;v[e>>2]=0;Fc(h,d);v[22708]=0;i=T(2481,h|0)|0;j=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h);S(a|0);L()}XG(a,f+24|0,h+56|0,c,e,i);break b}WG(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=ik(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[20875];v[h+24>>2]=v[20874];v[h+28>>2]=g;g=v[20873];v[h+16>>2]=v[20872];v[h+20>>2]=g;g=v[20871];v[h+8>>2]=v[20870];v[h+12>>2]=g;g=v[20869];v[h>>2]=v[20868];v[h+4>>2]=g;k=h,l=ik(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[20883];v[h+24>>2]=v[20882];v[h+28>>2]=g;g=v[20881];v[h+16>>2]=v[20880];v[h+20>>2]=g;g=v[20879];v[h+8>>2]=v[20878];v[h+12>>2]=g;g=v[20877];v[h>>2]=v[20876];v[h+4>>2]=g;k=h,l=ik(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+56|0;H:{if(!um(b,a+8|0)){break H}while(1){if(!jl(i,8192,tm(b))){break H}sm(b);if(um(b,a+8|0)){continue}break}}if(il(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+56|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ms(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=hc(h,83536,44);k=g,l=ik(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[20900];g=v[20899];v[h+8>>2]=v[20898];v[h+12>>2]=g;g=v[20897];v[h>>2]=v[20896];v[h+4>>2]=g;k=h,l=ik(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[20911];v[h+24>>2]=v[20910];v[h+28>>2]=g;g=v[20909];v[h+16>>2]=v[20908];v[h+20>>2]=g;g=v[20907];v[h+8>>2]=v[20906];v[h+12>>2]=g;g=v[20905];v[h>>2]=v[20904];v[h+4>>2]=g;k=h,l=ik(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=oj(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=ik(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}VG(f+20|0,h+56|0,c,e,i);break b}a=oj(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(il(c,a+8|0)){break M}b=4;if((Pn(i,tm(c))|0)!=37){break M}b=2;if(!il(sm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+56>>2]}gb=h- -64|0;return a|0}function X8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-128|0;gb=f;a:{if(gd(b)){break a}e=w[mL(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+112|0;Os(e,b,0,Ab(b)-1|0);Eb(b,e);vb(e)}g=f+112|0;Ld(g);e=v[f+112>>2];Ld(f+96|0);e=lL(e,v[f+100>>2],b);Ld(g);b:{c:{d:{e:{if((e|0)==v[f+116>>2]){if(qe(b,18720)){a=ba(8)|0;v[22708]=0;U(2054,f+112|0,14722,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}rc(a,f+112|0);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(f+112|0);break c}if(!d){break e}a=ba(8)|0;v[22708]=0;U(2054,f+80|0,14758,b|0);b=v[22708];v[22708]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[22708]=0;R(2055,f+96|0,f+80|0);b=v[22708];v[22708]=0;if((b|0)==1){break j}v[22708]=0;U(718,f+112|0,f+96|0,c|0);b=v[22708];v[22708]=0;d=1;if((b|0)==1){break i}rc(a,f+112|0);v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+112|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}vb(f+96|0)}vb(f+80|0);if(!d){break c}}da(a|0);break c}k:{switch(v[e+4>>2]){case 0:Dg(f+72|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22708]=0;R(99,b+32|0,e|0);c=v[22708];v[22708]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[22708]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break p}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22708]=0;g=ga(79)|0;h=v[22708];v[22708]=0;if((h|0)==1){break n}v[22708]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break n}Wb(b+8|0);v[22708]=0;e=Q(2056,c|0,b+32|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break n}g=v[v[e>>2]-12>>2];v[22708]=0;e=El(e+g|0);g=v[22708];v[22708]=0;if((g|0)==1){break n}g=w[b+32|0];vf(c);gb=b+192|0;b=(e^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break m}a=P()|0;O()|0;vf(c)}S(a|0);L()}c=v[f+76>>2];v[f>>2]=v[f+72>>2];v[f+4>>2]=c;kL(a,f,b,d);break e;case 1:Dg(f- -64|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22708]=0;R(99,b+32|0,e|0);c=v[22708];v[22708]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[22708]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22708]=0;g=ga(79)|0;h=v[22708];v[22708]=0;if((h|0)==1){break s}v[22708]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break s}Wb(b+8|0);v[22708]=0;e=Q(110,c|0,b+32|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break s}g=v[v[e>>2]-12>>2];v[22708]=0;e=El(e+g|0);g=v[22708];v[22708]=0;if((g|0)==1){break s}g=v[b+32>>2];h=v[b+36>>2];vf(c);gb=b+192|0;b=e?0:g;c=e?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;vf(c)}S(a|0);L()}e=v[f+68>>2];v[f+8>>2]=v[f+64>>2];v[f+12>>2]=e;jL(a,f+8|0,b,c,d);break e;case 2:Dg(f+56|0,b);b=gb-192|0;gb=b;e=b+16|0;$f(e,c);v[22708]=0;R(99,b+32|0,e|0);c=v[22708];v[22708]=0;v:{w:{x:{y:{z:{if((c|0)!=1){v[22708]=0;c=W(100,b+48|0,b+32|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break z}vb(b+32|0);vb(b+16|0);e=v[v[c>>2]-12>>2];v[22708]=0;g=ga(79)|0;h=v[22708];v[22708]=0;if((h|0)==1){break x}v[22708]=0;U(80,b+8|0,e+(b+48|0)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break x}Wb(b+8|0);v[22708]=0;e=Q(111,c|0,b+32|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break x}g=v[v[e>>2]-12>>2];v[22708]=0;e=El(e+g|0);g=v[22708];v[22708]=0;if((g|0)==1){break x}i=A[b+32>>3];vf(c);gb=b+192|0;i=e?0:i;break v}a=P()|0;O()|0;break y}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break w}a=P()|0;O()|0;vf(c)}S(a|0);L()}b=v[f+60>>2];v[f+16>>2]=v[f+56>>2];v[f+20>>2]=b;iL(a,f+16|0,i,d);break e;case 3:break k;default:break e}}Dg(f+48|0,b);Dg(f+40|0,c);b=v[f+52>>2];v[f+32>>2]=v[f+48>>2];v[f+36>>2]=b;b=v[f+44>>2];v[f+24>>2]=v[f+40>>2];v[f+28>>2]=b;gL(a,f+32|0,f+24|0,d)}gb=f+128|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Io(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-112|0;gb=d;p=SA(a);q=Si(p);f=q;c=a;e=Ec(c);a:{if(f>>>0>e>>>0){m=gb-32|0;gb=m;b:{i=f-e|0;c:{if(i>>>0<=(v[wb(c)>>2]-v[c+4>>2]|0)/12>>>0){f=gb-16|0;gb=f;i=Np(f,c,i);h=v[i+4>>2];e=v[i+8>>2];if((h|0)!=(e|0)){while(1){wb(c);fR(h);h=h+12|0;v[i+4>>2]=h;if((e|0)!=(h|0)){continue}break}}$b(i);gb=f+16|0;break c}e=wb(c);j=Tu(m+8|0,MB(c,Ec(c)+i|0),Ec(c),e);v[22708]=0;R(1130,j|0,i|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}_p(c);wb(c);f=j+4|0;l=f;k=v[c+4>>2];e=v[c>>2];if((k|0)!=(e|0)){i=v[l>>2];while(1){k=k-12|0;QB(i-12|0,k);i=v[l>>2]-12|0;v[l>>2]=i;if((e|0)!=(k|0)){continue}break}}wc(c,f);wc(c+4|0,j+8|0);wc(wb(c),dc(j));v[j>>2]=v[j+4>>2];Yw(c,Ec(c));gR(j)}gb=m+32|0;break a}a=P()|0;O()|0;gR(j);S(a|0);L()}if(e>>>0>f>>>0){f=v[c>>2]+B(f,12)|0;Ec(c);kR(c,f);hR(c)}}if(b){c=a+12|0;Kq(c,Yd(c));r=wb(c),s=0,v[r>>2]=s;r=c,s=fc(c),v[r>>2]=s;r=fc(c),s=0,v[r>>2]=s;v[a+28>>2]=0}n=mc(d+96|0);c=v[a+24>>2];v[22708]=0;e=oq(c+484344|0);c=v[22708];v[22708]=0;d:{e:{f:{g:{if((c|0)==1){break g}v[22708]=0;j=W(796,d+80|0,e|0,36524)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}h=0;u[d+78>>1]=0;if(q){o=a+12|0;while(1){l=x[sc(p,h&65535)>>1];c=vR(a,l);v[d+72>>2]=c;f=Ad(a,x[d+78>>1]);h:{if(b){v[22708]=0;t[d+32|0]=0;U(1124,f|0,c|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)!=1){break h}g=P()|0;O()|0;break e}v[22708]=0;U(953,f|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break f}}v[22708]=0;e=Q(472,p|0,x[d+78>>1])|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}i:{if(!e){break i}g=0;g=b?g:v[f+4>>2];v[22708]=0;v[d+32>>2]=g;e=Fb(d+32|0,d+72|0);c=v[22708];v[22708]=0;j:{k:{if((c|0)!=1){v[d+68>>2]=v[e>>2];i=Eh(o);if(x[sc(j,l)>>1]!=65535){e=tR(o,Sm(d+32|0,sc(j,l),d+68|0));v[d+64>>2]=e;r=d,s=Eh(o),v[r+8>>2]=s;f=d;l:{if(og(d- -64|0,d+8|0)){c=tR(o,Sm(d+32|0,sc(j,l),d+72|0));break l}c=Eh(o)}v[f+56>>2]=c;v[d+48>>2]=e;if(!og(d+48|0,d+56|0)){break i}while(1){m:{f=dd(d+32|0);c=tg(ve(d+48|0)+8|0);v[22708]=0;R(1125,f|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break m}vB(d+16|0,i);c=Sm(d+8|0,d+78|0,ve(d+48|0)+4|0);v[22708]=0;e=ca(1126,o|0,v[d+16>>2],c|0,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[d+24>>2]=e;sR(d+24|0);i=v[d+24>>2];Lq(f);if(og(sR(d+48|0),d+56|0)){continue}break i}break}g=P()|0;O()|0;Lq(f);break e}f=_b(v[a+24>>2]+484344|0,l);v[22708]=0;e=Ki(f);c=v[22708];v[22708]=0;n:{o:{if((c|0)!=1){v[22708]=0;t[d+32|0]=0;U(1128,n|0,e|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break o}k=v[d+72>>2];if((k|0)!=v[d+68>>2]){break n}break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}p:while(1){q:{h=0;v[22708]=0;k=k-1|0;v[d+64>>2]=k;g=Uf(f,k);c=v[22708];v[22708]=0;m=1;if((c|0)==1){break k}while(1){r:{v[22708]=0;e=Ki(f);c=v[22708];v[22708]=0;s:{if((c|0)!=1){if(m>>>0<16?e>>>0>h>>>0:0){break s}if(m>>>0>1){e=dd(d+32|0);v[22708]=0;R(1125,e|0,m|0);c=v[22708];v[22708]=0;if((c|0)==1){break r}vB(d,i);c=Sm(d+8|0,d+78|0,d- -64|0);v[22708]=0;i=ca(1126,o|0,v[d>>2],c|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}Lq(e)}if(v[d+68>>2]==(k|0)){break j}continue p}g=P()|0;O()|0;break e}e=w[kc(n,h)|0];t:{u:{v:{switch(w[g+3|0]-19|0){case 1:c=w[g+5|0];if((c&240)==176){break u}break t;case 0:break v;default:break t}}c=w[g+5|0];if((c&240)!=96){break t}}r=kc(n,h),s=c&15,t[r|0]=s;if(!w[kc(n,h)|0]){break t}e=w[kc(n,h)|0]}m=B(e?e+1|0:1,m);g=g+6|0;h=h+1|0;continue}break}}break}g=P()|0;O()|0;Lq(e);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}if(k){break i}c=x[d+78>>1];r=sc(j,l),s=c,u[r>>1]=s}h=x[d+78>>1]+1|0;u[d+78>>1]=h;if((h&65535)>>>0<q>>>0){continue}break}}Ye(j);gc(n);gb=d+112|0;return}g=P()|0;O()|0;break d}g=P()|0;O()|0}Ye(j)}gc(n);S(g|0);L()}function _2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;Fc(i,d);v[22708]=0;i=T(21,i|0)|0;j=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Wb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Wb(h+8|0);S(a|0);L()}_G(a,f+24|0,h+24|0,c,e,i);break b}ZG(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=jk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=jk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=jk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+24|0;H:{if(!mk(b,a+8|0)){break H}while(1){if(!nh(i,8192,nl(b))){break H}ml(b);if(mk(b,a+8|0)){continue}break}}if(lk(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+24|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ns(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[83460]|w[83461]<<8|(w[83462]<<16|w[83463]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[83457]|w[83458]<<8|(w[83459]<<16|w[83460]<<24);v[h+8>>2]=w[83453]|w[83454]<<8|(w[83455]<<16|w[83456]<<24);v[h+12>>2]=g;k=h,l=jk(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[83468];v[h+8>>2]=w[83464]|w[83465]<<8|(w[83466]<<16|w[83467]<<24);k=h,l=jk(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=jk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=pj(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=jk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}YG(f+20|0,h+24|0,c,e,i);break b}a=pj(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(lk(c,a+8|0)){break M}b=4;if((Qn(i,nl(c))|0)!=37){break M}b=2;if(!lk(ml(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+24>>2]}gb=h+32|0;return a|0}function oe(a,b){var c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),n=C(0),o=0,r=0,s=C(0),t=C(0),u=C(0);i=C(1);a:{b:{c:{k=(p(b),j(2));d=k&2147483647;d:{if(!d){break d}h=(p(a),j(2));if((h|0)==1065353216){break d}e=h&2147483647;c=C(a+b);if(!(d>>>0<2139095041?e>>>0<=2139095040:0)){break a}e:{f:{if((h|0)>-1){break f}o=2;if(d>>>0>1266679807){break e}if(d>>>0<1065353216){break f}g=150-(d>>>23|0)|0;r=d>>>g|0;o=0;if((d|0)!=r<<g){break e}o=2-(r&1)|0;break e}o=0}g=o;g:{if((d|0)!=1065353216){if((d|0)!=2139095040){break g}if((e|0)==1065353216){break d}c=(k|0)>-1?b:C(0);if(e>>>0>=1065353217){break a}c=(k|0)>-1?C(0):C(-b);break a}c=(k|0)>-1?a:C(C(1)/a);break a}c=C(a*a);if((k|0)==1073741824){break a}c=C(K(a));if(!((k|0)!=1056964608|(h|0)<0)){break a}f=C(D(a));if(!(e?(h&1073741823)!=1065353216:0)){i=(k|0)<0?C(C(1)/f):f;if((h|0)>-1){break d}if(!(g|e-1065353216)){a=C(i-i);c=C(a/a);break a}c=(g|0)==1?C(-i):i;break a}h:{if((h|0)>-1){break h}i:{switch(g|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}i=C(-1)}j:{if(d>>>0>=1291845633){c=(k|0)<0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0<=1065353207){break a}c=(k|0)>0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(e>>>0>=1065353224){break a}a=C(f+C(-1));c=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));f=c;a=C(a*C(1.44268798828125));c=(l(2,(p(C(c+a)),j(2))&-4096),q());f=C(f-C(c-a));break j}d=e>>>0<8388608;e=d?(p(C(f*C(16777216))),j(2)):e;h=e&8388607;g=h|1065353216;d=(e>>23)+(d?-151:-127)|0;e=0;k:{if(h>>>0<1885298){break k}if(h>>>0<6140887){e=1;break k}g=h|1056964608;d=d+1|0}h=e<<2;a=z[h+90048>>2];n=(l(2,g),q());m=C(C(1)/C(a+n));s=C(n-a);f=C(s*m);c=(l(2,(p(f),j(2))&-4096),q());t=C(c*c);u=m;m=(l(2,((g>>>1&536866816)+(e<<21)|0)+541065216|0),q());n=C(u*C(C(s-C(m*c))-C(C(n-C(m-a))*c)));a=C(f*f);m=C(C(n*C(f+c))+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(t+C(3))+m)),j(2))&-4096),q());f=C(C(n*a)+C(f*C(m-C(C(a+C(-3))-t))));c=C(c*a);a=(l(2,(p(C(f+c)),j(2))&-4096),q());n=z[h+90064>>2];f=C(z[h+90056>>2]+C(C(C(f-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(a*C(.9619140625));m=C(d|0);c=(l(2,(p(C(C(n+C(f+a))+m)),j(2))&-4096),q());f=C(f-C(C(C(c-m)-n)-a))}n=(l(2,k&-4096),q());a=C(c*n);b=C(C(f*b)+C(C(b-n)*c));c=C(a+b);g=(p(c),j(2));if((g|0)>=1124073473){break c}e=1124073472;l:{m:{if((g|0)==1124073472){if(!(C(b+C(4.299566569443414e-8))>C(c-a))){break m}break c}e=g&2147483647;if(!(!(b<=C(c-a))|(g|0)!=-1021968384)|e>>>0>=1125515265){break b}d=0;if(e>>>0<1056964609){break l}}k=(8388608>>>(e>>>23|0)-126|0)+g|0;e=k>>>23&255;d=(k&8388607|8388608)>>>150-e|0;d=(g|0)<0?0-d|0:d;a=C(a-(l(2,k&-8388608>>e-127),q()));g=(p(C(b+a)),j(2))}c=(l(2,g&-32768),q());f=C(c*C(.693145751953125));c=C(C(c*C(14286065379565116e-22))+C(C(b-C(c-a))*C(.6931471824645996)));a=C(f+c);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));m=C(C(a*b)/C(b+C(-2)));b=C(c-C(a-f));a=C(C(a-C(m-C(b+C(a*b))))+C(1));g=(p(a),j(2))+(d<<23)|0;n:{if((g|0)<=8388607){a=NI(a,d);break n}a=(l(2,g),q())}i=C(i*a)}c=i;break a}c=C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function lha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-11360|0;gb=g;vc(c);a:{b:{if(!Pb(c,4)){break b}c:{while(1){d:{j=g+16|0;d=j;f=gb-32|0;gb=f;h=c;e:{if(!Pb(c,3)){k=gb-16|0;gb=k;i=d+3|0;while(1){Jf(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}gb=k+16|0;break e}gY(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;kd(f+16|0,h,f+8|0)}gb=f+32|0;f:{if(!sd(j,12222,3)){d=g+4648|0;f=gb-32|0;gb=f;g:{if(!Pb(c,7)){h=gb-16|0;gb=h;j=d+7|0;while(1){Jf(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=h+16|0;break g}sn(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;kd(f+16|0,h,f+8|0)}gb=f+32|0;f=3;d=0;while(1){h=w[(g+4648|0)+f|0];if(h&128){break c}d=h|d<<7;f=f+1|0;if((f|0)!=7){continue}break}Rb(c,d);break f}h:{if(sd(g+16|0,11427,3)){break h}if(!zV(c,10877)){break h}Rb(c,sg(c)+16|0);break f}if(!sd(g+16|0,36527,3)){break f}if(!sd(g+16|0,36531,3)){break f}if(w[g+16|0]){break d}pg(c,2)}if(Pb(c,4)){continue}break b}break}if(SS(g+16|0)){break b}}f=0;break a}vc(c);d=g+11336|0;MC(d,c);k=v[d>>2];v[22708]=0;c=Sd(d);d=v[22708];v[22708]=0;i:{j:{k:{l:{if((d|0)!=1){c=zb(c);i=mc(g+11320|0);d=g+4648|0;Qb(d,0,6668);v[22708]=0;st(d);d=v[22708];v[22708]=0;if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;h=0;d=0;while(1){f=Ac(k,l);v[22708]=0;m=fa(1135,g+4648|0,c|0,f|0,g+16|0,g+4624|0)|0;f=v[22708];v[22708]=0;m:{n:{if((f|0)!=1){if((m|0)<0){break k}f=v[g+4624>>2];if((f|0)<0){break k}n=(m|0)<1;if(!(f?1:n)|!(f|m)){break k}if((f|0)<1){break m}j=v[g+4636>>2];if((j|0)!=(h|0)?h:0){break k}f=v[g+4632>>2];if((f|0)!=(d|0)?d:0){break k}if((j|0)<1|f-1>>>0>1){break l}v[g+12>>2]=0;d=Ac(k,l);v[22708]=0;v[g+8>>2]=d;d=dj(g+4624|0,g+12|0,g+8|0);h=v[22708];v[22708]=0;o:{if((h|0)!=1){d=v[d>>2];v[g+12>>2]=0;h=Ac(k,l);v[22708]=0;v[g+8>>2]=h;h=dj(g+4624|0,g+12|0,g+8|0);o=v[22708];v[22708]=0;if((o|0)==1){break o}c=c+d|0;d=k;h=v[h>>2];k=d-h|0;l=l-((h>>31)+(d>>>0<h>>>0)|0)|0;if(n){break n}v[22708]=0;d=g+16|0;U(1137,i|0,d|0,d+(B(f,m)<<1)|0);d=v[22708];v[22708]=0;if((d|0)!=1){break n}d=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break j}Z(d|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;h=j;d=f;if((c|0)!=1){break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}h=j;d=f}if((tc(i)>>>0)/(d>>>0)>>>0>268435456){break k}if((l|0)>0?1:(l|0)>=0?k:0){continue}break}break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break i}h=j;d=f}f=0;p:{q:{r:{s:{t:{if(!h|!d){break t}if(cd(i)){break t}if((tc(i)>>>0)/(d>>>0)>>>0>268435456){break t}v[22708]=0;Q(1138,a|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break p}if(!e){v[22708]=0;c=Q(70,g+16|0,18720)|0;f=v[22708];v[22708]=0;if((f|0)==1){break s}v[22708]=0;Q(301,((b<<5)+a|0)+946304|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break r}vb(c);v[22708]=0;c=B(b,104)+a|0;R(424,c+484380|0,0);f=v[22708];v[22708]=0;if((f|0)==1){break p}v[c+484404>>2]=h}h=B(b,104)+a|0;c=h+484380|0;p=c,q=(tc(i)>>>0)/(d>>>0)|0,v[p>>2]=q;f=h+484414|0;h=x[f>>1];u[f>>1]=(d|0)==2?h|65:h&65470|1;v[22708]=0;T(386,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break p}if(Md(c)){d=Vb(i);h=Zb(i);b=v[(B(b,104)+a|0)+484400>>2];v[22708]=0;W(1139,d|0,h|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break p}}if(!e){b=v[a+480180>>2];v[22708]=0;U(1140,c|0,32,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;_h(c,a,0);a=v[22708];v[22708]=0;if((a|0)==1){break p}}f=Md(c)}Ye(i);zc(g+11336|0);break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;vb(c);break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}Ye(i)}zc(g+11336|0);S(d|0);L()}gb=g+11360|0;return f|0}function d_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-576|0;gb=g;vc(b);f=gb-32|0;gb=f;d=f+24|0;i=g+72|0;CE(d,i);e=yb(d);d=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=d;v[f>>2]=h;v[f+4>>2]=d;h=f+16|0;d=b;cc(h,d,f);h=yb(h);if((h|0)==(e|0)){Rb(d,yb(f+24|0))}gb=f+32|0;d=(e|0)==(h|0);if(!d){BE(i)}a:{if(!d){break a}if(!IE(g+72|0)){break a}b:{if(!c){break b}if(!Pb(b,Qc(HE(g+72|0),jb))){break a}Hd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;f=1;Ob(a+1074312|0,7,1);d=g+40|0;e=Tb(d,11853);Eb(a+1298304|0,e);vb(e);d=Tb(d,11886);Eb(a+1298316|0,d);vb(d);Wc(a+1298328|0,x[g+72>>1]==26217?11853:11881);v[a+1298364>>2]=5;d=w[g+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){i=1;while(1){h=gb-32|0;gb=h;d=h+24|0;e=g+40|0;bc(d,e,25);k=yb(d);d=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=d;v[h>>2]=j;v[h+4>>2]=d;j=h+16|0;d=b;cc(j,d,h);j=yb(j);if((j|0)==(k|0)){Rb(d,yb(h+24|0))}gb=h+32|0;if((j|0)!=(k|0)){t[e|0]=0;t[e+1|0]=0;t[e+2|0]=0;t[e+3|0]=0;t[e+4|0]=0;t[e+5|0]=0;t[e+6|0]=0;t[e+7|0]=0;t[e+24|0]=0;t[e+16|0]=0;t[e+17|0]=0;t[e+18|0]=0;t[e+19|0]=0;t[e+20|0]=0;t[e+21|0]=0;t[e+22|0]=0;t[e+23|0]=0;t[e+8|0]=0;t[e+9|0]=0;t[e+10|0]=0;t[e+11|0]=0;t[e+12|0]=0;t[e+13|0]=0;t[e+14|0]=0;t[e+15|0]=0}if((w[g+53|0]|w[g+54|0]<<8|(w[g+55|0]<<16|w[g+56|0]<<24))>>>0>67108863){break a}e=(B(f,104)+a|0)+484380|0;ud(e,0);v[e+24>>2]=8363;h=g+40|0;d=h;v[e>>2]=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[e+4>>2]=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>y[e>>2]?v[e+4>>2]?d:0:d;v[e+8>>2]=d;if(d){u[e+34>>1]=2;xk(e)}d=g+8|0;li(d,2,h);e=g+24|0;Bc(e,d);v[22708]=0;Q(301,((f<<5)+a|0)+946304|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break e}vb(g+24|0);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}f=g+24|0;e=g+72|2;Xe(f,3,e,36);d=g+40|0;Bc(d,f);Eb(a+1298268|0,d);vb(d);f=0;RS(a+1298292|0,zb(e),108,36,0);d=a+484360|0;GE(Sb(d),g+185|0,128);if(x[sc(Sb(d),w[g+184|0])>>1]<w[g+183|0]){break d}break c}a=P()|0;O()|0;vb(g+24|0);S(a|0);L()}bf(Sb(d),w[g+184|0])}while(1){d=(f<<5)+a|0;We(d+480280|0);u[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;zg(h,w[g+183|0]);n=1;if(w[g+183|0]){o=c&1;e=0;while(1){f:{g:{if(o){if(wh(h,e&65535,64)){break g}}Rb(b,1536);break f}v[g+24>>2]=-1;v[g+28>>2]=-1;j=0;while(1){f=Uf(_b(h,e),j);k=0;while(1){i=g+40|0;Vr(i,b);d=qd(i);m=Ve(i);l=w[d|0];d=w[i|0];if(d>>>0<=253){t[f|0]=(d>>>2|0)+37;t[f+1|0]=(d<<4&48|l>>>4)+1;t[(g+24|0)+k|0]=255;d=w[i|0]}if((d&255)!=255){t[f+2|0]=1;t[f+4|0]=(((l&15)<<6|8)>>>0)/15}l=(g+24|0)+k|0;h:{i:{i=w[m|0];j:{if((i|0)!=255){t[l|0]=i;d=i&15;if(d|(i|0)==48){break j}break i}i=w[l|0];if((i|0)==255){break h}d=i&15}t[f+5|0]=d;k:{if(i<<24>>24<0){break k}m=i>>>4|0;t[f+3|0]=w[m+28392|0];l:{switch(m-3|0){case 0:t[f+5|0]=d|32;break i;case 1:t[f+5|0]=B(d,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(i&15){case 0:t[f+5|0]=79;break h;case 1:break m;default:break k}}t[f+5|0]=244;break h}t[f+3|0]=0;break h}t[l|0]=255}f=f+6|0;k=k+1|0;if((k|0)!=8){continue}break}j=j+1|0;if((j|0)!=64){continue}break}d=(g+72|0)+e|0;f=d;if(w[d+369|0]<63){Hm(_b(h,e),Gh(Ue(Ce(g+40|0,14,0),w[f+369|0])))}Hm(_b(h,e),Gh(Ce(g+40|0,16,w[d+241|0])))}e=e+1|0;if(e>>>0<w[g+183|0]){continue}break}}if(!(c&2)){break a}f=1;c=Rc(g+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){Cg(c,(B(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=1}gb=g+576|0;return n|0}function iL(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=gb-256|0;gb=e;A[e+248>>3]=c;a:{if(qk(b)){break a}f=w[ul(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}f=e+216|0;Ld(f);g=v[e+216>>2];Ld(e+200|0);h=tl(g,v[e+204>>2],b);Ld(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=uc(e+232|0,18720);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Gc(e+16|0,e+8|0)){d=ba(8)|0;v[22708]=0;R(2061,e+200|0,e+248|0);a=v[22708];v[22708]=0;f:{g:{h:{if((a|0)!=1){v[22708]=0;U(2038,e+216|0,14722,e+200|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}rc(d,e+216|0);a=0;v[22708]=0;U(186,d|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break c}}da(d|0);break c}if(!d){break e}d=ba(8)|0;v[22708]=0;f=Q(2058,e+168|0,b|0)|0;b=v[22708];v[22708]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22708]=0;U(2038,e+184|0,14758,f|0);a=v[22708];v[22708]=0;if((a|0)==1){break q}v[22708]=0;R(2055,e+200|0,e+184|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break p}v[22708]=0;R(2061,e+152|0,e+248|0);a=v[22708];v[22708]=0;if((a|0)==1){break o}v[22708]=0;U(2059,e+216|0,e+200|0,e+152|0);b=v[22708];v[22708]=0;a=1;if((b|0)==1){break n}rc(d,e+216|0);v[22708]=0;U(186,d|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(e+152|0)}vb(e+200|0)}vb(e+184|0)}vb(f)}if(!a){break c}da(d|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=uc(e+136|0,18720);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Gc(e+80|0,e+72|0)){d=ba(8)|0;v[22708]=0;R(2061,e+200|0,e+248|0);a=v[22708];v[22708]=0;r:{s:{t:{if((a|0)!=1){v[22708]=0;U(2038,e+216|0,14722,e+200|0);a=v[22708];v[22708]=0;if((a|0)==1){break t}rc(d,e+216|0);a=0;v[22708]=0;U(186,d|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break c}}da(d|0);break c}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=uc(e+120|0,4823);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Gc(e- -64|0,e+56|0)){if(!w[a+28|0]){break e}if(c>4?1:c<=0){a=ba(8)|0;v[22708]=0;d=Q(70,e+216|0,4918)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}rc(a,d);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=Bh(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;yq(v[a>>2]);break e}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=uc(e+104|0,4875);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Gc(e+48|0,e+40|0)){if(!w[a+28|0]){break e}if(c>4?1:c<=0){a=ba(8)|0;v[22708]=0;d=Q(70,e+216|0,4939)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,d);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=P()|0;O()|0;da(a|0);break c}b=Bh(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;yq(v[a>>2]);break e}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=uc(e+88|0,4893);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Gc(e+32|0,e+24|0)){break e}b=Po(c*65536);v[v[a+24>>2]+480236>>2]=b}gb=e+256|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function bna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,B=0,C=0;e=gb-48|0;gb=e;a:{b:{c:{d:{if(!c){break d}B=e,C=Be(a),t[B+32|0]=C;k=e+32|0;d=b;e:{if(y[d+4>>2]<y[wb(d)>>2]){h=gb-16|0;gb=h;f=Bi(h,d,1);wb(d);Bd(v[f+4>>2],k);v[f+4>>2]=v[f+4>>2]+1;$b(f);gb=h+16|0;break e}f=gb-32|0;gb=f;h=wb(d);h=Zg(f+8|0,qh(d,oc(d)+1|0),oc(d),h);Bd(v[h+8>>2],k);v[h+8>>2]=v[h+8>>2]+1;v[22708]=0;R(296,d|0,h|0);d=v[22708];v[22708]=0;f:{if((d|0)!=1){ae(h);gb=f+32|0;break f}a=P()|0;O()|0;ae(h);S(a|0);L()}}h=c-1|0;if(!h){break c}while(1){g:{h:{c=i<<1;i=c&254;i:{if(!i){if(!kf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0<256){break i}break h}if((c&65535)>>>0>255){break h}}if(!kf(a,e+32|0)){break d}g=e+32|0;c=b;j:{if(v[c+4>>2]!=v[wb(c)>>2]){iM(c,g);break j}k=gb-32|0;gb=k;f=wb(c);j=Zg(k+8|0,qh(c,oc(c)+1|0),oc(c),f);d=v[j+8>>2];v[22708]=0;ql(f,d,g);d=v[22708];v[22708]=0;k:{if((d|0)==1){break a}v[j+8>>2]=v[j+8>>2]+1;v[22708]=0;R(296,c|0,j|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}ae(j);gb=k+32|0;break k}}h=h-1|0;break g}d=1;while(1){l:{m:{n:{c=i<<1&254;o:{if(c){g=i>>>0>127}else{if(!kf(a,e+32|0)){break o}f=w[e+32|0]<<1|1;c=f&255;g=f>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break m}if(kf(a,e+32|0)){break n}}i=0;break l}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break l}if(c>>>0>127){continue}}break}p:{if((d|0)<=2){f=0;g=d-2|0;break p}c=kf(a,e+32|0);if(!c){break d}c=c?(w[e+32|0]|d<<8)-768|0:s;f=((c|0)>1279?2:1)+((c|0)>31999)|0;s=c^-1;g=0}c=i<<1&254;if(c){d=i>>>0>127}else{if(!kf(a,e+32|0)){break d}d=w[e+32|0]<<1|1;c=d&255;d=d>>>0>255}k=h;i=c<<1&254;if(i){c=c>>>0>127}else{if(!kf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(g<<2|(d?2:0));if(!c){d=1;while(1){q:{r:{s:{c=i<<1&254;t:{if(c){g=i>>>0>127}else{if(!kf(a,e+32|0)){break t}g=w[e+32|0]<<1|1;c=g&255;g=g>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break r}if(kf(a,e+32|0)){break s}}i=0;break q}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break q}if(c>>>0>127){continue}}break}c=d+2|0}g=k;k=c+f|0;d=0;if(g>>>0<k>>>0|(k|0)<1|(s|0)>-1){break b}d=0;if((0-oc(b)|0)>(s|0)){break b}B=e,C=Zb(b),v[B+32>>2]=C;Gd(e+40|0,e+32|0);t[e+24|0]=0;A=e+24|0;q=A;m=gb-32|0;gb=m;v[m+24>>2]=v[e+40>>2];c=b;d=v[c>>2];B=m,C=Vb(c),v[B>>2]=C;d=bk(m+24|0,m)+d|0;u:{g=k;f=v[wb(c)>>2];l=v[c+4>>2];v:{if(g>>>0<=f-l>>>0){f=g;j=l-d|0;if(f>>>0>j>>>0){Cn(c,g-j|0,q);f=j;if(!f){break v}}x=gb-16|0;gb=x;n=c;r=l;j=d;p=v[c+4>>2];o=(p-(d+g|0)|0)+d|0;z=Bi(x,c,l-o|0);if(l>>>0>o>>>0){u=v[z+4>>2];l=o;while(1){wb(n);Bd(u,l);u=u+1|0;v[z+4>>2]=u;l=l+1|0;if(r>>>0>l>>>0){continue}break}}$b(z);Ar(j,o,p);gb=x+16|0;oi(d,f,q+(d>>>0<=q>>>0?q>>>0<y[c+4>>2]?g:0:0)|0);break v}f=wb(c);j=Zg(m,qh(c,oc(c)+g|0),d-v[c>>2]|0,f);v[22708]=0;U(638,j|0,g|0,q|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}n=c;ut(c);r=j;f=v[j+4>>2];g=d;o=j+4|0;Ck(wb(c),v[c>>2],d,o);wb(c);l=j+8|0;p=l;d=v[c+4>>2];if((g|0)!=(d|0)){c=v[p>>2];while(1){Bd(c,g);c=v[p>>2]+1|0;v[p>>2]=c;g=g+1|0;if((d|0)!=(g|0)){continue}break}}xc(n,o);xc(n+4|0,l);xc(wb(n),dc(r));v[r>>2]=v[r+4>>2];tt(n,oc(n));d=f;ae(j)}Gg(d);gb=m+32|0;break u}B=e,C=Zb(b),v[B+16>>2]=C;B=e,C=OV(e+16|0,k),v[B+24>>2]=C;B=e,C=xe(A,s),v[B+32>>2]=C;B=e,C=Zb(b),v[B+16>>2]=C;B=e,C=OV(e+16|0,k),v[B+24>>2]=C;c=k;while(1){B=e,C=NV(e+32|0),v[B+16>>2]=C;d=w[v[e+16>>2]];B=e,C=NV(e+24|0),v[B+8>>2]=C;t[v[e+8>>2]]=d;d=(c|0)>1;c=c-1|0;if(d){continue}break}h=h-k|0}if(h){continue}break}break c}d=0;break b}d=1}gb=e+48|0;return d|0}a=P()|0;O()|0;ae(j);S(a|0);L()}function V7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-352|0;gb=d;a:{if(qk(b)){break a}e=w[ul(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Jl(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}f=d+320|0;Ld(f);e=v[d+320>>2];Ld(d+304|0);e=tl(e,v[d+308>>2],b);Ld(f);b:{c:{d:{e:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=uc(d+336|0,18720);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22708]=0;c=Q(70,d+320|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;if(!c){break e}c=ba(8)|0;v[22708]=0;e=Q(2058,d+304|0,b|0)|0;a=v[22708];v[22708]=0;f:{g:{h:{if((a|0)!=1){v[22708]=0;U(2038,d+320|0,14758,e|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}rc(c,d+320|0);a=0;v[22708]=0;U(186,c|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+320|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e);if(!a){break c}}da(c|0);break c}if(v[e+4>>2]){a=ba(8)|0;v[22708]=0;c=Q(70,d+320|0,8874)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=uc(d+288|0,18720);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Gc(d+152|0,d+144|0)){a=ba(8)|0;v[22708]=0;c=Q(70,d+320|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=uc(d+272|0,4506);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;i:{if(!Gc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=uc(d+256|0,4488);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Gc(d+120|0,d+112|0)){break i}}e=w[a+60|0]!=0;break e}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=uc(d+240|0,3991);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;j:{if(!Gc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=uc(d+224|0,3972);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Gc(d+88|0,d+80|0)){break j}}e=w[a+61|0]!=0;break e}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=uc(d+208|0,4075);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break e}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=uc(d+192|0,3156);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break e}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=uc(d+176|0,4555);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break e}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=uc(d+160|0,10714);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Gc(d+24|0,d+16|0)){break e}e=v[v[a+24>>2]+24668>>2]!=0}gb=d+352|0;return e|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function gk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;c=1;o(+b);e=j(1)|0;f=j(0)|0;h=e;a:{b:{v=e;m=e&2147483647;e=f;c:{if(!(m|e)){break c}o(+a);i=j(1)|0;f=j(0)|0;k=i;x=i;s=f;if(f?0:(i|0)==1072693248){break c}i=x&2147483647;if(!e|(m|0)!=2146435072?i>>>0>2146435072|(i|0)==2146435072&(s|0)!=0|m>>>0>2146435072:1){return a+b}d:{e:{f:{g:{if((k|0)>-1){break g}t=2;if(m>>>0>1128267775){break f}if(m>>>0<1072693248){break g}f=m>>>20|0;if(m>>>0>=1094713344){d=1075-f|0;f=e>>>d|0;t=0;if((e|0)!=f<<d){break f}t=2-(f&1)|0;break f}if(e){break d}f=1043-f|0;e=m>>>f|0;if((m|0)!=e<<f){break e}d=2-(e&1)|0;break e}t=0}d=t;if(e){break d}}if((m|0)==2146435072){if(!(i-1072693248|s)){break c}if(i>>>0>=1072693248){return(h|0)>-1?b:0}return(h|0)>-1?0:-b}if((m|0)==1072693248){if((h|0)>-1){return a}return 1/a}if((v|0)==1073741824){return a*a}if((v|0)!=1071644672|(k|0)<0){break d}return K(a)}c=D(a);if(!((i?(x&1073741823)!=1072693248:0)|s)){c=(h|0)<0?1/c:c;if((k|0)>-1){break c}if(!(i-1072693248|d)){a=c-c;return a/a}return(d|0)==1?-c:c}q=1;h:{if((k|0)>-1){break h}i:{switch(d|0){case 0:a=a-a;return a/a;case 1:break i;default:break h}}q=-1}j:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(i>>>0<=1072693247){return(h|0)<0?N:0}return(v|0)>0?N:0}if(i>>>0<=1072693246){return(h|0)<0?q*1e300*1e300:q*1e-300*1e-300}if(i>>>0>=1072693249){return(v|0)>0?q*1e300*1e300:q*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;g=c;c=a*1.4426950216293335;o(+(g+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=g-(a-c);break j}a=c*9007199254740992;e=i>>>0<1048576;c=e?a:c;o(+a);d=j(1)|0;j(0)|0;k=e?d:i;f=k&1048575;d=f|1072693248;k=(k>>20)+(e?-1076:-1023)|0;e=0;k:{if(f>>>0<235663){break k}if(f>>>0<767610){e=1;break k}d=f|1071644672;k=k+1|0}s=e<<3;y=A[s+90096>>3];a=A[s+90080>>3];o(+c);j(1)|0;f=0;l(0,j(0)|f);l(1,d|0);p=+n();c=1/(a+p);r=c;g=p-a;w=g;l(0,f|0);l(1,((e<<18)+(d>>>1|0)|0)+537395200|0);u=+n();g=g*c;o(+g);d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);c=+n();a=r*(w-u*c-(p-(u-a))*c);r=a;p=c*c;w=a*(g+c);a=g*g;u=w+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(p+3+u));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=r*a+g*(u-(a+-3-p));c=c*a;o(+(g+c));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();c=y+((g-(a-c))*.9617966939259756+a*-7.028461650952758e-9);r=c;g=A[s+90112>>3];c=a*.9617967009544373;p=+(k|0);o(+(g+(r+c)+p));d=j(1)|0;j(0)|0;l(0,0);l(1,d|0);a=+n();g=r-(a-p-g-c)}l(0,0);l(1,h|0);p=+n();c=a*p;a=g*b+(b-p)*a;b=c+a;o(+b);h=j(1)|0;d=j(0)|0;f=h;e=d;l:{if((f|0)>=1083179008){if(e|h-1083179008){break b}if(!(a+8.008566259537294e-17>b-c)){break l}break b}if((h&2147482624)>>>0<1083231232){break l}if(e|h+1064252416){break a}if(!(a<=b-c)){break l}break a}e=0;k=h&2147483647;if(k>>>0>=1071644673){d=h+(1048576>>>(k>>>20|0)-1022|0)|0;h=d>>>20&2047;e=(d&1048575|1048576)>>>1043-h|0;e=(f|0)<0?0-e|0:e;l(0,0);l(1,d&-1048576>>h-1023);c=c-+n();o(+(a+c));f=j(1)|0;j(0)|0}l(0,0);l(1,f|0);b=+n();g=b*.6931471824645996;c=(a-(b-c))*.6931471805599453+b*-1.904654299957768e-9;a=g+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);r=a*b/(b+-2);b=c-(a-g);a=a-(r-(b+a*b))+1;o(+a);d=j(1)|0;f=j(0)|0;d=(e<<20)+d|0;m:{if((d|0)<=1048575){a=ji(a,e);break m}l(0,f|0);l(1,d|0);a=+n()}c=q*a}return c}return q*1e300*1e300}return q*1e-300*1e-300}function tP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;f=a+1074376|0;g=B(b,872);d=(f+g|0)+616|0;e=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+g|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(Kj(d)){a=B(b,872)+a|0;u[a+1075764>>1]=e-8;a=a+1075843|0;t[a|0]=w[a|0]|32;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=e<<28>>24;c=x[(e<<1)+39728>>1];v[b+1075696>>2]=c;d=b+1075692|0;if(!v[d>>2]){break a}k=d,l=_g(a,w[b+1075789|0],e<<28>>24,c),v[k>>2]=l;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){t[(B(b,872)+a|0)+1075814|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){t[(B(b,872)+a|0)+1075817|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:d=h+8|0;Db(d,a+1074312|0,21);if(Cb(d)){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1298260|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,872)+a|0;c:{if((i|0)!=x[c+1075778>>1]){break c}d:{e:{switch(j|0){case 0:Bo(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}if(!Dd(d)){break d}vk(v[d>>2],e&65535);break d;case 1:g=c+1075080|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!Dd(d)){break d}vk(v[d>>2],e&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!Dd(d)){break d}Pi(v[d>>2],e&65535,1)}f=v[c+1075648>>2];if(!f){break c}g=w[f+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}kb[v[v[g>>2]+92>>2]](g,f,w[c+1075789|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}jB(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Nm(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(!(k=ce(d+788|0),l=1,m=w[d+88|0]&2,m?k:l)){break h}a=d;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=e;f=h+8|0;Db(f,a+1074312|0,35);if(Cb(f)){break a}if(!ce(c+1075780|0)){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}ru(a,f,d,e);break a;case 11:i:{if(e){break i}e=1;if(v[a+480180>>2]&16777248){break i}e=0;if(v[a+480180>>2]==2){break a}}d=h+8|0;Db(d,a+1074312|0,30);c=a;if(Cb(d)){a=1}else{a=v[a+480180>>2]==2}qA(c,b,e,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=e}gb=h+16|0}function poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-288|0;gb=e;d=e+128|0;f=d;g=gb-48|0;gb=g;h=g+24|0;MC(h,b);v[22708]=0;Or(g+16|0,h);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[22708]=0;b=v[g+20>>2];v[g+8>>2]=v[g+16>>2];v[g+12>>2]=b;R(640,f|0,g+8|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}zc(g+24|0);gb=g+48|0;break a}a=P()|0;O()|0;zc(g+24|0);S(a|0);L()}v[22708]=0;R(610,e+24|0,d|0);b=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((b|0)!=1){v[22708]=0;g=W(100,e+144|0,e+24|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break D}vb(e+24|0);gc(e+128|0);if(c>>>0<2189){break i}v[22708]=0;b=Q(619,e+24|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break e}v[22708]=0;c=Q(620,e+8|0,7394)|0;d=v[22708];v[22708]=0;if((d|0)==1){break B}v[22708]=0;v[e>>2]=19923024;v[e+4>>2]=0;U(621,b|0,c|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break A}Hb(c);t[e|0]=0;v[22708]=0;c=Q(620,e+8|0,8280)|0;d=v[22708];v[22708]=0;if((d|0)==1){break k}d=0;v[22708]=0;W(622,b|0,e|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break z}Hb(c);if(!w[e|0]){v[22708]=0;d=Jk(a);c=v[22708];v[22708]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[22708]=0;c=Q(620,e+8|0,12902)|0;h=v[22708];v[22708]=0;if((h|0)==1){break x}v[22708]=0;Y(624,b|0,f|0,c|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break w}Hb(c);v[22708]=0;c=Q(620,e+8|0,12583)|0;f=v[22708];v[22708]=0;if((f|0)==1){break v}v[22708]=0;Y(625,b|0,a|0,c|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break u}Hb(c);v[22708]=0;c=Q(620,e+8|0,12482)|0;d=v[22708];v[22708]=0;if((d|0)==1){break t}v[22708]=0;d=a+484360|0;U(626,b|0,d|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break s}Hb(c);v[22708]=0;c=Q(620,e+8|0,28870)|0;f=v[22708];v[22708]=0;if((f|0)==1){break r}v[22708]=0;U(627,b|0,a+484344|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break q}Hb(c);v[22708]=0;f=Jk(a);c=v[22708];v[22708]=0;if((c|0)==1){break p}v[22708]=0;c=Q(620,e+8|0,28876)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}v[22708]=0;Y(628,b|0,d|0,c|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}Hb(c);if(v[b>>2]&1073741824){v[22708]=0;c=Q(2,e+8|0,13376)|0;d=v[22708];v[22708]=0;if((d|0)==1){break m}v[22708]=0;U(560,a|0,1,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}vb(c)}gh(b);break h}a=P()|0;O()|0;break C}a=P()|0;O()|0;vb(e+24|0)}gc(e+128|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0}gh(b);break d}b=Kb(e+24|0);d=v[a+4>>2];v[22708]=0;f=Jk(a);h=v[22708];v[22708]=0;if((h|0)==1){break g}v[22708]=0;d=ca(629,d|0,g|0,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break g}E:{if((d|0)!=1){v[22708]=0;c=Q(2,e+8|0,13682)|0;d=v[22708];v[22708]=0;F:{if((d|0)!=1){v[22708]=0;U(560,a|0,1,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break F}vb(c);break E}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22708]=0;d=Jk(a);f=v[22708];v[22708]=0;if((f|0)==1){break g}v[22708]=0;Y(630,g|0,a|0,d|0,c>>>0<2188|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}}vb(b)}vf(g);gb=e+288|0;return}a=P()|0;O()|0}vb(b);break d}a=P()|0;O()|0}vf(g)}S(a|0);L()}function xg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=gb-112|0;gb=k;l=h;o=i&2147483647;n=c-(b>>>0<1)|0;j=b-1|0;q=(j|0)==-1&(n|0)==-1;r=d;p=(c|0)==(n|0)&b>>>0>j>>>0|c>>>0>n>>>0;m=d+p|0;n=e&2147483647;j=n;j=m>>>0<p>>>0?j+1|0:j;p=m-1|0;a:{b:{j=j-(m>>>0<1)|0;if(!((p|0)==-1&(j|0)==2147418111?q:j>>>0>2147418111)){j=f;m=g-(j>>>0<1)|0;j=j-1|0;q=(j|0)!=-1|(m|0)!=-1;p=(g|0)==(m|0)&f>>>0>j>>>0|g>>>0>m>>>0;m=p+l|0;j=o;j=m>>>0<p>>>0?j+1|0:j;p=m;m=m-1|0;j=j-(p>>>0<1)|0;if((m|0)==-1&(j|0)==2147418111?q:(j|0)==2147418111&(m|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(n|0)==2147418112?!(b|c):n>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(n^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|n))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}j=(n|0)==(o|0);q=j&(l|0)==(r|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:j&l>>>0>r>>>0|n>>>0<o>>>0;j=q;m=j?f:b;o=j?g:c;l=j?i:e;r=l;n=j?h:d;j=l&65535;i=q?e:i;e=i;h=q?d:h;p=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|n);i=d<<6;l=E(d?m:n)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;Mf(k+96|0,m,o,n,j,d-15|0);n=v[k+104>>2];m=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=q?b:f;g=q?c:g;i=e&65535;if(!p){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;Mf(k+80|0,f,g,h,i,b-15|0);p=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=n;d=j<<3|b>>>29;n=b<<3|o>>>29;s=d;q=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-p|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}Mf(k- -64|0,b,c,h,i,128-d|0);mm(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=n;p=s|524288;b=m;j=o<<3|b>>>29;c=b<<3;d:{if((q|0)<-1?1:(q|0)<=-1){o=e;b=c-e|0;n=h;m=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=m-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<n>>>0)+i|0)|0)-(e>>>0>m>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;Mf(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=e>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);e=h;c=e<<31|c>>>1;l=l+1|0;h=(i&1)<<31|e>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}e=0;e:{if((l|0)>0){e=l;break e}Mf(k+16|0,b,c,h,i,l+127|0);mm(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2]}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;f:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;gb=k+112|0}function dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-176|0;gb=e;te(e+160|0,b);m=a;l=c;h=d;j=gb-48|0;gb=j;v[j+44>>2]=0;f=b;Hk(f,j+44|0);a:{b:{c:{if(v[j+44>>2]!=(zn(11373)|0)){break c}v[j+40>>2]=0;g=gb-32|0;gb=g;v[g+28>>2]=0;dX(g+8|0,g+28|0);i=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=i;i=g+16|0;nt(i,f,g);yb(i);v[g+16>>2]=v[g+28>>2];v[j+40>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);gb=g+32|0;g=-1;i=v[j+40>>2];if(i-1>>>0>1){break c}d:{e:{f:{if((i|0)<=1){i=Kb(j+24|0);v[22708]=0;k=W(653,f|0,i|0,256)|0;n=v[22708];v[22708]=0;if((n|0)==1){break b}if(!k){break e}v[22708]=0;U(13,j+8|0,h|0,i|0);k=v[22708];v[22708]=0;if((k|0)!=1){break f}break b}i=Kb(j+24|0);v[22708]=0;k=W(655,f|0,i|0,255)|0;n=v[22708];v[22708]=0;if((n|0)==1){break b}if(!k){break d}v[22708]=0;U(13,j+8|0,h|0,i|0);k=v[22708];v[22708]=0;if((k|0)==1){break b}}k=l;l=j+8|0;Eb(k,l);vb(l);vb(i);i=0;u[j+8>>1]=0;ag(f,l);v[j+24>>2]=0;Hk(f,j+24|0);l=v[j+24>>2];if(l>>>0>50){break c}if(l){while(1){if(!ZM(m,f,h)){break c}i=i+1|0;if(i>>>0<y[j+24>>2]){continue}break}}v[j+24>>2]=0;Hk(f,j+24|0);g=v[j+24>>2]==(zn(11411)|0)?1:-1;break c}vb(i);break c}vb(i)}gb=j+48|0;f=g;break a}a=P()|0;O()|0;vb(i);S(a|0);L()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!f){mo(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;kk(b,e);b=Fm(e+56|0,b);v[22708]=0;f=Q(620,e+40|0,11499)|0;h=v[22708];v[22708]=0;if((h|0)==1){break h}v[22708]=0;v[e+32>>2]=3;v[e+36>>2]=0;U(621,b|0,f|0,e+32|0);h=v[22708];v[22708]=0;if((h|0)==1){break i}Hb(f);t[e+31|0]=0;v[22708]=0;f=Q(620,e+40|0,11939)|0;h=v[22708];v[22708]=0;if((h|0)==1){break j}v[22708]=0;W(622,b|0,e+31|0,f|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break k}Hb(f);v[22708]=0;f=w[e+31|0];h=T(1521,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break l}v[22708]=0;g=T(1522,b|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break m}v[e+32>>2]=g;v[e+24>>2]=h;if(Gb(e+24|0,e+32|0)){f=f?0:d;while(1){u[e+22>>1]=65535;v[22708]=0;d=Q(620,e+40|0,12902)|0;h=v[22708];v[22708]=0;if((h|0)==1){break p}v[22708]=0;h=W(1523,b|0,e+24|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}Hb(d);s:{if(!h){v[22708]=0;Y(1524,b|0,e+24|0,c|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}break s}v[22708]=0;d=Q(620,e+40|0,12583)|0;h=v[22708];v[22708]=0;t:{u:{if((h|0)!=1){v[22708]=0;h=W(1523,b|0,e+24|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break u}Hb(d);if(h){break t}v[22708]=0;U(1525,b|0,e+24|0,e+22|0);d=v[22708];v[22708]=0;if((d|0)!=1){break s}break n}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}v[22708]=0;d=Q(620,e+40|0,12482)|0;h=v[22708];v[22708]=0;if((h|0)==1){break r}v[22708]=0;h=W(1523,b|0,e+24|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break q}Hb(d);if(h){break s}v[22708]=0;Y(1526,b|0,e+24|0,a|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break n}}d=e+24|0;Yo(d);if(Gb(d,e+32|0)){continue}break}}a=v[b>>2];gh(b);f=a&1073741824?-1:1}gb=e+176|0;return f|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Hb(f);break g}a=P()|0;O()|0}gh(b);S(a|0);L()}function A_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-160|0;gb=d;vc(b);rs(a);f=gb-32|0;gb=f;e=f+24|0;j=d+120|0;mF(e,j);h=yb(e);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;g=f+16|0;e=b;cc(g,e,f);g=yb(g);if((g|0)==(h|0)){Rb(e,yb(f+24|0))}gb=f+32|0;e=(g|0)==(h|0);if(!e){nF(j)}a:{if(!e){break a}if(!VN(d+120|0)){break a}h=b;g=0;k=Of(10435);if(k){p=v[h+8>>2];if(Zc(h,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){b:{if(!(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))){break b}while(1){if(!Pb(h,5)){break b}c:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((Li(h)|0)<1){break c}}g=0;f=1;while(1){e=Be(h);if(e){q=Zq(e<<24>>24);m=g>>>0>=k>>>0;j=m&f;e=j;d:{if(m){break d}e=j;if(!(f&1)){break d}e=w[g+10435|0]==(q&255)}f=e;g=g+1|0;continue}break}Rb(h,4);i=(g|0)==(k|0)?f?1:i:i}n=n+1|0;if(n>>>0<(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0){continue}break}}g=i&1}Zc(h,p)}if(!g){break a}if(!Pb(b,UN(d+120|0))){break a}if(!c){l=1;break a}f=gb-16|0;gb=f;c=b;j=d+120|0;e=j;Zc(c,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));g=d+104|0;h=mc(g);i=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[22708]=0;R(1421,h|0,i|0);i=v[22708];v[22708]=0;e:{f:{g:{if((i|0)!=1){h:{i:{j:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break j}while(1){v[22708]=0;i=Q(191,c|0,5)|0;k=v[22708];v[22708]=0;if((k|0)==1){break g}if(!i){break j}i=w[e+4|0]|w[e+5|0]<<8;v[22708]=0;U(1422,f|0,c|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break i}v[22708]=0;R(1423,h|0,f|0);i=v[22708];v[22708]=0;if((i|0)==1){break h}vb(f);o=o+1|0;if(o>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}gb=f+16|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(f);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}yd(h);S(a|0);L()}v[22708]=0;Y(273,d+88|0,b|0,j|0,g|0);c=v[22708];v[22708]=0;k:{l:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[22708]=0;Q(190,b|0,c|0)|0;c=v[22708];v[22708]=0;m:{if((c|0)!=1){if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break k}h=d+36|0;n:{o:{p:{q:{while(1){v[22708]=0;c=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;r:{if((e|0)!=1){if(c){break r}break k}b=P()|0;O()|0;break m}v[22708]=0;ka(274,d- -64|0,b|0,d+120|0,d+88|0,d+104|0,10435);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=d- -64|0;f=T(275,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}e=c;if(f){v[22708]=0;f=T(276,d+24|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break p}j=v[c+20>>2];s:{if((j|0)<0){break s}if(Ec(d+104|0)>>>0<=j>>>0){break s}c=Ad(d+104|0,v[c+20>>2]);v[22708]=0;U(13,d+8|0,2,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break o}c=d+8|0;Eb(d+24|0,c);vb(c)}Dw(h,e);v[22708]=0;R(277,a|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break o}Kw(f)}xb(d- -64|0);l=l+1|0;if(l>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break k}break}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break n}b=P()|0;O()|0;Kw(f)}xb(d- -64|0);break m}b=P()|0;O()|0}Lc(d+88|0);break l}b=P()|0;O()|0}yd(d+104|0);S(b|0);L()}l=cd(a)^1;Lc(d+88|0);yd(d+104|0)}gb=d+160|0;return l|0}function K1(){var a=0,b=0,c=0;Xd(465832);v[116458]=83656;v[22708]=0;X(2527);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;Q(70,465984,11503)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}Od(465840);Xd(465520);v[116380]=84980;v[22708]=0;X(2528);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465528);v[116382]=85012;v[22708]=0;X(2529);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465536);v[116384]=83676;t[465548]=0;v[116386]=0;b=465544,c=Yp(),v[b>>2]=c;v[22708]=0;X(2530);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465552);v[116388]=84160;v[22708]=0;X(2531);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465560);v[116390]=84308;v[22708]=0;X(2532);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2533);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2534);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465584);v[116396]=84456;v[22708]=0;X(2535);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465592);v[116398]=84572;v[22708]=0;X(2536);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465600);u[232804]=11310;v[116400]=83776;Kb(465612);v[22708]=0;X(2537);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465624);v[116408]=46;v[116409]=44;v[116406]=83816;Kb(465640);v[22708]=0;X(2538);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465656);v[116414]=85044;v[22708]=0;X(2539);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465664);v[116416]=85288;v[22708]=0;X(2540);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465672);v[116418]=85500;v[22708]=0;X(2541);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465680);v[116420]=85732;v[22708]=0;X(2542);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465688);v[116422]=86716;v[22708]=0;X(2543);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465696);v[116424]=86864;v[22708]=0;X(2544);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465704);v[116426]=86980;v[22708]=0;X(2545);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465712);v[116428]=87096;v[22708]=0;X(2546);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465720);v[116430]=87212;v[22708]=0;X(2547);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465728);v[116432]=87376;v[22708]=0;X(2548);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465736);v[116434]=87540;v[22708]=0;X(2549);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465744);v[116436]=87704;v[22708]=0;X(2550);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465752);v[116440]=88960;v[116440]=85980;v[116438]=85932;v[22708]=0;X(2551);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465768);v[116444]=88996;v[116444]=86244;v[116442]=86196;v[22708]=0;X(2552);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2553);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2554);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2555);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;X(2556);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465816);v[116454]=87868;v[22708]=0;X(2557);a=v[22708];v[22708]=0;if((a|0)==1){break d}Xd(465824);v[116456]=87988;v[22708]=0;X(2558);a=v[22708];v[22708]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(465984)}ox(465840)}S(a|0);L()}v[116058]=465832}function YL(a){var b=C(0),c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=C(0),j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=C(0),u=C(0),w=0,x=0,y=C(0);m=gb-16|0;gb=m;w=a,x=Jj(C(z[a+4256>>2]*C(3))),v[w+4264>>2]=x;w=a,y=C(wf(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[w+4268>>2]=y;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);w=m,y=oe(C(10),C(C(XL(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[w+12>>2]=y;v[m+8>>2]=1065353216;w=a,y=C(z[Em(m+12|0,m+8|0)>>2]*C(.7609999775886536)),z[w+4280>>2]=y;h=a;b=oe(C(10),C(C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(b!=C(1)){c=Qp(C(C(WL(a)*C(6.2831854820251465))/z[a+4268>>2]));j=C(b*b);k=C(K(C(C(C(C(b*C(8))+C(c*C(C(c*j)*C(4))))-C(j*C(4)))-C(C(b*c)*C(8)))));b=C(b+b);k=Fo(C(C(k+C(C(c*b)+C(-2)))/C(b+C(-2))),C(0),C(1))}else{k=C(0)}z[h+4276>>2]=k;l=gb-16|0;gb=l;e=a;b=z[a+4268>>2];c=C(z[a+4232>>2]*C(.30000001192092896));z[l+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[l+8>>2]=1000593162;h=a;j=z[$y(l+12|0,l+8|0)>>2];i=C(b*C(C(c+j)+C(.007000000216066837)));a:{if(C(D(i))<C(2147483648)){f=~~i;break a}f=-2147483648}v[h+4352>>2]=f;d=1;while(1){h=((B(d&1,24)+e|0)+(d<<1&-4)|0)+4352|0;i=C(b*C(c+C(j*z[(d<<2)+52736>>2])));b:{if(C(D(i))<C(2147483648)){f=~~i;break b}f=-2147483648}v[h>>2]=f;d=d+1|0;if((d|0)!=12){continue}break}z[l+12>>2]=C(C(C(z[e+4248>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353);v[l+8>>2]=1065353216;c=z[Em(l+12|0,l+8|0)>>2];j=C(b*C(C(c*C(75))/C(1e3)));c=C(b*C(C(c*C(67))/C(1e3)));d=0;while(1){p=(d<<2)+e|0;h=p+4316|0;q=d+q|0;i=oe(C(.9300000071525574),C(q|0));g=C(j*i);c:{if(C(D(g))<C(2147483648)){f=~~g;break c}f=-2147483648}v[h>>2]=f;h=p+4292|0;i=C(c*i);d:{if(C(D(i))<C(2147483648)){f=~~i;break d}f=-2147483648}v[h>>2]=f;d=d+1|0;if((d|0)!=6){continue}break}h=e+4348|0;c=C(b*C(.0035299998708069324));e:{if(C(D(c))<C(2147483648)){f=~~c;break e}f=-2147483648}v[h>>2]=f;h=e+4344|0;c=C(b*C(.0032500000670552254));f:{if(C(D(c))<C(2147483648)){f=~~c;break f}f=-2147483648}v[h>>2]=f;h=e+4340|0;b=C(b*C(.009999999776482582));g:{if(C(D(b))<C(2147483648)){f=~~b;break g}f=-2147483648}v[h>>2]=f;d=0;while(1){ZL((B(d,24)+e|0)+4504|0,v[((d<<2)+e|0)+4292>>2]);d=d+1|0;if((d|0)!=15){continue}break}gb=l+16|0;d=gb-16|0;gb=d;b=th(a,5);c=th(a,11);k=C(C(b*C(.02250000089406967))+C(0));b=C(b*th(a,4));j=C(k+C(b*C(.03999999910593033)));k=C(C(c*C(.02250000089406967))+C(0));c=C(c*th(a,10));i=C(k+C(c*C(.03999999910593033)));if(t[a+4264|0]&1){g=th(e,3);n=th(e,9);g=C(b*g);b=C(g*th(e,2));j=C(C(j+C(g*C(.12250000238418579)))+C(b*C(.1444000005722046)));g=C(c*n);c=C(g*th(e,8));i=C(C(i+C(g*C(.12250000238418579)))+C(c*C(.1444000005722046)))}th(e,12);g=z[e+4496>>2];n=th(e,1);o=th(e,7);s=th(e,0);u=th(e,6);w=d,y=oe(C(10),C(C(XL(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[w+12>>2]=y;v[d+8>>2]=1065353216;r=z[Em(d+12|0,d+8|0)>>2];k=b;b=C(g*g);g=C(n*C(k*b));n=C(s*g);b=C(o*C(c*b));c=C(u*b);o=C(C(C(n+c)*C(-.5))+C(1));z[e+4284>>2]=r*C(K(C(o/C(C(j+C(b*C(.1444000005722046)))+C(n*C(.1444000005722046))))));z[e+4288>>2]=r*C(K(C(o/C(C(i+C(g*C(.1444000005722046)))+C(c*C(.1444000005722046))))));gb=d+16|0;t[a+5046|0]=0;gb=m+16|0}function bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-736|0;gb=e;vc(b);g=gb-32|0;gb=g;f=g+24|0;k=e+120|0;BY(f,k);i=yb(f);f=v[g+28>>2];j=v[g+24>>2];v[g+8>>2]=j;v[g+12>>2]=f;v[g>>2]=j;v[g+4>>2]=f;j=g+16|0;f=b;cc(j,f,g);j=yb(j);if((j|0)==(i|0)){Rb(f,yb(g+24|0))}gb=g+32|0;f=(i|0)==(j|0);if(!f){AY(k)}a:{if(!f){break a}if(!DY(e+120|0)){break a}b:{if(!c){break b}Hd(a,67108864);Ag(a);d=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Tb(e,5312);Eb(a+1298304|0,d);vb(d);d=Tb(e,8058);Eb(a+1298316|0,d);vb(d);d=e+96|0;Ff(d,1283);v[e+72>>2]=w[e+144|0]>>>4;f=w[e+144|0];v[22708]=0;v[e+116>>2]=f&15;Y(460,e|0,d|0,e+72|0,e+116|0);d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){Eb(a+1298328|0,e);vb(e);Hb(e+96|0);v[a+1298364>>2]=2;Fr(Sb(a+484360|0),e+168|0,w[e+167|0]+1|0);while(1){d=h+1|0;g=B(d,104)+a|0;i=g+484380|0;ud(i,1);f=(e+120|0)+(h<<2)|0;o=i,p=Yb(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[o>>2]=p;k=Yb(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=k;o=g+484388|0,p=Yb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))+k|0,v[o>>2]=p;if(Yb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))){f=g+484414|0;u[f>>1]=x[f>>1]|2}xk(i);h=(e+120|0)+h|0;t[e|0]=w[h+548|0];t[e+96|0]=64;o=g+484410|0,p=w[ac(e,e+96|0)|0]<<2,u[o>>1]=p;t[g+484417|0]=w[h+579|0]<<4;h=d;if((d|0)!=31){continue}break}Qv(b,a+1298268|0,32);d=1;while(1){CY(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}j=c&1;if(j){zg(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;d=0;e:{while(1){f=d;g=Kh(e+96|0);f:{if(w[e+146|0]){v[22708]=0;d=T(416,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break e}v[22708]=0;U(288,e+72|0,b|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}break f}d=x[a+480188>>1];v[22708]=0;U(288,e+72|0,b|0,d<<8);d=v[22708];v[22708]=0;if((d|0)==1){break d}}d=e+72|0;Vc(g,jc(e,d));xb(e);xb(d);g:{if(!j){break g}v[22708]=0;d=W(331,k|0,f&65535,64)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!d){break g}if(!w[e+146|0]){h=0;if(!x[a+480188>>1]){break g}while(1){d=0;while(1){i=_b(k,f);v[22708]=0;i=Xc(i,d,h&65535);l=v[22708];v[22708]=0;if((l|0)==1){break d}v[22708]=0;R(461,g|0,i|0);i=v[22708];v[22708]=0;if((i|0)==1){break d}d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break g}i=0;v[22708]=0;R(462,g|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}while(1){d=_b(k,f);v[22708]=0;l=Uf(d,i);d=v[22708];v[22708]=0;if((d|0)==1){break d}if(x[a+480188>>1]){m=e+i|0;d=128;h=0;while(1){h:{if(!(w[m|0]&d)){break h}v[22708]=0;R(461,g|0,l+B(h,6)|0);n=v[22708];v[22708]=0;if((n|0)!=1){break h}break d}d=d>>>1|0;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}i=i+1|0;if((i|0)!=64){continue}break}}d=f+1|0;xb(e+96|0);if(f>>>0<w[e+166|0]){continue}break}d=1;if(!(c&2)){break a}c=Rc(e,8,1,1,0);while(1){Cg(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}break d}d=P()|0;O()|0;Hb(e+96|0);break c}d=P()|0;O()|0;xb(e+96|0)}S(d|0);L()}d=1}gb=e+736|0;return d|0}function Xb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116507]){break a}a=a+b|0;if(v[116508]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=466012,j=v[116503]&sqa(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+466316|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=466016,j=v[116504]&sqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116505]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116509]==(f|0)){v[116509]=d;a=v[116506]+a|0;v[116506]=a;v[d+4>>2]=a|1;if(v[116508]!=(d|0)){break a}v[116505]=0;v[116508]=0;return}if(v[116508]==(f|0)){v[116508]=d;a=v[116505]+a|0;v[116505]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=466012,j=v[116503]&sqa(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+466316|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=466016,j=v[116504]&sqa(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116508]!=(d|0)){break f}v[116505]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+466052|0;c=v[116503];a=1<<a;k:{if(!(c&a)){v[116503]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+466316|0;l:{m:{c=v[116504];b=1<<e;n:{if(!(c&b)){v[116504]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116511]-1|0;v[116511]=a?a:-1}}function $N(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;if(b){h=a+327720|0;c=gb-400|0;gb=c;KR(c+384|0,8);v[22708]=0;ta(1106,c+368|0,9);f=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((f|0)!=1){v[22708]=0;f=Q(1107,c+352|0,14)|0;e=v[22708];v[22708]=0;if((e|0)==1){break l}v[22708]=0;R(1108,c+384|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}v[22708]=0;R(1108,c+368|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}JR(c+280|0,4900);JR(c+208|0,32e3);FR(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[22708]=0;e=Q(1109,c+104|0,c+384|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break j}Cu(c+120|0,c+280|0,e);Nf(e);v[22708]=0;e=Q(1109,c+72|0,c+368|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break i}Cu(c+88|0,c+208|0,e);Nf(e);v[22708]=0;e=Q(1109,c+40|0,c+120|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break h}Cu(c+56|0,c+136|0,e);Nf(e);v[22708]=0;g=Q(1109,c+8|0,c+88|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}e=c+24|0;Cu(e,c+136|0,g);Nf(g);g=c+120|0;Pq(g);k=c+56|0;Pq(k);l=c+88|0;Pq(l);Pq(e);n=c+368|0;Pq(n);Oq(g,Hj(h,0));Oq(k,Hj(h,1));Oq(l,Hj(h,2));Oq(e,Hj(h,3));Oq(n,Hj(h,4));Nf(e);Nf(k);Nf(l);Nf(g);Nq(f);Nf(n);Nf(c+384|0);gb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Nf(c+56|0)}Nf(c+88|0)}Nf(c+120|0)}Nq(f)}Nf(c+368|0)}Nf(c+384|0);S(a|0);L()}Hz(a+131112|0,9.6377,.97);Hz(a+196648|0,8.5,.5);Hz(a+262184|0,2.7625,.425)}f=a+368680|0;if(!(s=0,t=_N(f,a),x=b,x?s:t)){g=a+24|0;q=A[a+8>>3];c=w[a+16|0];e=gb+-64|0;gb=e;while(1){r=+(m-4096|0)*.0001220703125;o=0;b=0;while(1){j=q;h=c;i=1;d=+(b|0)-r;p=d+-3.5;if(!(D(p)<1e-8)){m:{n:{switch(h|0){case 0:i=.5-Me(d*.8975979010256552)*.5;break m;case 1:i=Me(d*.8975979010256552)*-.46+.54;break m;case 2:i=Me(d*1.7951958020513104)*.08+(Me(d*.8975979010256552)*-.5+.42);break m;case 3:i=Me(d*1.7951958020513104)*.05677+(Me(d*.8975979010256552)*-.49364+.44959);break m;case 4:i=Me(d*1.7951958020513104)*.07922+(Me(d*.8975979010256552)*-.49755+.42323);break m;case 5:i=Me(d*1.7951958020513104)*.14128+(Me(d*.8975979010256552)*-.48829+.35875)+Me(d*2.6927937030769655)*-.01168;break m;case 6:i=Me(d*1.7951958020513104)*.09392+(Me(d*.8975979010256552)*-.49703+.40217)+Me(d*2.6927937030769655)*-.00183;break m;case 7:break n;default:break m}}i=Me(d*1.7951958020513104)*.09831+(Me(d*.8975979010256552)*-.49804+.40243)+Me(d*2.6927937030769655)*-.00122}d=p*3.141592653589793;j=si(d*j)/d}j=i*j;A[e+(b<<3)>>3]=j;o=o+j;b=b+1|0;if((b|0)!=8){continue}break}j=1/o;k=m<<3;b=0;while(1){l=g+(b+k<<1)|0;d=H(j*(A[e+(b<<3)>>3]*32768)+.5);d=d<-32768?-32768:F(d,32768);o:{if(D(d)<2147483648){h=~~d;break o}h=-2147483648}u[l>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}m=m+1|0;if((m|0)!=8193){continue}break}gb=e- -64|0;b=v[a+20>>2];v[f+16>>2]=v[a+16>>2];v[f+20>>2]=b;b=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=b;b=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=b}}function jX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-128|0;gb=g;j=Ik(g+112|0);a:{b:{c:{if(d){v[22708]=0;U(645,a|0,j|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}break b}v[22708]=0;U(646,a|0,j|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}}k=mc(g+96|0);if(x[b+480192>>1]){d=1;c=1;while(1){v[22708]=0;u[g+94>>1]=0;Q(647,a|0,g+94|0)|0;f=v[22708];v[22708]=0;d:{e:{f:{if((f|0)!=1){l=gb-16|0;gb=l;p=l+8|0;i=gb-16|0;gb=i;f=j;m=f;o=g+94|0;q=o;e=Yd(f);h=fc(f);n=gb-16|0;gb=n;if(e){wb(m);while(1){m=KC(e+16|0,q);h=m?h:e;e=v[(m?4:0)+e>>2];if(e){continue}break}}e=v[yc(n+8|0,h)>>2];gb=n+16|0;v[i+8>>2]=e;r=i,s=Dh(f),v[r>>2]=s;g:{if(Gb(i+8|0,i)){if(!LC(wb(f),o,ve(i+8|0))){break g}}e=Dh(f)}gb=i+16|0;f=v[yc(p,e)>>2];gb=l+16|0;v[g+88>>2]=f;i=((d<<2)+b|0)+900380|0;if(!v[i>>2]){break d}r=g,s=Eh(j),v[r+72>>2]=s;if(og(g+88|0,g+72|0)){d=ve(g+88|0);v[22708]=0;d=Q(4,g+72|0,d+4|0)|0;f=v[22708];v[22708]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)!=1){v[22708]=0;f=Q(2,g+56|0,13849)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}e=wr(d,f);vb(f);if(e){break r}f=v[b+4>>2];v[22708]=0;f=Q(648,f|0,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break x}v[v[i>>2]+44>>2]=f;if(!v[v[i>>2]+44>>2]){break y}break e}b=P()|0;O()|0;break f}v[22708]=0;f=Q(2,g+56|0,10745)|0;e=v[22708];v[22708]=0;if((e|0)==1){break w}z:{A:{if(wr(d,f)){vb(f);break A}v[22708]=0;e=Q(2,g+40|0,10957)|0;h=v[22708];v[22708]=0;if((h|0)==1){break v}h=wr(d,e);vb(e);vb(f);if(!h){break z}}v[22708]=0;f=T(649,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break u}v[g+56>>2]=f;f=v[b+4>>2];qi(g+32|0,g+56|0);v[22708]=0;f=Q(650,f|0,v[g+32>>2])|0;e=v[22708];v[22708]=0;if((e|0)==1){break t}Ig(g+56|0);if(f){break e}}h=Vb(k);l=Zb(k);f=d;e=gb-16|0;gb=e;v[e>>2]=l;v[e+8>>2]=h;if(Gb(e+8|0,e)){while(1){if(!wr(v[e+8>>2],f)){h=e+8|0;tr(h);if(Gb(h,e)){continue}}break}h=v[e+8>>2]}gb=e+16|0;v[g+56>>2]=h;r=g,s=Zb(k),v[r+40>>2]=s;if(Gb(g+56|0,g+40|0)){break r}v[22708]=0;R(651,k|0,d|0);f=v[22708];v[22708]=0;if((f|0)!=1){break s}}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(f);break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;Ig(g+56|0);break h}v[22708]=0;f=Q(2,g+16|0,14551)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}v[22708]=0;U(652,g+40|0,f|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break p}v[22708]=0;e=Q(2,g|0,13425)|0;h=v[22708];v[22708]=0;if((h|0)==1){break o}v[22708]=0;U(3,g+56|0,g+40|0,e|0);h=v[22708];v[22708]=0;if((h|0)==1){break n}v[22708]=0;U(560,b|0,2,g+56|0);h=v[22708];v[22708]=0;if((h|0)==1){break m}vb(g+56|0);vb(e);vb(g+40|0);vb(f)}v[v[i>>2]+44>>2]=0;break e}b=P()|0;O()|0;break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(g+56|0)}vb(e)}vb(g+40|0)}vb(f);break h}b=P()|0;O()|0}vb(d);break f}if(!v[i>>2]){break d}v[v[i>>2]+44>>2]=0;break d}b=P()|0;O()|0}qm(k);break a}vb(d)}c=c+1|0;d=c&65535;if(d>>>0<=x[b+480192>>1]){continue}break}}qm(k);eX(j);gb=g+128|0;return}b=P()|0;O()|0}eX(j);S(b|0);L()}function oA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0;h=gb-16|0;gb=h;i=B(b,872)+a|0;l=i+1075800|0;j=w[l|0];e=h+8|0;k=a+1074312|0;Db(e,k,23);g=c&15;a:{b:{c:{if(Cb(e)){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[l|0]=g;e=0;break c}e=w[l|0];if(e){f=e-1|0;t[l|0]=f;e=0;if(f&255){break c}}t[l|0]=g;e=1;break c}e=h+8|0;Db(e,k,52);f=c&256;if(!(!Cb(e)|!f)){d:{if(!(w[a+480209|0]&16)){break d}e=B(b,872)+a|0;if(w[e+1075781|0]){j=VC(e+1075780|0)?1:j}if(w[e+1075782|0]!=1){break d}if(w[(B(b,872)+a|0)+1075784|0]){break b}}e=0;if((j&255)>>>0<g>>>0){break c}if(w[a+480209|0]&16){if(ce((B(b,872)+a|0)+1075780|0)){break c}}j=0;e=1;break c}if(v[a+480180>>2]&16777250){e=j&255;if(e){e=(e>>>0)%((g?g:1)>>>0)|0}else{e=1}e=!e;j=j+1|0;break c}if(v[a+480180>>2]==1){f=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!f){if(ce((B(b,872)+a|0)+1075780|0)){break a}}e=0;e=g?!((f>>>0)%(g>>>0)|0):e;break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}e:{f:{g:{h:{i:{if(f){e=B(b,872)+a|0;if(w[e+1075782|0]==1){g=(w[e+1075785|0]>15)+g|0}g=g?g:1;break i}if(w[a+480209|0]&16){break f}g=g?g:1;if(v[a+1074416>>2]){break h}}e=0;break g}e=!(y[a+1074392>>2]%(g>>>0)|0)}j=j+1|0;break e}e=0;j=v[a+480180>>2]&1048580?0:j}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!f?v[a+1074392>>2]:1)|(j&255)<(g|0))){e=1}g=h+8|0;Db(g,k,52);if(!Cb(g)|c){break c}e=!v[a+1074392>>2]}g=i+1074992|0;i=(B(b,872)+a|0)+1075068|0;j:{if(v[i>>2]){break j}f=h+8|0;Db(f,k,38);if(!Cb(f)){break j}if(!tk(g)){break a}}f=h+8|0;Db(f,k,106);if(z=0,A=Cb(f),C=v[(B(b,872)+a|0)+1075688>>2],C?z:A){break a}if(e){f=B(b,872)+a|0;p=f+1075680|0;v[h+4>>2]=v[p>>2];e=c>>>4&15;if(e){m=h+8|0;Db(m,k,52);k:{if(z=Cb(m),A=0,C=w[(B(b,872)+a|0)+1075782|0]==1,C?z:A){break k}if(!(16191>>>e&1)){v[h+4>>2]=(B(v[h+4>>2],t[e+40144|0])|0)/16;break k}v[h+4>>2]=v[h+4>>2]+(t[e+40160|0]<<2)}Rd(h+4|0,0,256);e=(B(b,872)+a|0)+1075080|0;v[e>>2]=v[e>>2]|2097152}q=f+1075692|0;m=v[q>>2];e=w[f+1075794|0];l:{if(!v[i>>2]|(e-1&255)>>>0>119){break l}if(!(!(w[(B(b,872)+a|0)+1075081|0]&2)|v[a+480180>>2]!=2)){f=h+8|0;Db(f,k,108);if(!Cb(f)){break l}}AP(a,b,0,e,1)}f=0;m:{if(!(v[a+480180>>2]&1048580)){break m}i=w[(B(b,872)+a|0)+1075781|0];f=(c|0)<256;if(!i|(c|0)>255){break m}Do(a,g,i,0,0,1);f=1}i=B(b,872)+a|0;n=i+1075652|0;s=v[n>>2];v[n>>2]=0;o=i+1075080|0;u=v[o>>2];r=h+8|0;Db(r,k,23);qu(a,g,e,Cb(r),f,0,b);if(!w[i+1075781|0]){v[n>>2]=s}if(!(!(u&4096)|v[a+480180>>2]!=4)){v[o>>2]=v[o>>2]|4096}f=i+1075780|0;v[p>>2]=v[h+4>>2];if(x[a+480192>>1]){t[f|0]=e;iO(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[f|0]|!m))){v[q>>2]=m}e=v[a+480180>>2];f=h+8|0;Db(f,k,23);if(Cb(f)){v[g>>2]=0;v[g+4>>2]=0}e=e&16777250;f=(B(b,872)+a|0)+1075096|0;n:{if(!v[f>>2]|(d|0)<1){break n}i=d-1|0;if((i|0)>9){break n}o:{if(!i){b=v[(B(b,872)+a|0)+1075656>>2];break o}i=(B(b,872)+a|0)+1075656|0;b=v[yf(v[f>>2]+68|0,d-2|0)>>2];v[i>>2]=b}Mm(a,g,b)}j=e?j:0}a=h+8|0;Db(a,k,52);b=Cb(a);Db(a,k,23);if(Cb(a)){break a}j=(b&(c&256)>>>8)+j|0}t[l|0]=j}gb=h+16|0}function Jka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=gb-4144|0;gb=f;a:{b:{if(!Ib(w[a+14|0]|w[a+15|0]<<8)){break b}i=a;if(Ib(w[a+14|0]|w[a+15|0]<<8)>>>0>20|x[b+480190>>1]<=w[a+23|0]){break b}ud(d,32);u[d+34>>1]=1;h=f+24|0;g=h;a=a+20|0;td(g,a,a+80|0);a=f+4136|0;NT(a,g,Ib(w[i+14|0]|w[i+15|0]<<8));j=Tl(b,w[Lb(a,0)+3|0]+1|0);v[f+24>>2]=1;n=1/+y[Mc(j+24|0,g)>>2];if(c){j=br(f+4136|0)}else{j=1}NT(g,a,j);a=v[h>>2];g=v[h+4>>2];if((a|0)!=(g|0)){while(1){if(!(t[a+1|0]<0|x[b+480190>>1]<=w[a+3|0])){h=Tl(b,w[a+3|0]+1|0);j=v[h>>2];s=d,z=Bh(n*(Dk(+(t[a+1|0]-t[Lb(f+4136|0,0)+1|0]|0)/-12)*+(j>>>0)*+y[h+24>>2]))+v[d>>2]|0,v[s>>2]=z}a=a+4|0;if((g|0)!=(a|0)){continue}break}}q=Zm(d);if(q){j=(e<<12>>>0)/1e4|0;e=br(f+4136|0);a=f+4120|0;h=vh(a);c:{if(!e){break c}v[22708]=0;R(944,a|0,e|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;R(945,a|0,e|0);e=v[22708];v[22708]=0;if((e|0)!=1){break c}}break a}h=a;d:{if(!br(f+4136|0)){break d}a=0;while(1){e:{e=Lb(f+4136|0,a);g=MT(h,a);if(!(t[e+1|0]<0|x[b+480190>>1]<=w[e+3|0])){k=0;k=w[e+2|0]<242|w[e+2|0]>247?k:t[w[e+2|0]+33118|0];l=Tl(b,w[e+3|0]+1|0);e=t[e+1|0];m=Lb(f+4136|0,0);o=v[l+24>>2];m=t[m+1|0];v[22708]=0;k=Oa(939,+(n*(Dk(+(k<<24>>24)/96+ +(e-m|0)/12)*+(o>>>0))))|0;e=O()|0;m=k|0;o=v[22708];v[22708]=0;k=g;f:{g:{if((o|0)!=1){v[g+8>>2]=m;v[g+12>>2]=e;v[g+16>>2]=v[l+20>>2];e=v[l>>2];v[g+76>>2]=e;v[g+88>>2]=x[l+34>>1]&1023;if(!c){break g}v[g+664>>2]=r;p=JB(g+8|0);v[22708]=0;e=Bh(+(e>>>0)/p);l=v[22708];v[22708]=0;if((l|0)==1){break e}r=e+r|0;e=j;break f}break a}e=(j>>>0)/(Ib(w[i+14|0]|w[i+15|0]<<8)>>>0)|0}v[k+20>>2]=e;v[g+24>>2]=e}a=a+1|0;if(br(f+4136|0)>>>0>a>>>0){continue}break d}break}break a}a=v[d>>2];if(a){k=b+24648|0;c=0;while(1){Qb(f+24|0,0,4096);v[f+16>>2]=512;v[22708]=0;v[f+8>>2]=a-c;a=Fb(f+16|0,f+8|0);b=v[22708];v[22708]=0;h:{i:{if((b|0)!=1){g=v[a>>2];s=f,z=Vb(h),v[s+16>>2]=z;s=f,z=Zb(h),v[s+8>>2]=z;if(Gb(f+16|0,f+8|0)){break i}break h}break a}while(1){j:{a=v[f+16>>2];if(!v[a+16>>2]){break j}b=v[a+664>>2];if(b>>>0>=g>>>0){v[a+664>>2]=b-g;break j}e=v[a+88>>2];v[f+4>>2]=g-b;b=v[a+76>>2];n=JB(a);p=JB(a+8|0);v[22708]=0;b=Bh((+(b>>>0)-n)/p);i=v[22708];v[22708]=0;if((i|0)==1){break a}v[22708]=0;v[f>>2]=b;b=Fb(f+4|0,f);i=v[22708];v[22708]=0;if((i|0)==1){break a}b=v[b>>2];i=v[a+664>>2];v[22708]=0;Y(v[((e&1|(e&64?18:16))<<2)+33696>>2],a|0,k|0,(f+24|0)+(i<<3)|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break j}v[a+16>>2]=0;break j}break a}a=f+16|0;v[a>>2]=v[a>>2]+872;if(Gb(a,f+8|0)){continue}break}}e=v[d+20>>2]+(c<<1)|0;i=f+24|0;b=gb-16|0;gb=b;v[b+12>>2]=g;qc(b+12|0,512);a=v[b+12>>2];v[b+12>>2]=a-1;if(a){while(1){a=e;j=id(v[i>>2]+2048|0,12);if((j|0)<-32768){j=-32768}u[a>>1]=(j|0)>32767?32767:j;a=v[b+12>>2];v[b+12>>2]=a-1;i=i+8|0;e=e+2|0;if(a){continue}break}}gb=b+16|0;a=v[d>>2];c=c+g|0;if(a>>>0>c>>>0){continue}break}}GT(h)}h=(q|0)!=0}gb=f+4144|0;return h|0}a=P()|0;O()|0;GT(h);S(a|0);L()}function jL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-224|0;gb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(qk(b)){break a}g=w[ul(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Jl(f+184|0,b,v[b+4>>2]-1|0);g=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=g}g=f+184|0;Ld(g);h=v[f+184>>2];Ld(f+168|0);i=tl(h,v[f+172>>2],b);Ld(g);g=v[b>>2];h=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+188>>2]){v[f+208>>2]=g;v[f+212>>2]=h;a=uc(f+200|0,18720);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Gc(f+16|0,f+8|0)){a=ba(8)|0;v[22708]=0;R(2060,f+168|0,f+216|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(2038,f+184|0,14722,f+168|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}rc(a,f+184|0);e=0;v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);break e}if(!e){break h}a=ba(8)|0;v[22708]=0;c=Q(2058,f+136|0,b|0)|0;b=v[22708];v[22708]=0;e=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22708]=0;U(2038,f+152|0,14758,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break q}v[22708]=0;R(2055,f+168|0,f+152|0);b=v[22708];v[22708]=0;if((b|0)==1){break p}v[22708]=0;R(2060,f+120|0,f+216|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}v[22708]=0;U(2059,f+184|0,f+168|0,f+120|0);b=v[22708];v[22708]=0;if((b|0)==1){break n}rc(a,f+184|0);v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);e=0;break m}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0}vb(f+120|0)}vb(f+168|0)}vb(f+152|0)}vb(c)}if(e){break d}break c}v[f+112>>2]=g;v[f+116>>2]=h;e=uc(f+104|0,18720);g=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=g;g=v[e+4>>2];v[f+56>>2]=v[e>>2];v[f+60>>2]=g;if(Gc(f- -64|0,f+56|0)){a=ba(8)|0;v[22708]=0;R(2060,f+168|0,f+216|0);b=v[22708];v[22708]=0;r:{s:{if((b|0)!=1){v[22708]=0;U(2038,f+184|0,14722,f+168|0);b=v[22708];v[22708]=0;if((b|0)==1){break s}rc(a,f+184|0);e=0;v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);break r}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}vb(f+168|0);if(e){break d}break c}e=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=e;e=uc(f+88|0,8207);g=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=g;g=v[e+4>>2];v[f+40>>2]=v[e>>2];v[f+44>>2]=g;if(Gc(f+48|0,f+40|0)){XK(a,Ac(c,d));break h}e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;b=uc(f+72|0,5758);e=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=e;e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(!Gc(f+32|0,f+24|0)){break h}b=JA(c,d);c=gb-16|0;gb=c;a=v[a+32>>2];b=b>>>0<4?b:1;t:{if((Gy(a)|0)==(b|0)){d=a+120|0;Ci(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[14910];v[a+8>>2]=v[14909];v[a+12>>2]=e;e=v[14908];v[a>>2]=v[14907];v[a+4>>2]=e;kb[v[Sh(a,Yg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break t}vK(a,b,wK(a))}gb=c+16|0}gb=f+224|0;return}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}vb(f+168|0);if(!e){break c}}da(a|0)}S(b|0)}L()}function SL(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);TP(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=wf(v[a+16>>2]);o=oe(C(10),C(C(C(z[a+4216>>2]+C(-.5))*C(30))/C(40)));b=C(C(c/C(d>>>0))*C(6.2831854820251465));c=sG(b);r=Qp(b);s=a;t=c;k=C(C(b*C(C(C(z[a+4212>>2]*C(35))+C(1))*C(.02888113260269165)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());c=C(((d|0)<=22?C(C(C(1)-g)+C(c-e)):C(C(c-C(e+g))+C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>-1){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+71232>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=NI(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(o*b);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function As(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116508]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=466012,j=v[116503]&sqa(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+466316|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=466016,j=v[116504]&sqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116505]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116509]==(f|0)){v[116509]=a;b=v[116506]+b|0;v[116506]=b;v[a+4>>2]=b|1;if(v[116508]!=(a|0)){break a}v[116505]=0;v[116508]=0;return}if(v[116508]==(f|0)){v[116508]=a;b=v[116505]+b|0;v[116505]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=466012,j=v[116503]&sqa(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+466316|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=466016,j=v[116504]&sqa(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116508]!=(a|0)){break g}v[116505]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+466052|0;d=v[116503];b=1<<b;l:{if(!(d&b)){v[116503]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+466316|0;m:{d=v[116504];c=1<<e;n:{if(!(d&c)){v[116504]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function R8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;v[d+184>>2]=c;a:{b:{c:{d:{if(b>=.8){v[22708]=0;c=ga(2071)|0;e=v[22708];v[22708]=0;e:{f:{g:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22708]=0;c=T(2072,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+72>>2]=c;lo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+160|0,a);v[22708]=0;e=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=e;v[d- -64>>2]=v[a+16>>2];e=v[a+4>>2];v[d+48>>2]=v[a>>2];v[d+52>>2]=e;a=W(2062,c|0,d+48|0,15)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}if(a){a=v[d+88>>2];v[22708]=0;T(1291,a|0)|0;a=v[22708];v[22708]=0;f=1;if((a|0)==1){break g}}Di(d+72|0);Ei(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Di(d+72|0);break e}c=V(0)|0;O()|0}Ei(d+88|0);break d}if(b>=.6){v[22708]=0;c=ga(2071)|0;e=v[22708];v[22708]=0;h:{i:{j:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22708]=0;c=T(2072,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}v[d+72>>2]=c;lo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+136|0,a);v[22708]=0;e=v[a+12>>2];v[d+32>>2]=v[a+8>>2];v[d+36>>2]=e;v[d+40>>2]=v[a+16>>2];e=v[a+4>>2];v[d+24>>2]=v[a>>2];v[d+28>>2]=e;a=W(2062,c|0,d+24|0,2)|0;c=v[22708];v[22708]=0;if((c|0)==1){break j}if(a){a=v[d+88>>2];v[22708]=0;T(1291,a|0)|0;a=v[22708];v[22708]=0;f=.8;if((a|0)==1){break j}}Di(d+72|0);Ei(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Di(d+72|0);break h}c=V(0)|0;O()|0}Ei(d+88|0);break d}f=.2;if(b>=.2){v[22708]=0;c=ga(2071)|0;e=v[22708];v[22708]=0;k:{l:{m:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22708]=0;c=T(2072,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break l}v[d+72>>2]=c;lo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=le(d+112|0,a);v[22708]=0;e=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=e;v[d+16>>2]=v[a+16>>2];e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;a=W(2062,c|0,d|0,0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}f=0;if(a){a=v[d+88>>2];v[22708]=0;T(1291,a|0)|0;a=v[22708];v[22708]=0;f=.6;if((a|0)==1){break m}}Di(d+72|0);Ei(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Di(d+72|0);break k}c=V(0)|0;O()|0}Ei(d+88|0);break d}if(!(b>=.1)){break c}v[22708]=0;U(755,d+88|0,a|0,2048);c=v[22708];v[22708]=0;n:{o:{p:{if((c|0)!=1){v[22708]=0;c=Sd(d+88|0);e=v[22708];v[22708]=0;if((e|0)==1){break o}e=v[d+88>>2];v[22708]=0;a=T(195,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break o}v[22708]=0;a=oG(2073,3,0,c,e,a,0);c=v[22708];v[22708]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=A[(a<<3)+59648>>3];zc(d+88|0);break c}c=V(0)|0;O()|0;break d}a=ba(8)|0;v[22708]=0;e=Q(70,d+72|0,18720)|0;c=v[22708];v[22708]=0;if((c|0)!=1){rc(a,e);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=V(0)|0;O()|0;vb(e);break n}c=V(0)|0;O()|0;da(a|0);break n}c=V(0)|0;O()|0}zc(d+88|0)}Z(c|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;f=0;if((a|0)==1){break a}}eg(d+184|0);gb=d+192|0;return+f}L()}a=P()|0;O()|0;eg(d+184|0);S(a|0);L()}function jga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=49424;v[a+4>>2]=0;v[a>>2]=38432;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;Wq(a+24604|0);aP(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Qb(b+28|0,0,40);Qb(b+68|0,0,49824);Qb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=Go(a+480248|0);v[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){v[22708]=0;c=$O(c);e=v[22708];v[22708]=0;if((e|0)==1){break k}c=c+32|0;if((b|0)!=(c|0)){continue}break}e=a+484344|0;dd(e);v[e+12>>2]=a;v[22708]=0;l=Q(1282,a+484360|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break j}b=a+900380|0;c=a+484380|0;while(1){v[22708]=0;c=Q(900,c|0,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}c=c+104|0;if((b|0)!=(c|0)){continue}break}v[22708]=0;T(1283,a+901404|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}c=a+946300|0;f=a+906300|0;b=f;while(1){b=_O(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;d=a+1074304|0;g=a+946304|0;b=g;while(1){v[22708]=0;b=Uq(b);h=v[22708];v[22708]=0;if((h|0)==1){break g}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;nA(a+1074312|0);v[22708]=0;b=ga(1284)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}v[22708]=0;b=T(1285,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}v[a+1074328>>2]=b;v[22708]=0;gO(a+1074332|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;T(1287,a+1074376|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;d=W(1248,a+1298224|0,a|0,255)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}h=Ah(a+1298260|0);b=gb-16|0;gb=b;v[b+12>>2]=0;i=a+1298264|0;xq(i,b+12|0);gb=b+16|0;m=Kb(a+1298268|0);n=Kb(a+1298280|0);j=a+1298292|0;Kb(j);o=ZO(a+1298304|0);p=dd(a+1298368|0);t[a+1298380|0]=0;b=a+1298384|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298424>>2]=0;Aq(a+12|0);Wo(a+8204|0);v[22708]=0;Wo(a+12300|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[a+480216>>2]=4;v[a+480220>>2]=16;b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;XO(a+900380|0);v[22708]=0;lA(g);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=T(1290,12)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;hh(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;mA(p);ju(o);vb(j);vb(n);vb(m);iu(i);hu(h);Eq(d)}while(1){c=Bq(c-160|0);if((f|0)!=(c|0)){continue}break}}Gu(l)}kA(e)}Lc(k);S(b|0);L()}function rO(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=C(0),s=0,t=0,w=0,A=0,E=C(0),G=0;if(b){wq(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;JO(a)}qO(a+24648|0);s=v[a+24620>>2];g=gb-144|0;gb=g;f=a+397456|0;c=v[f+4>>2];if(c>>>0>=29){v[f+4>>2]=0;c=0}j=B(c,44)+53296|0;if(!(b?0:(j|0)==v[f+8>>2])){v[f+8>>2]=j;r=C(s>>>0);h=r;c=g+8|0;d=v[j+24>>2];v[c>>2]=d;e=v[j+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[j+4>>2];m=(d|0)>(e|0)?d:e;if((m|0)<=-601){i=e;e=m+600|0;v[c+4>>2]=i-e;v[c>>2]=d-e}e=c;k=C(z[j+36>>2]*C(79.30999755859375));a:{if(C(D(k))<C(2147483648)){d=~~k;break a}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(C(z[j+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(k))<C(2147483648)){e=~~k;break b}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;m=0;k=z[j+8>>2];e=c;o=C(C(F(z[j+20>>2],C(.10000000149011612)))*h);c:{if(C(D(o))<C(2147483648)){d=~~o;break c}d=-2147483648}i=(d|0)<96;p=i?96:d;l=(p|0)>7500;o=C(z[j+28>>2]*h);d:{if(C(D(o))<C(2147483648)){n=~~o;break d}n=-2147483648}d=(n+(i?d-96|0:0)|0)+(l?p-7500|0:0)|0;i=(d|0)<128;n=i?128:d;t=(n|0)>3800;w=t?3800:n;v[e+24>>2]=w;i=i?d-128|0:0;e=c;h=C(k*h);e:{if(C(D(h))<C(2147483648)){d=~~h;break e}d=-2147483648}i=(d+i|0)+(t?n-3800|0:0)|0;v[e+32>>2]=i;p=l?7500:p;while(1){d=B(m,12);e=d+c|0;u[e+42>>1]=x[d+54586>>1];u[e+36>>1]=x[d+54580>>1];l=d+54582|0;l=x[l>>1]|x[l+2>>1]<<16;u[e+38>>1]=l;u[e+40>>1]=l>>>16;v[e+44>>2]=p+((B(v[d+54576>>2],w)+50|0)/100|0);m=m+1|0;if((m|0)!=8){continue}break}e=c;h=C(i|0);k=C(oe(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/h))*C(32768));f:{if(C(D(k))<C(2147483648)){d=~~k;break f}d=-2147483648}v[e+12>>2]=d;h=C(z[j+12>>2]*h);A=c,E=oe(C(.0010000000474974513),h<=C(4720)?C(1):C(C(4720)/h)),z[A+28>>2]=E;v[f+20>>2]=v[g+40>>2];c=KL(LL(v[g+16>>2]),r);u[f+86>>1]=c;u[f+84>>1]=c;c=x[g+24>>1]<<1;u[f+94>>1]=c;u[f+92>>1]=c;while(1){c=(q<<4)+f|0;d=(g+8|0)+B(q,12)|0;e=v[d+44>>2];v[c+100>>2]=e;v[c+104>>2]=e;u[c+108>>1]=x[d+36>>1];u[c+110>>1]=x[d+42>>1];u[c+112>>1]=x[d+40>>1];u[c+114>>1]=x[d+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[f+49892>>2]=v[g+32>>2];c=f;d=v[g+12>>2];if((d|0)>-9e3){e=JL(d)}else{e=0}v[c+80>>2]=e;e=f+49948|0;c=v[g+8>>2];if((c|0)>=-8999){c=JL(c)}else{c=0}v[e>>2]=c;c=v[g+28>>2];d=f+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+49906>>1]=c;u[f+49904>>1]=c;u[f+49902>>1]=c;u[f+49900>>1]=c;v[g+4>>2]=v[g+20>>2];Rd(g+4|0,0,32752);c=x[g+4>>1];u[f+49914>>1]=c;d=f+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[f+49908>>1]=c;h=z[g+36>>2];A=g,G=KL(C(h*h),r),v[A>>2]=G;Rd(g,256,32512);c=x[g>>1];u[f+49922>>1]=c;d=f+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[f+49916>>1]=c}c=a+397448|0;d=a+397452|0;if(b){v[f+16>>2]=0;NL(f,c,d)}b=B(s,5);if(b>>>0>y[f+20>>2]){v[f+20>>2]=b}gb=g+144|0;b=a+1298260|0;if(Dd(b)){SR(v[b>>2],v[a+24620>>2])}}function w_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-32|0;gb=e;v[e+28>>2]=b;a:{b:{if((d|0)<1){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Fb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;Mt(c,v[Fb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){c:{b=e+8|0;f=lh(b,a);i=lh(b,a+4|0);o=lh(b,a+5|0);r=e,s=lh(b,a+6|0)<<8|lh(b,a+7|0),v[r+24>>2]=s;b=o|i<<8;p=a+8|0;d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){i=0;o=0;if(b){break f}break d}a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}break b}while(1){r=e,s=lh(e+8|0,i+p|0),t[r+20|0]=s;kq(c,e+20|0);i=i+1|0;if((b|0)!=(i|0)){continue}break};i=b;o=b;break d;case 1:break e;default:break c}}ck(e+24|0,d);i=v[e+24>>2];m=lh(e+8|0,a+10|0);t[e+20|0]=m;kq(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;o=b+3&65532;if((f|0)<2){break d}h=a+11|0;k=0;n=0;j=0;b=0;while(1){a=qg(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((j|0)<=7){if(a){f=b;break h}b=b+1|0;k=8;break k}f=b+1|0;l:{if(!a){if(!qg(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!qg(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!qg(h,a,1,e+8|0)){break n}f=qg(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;f=((k<<3)+f|0)-17|0;if((f|0)<=-1){a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}break b}if(f>>>0>=56){a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}break b}k=w[f+28336|0];if((k|0)!=8){break j}break l}a=4;b=f;if((k|0)!=8){break j}}k=8;a=1;if((n|0)>19){break j}}a=0;break i}n=n+8|0}g=v[e+24>>2];o:{if((g|0)<1){break o}while(1){f=e+8|0;l=(b|0)/8|0;g=l+h|0;q=lh(f,g);m=m-((lh(f,g+1|0)<<8|q<<16|lh(f,g+2|0))<<(b-(l<<3)|0)+8>>32-k)|0;t[e+20|0]=m;kq(c,e+20|0);f=v[e+24>>2];g=f-1|0;v[e+24>>2]=g;b=b+k|0;if((a|0)<1){break o}a=a-1|0;if((f|0)>1){continue}break}}j=(j|0)==31?31:j+1|0;break g}p:{q:{r:{a=f+1|0;if(!qg(h,a,1,e+8|0)){f=2;break r}a=f+2|0;if(!qg(h,a,1,e+8|0)){f=4;break r}a=f+3|0;if(!qg(h,a,1,e+8|0)){f=6;break r}a=f+5|0;if(!qg(h,f+4|0,1,e+8|0)){b=f+8|0;a=qg(h,a,3,e+8|0)+8|0;break p}b=f+10|0;f=16;a=qg(h,a,5,e+8|0);break q}b=a+2|0;a=qg(h,a+1|0,1,e+8|0)}a=a+f|0}s:{if(qg(h,b,1,e+8|0)){f=-256;g=12;break s}b=b+1|0;g=qg(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;l=qg(h,b,g,e+8|0);if((a|0)>=3){j=j-((a|0)!=3)|0;j=((j|0)>1?j:1)-1|0}f=oc(c)+((l^-1)+f|0)|0;if(f>>>0<oc(c)>>>0){b=b+g|0;g=v[e+24>>2];if((a|0)<1|(g|0)<=0){break g}while(1){m=w[kc(c,f)|0];t[e+20|0]=m;kq(c,e+20|0);l=v[e+24>>2];g=l-1|0;v[e+24>>2]=g;if((a|0)<2){break g}f=f+1|0;a=a-1|0;if((l|0)>1){continue}break}break g}a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}break a}n=n-(n>>3)|0;if((g|0)>0){continue}break}}a=o+p|0;d=d-i|0;if((d|0)>0){continue}}break}a=cd(c)^1}gb=e+32|0;return a|0}b=P()|0;O()|0;da(a|0);S(b|0);L()}ia(a|0,28304,206);L()}function Lfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=gb-144|0;gb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){xz(a+96|0,c);v[22708]=0;c=Q(2,a+80|0,14858)|0;d=v[22708];v[22708]=0;if((d|0)==1){break E}v[22708]=0;U(3,a+112|0,a+96|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break D}v[22708]=0;d=Q(4,a+48|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break C}v[22708]=0;e=Q(2,a+32|0,16663)|0;f=v[22708];v[22708]=0;if((f|0)==1){break B}v[22708]=0;U(5,a- -64|0,d|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break A}v[22708]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[22708];v[22708]=0;if((f|0)==1){break z}vb(a- -64|0);vb(e);vb(d);d=a+112|0;vb(d);vb(c);vb(a+96|0);c=v[b>>2];v[22708]=0;U(6,d|0,1,(c?c:18720)|0);c=v[22708];v[22708]=0;if((c|0)==1){break t}c=v[b+4>>2];v[22708]=0;U(6,a+96|0,1,(c?c:18720)|0);c=v[22708];v[22708]=0;if((c|0)==1){break s}b=v[b+8>>2];v[22708]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[22708];v[22708]=0;if((b|0)==1){break r}v[22708]=0;b=Q(8,463432,14737)|0;c=v[22708];v[22708]=0;if((c|0)==1){break q}v[22708]=0;U(9,a- -64|0,0,a+112|0);c=v[22708];v[22708]=0;if((c|0)==1){break p}v[22708]=0;b=Q(10,b|0,a- -64|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break o}v[22708]=0;b=Q(8,b|0,14511)|0;c=v[22708];v[22708]=0;if((c|0)==1){break o}v[22708]=0;U(9,a+32|0,0,a+80|0);c=v[22708];v[22708]=0;if((c|0)==1){break n}v[22708]=0;b=Q(10,b|0,a+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;b=Q(8,b|0,14508)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;b=Q(8,b|0,14858)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[22708]=0;U(9,a+16|0,0,a+128|0);c=v[22708];v[22708]=0;if((c|0)==1){break l}v[22708]=0;b=Q(10,b|0,a+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;b=Q(8,b|0,10771)|0;c=v[22708];v[22708]=0;if((c|0)==1){break k}v[22708]=0;U(9,a|0,0,a+96|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[22708]=0;b=Q(10,b|0,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;b=Q(8,b|0,10769)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;Q(11,b|0,12)|0;b=v[22708];v[22708]=0;if((b|0)==1){break i}vb(a);vb(a+16|0);vb(a+32|0);vb(a- -64|0);vb(a+80|0);vb(a+96|0);vb(a+112|0);vb(a+128|0)}gb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;vb(a- -64|0)}vb(e)}vb(d)}vb(a+112|0)}vb(c)}vb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a)}vb(a+16|0)}vb(a+32|0)}vb(a- -64|0)}vb(a+80|0)}vb(a+96|0)}vb(a+112|0)}vb(a+128|0)}S(b|0);L()}function $m(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-96|0;gb=d;g=mc(a);v[22708]=0;e=T(426,b|0)|0;a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)==1){break e}v[22708]=0;a=Q(191,b|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}if(a){break d}v[22708]=0;a=T(467,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}v[22708]=0;Q(318,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[22708]=0;U(288,d+48|0,b|0,e|0);b=v[22708];v[22708]=0;a=d;f:{g:{h:{i:{if((b|0)!=1){b=d+48|0;f=jc(d+72|0,b);xb(b);if(e>>>0<10){break g}v[22708]=0;b=T(935,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break g}v[22708]=0;b=T(426,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[d+44>>2]=b;v[d+40>>2]=e-10;b=v[d+40>>2];if(b>>>0>25264513){break i}b=B(b,170);break h}a=P()|0;O()|0;break a}b=-1}v[a+40>>2]=b;qc(d+44|0,b);v[22708]=0;R(440,g|0,v[d+44>>2]);a=v[22708];v[22708]=0;if((a|0)==1){break b}e=v[d+44>>2];b=0;while(1){j:{v[22708]=0;a=T(936,f|0)|0;c=v[22708];v[22708]=0;k:{l:{m:{n:{if((c|0)!=1){if(a){break j}v[22708]=0;a=T(707,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}switch(a|0){case 3:break k;case 2:break l;case 1:break m;case 0:break n;default:break j}}break b}v[22708]=0;a=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(a>>>0>e>>>0){break j}v[22708]=0;c=Q(191,f|0,a|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!c){break j}v[22708]=0;Vd(d+48|0,g);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;Y(937,d+24|0,d+48|0,b|0,a|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;c=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=c;U(633,d+16|0,f|0,d+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){e=e-a|0;b=a+b|0;continue}break b}v[22708]=0;a=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}c=a<<2;if(c>>>0>e>>>0){break j}v[22708]=0;h=Q(938,f|0,d+32|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break b}if(!h){break j}e=e-c|0;if(!a){continue}while(1){c=d+32|0;h=fc(c);j=d,k=Vb(g),v[j+48>>2]=k;Qu(c,h,xe(d+48|0,b));b=b+4|0;a=a-1|0;if(a&255){continue}break}continue}if(e>>>0<8){break j}v[22708]=0;a=Q(938,f|0,d+32|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!a){break j}a=d+32|0;c=fc(a);j=d,k=Vb(g),v[j+48>>2]=k;i=c;c=d+48|0;Qu(a,i,xe(c,b));h=fc(a);j=d,k=Vb(g),v[j+16>>2]=k;j=d,k=xe(d+16|0,b),v[j+48>>2]=k;Qu(a,h,xe(c,4));e=e-8|0;b=b+8|0;continue}v[22708]=0;a=T(374,f|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(a>>>0>e>>>0){break j}e=e-a|0;b=a+b|0;continue}break}if(!e){break f}a=mc(d+48|0);xc(a,g);xc(a+4|0,g+4|0);xc(wb(a),wb(g));wb(a);wb(g);gc(a);break f}v[22708]=0;W(505,f|0,g|0,e|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}}xb(f)}gb=d+96|0;return}a=P()|0;O()|0;xb(f)}gc(g);S(a|0);L()}function Dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-96|0;gb=d;a:{b:{c:{d:{if(w[a|0]==23){e=t[a+1|0];f=d,g=AA(c,+w[a+2|0]*1e4/240),t[f+8|0]=g;v[d+80>>2]=127;v[d+64>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[pd(d+80|0,d- -64|0)>>2],t[f+95|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:Ff(d- -64|0,12694);v[22708]=0;R(737,d+48|0,d+8|0);a=v[22708];v[22708]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){v[22708]=0;R(737,d+32|0,d+95|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}v[22708]=0;Y(738,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break j}v[22708]=0;R(444,d+16|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;Q(401,d+16|0,d+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;case 1:Ff(d- -64|0,12634);v[22708]=0;R(737,d+48|0,d+8|0);a=v[22708];v[22708]=0;l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22708]=0;R(737,d+32|0,d+95|0);a=v[22708];v[22708]=0;if((a|0)==1){break q}v[22708]=0;Y(738,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22708];v[22708]=0;if((a|0)==1){break p}v[22708]=0;R(444,d+16|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break o}v[22708]=0;Q(401,d+16|0,d+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break o}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;default:break e}}a=Tb(d+80|0,12721);v[22708]=0;R(444,d- -64|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(401,d- -64|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}vb(a);break b}if(w[a|0]==24){t[d+95|0]=t[a+1|0]<=4?w[a+1|0]:0;t[d+31|0]=t[a+2|0]>=0?w[a+2|0]:127;t[d+30|0]=t[a+3|0]>=0?w[a+3|0]:127;a=gb-16|0;gb=a;c=Tb(a,1157);Dc(d- -64|0,c);vb(c);gb=a+16|0;v[22708]=0;R(737,d+48|0,d+95|0);a=v[22708];v[22708]=0;r:{s:{t:{u:{v:{w:{x:{y:{if((a|0)!=1){v[22708]=0;R(737,d+32|0,d+31|0);a=v[22708];v[22708]=0;if((a|0)==1){break y}v[22708]=0;R(737,d+16|0,d+30|0);a=v[22708];v[22708]=0;if((a|0)==1){break x}v[22708]=0;ha(942,d+80|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break w}v[22708]=0;R(444,d+8|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break v}v[22708]=0;Q(401,d+8|0,d+80|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break v}vb(d+80|0);vb(d+16|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break t}b=P()|0;O()|0;break u}b=P()|0;O()|0;vb(d+80|0)}vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c}a=0;break a}b=P()|0;O()|0;vb(a)}S(b|0);L()}a=1}gb=d+96|0;return a|0}function Qy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-96|0;gb=e;a:{b:{c:{if(j=1,k=nd(a,11),l=v[a+4>>2],l?j:k){g=v[a+28>>2];b=e;d=v[a+12>>2];f=v[a+64>>2];c=f+v[a+8>>2]|0;d=sh(b+80|0,c,c>>>0<f>>>0?d+1|0:d);c=v[d+12>>2];v[b+32>>2]=v[d+8>>2];v[b+36>>2]=c;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;kk(g,e+24|0);b=v[a+28>>2];if(El(v[v[b>>2]-12>>2]+b|0)){uh(a,1073741826);break a}d=v[a+92>>2];g=a+44|0;b=g;c=uf(b);d:{if(d>>>0>c>>>0){f=gb-32|0;gb=f;e:{c=d-c|0;f:{if(c>>>0<=v[wb(b)>>2]-v[b+4>>2]>>4>>>0){h=gb-16|0;gb=h;c=cq(h,b,c);d=v[c+4>>2];i=v[c+8>>2];if((d|0)!=(i|0)){while(1){wb(b);XH(d);d=d+16|0;v[c+4>>2]=d;if((d|0)!=(i|0)){continue}break}}$b(c);gb=h+16|0;break f}d=wb(b);d=QI(f+8|0,dy(b,uf(b)+c|0),uf(b),d);v[22708]=0;OI(d,c);c=v[22708];v[22708]=0;if((c|0)==1){break e}Sx(b);wb(b);c=d+4|0;ol(v[b>>2],v[b+4>>2],c);wc(b,c);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];aI(b,uf(b));II(d)}gb=f+32|0;break d}a=P()|0;O()|0;II(d);S(a|0);L()}if(c>>>0>d>>>0){d=v[b>>2]+(d<<4)|0;uf(b);FI(b,d);xi(b);uf(b)}}h=a+32|0;Mt(h,v[a+92>>2]<<2);if(v[a+92>>2]){c=0;while(1){b=v[a+28>>2];if(El(v[v[b>>2]-12>>2]+b|0)){uh(a,1073741828);break a}b=x[a+16>>1];u[e+78>>1]=b;if((b|0)==65535){Ry(v[a+28>>2],e+78|0);b=x[e+78>>1]}f=oc(h);v[e+72>>2]=f;g:{if(!b){break g}d=b;f=v[e+72>>2];if(b>>>0>-1-f>>>0){break g}Py(h,d+f|0);kl(v[a+28>>2],kc(h,v[e+72>>2]),d);f=v[e+72>>2]}j=Tc(g,c),k=b,u[j+12>>1]=k;j=Tc(g,c),k=f,v[j>>2]=k;if(nd(a,6)){yl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break c}j=Tc(g,c),k=v[e+56>>2],v[j+4>>2]=k}b=v[a+4>>2];h:{if(b){j=Tc(g,c),k=b,v[j+8>>2]=k;break h}if(!nd(a,7)){break h}yl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break b}j=Tc(g,c),k=v[e+56>>2],v[j+8>>2]=k}i:{if(v[Tc(g,c)+8>>2]==-1){break i}if(nd(a,6)){break i}if(c){b=Tc(g,c-1|0);b=v[b+8>>2]+v[b+4>>2]|0}else{b=0}j=Tc(g,c),k=b,v[j+4>>2]=k}if(nd(a,8)){u[e+56>>1]=0;Ry(v[a+28>>2],e+56|0);b=nd(a,9);vm(v[a+28>>2],x[e+56>>1]<<b,-1)}c=c+1|0;if(c>>>0<y[a+92>>2]){continue}break}}te(e+56|0,v[a+28>>2]);b=v[e+68>>2];v[a+72>>2]=v[e+64>>2];v[a+76>>2]=b}zl(a,4,1);g=v[a+76>>2];f=v[a+88>>2];c=f+v[a+8>>2]|0;d=v[a+12>>2];d=c>>>0<f>>>0?d+1|0:d;b=c;c=(f|0)==v[a+64>>2];f=c?v[a+72>>2]:b;v[a+80>>2]=f;b=c?g:d;v[a+84>>2]=b;d=v[a+28>>2];b=sh(e+40|0,f,b);c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;kk(d,e+8|0);if(nd(a,6)){break a}if(!(j=1,k=nd(a,7),l=v[a+4>>2],l?j:k)){break a}b=v[a+92>>2];if(!b){break a}d=a+44|0;c=v[a+80>>2];a=v[a+8>>2];c=c-a|0;a=0;while(1){g=Tc(d,a);v[g+4>>2]=c+v[g+4>>2];a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}uh(a,1073741829);break a}uh(a,1073741829)}gb=e+96|0}function Jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-48|0;gb=c;if(ii(b)){h=Ki(b);j=v[b+12>>2];f=c+32|0;e=Hg(f);a:{d=h;if(!d){break a}v[22708]=0;R(617,f|0,d|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;DN(f,d);d=v[22708];v[22708]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;uv(e);S(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[22708]=0;d=_f(a+d|0);e=v[22708];v[22708]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[22708]=0;t[c+31|0]=0;Q(1484,a|0,c+31|0)|0;d=v[22708];v[22708]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>-1){break f}v[22708]=0;Q(1484,a|0,c+30|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;hi(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[22708]=0;g=Xc(b,i,d);e=v[22708];v[22708]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[22708]=0;Q(1484,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=ad(f,d),m=e,t[l|0]=m}l=g,m=w[ad(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[22708]=0;Q(1484,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=ad(f,d),m=e,t[l+1|0]=m}l=g,m=w[ad(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[22708]=0;Q(1484,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=ad(f,d),m=e,t[l+2|0]=m}l=g,m=w[ad(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[22708]=0;Q(1484,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=ad(f,d),m=e,t[l+4|0]=m}l=g,m=w[ad(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[22708]=0;Q(1484,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+3|0]=m}l=g,m=w[ad(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[22708]=0;Q(1484,a|0,c+29|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=ad(f,d),m=e,t[l+5|0]=m}l=g,m=w[ad(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[22708]=0;Q(1484,a|0,c+15|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){d=w[c+15|0];v[22708]=0;W(1485,a|0,d|0,-1)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;hn(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}hn(f)}gb=c+48|0}function T7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;a:{if(qk(b)){break a}e=w[ul(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Jl(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}g=d+160|0;Ld(g);e=v[d+160>>2];Ld(d+144|0);e=tl(e,v[d+148>>2],b);Ld(g);b:{c:{d:{e:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=uc(d+176|0,18720);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22708]=0;c=Q(70,d+160|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}f=0;if(!c){break e}a=ba(8)|0;v[22708]=0;e=Q(2058,d+144|0,b|0)|0;b=v[22708];v[22708]=0;f:{g:{h:{if((b|0)!=1){v[22708]=0;U(2038,d+160|0,14758,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}rc(a,d+160|0);c=0;v[22708]=0;U(186,a|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+160|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}vb(e);if(!c){break c}}da(a|0);break c}if(v[e+4>>2]!=2){a=ba(8)|0;v[22708]=0;c=Q(70,d+160|0,8874)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=uc(d+128|0,18720);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Gc(d+72|0,d- -64|0)){a=ba(8)|0;v[22708]=0;c=Q(70,d+160|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=uc(d+112|0,4823);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,4875);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=uc(d+80|0,4893);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Gc(d+24|0,d+16|0)){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}gb=d+192|0;return+f}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function fna(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[ac(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[ac(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=fn(+(eW(e,b,c,d)>>>0)/1e4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[ac(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[ac(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=ac(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[ac(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[ac(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[ac(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[ac(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[ac(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=44;h=a,i=dm(Qc(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=ei(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){Pf(a);break a}t[a+3|0]=0}gb=f+16|0}function pga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=gb-32|0;gb=f;r=a+4|0;p=v[r>>2];m=a+20|0;A=v[ze(m,b)>>2];a:{if(A+1>>>0<2){break a}h=(B(b,872)+p|0)+616|0;if(!Ni(h)){if(!w[ze(m,b)+4|0]){break a}}i=B(b,872)+p|0;if(!v[i+720>>2]){break a}j=v[i+704>>2]&2;g=v[(j?i+700|0:i+692|0)>>2];s=v[i+700>>2];u=v[i+696>>2];Db(f,v[a>>2]+1074312|0,31);D=Cb(f);E=i+1362|0;k=w[E|0];F=i+624|0;e=Bw(F,c);y=jb;n=y;v[f+24>>2]=e;v[f+28>>2]=n;if(w[i+704|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+n|0)}e=0;H=e;n=g;G=j?e:0;e=u;q=j?e:0;l=s-e|0;s=l<<1;e=B(b,872)+p|0;y=e+1316|0;o=e+1467|0;u=(k&17)!=1;b:{while(1){c:{if(d>>>0>z>>>0){g=(w[E|0]&17)==1;break c}t[o|0]=w[o|0]&254;k=Xc(_b(v[a>>2]+484344|0,x[v[r>>2]+70>>1]),v[v[r>>2]+48>>2],b);j=w[k+3|0];if(w[k+2|0]==11){yA(f,v[a>>2],k,0);e=Ve(f);zo(v[a>>2],h,x[f>>1]);g=1;if(w[e|0]){break c}}g=1;d:{switch(j-4|0){case 0:zo(v[a>>2],h,w[k+5|0]);break c;case 2:break d;default:break c}}zo(v[a>>2],h,0)}v[f+20>>2]=v[y>>2];if(D){au(v[a>>2],h)}if(!u){nO(v[a>>2],h,f+20|0);g=1}if(!D){au(v[a>>2],h)}v[f+16>>2]=0;oO(h,f+16|0);e:{f:{if(w[i+705|0]&2){break f}g:{if(!g){if(!w[ze(m,b)+4|0]){break g}}if(w[o|0]&48){IS(h,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&32?-33:-17)&e}Sz(f,v[a>>2],h,v[f+20>>2],0);g=v[f+4>>2];e=F;v[e>>2]=v[f>>2];v[e+4>>2]=g;I=ze(m,b),J=0,t[I+4|0]=J;e=Bw(e,c);j=jb;g=j;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+704|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+g|0)}Ub(h,f+24|0);k=v[h>>2];e=v[h+4>>2];if(v[f+28>>2]>-1|((e|0)>(q|0)?1:(e|0)>=(q|0)?k>>>0>=G>>>0:0)?(e|0)<(n|0)?1:(e|0)<=(n|0)?k>>>0<H>>>0:0:0){break f}g=v[i+704>>2];if(!(g&2)){break e}if(g&4){if((e|0)<(q|0)?1:(e|0)<=(q|0)?k>>>0<G>>>0:0){g=v[i+696>>2]<<1;v[f>>2]=0;v[f+4>>2]=g;I=h,J=Pg(f,h),v[I>>2]=J;v[h+4>>2]=jb;v[i+704>>2]=v[i+704>>2]^128;g=v[f+24>>2];e=0-(v[f+28>>2]+((g|0)!=0)|0)|0;v[f+24>>2]=0-g;v[f+28>>2]=e;e=v[h+4>>2]}g=v[i+696>>2];Db(f,v[a>>2]+1074312|0,33);e=(e-g>>>0)%(s-Cb(f)>>>0)|0;h:{if(e>>>0>=l>>>0){v[h+4>>2]=v[i+700>>2]+(l-e|0);g=v[i+704>>2];if(!(g&128)){break h}break f}v[h+4>>2]=e+v[i+696>>2];g=v[i+704>>2];if(!(g&128)){break f}}v[i+704>>2]=g^128;g=v[f+24>>2];e=0-(v[f+28>>2]+((g|0)!=0)|0)|0;v[f+24>>2]=0-g;v[f+28>>2]=e;break f}g=e;j=v[i+700>>2];if(e>>>0>=j+l>>>0){g=j+((g-j>>>0)%(l>>>0)|0)|0}while(1){e=g;g=e-l|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=k;v[h+4>>2]=e}z=z+1|0;if((A|0)!=(z|0)){continue}break b}break}kB(h);v[(B(b,872)+p|0)+1324>>2]=0}I=ze(m,b),J=0,v[I>>2]=J}gb=f+32|0}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-192|0;gb=d;g=d+176|0;fL(g);v[g>>2]=55124;dd(g+4|0);h=a;lo(v[a+24>>2],g);e=w[a+62|0];f=w[a+61|0];j=w[a+60|0];k=v[a+24>>2];b=le(d+152|0,b);v[22708]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;v[d+16>>2]=v[b+16>>2];i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;b=j?13:15;b=f?b&14:b;b=W(2062,k|0,d|0,(e?b&3:b)|0)|0;e=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)==1){break p}if(!b){b=ba(8)|0;v[22708]=0;c=Q(70,d+136|0,9264)|0;a=v[22708];v[22708]=0;if((a|0)!=1){rc(b,c);v[22708]=0;U(186,b|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;da(b|0);break b}if(!w[a+63|0]){v[22708]=0;R(2063,a|0,a+36|0);b=v[22708];v[22708]=0;if((b|0)==1){break p}}t[a+28|0]=1;lo(v[h+24>>2],v[a+4>>2]);v[22708]=0;R(2064,d+136|0,g|0);b=v[22708];v[22708]=0;if((b|0)==1){break o}b=d+136|0;l=d,m=Vb(b),v[l+128>>2]=m;l=d,m=Zb(b),v[l+120>>2]=m;if(Gb(d+128|0,d+120|0)){h=a+68|0;while(1){b=v[d+128>>2];e=v[b>>2];v[22708]=0;f=e;e=b+4|0;U(2065,a|0,f|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}b=v[b>>2];v[22708]=0;R(2066,d+56|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;R(2040,d+72|0,d+56|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;b=Q(70,d+40|0,14858)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}v[22708]=0;U(2059,d+88|0,d+72|0,b|0);f=v[22708];v[22708]=0;if((f|0)==1){break k}v[22708]=0;U(718,d+104|0,d+88|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break m}v[22708]=0;R(1423,h|0,d+104|0);e=v[22708];v[22708]=0;if((e|0)==1){break n}vb(d+104|0);vb(d+88|0);vb(b);vb(d+72|0);vb(d+56|0);b=d+128|0;Yo(b);if(Gb(b,d+120|0)){continue}break}}l=d,m=pr(c),v[l+104>>2]=m;l=d,m=Eh(c),v[l+88>>2]=m;q:{while(1){v[22708]=0;b=og(d+104|0,d+88|0);c=v[22708];v[22708]=0;r:{if((c|0)!=1){if(b){break r}Jt(d+136|0);Ht(g);gb=d+192|0;return}a=P()|0;O()|0;break c}v[22708]=0;c=ve(d+104|0);b=v[22708];v[22708]=0;s:{if((b|0)==1){break s}v[22708]=0;b=Q(69,d+24|0,c|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break s}v[22708]=0;Y(2001,a|0,b|0,c+12|0,0);c=v[22708];v[22708]=0;if((c|0)==1){break q}vb(b);Tj(d+104|0);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(b);break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+104|0);break l}a=P()|0;O()|0}vb(d+88|0);break j}a=P()|0;O()|0}vb(b);break h}a=P()|0;O()|0}vb(d+72|0);break f}a=P()|0;O()|0}vb(d+56|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Jt(d+136|0)}Ht(g);S(a|0)}L()}function yma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=gb-560|0;gb=f;a:{if(!Zc(b,1464)){break a}if(!gp(b,f+556|0)){break a}Hd(a,1);d=a+1074312|0;Sf(d,83);Ob(d,84,1);Ob(d,85,1);b:{if(je(f+556|0,33202)){d=f+32|0;e=Tb(d,5577);Eb(a+1298304|0,e);vb(e);e=Tb(d,12014);Eb(a+1298316|0,e);vb(e);d=Tb(d,12079);Eb(a+1298328|0,d);break b}if(!je(f+556|0,12629)){break a}d=f+32|0;e=Tb(d,5735);Eb(a+1298304|0,e);vb(e);e=Tb(d,9516);Eb(a+1298316|0,e);vb(e);d=Tb(d,12546);Eb(a+1298328|0,d)}vb(d);v[a+1298364>>2]=2;d=0;Zc(b,0);RC(b,a+1298268|0,20);u[a+480190>>1]=31;e=1;while(1){d=dC(b,f+32|0,(B(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}i=f+552|0;iw(i,b);m=qd(i);if(w[i|0]>128){break a}e=f+32|0;h=e;g=gb-32|0;gb=g;d=b;c:{if(!Pb(d,512)){kV(h);break c}Rv(g+24|0,h);h=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=h;kd(g+16|0,d,g+8|0)}gb=g+32|0;d=f+544|0;g=w[m|0];d:{while(1){if(g>>>0>=w[e|0]){e=e+1|0;if((d|0)!=(e|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;yh(a,0);n=a+484360|0;Bf(Sb(n),w[i|0]);u[f+30>>1]=0;j=a+484344|0;zg(j,w[i|0]);if(w[i|0]){g=0;while(1){s=sc(Sb(n),g),x=g,u[s>>1]=x;if(wh(j,g&65535,64)){p=g<<2;h=0;while(1){Zc(b,(w[f+32+(h+p)|0]<<8)+1468|0);e=Xc(_b(j,g),0,h&65535);d=0;while(1){fv(b,e);e:{f:{l=w[e+3|0];g:{if((l|0)!=14){if(!l){if(w[e+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[e+5|0]<=15){break f}}t[e+3|0]=0;break e}Pf(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=f,x=Vb(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){e=d;d=w[v[f+24>>2]+3|0];h:{if((d|0)!=17?(d|0)!=16:0){break h}t[v[f+24>>2]+3|0]=16;k=0;if(w[v[f+24>>2]+5|0]<16){break h}d=w[v[f+24>>2]+5|0];if(!((d&15)==(d>>>4|0)|!(d&15))){d=w[v[f+24>>2]+5|0];q=d>>>4|0;r=d&15;k=1}d=v[f+24>>2];t[d+5|0]=w[d+5|0]>>>4}ak(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}t[f+31|0]=r;t[f+30|0]=q;d=k&255;if(d){Hm(_b(j,g),Ue(Ce(f+8|0,16,w[(d+f|0)+29|0]),h));d=k+1|0;k=(d&255)==3?1:d}else{k=0}h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Zc(b,(w[m|0]<<8)+1468|0);e=1;while(1){c=(B(e,104)+a|0)+484380|0;if(v[c>>2]){Cg(Rc(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}gb=f+560|0;return o|0}function a_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-384|0;gb=f;vc(b);d=gb-32|0;gb=d;e=d+24|0;h=f+344|0;lE(e,h);k=yb(e);e=v[d+28>>2];g=v[d+24>>2];v[d+8>>2]=g;v[d+12>>2]=e;v[d>>2]=g;v[d+4>>2]=e;g=d+16|0;e=b;cc(g,e,d);g=yb(g);if((g|0)==(k|0)){Rb(e,yb(d+24|0))}gb=d+32|0;e=(g|0)==(k|0);if(!e){kE(h)}a:{b:{if(!e){break b}if(!yE(f+344|0)){break b}if(!Pb(b,Qc(xE(f+344|0),jb))){break b}c:{if(!c){break c}Hd(a,2097152);Ag(a);i=1;yh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);u[a+480190>>1]=w[f+378|0];if(w[f+381|0]<w[f+380|0]){bf(Sb(a+484360|0),w[f+381|0])}e=f+80|0;d=Tb(e,3576);Eb(a+1298304|0,d);vb(d);d=Tb(e,8337);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;jw(b,e);Ur(Sb(a+484360|0),e,w[f+380|0],65535,65535);if(x[a+480190>>1]){j=1;while(1){e=f+40|0;wE(b,e);l=gb-16|0;gb=l;g=(B(i,104)+a|0)+484380|0;ud(g,0);k=e;t[g+37|0]=w[e+22|0]<<4;t[l+15|0]=w[e+23|0];t[l+14|0]=64;n=g,o=w[ac(l+15|0,l+14|0)|0]<<2,u[n+30>>1]=o;t[g+36|0]=w[e+24|0];d=e+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e+33|0;d:{if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0<3){break d}m=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(m>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))}gb=l+16|0;d=f+8|0;Qk(d,2,e);e=f+24|0;Bc(e,d);v[22708]=0;Q(301,((i<<5)+a|0)+946304|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}vb(f+24|0);j=j+1|0;i=j&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Rb(b,B(64-w[f+378|0]|0,37));k=a+484344|0;zg(k,w[f+379|0]);if(w[f+379|0]){h=c&1;j=0;while(1){e:{f:{if(h){if(wh(k,j&65535,64)){break f}}Rb(b,2048);break e}e=_b(k,j);n=f,o=Vb(e),v[n+40>>2]=o;n=f,o=Zb(e),v[n+24>>2]=o;if(!Gb(f+40|0,f+24|0)){break e}while(1){e=v[f+40>>2];d=f+8|0;vn(d,b);i=qd(d);g=Ve(d);l=ej(d);d=w[d|0];if((d-1&255)>>>0<=106){t[e|0]=d+13}t[e+1|0]=w[i|0];t[e+3|0]=w[g|0];t[e+5|0]=w[l|0];Pf(e);e=f+40|0;ak(e);if(Gb(e,f+24|0)){continue}break}}j=j+1|0;if(j>>>0<w[f+379|0]){continue}break}}if(!(c&2)){break c}i=1;c=Rc(f+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){Cg(c,(B(i&65535,104)+a|0)+484380|0,b);i=i+1|0;if(x[a+480190>>1]>=(i&65535)>>>0){continue}break}}i=1}gb=f+384|0;return i|0}a=P()|0;O()|0;vb(f+24|0);S(a|0);L()}function rG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;g=gb-48|0;gb=g;o(+a);d=j(1)|0;f=j(0)|0;a:{b:{e=d;d=e;h=e&2147483647;c:{if(h>>>0<=1074752122){if((d&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;e=h>>>20|0;f=(e-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(f){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;f=e;o(+a);e=j(1)|0;j(0)|0;if((f-(e>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(h>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,f|0);l(1,e&1048575|1096810496);a=+n();d=0;f=1;while(1){m=(g+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=f&1;f=0;if(m){continue}break}A[g+32>>3]=a;e:{if(a!=0){d=2;break e}f=1;while(1){d=f;f=d-1|0;if(A[(g+16|0)+(d<<3)>>3]==0){continue}break}}d=LI(g+16|0,g,(h>>>20|0)-1046|0,d+1|0,1);a=A[g>>3];if((e|0)<-1?1:(e|0)<=-1){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}gb=g+48|0;return d}function i3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;n=Ox(g);o=ux(g);Ug(l,o);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22708]=0;g=Q(2503,n|0,g<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22708]=0;j=Q(2503,n|0,48)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=t[h+1|0];v[22708]=0;j=Q(2503,n|0,j|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=j;j=h+2|0;if(j>>>0>=c>>>0){g=j;break d}h=g+h|0;g=j;e:{while(1){i=t[g|0];v[22708]=0;k=ga(2477)|0;m=v[22708];v[22708]=0;if((m|0)==1){break e}v[22708]=0;i=Ex(i,k);k=v[22708];v[22708]=0;if((k|0)==1){break e}if(!i){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}j=g+h|0;g=h;while(1){i=t[g|0];v[22708]=0;ga(2477)|0;k=v[22708];v[22708]=0;if((k|0)==1){break a}v[22708]=0;i=Rh(i);k=v[22708];v[22708]=0;if((k|0)==1){break a}if(!i){break f}g=g+1|0;if((j|0)!=(g|0)){continue}break}g=j}j=h}g:{if(gd(l)){h=v[f>>2];v[22708]=0;Y(2493,n|0,j|0,g|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-j<<2);break g}nm(j,g);v[22708]=0;p=T(2491,o|0)|0;h=v[22708];v[22708]=0;h:{i:{if((h|0)!=1){if(g>>>0>j>>>0){break i}h=v[f>>2];break h}break a}h=j;i=0;k=0;j:{while(1){k:{if(t[pc(l,i)|0]<1){break k}if(t[pc(l,i)|0]!=(k|0)){break k}k=v[f>>2];v[f>>2]=k+4;v[k>>2]=p;i=(Ab(l)-1>>>0>i>>>0)+i|0;k=0}m=t[h|0];v[22708]=0;q=Q(2503,n|0,m|0)|0;m=v[22708];v[22708]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;k=k+1|0;h=h+1|0;if((h|0)==(g|0)){break j}continue}break}break a}h=m+4|0}qx((j-a<<2)+d|0,h)}l:{if(c>>>0<=g>>>0){h=v[f>>2];break l}while(1){h=w[g|0];if((h|0)==46){v[22708]=0;j=T(2494,o|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}i=v[f>>2];h=i+4|0;v[f>>2]=h;v[i>>2]=j;g=g+1|0;break l}v[22708]=0;j=Q(2503,n|0,h<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;g=g+1|0;if((g|0)!=(c|0)){continue}break}h=h+4|0;g=c}v[22708]=0;Y(2493,n|0,g|0,c|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g<<2)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function jba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-320|0;gb=d;e=gb-16|0;gb=e;v[a>>2]=0;f=a+32|0;Mt(f,32);t[e+15|0]=0;kq(f,e+15|0);gb=e+16|0;e=v[a+28>>2];a:{if(!_f(v[v[e>>2]-12>>2]+e|0)){uh(a,1073741825);break a}f=d+56|0;te(f,v[a+28>>2]);e=f;g=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=g;v[e>>2]=3;i=v[a+28>>2];h=d+16|0;j=h;g=0;if(v[e>>2]){while(1){Wh(i,g+j|0);g=g+1|0;if(g>>>0<y[f>>2]){continue}break}}if(sd(h,27248,3)){uh(a,1073741827);break a}g=0;t[d+319|0]=0;Wh(v[a+28>>2],d+319|0);Qb(d+56|0,0,256);e=w[d+319|0];b:{if(!e){f=d+56|0;break b}f=d+56|0;kl(v[a+28>>2],f,e);g=w[d+319|0]}e=b;b=oo(d+16|0,f,g);e=Ty(e,b);Hb(b);if(!e){uh(a,1073741830)}if(w[a+3|0]&64){break a}Wh(v[a+28>>2],d+55|0);e=w[d+55|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(Ej(e,6)){zl(a,9,1)}v[d+48>>2]=0;xL(v[a+28>>2],d+48|0);b=v[d+48>>2];t[d+47|0]=0;if(b>>>0>=2){Wh(v[a+28>>2],d+55|0);f=w[d+55|0];if(!f){Wh(v[a+28>>2],d+47|0);f=w[d+55|0]}vm(v[a+28>>2],b+(f&255?-1:-2)|0,-1)}v[d+32>>2]=0;v[d+36>>2]=0;c:{if(!Ej(e,4)){break c}yl(v[a+28>>2],d+32|0);b=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break c}uh(a,536871424)}if(Ej(e,5)){Wh(v[a+28>>2],d+55|0);vm(v[a+28>>2],w[d+55|0],-1)}d:{if(!Ej(w[d+47|0],0)){break d}Wh(v[a+28>>2],d+55|0);b=w[d+55|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break d}uh(a,536871168)}v[a+4>>2]=0;b=1;if(Ej(w[d+47|0],1)){xL(v[a+28>>2],a+4|0)}zl(a,6,Ej(e,2));zl(a,7,Ej(e,3));zl(a,5,x[a+16>>1]!=0);zl(a,8,Ej(e,7));e:{if(nd(a,5)){break e}if(nd(a,6)){break e}if(nd(a,7)){break e}b=nd(a,8)}zl(a,11,b);nd(a,11);b=w[d+47|0];if(Ej(b,2)){u[d+16>>1]=0;Ry(v[a+28>>2],d+16|0);vm(v[a+28>>2],B(x[d+16>>1],nd(a,9)?2:1),-1);b=w[d+47|0]}if(Ej(b,3)){vm(v[a+28>>2],5,-1)}yl(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){uh(a,1073741831);break a}v[a+92>>2]=b;if(!b){uh(a,536871040)}f:{if(!nd(a,11)){break f}yl(v[a+28>>2],d+32|0);b=v[d+36>>2];if((b|0)==2147483647|b>>>0<2147483647){break f}uh(a,1073741829);break a}te(d,v[a+28>>2]);TL(d+16|0,d,v[a+8>>2],v[a+12>>2]);b=v[d+28>>2];e=v[d+24>>2];if(!(b?0:(b|0)>0?1:(b|0)>=0)){uh(a,1073741832);break a}v[a+88>>2]=e;k=a,l=v[(nd(a,11)?d+32|0:a+88|0)>>2],v[k+64>>2]=l;if(!nd(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}zl(a,10,1)}gb=d+320|0}function WU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=ne(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=gb-16|0;gb=b;d=Qj(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<1){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[pd(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}h=c;d=(d|0)/32|0;c=d<<2;zh(h,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<1){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}ne(a,f);gb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=ne(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=gb-16|0;gb=f;d=Qj(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<1){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;d=f+8|0;b=v[pd(d,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;h=v[g+4>>2];j=v[v[e+24>>2]>>2];k=v[e+28>>2];v[f+8>>2]=b;h=32-h|0;v[f+4>>2]=h;l=Fb(d,f+4|0);i=v[g>>2];j=j&(-1<<k&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];k=h;h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>=1){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<1){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=pd(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<1){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}ne(a,g);gb=f+16|0}gb=e+80|0}function ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=gb-128|0;gb=c;f=gb-32|0;gb=f;d=f+24|0;h=b+16|0;EW(d,h);e=yb(d);d=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=d;v[f>>2]=g;v[f+4>>2]=d;d=a;g=f+16|0;cc(g,d,f);g=yb(g);if((g|0)==(e|0)){Rb(d,yb(f+24|0))}gb=f+32|0;if((e|0)!=(g|0)){Qb(h,0,128)}hX(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;d=c+80|0;Td(d,a,sg(a));f=jc(c+104|0,d);xb(d);v[22708]=0;d=T(467,f|0)|0;e=v[22708];v[22708]=0;a:{b:{if((e|0)==1){break b}v[22708]=0;e=b+4|0;R(440,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;Vd(c+72|0,e);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;d=v[c+76>>2];v[c+8>>2]=v[c+72>>2];v[c+12>>2]=d;U(633,c+80|0,f|0,c+8|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;d=T(192,a|0)|0;e=v[22708];v[22708]=0;c:{if((e|0)==1){break c}v[22708]=0;U(288,c+48|0,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=c+48|0;d=jc(c+80|0,a);xb(a);v[22708]=0;a=T(275,d|0)|0;e=v[22708];v[22708]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{v[22708]=0;a=Q(191,d|0,5)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}if(!a){break f}v[22708]=0;Q(634,d|0,c+44|0)|0;a=v[22708];v[22708]=0;h:{if((a|0)!=1){a=4;e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);if((e|0)==1414682436|(e|0)==1196380752){break h}v[22708]=0;a=T(192,d|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[22708]=0;U(288,c+24|0,d|0,a|0);a=v[22708];v[22708]=0;i:{j:{k:{if((a|0)!=1){e=c+24|0;a=jc(c+48|0,e);xb(e);if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1414682436){break k}v[22708]=0;i=C(Ba(635,a|0));a=v[22708];v[22708]=0;if((a|0)==1){break g}z[c+24>>2]=i;v[c+20>>2]=0;v[22708]=0;v[c+16>>2]=1065353216;a=Af(c+24|0,c+20|0,c+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break g}e=v[a>>2];z[b+144>>2]=z[a>>2];if(e+8388608&2130706432){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1196380752){break j}v[22708]=0;a=T(192,a|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}v[b+148>>2]=a}xb(c+48|0);continue}}break}a=P()|0;O()|0;xb(c+48|0);break d}xb(d);xb(f);gb=c+128|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}xb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}xb(f);S(a|0);L()}function s3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=gb-16|0;gb=l;m=wD(g);q=yx(g);Ug(l,q);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22708]=0;g=Q(22,m|0,g<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;h=a+1|0}g=c-h|0;d:{if(!(w[h|0]!=48|(g|0)<2|(w[h+1|0]|32)!=120)){v[22708]=0;i=Q(22,m|0,48)|0;j=v[22708];v[22708]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=t[h+1|0];v[22708]=0;i=Q(22,m|0,i|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break a}j=v[f>>2];v[f>>2]=j+1;t[j|0]=i;i=h+2|0;if(i>>>0>=c>>>0){g=i;break d}h=g+h|0;g=i;e:{while(1){j=t[g|0];v[22708]=0;k=ga(2477)|0;n=v[22708];v[22708]=0;if((n|0)==1){break e}v[22708]=0;j=Ex(j,k);k=v[22708];v[22708]=0;if((k|0)==1){break e}if(!j){break d}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h;break d}break a}f:{if(c>>>0<=h>>>0){g=h;break f}i=g+h|0;g=h;while(1){j=t[g|0];v[22708]=0;ga(2477)|0;k=v[22708];v[22708]=0;if((k|0)==1){break a}v[22708]=0;j=Rh(j);k=v[22708];v[22708]=0;if((k|0)==1){break a}if(!j){break f}g=g+1|0;if((i|0)!=(g|0)){continue}break}g=i}i=h}g:{if(gd(l)){h=v[f>>2];v[22708]=0;Y(2473,m|0,i|0,g|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break g}nm(i,g);v[22708]=0;j=T(2465,q|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}if(g>>>0>i>>>0){h=i;while(1){h:{if(t[pc(l,p)|0]<1){break h}if(t[pc(l,p)|0]!=(o|0)){break h}o=v[f>>2];v[f>>2]=o+1;t[o|0]=j;p=(Ab(l)-1>>>0>p>>>0)+p|0;o=0}k=t[h|0];v[22708]=0;k=Q(22,m|0,k|0)|0;n=v[22708];v[22708]=0;if((n|0)==1){break a}n=v[f>>2];v[f>>2]=n+1;t[n|0]=k;o=o+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}}nm((i-a|0)+d|0,v[f>>2])}i:{if(c>>>0<=g>>>0){break i}while(1){h=w[g|0];if((h|0)==46){v[22708]=0;h=T(2474,q|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;break i}v[22708]=0;h=Q(22,m|0,h<<24>>24)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=c}h=v[f>>2];v[22708]=0;Y(2473,m|0,g|0,c|0,h|0);h=v[22708];v[22708]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g|0)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;vb(l);gb=l+16|0;return}a=P()|0;O()|0;vb(l);S(a|0);L()}function Ipa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;a:{b:{c:{d:{i=a+24|0;e:{if(Dd(i)){break e}h=a+4|0;j=Ab(h);a=gb-48|0;gb=a;c=a+40|0;b=c;v[b>>2]=-1;v[b+4>>2]=-1;v[22708]=0;b=mG(2291);d=v[22708];v[22708]=0;if((d|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;g=a+16|0;d=g;k=b,l=oqa(v[d>>2],v[d+4>>2],1e3,0),v[k>>2]=l;v[b+4>>2]=jb;d=Xl(b+8|0,b);f=v[d+4>>2];gb=b+16|0;v[a+24>>2]=v[d>>2];v[a+28>>2]=f;d=a+24|0;b=d;b=NC(v[b>>2],v[b+4>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;iX(c,d,wb(d));v[22708]=0;b=mG(2292);f=v[22708];v[22708]=0;if((f|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;f=v[g+4>>2];v[b>>2]=v[g>>2];v[b+4>>2]=f;g=Xl(b+8|0,b);f=v[g+4>>2];gb=b+16|0;v[a+24>>2]=v[g>>2];v[a+28>>2]=f;b=NC(v[d>>2],v[d+4>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;iX(c,d,wb(d));d=v[c>>2];c=v[c+4>>2];gb=a+48|0;if(j){b=mc(e+32|0);v[22708]=0;v[e+16>>2]=c;R(40,b|0,e+16|0);a=v[22708];v[22708]=0;f:{g:{h:{if((a|0)!=1){v[22708]=0;v[e+16>>2]=d;R(40,b|0,e+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}if(Ab(h)){a=0;while(1){c=w[pc(h,a)|0];v[22708]=0;v[e+16>>2]=c;R(40,b|0,e+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}a=a+1|0;if(Ab(h)>>>0>a>>>0){continue}break}}a=Vb(b);c=Zb(b);v[22708]=0;c=W(41,e+16|0,a|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;a=T(42,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}v[e+8>>2]=a;a=e+8|0;TC(i,a);kn(a);Lc(c);Lc(b);break e}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Lc(c);break b}jb=d;v[e+16>>2]=c;v[e+20>>2]=jb;b=e+32|0;a=mc(b);v[22708]=0;U(49,b|0,e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){b=P()|0;O()|0;Lc(a);S(b|0);L()}v[22708]=0;a=T(42,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[e+8>>2]=a;a=e+8|0;TC(i,a);kn(a);Lc(b)}gb=e+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(b);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-48|0;gb=l;f=v[a+4>>2];e=ne(l+40|0,b);j=ne(l+32|0,c);d=gb-16|0;gb=d;e=VU(ne(d+8|0,e),ne(d,j));gb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!f){e=d-1|0;break b}e=d-1|0;if((e^f-1)>>>0<32){break a}}v[v[a>>2]+((d>>>0<33?0:e>>>5|0)<<2)>>2]=0}d=ne(l+24|0,b);g=ne(l+16|0,c);c=l+8|0;yp(c,a,f);b=l;j=gb-48|0;gb=j;c:{if(v[d+4>>2]==v[c+4>>2]){d=ne(j+40|0,d);e=ne(j+32|0,g);f=ne(j+24|0,c);a=gb-16|0;gb=a;c=Qj(e,d);v[a+12>>2]=c;d:{if((c|0)<1){break d}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[pd(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;zh(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<1){break d}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];i=d;n=v[d>>2];d=-1>>>32-e|0;v[i>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}ne(b,f);gb=a+16|0;break c}e=ne(j+16|0,d);a=ne(j+8|0,g);d=ne(j,c);f=gb-16|0;gb=f;a=Qj(a,e);v[f+12>>2]=a;e:{if((a|0)<1){break e}c=v[e+4>>2];f:{if(!c){c=v[d+4>>2];break f}c=32-c|0;v[f+8>>2]=c;g=f+8|0;a=v[pd(g,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;h=v[d+4>>2];k=v[v[e>>2]>>2];i=v[e+4>>2];v[f+8>>2]=a;m=32-h|0;v[f+4>>2]=m;n=Fb(g,f+4|0);h=v[d>>2];k=k&(-1<<i&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];i=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=i|v[h>>2]&(-1<<c&-1>>>m-g^-1);i=c+g|0;c=i&31;v[d+4>>2]=c;h=h+(i>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>=1){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;i=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=i&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<1){break e}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=pd(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];i=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=i|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<1){break e}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}ne(b,d);gb=f+16|0}gb=j+48|0;gb=l+48|0}function U7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-160|0;gb=d;a:{if(qk(b)){break a}e=w[ul(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Jl(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}f=d+128|0;Ld(f);e=v[d+128>>2];Ld(d+112|0);e=tl(e,v[d+116>>2],b);Ld(f);b:{c:{d:{e:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=uc(d+144|0,18720);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Gc(d+8|0,d)){a=ba(8)|0;v[22708]=0;c=Q(70,d+128|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;f=0;if(!c){break e}c=ba(8)|0;v[22708]=0;e=Q(2058,d+112|0,b|0)|0;a=v[22708];v[22708]=0;f:{g:{h:{if((a|0)!=1){v[22708]=0;U(2038,d+128|0,14758,e|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}rc(c,d+128|0);a=0;v[22708]=0;U(186,c|0,54936,1937);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+128|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e);if(!a){break c}}da(c|0);break c}if(v[e+4>>2]!=1){a=ba(8)|0;v[22708]=0;c=Q(70,d+128|0,8874)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,18720);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Gc(d+56|0,d+48|0)){a=ba(8)|0;v[22708]=0;c=Q(70,d+128|0,7752)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=uc(d+80|0,8207);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Gc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break e}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=uc(d- -64|0,5758);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Gc(d+24|0,d+16|0)){break e}e=Gy(v[a+32>>2]);f=0}gb=d+160|0;jb=f;return e|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function nR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-96|0;gb=g;t[g+95|0]=d;n=SA(a);o=Si(n);u[b>>1]=0;a:{if(o){while(1){b:{if(!No(n,h&65535)){break b}h=x[b>>1];if(Ec(a)>>>0<=h>>>0){v[c>>2]=0;a=1;break a}m=Ad(a,x[b>>1]);Ak(g+72|0,m);Sl(g- -64|0,m);h=v[g+76>>2];v[g+32>>2]=v[g+72>>2];v[g+36>>2]=h;h=v[g+68>>2];v[g+24>>2]=v[g+64>>2];v[g+28>>2]=h;l=g+80|0;e=g+32|0;j=g+24|0;h=gb-32|0;gb=h;c:{if(w[g+95|0]){f=v[e+4>>2];v[h+24>>2]=v[e>>2];v[h+28>>2]=f;e=Qj(j,e);j=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=j;j=gb-16|0;gb=j;v[j+12>>2]=e;i=h+8|0;f=v[i+4>>2];d:{if(f){v[j+8>>2]=32-f;e=Fb(j+8|0,j+12|0);k=v[i>>2];e=v[e>>2];f=v[k>>2]&(-1<<f&-1>>>v[j+8>>2]-e);if(f){td(l,k,nqa(f));break d}f=v[j+12>>2];if((f|0)==(e|0)){ZQ(l,i,e);break d}e=f-e|0;v[j+12>>2]=e;v[i>>2]=k+4}if(e>>>0>=32){f=v[i>>2];while(1){k=v[f>>2];if(k){td(l,f,nqa(k));break d}f=f+4|0;v[i>>2]=f;e=e-32|0;v[j+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){f=v[i>>2];break e}f=v[i>>2];i=v[f>>2]&-1>>>32-e;if(!i){break e}td(l,f,nqa(i));break d}td(l,f,e)}gb=j+16|0;break c}f=v[e+4>>2];v[h+16>>2]=v[e>>2];v[h+20>>2]=f;e=Qj(j,e);j=v[h+20>>2];v[h>>2]=v[h+16>>2];v[h+4>>2]=j;f=gb-16|0;gb=f;v[f+12>>2]=e;j=h;i=v[h+4>>2];f:{if(i){v[f+8>>2]=32-i;e=v[Fb(f+8|0,f+12|0)>>2];k=-1<<i&-1>>>v[f+8>>2]-e;i=v[j>>2];k=k&(v[i>>2]^-1);if(k){td(l,i,nqa(k));break f}k=v[f+12>>2];if((k|0)==(e|0)){ZQ(l,j,e);break f}e=k-e|0;v[f+12>>2]=e;v[j>>2]=i+4}if(e>>>0>=32){i=v[j>>2];while(1){k=v[i>>2];if((k|0)!=-1){td(l,i,nqa(k^-1));break f}i=i+4|0;v[j>>2]=i;e=e-32|0;v[f+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){i=v[j>>2];break g}i=v[j>>2];j=(v[i>>2]^-1)&-1>>>32-e;if(!j){break g}td(l,i,nqa(j));break f}td(l,i,e)}gb=f+16|0}gb=h+32|0;if(d){h=g+56|0;Sl(h,m);if(!mR(g+80|0,h)){break b}v[c>>2]=0;a=1;break a}h=g+56|0;Sl(h,m);if(mR(g+80|0,h)^1){Ak(g+48|0,m);a=v[g+84>>2];b=v[g+80>>2];v[g+40>>2]=b;v[g+44>>2]=a;d=v[g+52>>2];v[g+16>>2]=v[g+48>>2];v[g+20>>2]=d;v[g+8>>2]=b;v[g+12>>2]=a;p=c,q=BU(g+16|0,g+8|0),v[p>>2]=q;a=1;break a}if(y[m+4>>2]>=y[_b(v[a+24>>2]+484344|0,x[sc(n,x[b>>1])>>1])+12>>2]){break b}v[c>>2]=v[m+4>>2];a=1;break a}h=x[b>>1]+1|0;u[b>>1]=h;if((h&65535)>>>0<o>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}gb=g+96|0;return a|0}function Uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-1184|0;gb=d;vc(b);a:{if(!Xw(b,d+1160|0)){break a}if(!LN(d+1160|0)){break a}e=d+1168|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(jm(b)|0)){break a}f=d+1176|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))!=(mf(b)|0)){break a}if(!c){g=1;break a}e=d+1104|0;Qb(e,0,56);i=-2;b:{if(!e){break b}v[e+44>>2]=0;v[e+48>>2]=0;v[e+52>>2]=0;v[e+20>>2]=0;v[e+24>>2]=0;v[e+8>>2]=0;h=v[e+32>>2];if(!h){v[e+32>>2]=2282;h=2282}if(!v[e+36>>2]){v[e+36>>2]=2283}h=kb[h|0](v[e+40>>2],1,43784)|0;i=-4;if(!h){break b}v[e+28>>2]=h;v[h+43780>>2]=1;v[h+10992>>2]=0;v[h+10996>>2]=0;v[h>>2]=0;v[h+11008>>2]=15;v[h+11e3>>2]=1;v[h+11004>>2]=0;i=0}if(i){break a}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+1100>>2]=e;g=d+1180|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=(g|0)!=0;h=qX(d+1088|0,g);c:{d:{e:{f:{g:{h:{i:{j:{if(!e|!g){break j}while(1){v[22708]=0;v[d+48>>2]=1024;e=Fb(d+48|0,d+1100|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}e=v[e>>2];f=vd(d+56|0,d- -64|0,e);v[22708]=0;i=v[f+4>>2];v[d+24>>2]=v[f>>2];v[d+28>>2]=i;U(201,d+48|0,b|0,d+24|0);f=v[22708];v[22708]=0;if((f|0)==1){break h}v[22708]=0;j=pJ(j,d- -64|0,e);f=v[22708];v[22708]=0;if((f|0)==1){break i}v[d+1120>>2]=g;v[d+1108>>2]=e;v[d+1104>>2]=d- -64;f=v[h>>2];v[22708]=0;v[d+1116>>2]=f+k;l=Q(1470,d+1104|0,0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}i=v[d+1100>>2]-e|0;v[d+1100>>2]=i;e=v[d+1120>>2];f=(e|0)!=0;if(!i|!e){break j}k=(g+k|0)-e|0;g=e;if((l|0)!=1){continue}break}}v[22708]=0;T(1471,d+1104|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}g=0;b=d+1172|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(j|0)|f|(l|0)!=1)){v[22708]=0;Vd(d+40|0,h);b=v[22708];v[22708]=0;if((b|0)==1){break f}b=Ud(d+32|0);v[22708]=0;g=v[d+44>>2];v[d+16>>2]=v[d+40>>2];v[d+20>>2]=g;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=W(732,d- -64|0,d+16|0,d+8|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[22708]=0;g=W(1384,a|0,b|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}xb(b)}gc(h);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;xb(b);break c}a=P()|0;O()|0}gc(h);S(a|0);L()}gb=d+1184|0;return g|0}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;v[22708]=0;e=T(788,a|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){a:{b:{if(e){break b}v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}i=Fd(e+1|0,1,1024);v[22708]=0;k=d+484344|0;e=W(331,k|0,b|0,i|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}if(!e){break b}d=x[d+480188>>1];if(!d|!i){break b}l=d-1|0;while(1){v[22708]=0;d=Q(191,a|0,1)|0;e=v[22708];v[22708]=0;c:{d:{if((e|0)!=1){if(!d){break b}v[22708]=0;g=T(374,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}if(g){break d}j=j+1|0;break c}break a}d=_b(k,b);u[h+14>>1]=g&31;v[22708]=0;u[h+12>>1]=l;e=Pc(h+14|0,h+12|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}e=x[e>>1];v[22708]=0;d=Xc(d,j,e);e=v[22708];v[22708]=0;if((e|0)==1){break a}if(!(g&224)){break c}e:{if(!(g&128)){break e}v[22708]=0;e=T(374,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[d+5|0]=e;v[22708]=0;e=T(374,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}f:{if(e>>>0>=26){break f}e=w[e+49024|0];t[d+3|0]=e;g:{switch(e-1|0){case 0:if(!w[d+5|0]){break f}break e;case 12:if(w[d+2|0]){break e}t[d+2|0]=1;e=Fd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break e}t[d+5|0]=e;break e;case 8:e=w[d+5|0];if(e>>>0<=128){n=d,o=ei(e<<1),t[n+5|0]=o;break e}if((e|0)!=164){break e}t[d+5|0]=145;t[d+3|0]=20;break e;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:v[22708]=0;Yt(d);e=v[22708];v[22708]=0;if((e|0)!=1){break e}break a;case 16:if(w[d+5|0]>31){break e}t[d+3|0]=16;break e;case 27:break g;default:break e}}m=d;e=w[d+5|0];f=e&240;h:{if((f|0)==16){f=2}else{if((f|0)!=32){break h}f=3}t[m+3|0]=f}t[d+5|0]=e&15|224;break e}t[d+3|0]=0}i:{if(!(g&64)){break i}v[22708]=0;R(403,h+8|0,a|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}e=h+8|0;f=qd(e);t[d+1|0]=w[e|0];e=w[f|0];t[d|0]=e;f=255;if((e|0)!=128){f=253;if(e>>>0<129){break i}}t[d|0]=f}if(!(g&32)){break c}t[d+2|0]=1;v[22708]=0;e=T(374,a|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}t[d+4|0]=e;if(!c){break c}t[d+4|0]=(e<<6>>>0)/127}if(i>>>0>j>>>0){continue}break}}xb(a);gb=h+16|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function S7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;a:{if(qk(c)){break a}f=w[ul(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Jl(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}f=e+128|0;Ld(f);g=v[e+128>>2];Ld(e+112|0);h=tl(g,v[e+116>>2],c);Ld(f);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=uc(e+144|0,18720);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Gc(e+8|0,e)){a=ba(8)|0;v[22708]=0;b=Q(70,e+128|0,7752)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(d){a=ba(8)|0;v[22708]=0;b=Q(2058,e+112|0,c|0)|0;c=v[22708];v[22708]=0;f:{g:{h:{if((c|0)!=1){v[22708]=0;U(2038,e+128|0,14758,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}rc(a,e+128|0);d=0;v[22708]=0;U(186,a|0,54936,1937);c=v[22708];v[22708]=0;if((c|0)!=1){break b}c=P()|0;O()|0;vb(e+128|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}vb(b);if(!d){break c}}da(a|0);break c}Kb(a);break e}v[e+104>>2]=f;v[e+108>>2]=g;d=uc(e+96|0,18720);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Gc(e+56|0,e+48|0)){a=ba(8)|0;v[22708]=0;b=Q(70,e+128|0,7752)|0;c=v[22708];v[22708]=0;if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}c=P()|0;O()|0;da(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=uc(e+80|0,9591);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Gc(e+40|0,e+32|0)){i:{switch(v[b+52>>2]){case 0:Tb(a,2693);break e;case 1:Tb(a,8575);break e;case 2:Tb(a,6363);break e;default:break i}}Kb(a);break e}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=uc(e- -64|0,8812);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Gc(e+24|0,e+16|0)){j:{switch(v[b+56>>2]){case 0:Tb(a,12683);break e;case 1:Tb(a,12688);break e;case 2:Tb(a,9896);break e;case 3:Tb(a,6427);break e;default:break j}}Kb(a);break e}Kb(a)}gb=e+160|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function wZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=gb-32|0;gb=f;j=bj(f+24|0);if(v[a+12>>2]){q=b^1;r=j+3|0;s=j+5|0;x=j+4|0;z=j+2|0;A=j+1|0;d=f+16|0;C=d|5;D=d|3;while(1){E=Uf(a,n);while(1){a:{if(!Pb(c,1)){break a}k=Be(c);if((k|0)==255){break a}h=k&31;d=Ki(a)>>>0>h>>>0;h=B(h,6)+E|0;if(k&64){l=1}else{e=Be(c);i=e<<24>>24;g=255;b:{c:{d:{e=e&127;switch(e|0){case 0:break b;case 1:break c;default:break d}}if(!(e>>>0>121|q)){g=e-1|0;break c}if((e-12&255)>>>0>96|b){break b}g=e+13|0}t[(d?h:f+24|0)|0]=g}F=d?h+1|0:A,G=Be(c),t[F|0]=G;l=(i|0)<0}if(l){p=d?h:j;g=d?h+3|0:r;e=d?h+5|0:s;o=d?h+4|0:x;m=d?h+2|0:z;h=d?h:f+24|0;while(1){d=h;v[f+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[f+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=Be(c);l=d&128;i=d&63;e:{if(d&64){t[m|0]=1;t[o|0]=i;break e}d=Be(c);t[e|0]=d;f:{g:{if(i>>>0<=15){t[g|0]=i;Pf(p);h:{i:{j:{d=w[g|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[e|0]=B(w[e|0]&15,17);break f}t[g|0]=0;t[m|0]=1;v[f+12>>2]=w[e|0]+1>>>1;v[f+8>>2]=64;F=o,G=v[pd(f+12|0,f+8|0)>>2],t[F|0]=G;break f}if((d|0)!=19){break f}if(w[e|0]==128){break g}Yt(p);break f}if(i>>>0>44){break f}t[g|0]=w[i+28448|0];k:{switch(i-16|0){case 0:if(d>>>0>1){break g}t[e|0]=d|158;break f;case 1:case 2:t[f+12|0]=15;F=e,G=w[ac(f+12|0,e)|0]|224,t[F|0]=G;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=d+1;F=e,G=v[pd(f+12|0,f+8|0)>>2]/2|240,t[F|0]=G;break f;case 14:l:{m:{n:{o:{p:{i=d>>>4|0;switch(i-1|0){case 1:break n;case 0:break o;default:break p}}switch(i-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[e|0]=d|240;break f}t[g|0]=3;t[e|0]=d|240;break f}t[g|0]=11;t[e|0]=(d<<3&120)+8|15;break f}t[g|0]=11;t[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=d+1>>>1;v[f+8>>2]=64;F=e,G=v[pd(f+12|0,f+8|0)>>2],t[F|0]=G;break f}t[g|0]=0}pz(g,e,D,C);if(to(w[f+19|0])>>>0<=to(w[g|0])>>>0){break e}q:{if(w[m|0]){break q}if(!qz(g,e,1)){break q}t[m|0]=w[g|0];t[o|0]=w[e|0]}t[g|0]=w[f+19|0];t[e|0]=w[f+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}gb=f+32|0}function s9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);v[22708]=0;X(2028);c=v[22708];v[22708]=0;a:{b:{if((c|0)==1){c=Sa(54936,89104,89080,0)|0;c:{d:{e:{d=O()|0;if((d|0)==(ea(54936)|0)){c=Z(c|0)|0;v[22708]=0;Q(1918,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Q(1918,a|0,14858)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Q(1918,a|0,14834)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22708]=0;Q(1918,a|0,(b?b:18720)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(89104)|0)==(d|0)){c=Z(c|0)|0;v[22708]=0;Q(1918,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;Q(1918,a|0,14858)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;Q(1918,a|0,14809)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22708]=0;Q(1918,a|0,(b?b:18720)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(89080)|0;c=Z(c|0)|0;g:{if((d|0)==(e|0)){v[22708]=0;Q(1918,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;Q(1918,a|0,14858)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;Q(1918,a|0,14825)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22708]=0;Q(1918,a|0,(b?b:18720)|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[22708]=0;Q(1918,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(1918,a|0,14858)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;Q(1918,a|0,11034)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Bb()}L()}return}vb(a);S(b|0);L()}function upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=gb-1120|0;gb=d;v[d+1116>>2]=c;j=lD(d+56|0,b);v[22708]=0;p=mn(j);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){f=mc(a);v[22708]=0;a=T(467,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break h}v[d+16>>2]=a;v[22708]=0;v[d+48>>2]=85899345;a=Fb(d+16|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}a=v[a>>2];v[22708]=0;v[d+32>>2]=B(a,50);a=Fb(d+1116|0,d+32|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}a=v[a>>2];v[22708]=0;R(499,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}v[22708]=0;e=T(512,d+32|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}a=0;v[22708]=0;g=Q(513,d+16|0,8192)|0;c=v[22708];v[22708]=0;if((c|0)==1){break e}while(1){s=Lb(e,a),z=8192,u[s>>1]=z;s=Lb(e,a),z=a,t[s+2|0]=z;a=a+1|0;if((a|0)!=256){continue}break}m=9;break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}i:{j:while(1){c=0;n=257;while(1){q=m&255;k:{while(1){i=n&65535;while(1){v[22708]=0;h=Q(200,j|0,q|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}k=h&65535;if((k|0)==257|i>>>0<k>>>0){break k}if(oc(f)>>>0>=y[d+1116>>2]){break k}if((k|0)==256){m=9;continue j}a=i>>>0>k>>>0?h:c;l=8192;while(1){a=a&65535;r=w[Lb(e,a)+2|0];l=l-1|0;o=l&65535;s=kc(g,o),z=r,t[s|0]=z;a=x[Lb(e,a)>>1];if(a>>>0<8192){continue}break}s=d,z=Zb(f),v[s+48>>2]=z;Gd(d+8|0,d+48|0);s=d,z=Vb(g),v[s>>2]=z;a=xe(d,o);l=Zb(g);v[22708]=0;Y(500,f|0,v[d+8>>2],a|0,l|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}l:{if((i|0)!=(k|0)){break l}a=kc(g,o);v[22708]=0;R(514,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break l}break i}if(i>>>0>=8192){c=h;continue}if(oc(f)>>>0>=y[d+1116>>2]){continue}break}a=kc(g,o);s=Lb(e,i),z=w[a|0],t[s+2|0]=z;s=Lb(e,i),z=c,u[s>>1]=z;a=n+1|0;n=8192;c=h;h=a&65535;if((h|0)==8192){continue}break}m=((h|0)==1<<q)+m|0;n=a;continue}break}break}v[22708]=0;a=mn(j);c=v[22708];v[22708]=0;m:{if((c|0)!=1){v[22708]=0;Q(190,b|0,((a-p|0)+3&-4)+p|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break m}}break i}gc(g);fD(e);xb(j);gb=d+1120|0;return}a=P()|0;O()|0;gc(g)}fD(e)}gc(f)}xb(j);S(a|0);L()}function Au(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-48|0;gb=f;v[f+32>>2]=c;u[f+38>>1]=b;i=SA(a);a:{if(tc(i)>>>0<=b>>>0){break a}if(vR(a,x[sc(i,b)>>1])>>>0<=c>>>0){break a}b:{if(Ec(a)>>>0>b>>>0){if(y[Ad(a,b)+4>>2]>c>>>0){break b}}Io(a,0);if(Ec(a)>>>0<=b>>>0){break a}}g=x[v[a+24>>2]+480188>>1];c=f+16|0;b=v[d>>2];v[c>>2]=b;v[c+4>>2]=b+B(g,872);d=f+24|0;b=d;v[b>>2]=-2078137563;v[b+4>>2]=-873292572;g=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;b=c;if(xR(b)){while(1){e=w[MT(b,h)+841|0];l=e^oqa(g^h,i^j,435,256);e=!e;g=(o=g,p=oqa(l,jb,435,256),q=e,q?o:p);i=e?i:jb;e=h+1|0;j=e>>>0<1?j+1|0:j;h=e;if(!j&xR(b)>>>0>e>>>0){continue}break}}v[d>>2]=g;v[d+4>>2]=i;i=Sm(c,f+38|0,f+32|0);j=gb-16|0;gb=j;e=j+8|0;h=gb-16|0;gb=h;l=a+12|0;g=l;b=Yd(g);m=eR(g,i,b,fc(g));v[h+8>>2]=m;o=h,p=Dh(g),v[o>>2]=p;c:{if(Gb(h+8|0,h)){if(!Ml(wb(g),i,ve(h+8|0))){break c}}m=Dh(g)}gb=h+16|0;b=v[yc(e,m)>>2];gb=j+16|0;v[f+8>>2]=b;o=f,p=Eh(l),v[o+16>>2]=p;b=0;if(og(f+8|0,c)){b=cd(ve(f+8|0)+8|0)^1}h=v[d>>2]!=-2078137563|v[d+4>>2]!=-873292572;c=f+16|0;re(c,Ad(a,x[f+38>>1]),v[f+32>>2]);m=1;i=b|h;j=Cb(c)^1;if(!(j?1:i)){break a}if(b){g=ve(f+8|0)+8|0;n=Vb(g);e=Zb(g);c=d;k=gb-16|0;gb=k;v[k>>2]=e;v[k+8>>2]=n;if(Gb(k+8|0,k)){while(1){e=v[k+8>>2];if(v[e>>2]!=v[c>>2]|v[e+4>>2]!=v[c+4>>2]){e=k+8|0;Bu(e);if(Gb(e,k)){continue}}break}n=v[k+8>>2]}gb=k+16|0;v[f+16>>2]=n;o=f,p=Zb(g),v[o+40>>2]=p;if(Gb(f+16|0,f+40|0)){break a}}if(h){v[a+28>>2]=v[a+28>>2]+1}if(i){if(!(b|j)){d:{e=oR(l,Sm(f+16|0,f+38|0,f+32|0));if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=aR(b,e);wb(e);$Q(v[c+4>>2]);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break d}c=gb-32|0;gb=c;b=wb(e);b=RA(c+8|0,gs(e,rf(e)+1|0),rf(e),b);$Q(v[b+8>>2]);v[b+8>>2]=v[b+8>>2]+8;QA(e,b);PA(b);gb=c+32|0}}e=oR(l,Sm(f+16|0,f+38|0,f+32|0));e:{if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=aR(b,e);wb(e);_Q(v[c+4>>2],d);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break e}c=gb-32|0;gb=c;b=wb(e);b=RA(c+8|0,gs(e,rf(e)+1|0),rf(e),b);_Q(v[b+8>>2],d);v[b+8>>2]=v[b+8>>2]+8;QA(e,b);PA(b);gb=c+32|0}}b=f+16|0;re(b,Ad(a,x[f+38>>1]),v[f+32>>2]);Df(b,1);m=0}gb=f+48|0;return m|0}function P9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{k=Wp(1,32);d:{e:{if(!k){a=ba(4)|0;lm(a);v[22708]=0;U(186,a|0,89104,1929);a=v[22708];v[22708]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1920;d=zu(j- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,j+48|0,c|0)|0;f=v[22708];v[22708]=0;i:{if((f|0)!=1){v[22708]=0;f=Q(1930,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break i}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22708]=0;c=Q(70,j+48|0,c|0)|0;e=v[22708];v[22708]=0;j:{if((e|0)!=1){v[22708]=0;R(1931,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22708]=0;a=T(1290,96)|0;i=v[22708];v[22708]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22708]=0;b=Q(1932,k|0,k+4|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break m}v[j+48>>2]=b;b=v[jq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22708]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;ca(2006,a|0,j+8|0,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break l}v[k+28>>2]=a;Dj(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Kl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Dj(j+48|0)}Xb(a)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1912,8630,k|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){a=v[k+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Xb(a);v[k+20>>2]=0}Xb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}Z(i|0)|0;k=0;v[22708]=0;Y(1912,8630,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=j+80|0;return k|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=d;k=fg(a,c);te(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}f=v[h+24>>2];d=gb-160|0;gb=d;i=Fm(d+56|0,v[a+28>>2]);v[22708]=0;g=Q(620,d+40|0,34104)|0;e=v[22708];v[22708]=0;b:{c:{d:{e:{if((e|0)!=1){v[22708]=0;v[d+24>>2]=19923024;v[d+28>>2]=0;U(621,i|0,g|0,d+24|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}Hb(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}t[d+39|0]=0;v[22708]=0;g=Q(620,d+40|0,2597)|0;e=v[22708];v[22708]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[22708]=0;W(622,i|0,d+39|0,g|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break q}Hb(g);g=Kb(d+40|0);v[22708]=0;e=Q(620,d+24|0,7364)|0;j=v[22708];v[22708]=0;if((j|0)==1){break p}v[22708]=0;U(1091,i|0,g|0,e|0);j=v[22708];v[22708]=0;if((j|0)==1){break o}Hb(e);v[22708]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break n}v[22708]=0;R(418,b|0,d+24|0);e=v[22708];v[22708]=0;if((e|0)==1){break m}e=d+24|0;vb(e);u[d+22>>1]=0;v[22708]=0;e=Q(620,e|0,8041)|0;f=v[22708];v[22708]=0;if((f|0)==1){break g}v[22708]=0;W(1092,i|0,d+22|0,e|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break l}Hb(e);yg(d+22|0,4e3);v[22708]=0;e=Q(620,d+24|0,10743)|0;f=v[22708];v[22708]=0;if((f|0)==1){break k}f=v[yc(d+16|0,x[d+22>>1])>>2];v[22708]=0;Y(1093,i|0,b|0,e|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}Hb(e);u[d+14>>1]=65535;v[22708]=0;e=Q(620,d+24|0,6095)|0;f=v[22708];v[22708]=0;if((f|0)==1){break i}v[22708]=0;f=W(1092,i|0,d+14|0,e|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Hb(e);if(!((f|0)==1|j>>>0<=l>>>0)){bf(b,x[d+14>>1])}vb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+24|0);break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0}vb(g)}gh(i);S(a|0);L()}gh(i);gb=d+160|0}Zf(a,k,c,h+16|0);gb=h+32|0}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=lg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Jd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Mb(q,-16777216,16776704);p=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=oqa(l,s,f,f>>31);l=jb;p=oqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Uy(a){a=a|0;var b=0,c=0,d=C(0),e=0;Qb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[22708]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ha(1839,e|0,67,5,c|0,b|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[22708]=0;ha(1839,a+4528|0,62,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[22708]=0;ha(1839,a+4552|0,53,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[22708]=0;ha(1839,a+4576|0,43,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[22708]=0;ha(1839,a+4600|0,32,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[22708]=0;ha(1839,a+4624|0,22,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[22708]=0;ha(1839,a+4648|0,75,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[22708]=0;ha(1839,a+4672|0,69,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[22708]=0;ha(1839,a+4696|0,60,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[22708]=0;ha(1839,a+4720|0,48,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[22708]=0;ha(1839,a+4744|0,36,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[22708]=0;ha(1839,a+4768|0,25,5,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1839,a+4792|0,0,0,0,0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[22708]=0;ha(1839,a+4816|0,3,0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[22708]=0;ha(1839,a+4840|0,3,0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1839,a+4864|0,407,1,c|0,0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1839,a+4888|0,400,1,c|0,0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1839,a+4912|0,10,0,c|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;ha(1839,a+4936|0,10,0,c|0,-1);c=v[22708];v[22708]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(89104)|0;if((O()|0)==(ea(89104)|0)){Z(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=C(0),k=0,l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,t=0,u=0,x=C(0),y=0,A=0,B=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=C(0);a:{if(!v[a+4316>>2]){break a}k=a+44|0;if(!ni(k)){break a}p=Nd(k,0);q=Nd(k,1);r=od(k,0);s=od(k,1);H=kb[v[v[a>>2]+192>>2]](a)|0;e=C(kb[v[v[a>>2]+200>>2]](a));B=C(kb[v[v[a>>2]+188>>2]](a));t=kb[v[v[a>>2]+212>>2]](a)|0;b:{if(!d){break b}u=a+4276|0;l=a+4264|0;h=w[a+4260|0];E=h?u:l;F=a+4300|0;G=a+4288|0;x=C(e/C(100));I=t&1;m=v[a+4256>>2];n=v[a+4312>>2];y=d;while(1){j=z[q>>2];i=z[p>>2];f=po(a,m+n|0);m=po(a,n);c:{if(h){n=v[a+4328>>2];J=yf(G,n),K=i,z[J>>2]=K;J=yf(F,n),K=j,z[J>>2]=K;e=z[Lb(l,f)>>2];J=Lb(l,m),K=C(i+C(x*e)),z[J>>2]=K;e=C(j+C(x*z[Lb(u,f)>>2]));h=u;break c}e=C(C(C(i+j)*C(.5))+C(x*z[Lb(l,f)>>2]));h=l}J=Lb(h,m),K=e,z[J>>2]=K;d:{if(H){g=z[a+4244>>2];e=C(g+z[a+4236>>2]);z[a+4236>>2]=e;g=C(g+z[a+4240>>2]);z[a+4240>>2]=g;if(e>C(1)){e=C(e+C(-2));z[a+4236>>2]=e}if(g>C(1)){z[a+4240>>2]=g+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));g=C(D(z[a+4240>>2]));g=C(C(g+g)+C(-1));break d}g=z[a+4240>>2];o=z[a+4244>>2];e=C(C(g*o)+z[a+4236>>2]);z[a+4236>>2]=e;g=C(g-C(o*e));z[a+4240>>2]=g}if(w[a+4260|0]){f=(v[a+4328>>2]+2|0)%3|0;i=z[yf(G,f)>>2];j=z[yf(F,f)>>2]}o=z[Lb(l,po(a,v[a+4320>>2]+v[a+4312>>2]|0))>>2];J=r,K=C(i+C(B*C(C(o+C(C(z[Lb(l,po(a,(v[a+4312>>2]+v[a+4320>>2]|0)+4096|0))>>2]-o)*C(C(v[a+4320>>2]&4095)*C(.000244140625))))-i))),z[J>>2]=K;i=z[Lb(E,po(a,v[a+4324>>2]+v[a+4312>>2]|0))>>2];J=s,K=C(j+C(B*C(C(i+C(C(z[Lb(E,po(a,(v[a+4312>>2]+v[a+4324>>2]|0)+4096|0))>>2]-i)*C(C(v[a+4324>>2]&4095)*C(.000244140625))))-j))),z[J>>2]=K;f=v[a+4328>>2];v[a+4328>>2]=((f|0)<1?f+3|0:f)-1;f=v[a+4312>>2];n=(((f|0)>0?0:v[a+4316>>2]<<12)+f|0)-4096|0;v[a+4312>>2]=n;A=a;m=v[a+4256>>2];f=m;j=z[a+4248>>2];i=C((I?g:e)*j);e:{if(C(D(i))<C(2147483648)){h=~~i;break e}h=-2147483648}v[A+4324>>2]=f+(t>>>0>1?h:0-h|0);f=t>>>0<4;A=a;e=C(e*j);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[A+4320>>2]=(f?h:0-h|0)+m;y=y-1|0;if(!y){break b}q=q+4|0;p=p+4|0;r=r+4|0;s=s+4|0;h=w[a+4260|0];continue}}Fi(a,b,c,od(k,0),od(k,1),d)}}function FE(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=gb-128|0;gb=j;a:{b:{c:{if(!rn(f,g,h,i,0,0,0,0)){break c}m=f;n=g;l=h;o=i&65535;k=i>>>16&32767;d:{e:{if((k|0)!=32767){p=4;if(k){break e}m=l|m|(n|o)?3:2;break d}p=!(l|m|(n|o))}m=p}if(!m){break c}r=e>>>16|0;o=r&32767;if((o|0)!=32767){break b}}Ed(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];_E(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=o<<16;p=d;q=l|e&65535;m=q;n=h;q=i>>>16&32767;k=i&65535|q<<16;if((rn(b,c,p,m,f,g,h,k)|0)<=0){if(rn(b,c,p,m,f,g,n,k)){h=b;i=c;break a}Ed(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Ed(j+96|0,b,c,p,m,0,0,0,1081540608);h=v[j+108>>2];m=h;p=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Ed(j+80|0,f,g,n,k,0,0,0,1081540608);f=v[j+92>>2];k=f;n=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((o|0)>(q|0)){while(1){k=p;l=n;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0?1:(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){Ed(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;p=k<<1|i>>>31;break f}l=m<<1|p>>>31;p=p<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}l=p;q=l-n|0;n=m-((l>>>0<n>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=n-(l>>>0>q>>>0)|0;n=q-l|0;g:{if((k|0)<0){n=p;k=m;break g}p=h;h=h-f|0;i=i-((f>>>0>p>>>0)+g|0)|0;if(h|n|(i|k)){break g}Ed(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=n;k=k<<1|b>>>31;n=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Ed(j- -64|0,h,i,n,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=n;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;gb=j+128|0}function AL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{d:{e:{f:{k=Wp(1,28);if(!k){a=ba(4)|0;lm(a);v[22708]=0;U(186,a|0,89104,1929);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1920;d=zu(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,j+48|0,c|0)|0;f=v[22708];v[22708]=0;j:{if((f|0)!=1){v[22708]=0;f=Q(1930,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break j}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22708]=0;c=Q(70,j+48|0,c|0)|0;e=v[22708];v[22708]=0;k:{if((e|0)!=1){v[22708]=0;R(1931,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22708]=0;a=T(1290,80)|0;i=v[22708];v[22708]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22708]=0;b=Q(1932,k|0,k+4|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break n}v[j+48>>2]=b;b=v[jq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22708]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;ca(1933,a|0,j+8|0,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break m}v[k+24>>2]=a;Dj(j+48|0);Kl(d);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Dj(j+48|0)}Xb(a)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1912,12322,k|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Xb(Ft(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Xb(a);v[k+20>>2]=0}Xb(k);break d}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22708]=0;Y(1912,12322,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=j+80|0;return i|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function Hm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;a:{b:{if(cd(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=Ki(a)>>>0;g=x[b+8>>1];if((g|0)!=65535?c:0){break b}f=g;if((f&65535)==65535){g=Ki(a)-1|0;f=0}d=Xc(a,v[b+4>>2],f&65535);i=w[b+12|0];k=i&4;c:{d:{if(i&2){break d}l=g&65535;if(l>>>0<(f&65535)>>>0){break d}j=w[b+10|0];e=f;c=d;while(1){e:{if(!k){if((j|0)!=w[c+3|0]){break e}break c}if((j|0)==w[c+2|0]){break c}}c=c+6|0;e=e+1|0;if((e&65535)>>>0<=l>>>0){continue}break}}j=g&65535;if(j>>>0>=(f&65535)>>>0){e=f;c=d;while(1){f:{if(!k){if(w[c+3|0]){break f}t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break c}if(w[c+2|0]){break f}t[c+2|0]=w[b+10|0];t[c+4|0]=w[b+11|0];break c}c=c+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(i&1)){break g}i=v[ro(a)+480180>>2]&2;e=w[b+12|0];h:{if(e&4){break h}g=g&65535;if(g>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(w[d+3|0]-9|0){case 4:if(!uz(v[ro(a)+8>>2],1)){break i}c=1;t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}c=d;k:{if(i){e=w[d+5|0];if(e>>>0>128){break i}t[d+2|0]=2;t[d+3|0]=w[b+10|0];a=1;break k}t[d+2|0]=2;t[d+3|0]=w[b+10|0];e=w[d+5|0];a=2}t[c+4|0]=a+e>>>a;t[d+5|0]=w[b+11|0];break c}d=d+6|0;f=f+1|0;if(g>>>0>=(f&65535)>>>0){continue}break}e=w[b+12|0]}l:{if(e&4){c=w[b+11|0];d=13;m:{switch(w[b+10|0]-1|0){case 1:c=dm(B(i?2:4,c));e=w[b+12|0];d=9;break;case 0:break m;default:break l}}t[b+11|0]=c;t[b+10|0]=d;e=e&254;t[b+12|0]=e;break l}f=w[b+11|0];t[h+14|0]=f;d=b;c=w[b+10|0];n:{o:{if(!(!i|(c|0)!=9)){if(f>>>0>128){break n}c=2;f=(f&254)>>>1|0;break o}t[h+15|0]=c;if(!qz(h+15|0,h+14|0,1)){break n}c=w[h+15|0];if(!c){break n}e=w[b+12|0];f=w[h+14|0]}t[d+11|0]=f;t[b+10|0]=c;t[b+12|0]=e&254}e=w[b+12|0]}c=1;if(e&1){break g}t[b+12|0]=e^4;if(Hm(a,b)){break a}}d=v[b>>2];p:{if((d|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){v[b+4>>2]=v[b+4>>2]+1;break p}d=v[b>>2]}if((d|0)!=2){break b}c=0;d=v[b+4>>2];if(!d){break a}v[b+4>>2]=d-1}t[b+12|0]=w[b+12|0]|1;c=Hm(a,b);break a}c=1;break a}c=0}gb=h+16|0;return c|0}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;a:{b:{c:{h=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?h>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?h>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?h>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?h>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=h;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(j>>>16&65520)+r|0;j=u[e+14>>1];h=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];p=u[e+6>>1];t=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];i=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],w)+B(u[b+(e|-12)>>1],x)|0)+B(u[b+(e|-4)>>1],t)|0)+B(u[b+e>>1],p)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(h,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(i<<2)|0;j=v[k>>2];h=v[a+60>>2];l=h;e=(g+32|0)+(i<<3)|0;q=v[e>>2];b=Mb(q,-16777216,16776704);i=v[a+64>>2];f=Mb(v[e+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=oqa(l,p,h,h>>31);l=jb;p=h;h=oqa(i,i>>31,b,b>>31);i=p+h|0;b=jb+l|0;b=i>>>0<h>>>0?b+1|0:b;h=i;i=v[a+68>>2];i=oqa(i,i>>31,f,f>>31);f=h+i|0;b=jb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Jc(f,b,24);v[e+4>>2]=q;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[e>>2]=b-(f&j);i=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=g+48|0}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=lg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=(((i&2147483647)<<1|g>>>31)&-2)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Jd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Mb(q,-16777216,16776704);p=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=oqa(l,s,f,f>>31);l=jb;p=oqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function _h(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;a:{if(!Md(a)){break a}xk(a);if(c){c=b;n=gb-16|0;gb=n;g=a;if(Md(a)){e=x[g+34>>1];o=v[g+4>>2];h=v[g+8>>2];m=v[g>>2];r=!(e&2)|(o>>>0>=h>>>0|h>>>0>m>>>0);p=v[g+12>>2];f=v[g+16>>2];s=!(e&8)|(p>>>0>=f>>>0|f>>>0>m>>>0);z=c+1298224|0;d=c+1074992|0;i=e&4;j=e&16;while(1){b:{if((g|0)!=v[d+104>>2]){break b}c=v[d+76>>2];if(!c){break b}c:{d:{k=d;e:{f:{if(s){break f}l=v[d+88>>2];if(l&2048){break f}v[d+84>>2]=f;v[d+80>>2]=p;e=j;c=f;break e}if(r){break d}v[d+84>>2]=h;v[d+80>>2]=o;l=v[d+88>>2];e=i;c=h}v[k+76>>2]=c;k=l|2;q=d+88|0;l=(e|0)!=0;e=1;break c}q=d+88|0;k=v[d+88>>2]&-3;l=0;e=0}k=k&-5|(e?l?4:0:0);v[d+88>>2]=k;if(y[d+4>>2]>c>>>0){k=k&-129;v[d+88>>2]=k;c=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=c}if(!l){v[q>>2]=k&-129}if(e){break b}v[d+76>>2]=m}d=d+872|0;if((z|0)!=(d|0)){continue}break}}gb=n+16|0}if((ij(a)|0)==2){d=0;g=gb+-64|0;gb=g;e=fd(a);h=v[a+20>>2];f=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){i=B(d,e);j=B(e,d^-1);c=0;while(1){u[f+(c+i<<1)>>1]=x[f+(c-e<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];j=g+32|0;Db(j,b+1074312|0,33);wS(g+40|0,d,h+(B(e,f)<<1)|0,i-f|0,e,(c&4)>>>2|0,Cb(j));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];i=g+32|0;Db(i,b+1074312|0,33);wS(g+8|0,d+(e<<7)|0,h+(B(a,e)<<1)|0,f-a|0,e,(c&16)>>>4|0,Cb(i))}gb=g- -64|0;return}if((ij(a)|0)!=1){break a}d=0;g=gb+-64|0;gb=g;e=fd(a);h=v[a+20>>2];f=h+B(e,v[a>>2])|0;while(1){if(e){i=B(d,e);j=B(e,d^-1);c=0;while(1){t[f+(c+i|0)|0]=w[f+(c-e|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];j=g+32|0;Db(j,b+1074312|0,33);vS(g+40|0,d,h+B(e,f)|0,i-f|0,e,(c&4)>>>2|0,Cb(j));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];i=g+32|0;Db(i,b+1074312|0,33);vS(g+8|0,d+(e<<6)|0,h+B(a,e)|0,f-a|0,e,(c&16)>>>4|0,Cb(i))}gb=g- -64|0}}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;d=gb-48|0;gb=d;e=IR(d+32|0,1<<v[b+12>>2]);if(rf(a)){while(1){f=A[ze(a,c)>>3];HR(Tc(e,c),f);c=c+1|0;if(rf(a)>>>0>c>>>0){continue}break}}v[22708]=0;Dz(b,e);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}w=d,x=Vb(e),v[w>>2]=x;w=d,x=Zb(e),v[w+24>>2]=x;if(Gb(d,d+24|0)){while(1){c=v[d>>2];t=c;f=A[c+8>>3];i=gb-32|0;gb=i;o(+A[c>>3]);c=j(1)|0;g=j(0)|0;o(+f);k=j(1)|0;q=j(0)|0;p=c&2147483647;h=p;k=k&2147483647;r=(h|0)==(k|0)&g>>>0<q>>>0|h>>>0<k>>>0;c=r?g:q;h=r?h:k;r=h;l(0,c|0);l(1,h|0);f=+n();h=h>>>20|0;b:{if((h|0)==2047){break b}u=g;g=(k|0)==(p|0)&g>>>0>q>>>0|k>>>0<p>>>0;l(0,(g?u:q)|0);g=g?p:k;l(1,g|0);m=+n();p=!(c|r);c=g>>>20|0;if(!(p|(c|0)==2047)){if((c-h|0)>=65){f=m+f;break b}c:{if(c>>>0>=1534){f=f*1.90109156629516e-211;m=m*1.90109156629516e-211;s=5.260135901548374e210;break c}s=1;if(h>>>0>572){break c}f=f*5.260135901548374e210;m=m*5.260135901548374e210;s=1.90109156629516e-211}PI(i+24|0,i+16|0,m);PI(i+8|0,i,f);f=s*K(A[i>>3]+A[i+16>>3]+A[i+8>>3]+A[i+24>>3]);break b}f=m}gb=i+32|0;HR(t,Tp(f));Yo(d);if(Gb(d,d+24|0)){continue}break}}v[22708]=0;Bz(b,e);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;Az(e);c=v[22708];v[22708]=0;if((c|0)==1){break a}if(uf(e)>>>0>3){c=1;while(1){UA(Tc(e,c),2);UA(Tc(e,(uf(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<uf(e)>>>1>>>0){continue}break}}v[22708]=0;Dz(b,e);c=v[22708];v[22708]=0;if((c|0)==1){break a}w=d,x=Vb(e),v[w+24>>2]=x;w=d,x=Zb(e),v[w+16>>2]=x;d:{if(Gb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[22708]=0;TA(d,c);g=v[22708];v[22708]=0;if((g|0)==1){break d}g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;c=d+24|0;Yo(c);if(Gb(c,d+16|0)){continue}break}}v[22708]=0;Bz(b,e);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;Az(e);b=v[22708];v[22708]=0;if((b|0)==1){break a}if(rf(a)){c=0;while(1){f=A[Tc(e,c)>>3];w=ze(a,c),y=f,A[w>>3]=y;c=c+1|0;if(rf(a)>>>0>c>>>0){continue}break}}Nq(e);gb=d+48|0;return}}a=P()|0;O()|0;Nq(e);S(a|0);L()}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];h=v[a+44>>2];v[f+32>>2]=h;m=v[a+48>>2];v[f+36>>2]=m;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){i=(((i&2147483647)<<1|j>>>31)&-2)+s|0;b=(j>>>16&65520)+r|0;e=u[b+14>>1];j=u[b+12>>1];g=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];p=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];h=0;m=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[i+(b|-4)|0],w)+B(t[i+(b|-6)|0],x)|0)+B(t[i+(b|-2)|0],p)|0)+B(t[b+i|0],q)|0)+B(t[i+(b|2)|0],l)|0)+B(t[i+(b|4)|0],g)|0)+B(j,t[i+(b|6)|0])|0)+B(e,t[i+(b|8)|0])<<8)/32768;y=k&1;k=0;b=1;if(y){continue}break}while(1){k=(f+8|0)+(h<<2)|0;j=v[k>>2];g=v[a+60>>2];l=g;i=(f+32|0)+(h<<3)|0;q=v[i>>2];b=Mb(q,-16777216,16776704);h=v[a+64>>2];e=Mb(v[i+4>>2],-16777216,16776704);p=g>>31;j=j<<8;g=j;g=oqa(l,p,g,g>>31);l=jb;p=g;g=oqa(h,h>>31,b,b>>31);h=p+g|0;b=jb+l|0;b=h>>>0<g>>>0?b+1|0:b;g=h;h=v[a+68>>2];h=oqa(h,h>>31,e,e>>31);e=g+h|0;b=jb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Jc(e,b,24);v[i+4>>2]=q;e=v[a+72>>2];v[k>>2]=(b|0)/256;v[i>>2]=b-(e&j);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;e=o>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];i=v[f+28>>2];continue}break}j=v[f+24>>2];i=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];m=v[f+36>>2];h=v[f+32>>2];break e}b=n>>12;e=o>>12}v[a+40>>2]=n;v[a+20>>2]=e;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=i;gb=f+48|0}function w2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-1072|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=Wx(j,100,8345,a+16|0);v[a+48>>2]=2457;k=a+48|0;o=ge(a+536|0,0,k);v[a+48>>2]=2457;k=ge(a+528|0,0,k);m=a+544|0;a:{b:{c:{if(j>>>0>=100){v[22708]=0;j=ga(2477)|0;m=v[22708];v[22708]=0;if((m|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22708]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ca(2496,a+956|0,j|0,8345,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if((j|0)==-1){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}Fe(o,v[a+956>>2]);Fe(k,Cd(j<<2));if(wk(k)){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)==1){break b}break c}m=v[k>>2]}v[22708]=0;Fc(a+520|0,d);f=v[22708];v[22708]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22708]=0;q=T(2481,a+520|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}v[22708]=0;f=v[a+956>>2];Y(2493,q|0,f|0,f+j|0,m|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+956>>2]]==45:p;h=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);v[22708]=0;na(2525,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,f|0,g|0,a+452|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[a+36>>2]=2457;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Ab(g)+(j-n<<1)|0)+Ab(f)|0)+1|0;break k}l=(Ab(g)+Ab(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Fe(c,Cd(l<<2));i=v[c>>2];if(i){break h}v[22708]=0;X(2458);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[22708]=0;qa(2526,i|0,a+36|0,a+32|0,l|0,m|0,(j<<2)+m|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],h|0,f|0,g|0,n|0);j=v[22708];v[22708]=0;if((j|0)!=1){v[22708]=0;b=la(2506,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}Ic(g);Ic(f);vb(h)}Wb(a+520|0);break a}Hc(c);Ic(g);Ic(f);vb(h);Wb(a+520|0);Hc(k);Hc(o);gb=a+1072|0;return b|0}L()}j=P()|0;O()|0}Hc(k);Hc(o);S(j|0);L()}function Pl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(60,a|0,d|0);d=v[22708];v[22708]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=v[yk(c,b)>>2];f:{if(d>>>0<=127){v[22708]=0;R(61,a|0,d<<24>>24);d=v[22708];v[22708]=0;if((d|0)!=1){break f}break e}v[22708]=0;R(61,a|0,63);d=v[22708];v[22708]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(60,a|0,d|0);d=v[22708];v[22708]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=v[yk(c,b)>>2];i:{if(d>>>0<=255){v[22708]=0;R(61,a|0,d<<24>>24);d=v[22708];v[22708]=0;if((d|0)!=1){break i}break h}v[22708]=0;R(61,a|0,63);d=v[22708];v[22708]=0;if((d|0)==1){break h}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Yq(a,c,20896);return;case 5:Yq(a,c,21920);return;case 4:Yq(a,c,22944);return;case 6:Yq(a,c,23968);return;default:a=ba(8)|0;v[22708]=0;Q(59,a|0,8299)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;da(a|0);S(b|0);L();case 0:break c}}e=gb-16|0;gb=e;f=Kb(a);j:{k:{if(Ab(c)){while(1){a=v[yk(c,h)>>2];l:{if(a>>>0>=2097152){v[22708]=0;R(61,f|0,63);a=v[22708];v[22708]=0;if((a|0)!=1){break l}break k}d=0;m:{n:{while(1){g=a&63;t[(e+10|0)+d|0]=g;if(a>>>0<64){break n}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break m}o:{if(!d){v[22708]=0;R(61,f|0,t[e+10|0]);break o}b=d+1|0;if((b|0)!=2){break m}d=1;b=2;if((g|0)!=1){break m}v[22708]=0;R(61,f|0,t[e+10|0]|64)}a=v[22708];v[22708]=0;if((a|0)!=1){break l}break k}g=(-1<<b^-1)<<7-d;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){p:{if((a|0)==(b|0)){a=w[j|0];v[22708]=0;R(61,f|0,(a|g)<<24>>24);i=v[22708];v[22708]=0;a=d;if((i|0)!=1){break p}break k}v[22708]=0;a=a-1|0;R(61,f|0,t[a+(e+10|0)|0]|-128);i=v[22708];v[22708]=0;if((i|0)==1){break k}}if(a){continue}break}}h=h+1|0;if(Ab(c)>>>0>h>>>0){continue}break}}gb=e+16|0;break j}a=P()|0;O()|0;vb(f);S(a|0);L()}return}ia(a|0,89224,24);L()}b=P()|0;O()|0;vb(a);S(b|0);L()}function Ax(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[22614]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Of(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}h=e+1|0;f=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}h=e+2|0;f=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];f=e+4|0;e=f;if(!((g-16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76800>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76800>>2];f=1;continue}h=w[e|0];f=h>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{i=e+1|0;f=h-128|g<<6;h=i;v:{if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=e+2|0;f=h|f<<6;h=i;if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[115189]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[115189]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function gA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-160|0;gb=h;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!c){break i}d=v[c+4>>2];if(!d&y[c>>2]>=yb(b)>>>0|d){break i}b=ba(8)|0;v[22708]=0;Q(126,b|0,18720)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break h}a=P()|0;O()|0;da(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[22708]=0;T(1292,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break g}a=P()|0;O()|0;da(b|0);break a}d=v[b+4>>2];g=v[b>>2];v[h>>2]=g;v[h+4>>2]=d;v[h+128>>2]=g;v[h+132>>2]=d;g=gb-16|0;gb=g;d=v[h+4>>2];e=v[h>>2];v[g>>2]=e;v[g+4>>2]=d;v[g+8>>2]=e;v[g+12>>2]=d;d=gb-32|0;gb=d;e=v[g+4>>2];f=v[g>>2];v[d+8>>2]=f;v[d+12>>2]=e;v[d+16>>2]=f;v[d+20>>2]=e;rh(d+24|0,d+8|0);e=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=e;e=gb-16|0;gb=e;f=v[d+4>>2];i=v[d>>2];v[e>>2]=i;v[e+4>>2]=f;v[e+8>>2]=i;v[e+12>>2]=f;f=gb-16|0;gb=f;i=v[e+4>>2];k=v[e>>2];v[f>>2]=k;v[f+4>>2]=i;v[f+8>>2]=k;v[f+12>>2]=i;i=h+136|0;VF(i,f);gb=f+16|0;gb=e+16|0;v[i+12>>2]=0;gb=d+32|0;gb=g+16|0;j:{k:{if(a&2){d=In(h+104|0,i);v[22708]=0;g=Q(1293,d|0,c|0)|0;e=v[22708];v[22708]=0;d=1;if((e|0)==1){break j}if((g|0)==1){break k}e=In(h+80|0,i);v[22708]=0;e=Q(1294,e|0,c|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break f}k=(e|0)==1;if(k){break k}f=In(h+56|0,i);v[22708]=0;f=Q(1295,f|0,c|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break e}l=(f|0)==1;if(l){break k}j=In(h+32|0,i);v[22708]=0;j=Q(1296,j|0,c|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break d}if((j|0)==1){break k}d=(g|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(j|0)==-1?-1:l?d:(f|0)==-1?-1:d}if(a&1){a=37824;while(1){d=v[a>>2];if(d){g=In(h+8|0,i);v[22708]=0;g=Q(d|0,g|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=1;if((g|0)==1){break k}j=(g|0)==-1?-1:j}a=a+12|0;if((a|0)!=38328){continue}break}}if(c){d=0;if((j|0)!=-1){break k}d=Qc(v[c>>2],v[c+4>>2])>>>0>yb(b)>>>0?-1:0;break k}d=0;if((j|0)!=-1){break k}d=yb(b)>>>0>2047?1:-1}gb=h+160|0;return d}a=P()|0;break b}ia(b|0,89384,24);L()}ia(b|0,89280,24);L()}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=P()|0}O()|0}S(a|0);L()}function A2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-464|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=Wx(j,100,8345,a+16|0);v[a+48>>2]=2457;k=a+48|0;o=ge(a+232|0,0,k);v[a+48>>2]=2457;k=ge(a+224|0,0,k);m=a+240|0;a:{b:{c:{if(j>>>0>=100){v[22708]=0;j=ga(2477)|0;m=v[22708];v[22708]=0;if((m|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22708]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ca(2496,a+348|0,j|0,8345,a|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}if((j|0)==-1){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}Fe(o,v[a+348>>2]);Fe(k,Cd(j));if(wk(k)){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)==1){break b}break c}m=v[k>>2]}v[22708]=0;Fc(a+216|0,d);f=v[22708];v[22708]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22708]=0;q=T(21,a+216|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break j}v[22708]=0;f=v[a+348>>2];Y(2473,q|0,f|0,f+j|0,m|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+348>>2]]==45:p;h=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);v[22708]=0;na(2523,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,f|0,g|0,a+156|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[a+36>>2]=2457;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Ab(g)+(j-n<<1)|0)+Ab(f)|0)+1|0;break k}l=(Ab(g)+Ab(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Fe(c,Cd(l));i=v[c>>2];if(i){break h}v[22708]=0;X(2458);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[22708]=0;qa(2524,i|0,a+36|0,a+32|0,l|0,m|0,j+m|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],h|0,f|0,g|0,n|0);j=v[22708];v[22708]=0;if((j|0)!=1){v[22708]=0;b=la(17,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Hc(c)}vb(g);vb(f);vb(h)}Wb(a+216|0);break a}Hc(c);vb(g);vb(f);vb(h);Wb(a+216|0);Hc(k);Hc(o);gb=a+464|0;return b|0}L()}j=P()|0;O()|0}Hc(k);Hc(o);S(j|0);L()}function Bz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=gb-208|0;gb=c;i=1;h=v[a+12>>2];k=1<<h;m=2;g=h;if(g>>>0>=2){f=k;while(1){l=f>>>2|0;if(f>>>0>=4){w=B(i,3);x=i<<1;y=l>>>0>1?l:1;g=0;while(1){e=c+192|0;WN(e,Tc(a,g<<1));f=c+176|0;WN(f,Tc(a,g));Mi(c+160|0,f,e);f=g<<m;u=i+f|0;if(f>>>0<u>>>0){while(1){d=Tc(b,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;n=f+i|0;d=Tc(b,n);e=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=e;e=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=e;o=f+x|0;d=Tc(b,o);e=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=e;e=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=e;p=f+w|0;d=Tc(b,p);e=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=e;e=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=e;q=c+80|0;d=c+144|0;e=c+128|0;Fl(q,d,e);r=c- -64|0;Fj(r,d,e);s=c+48|0;d=c+112|0;e=c+96|0;Fl(s,d,e);j=c+16|0;Fj(j,d,e);t=c+32|0;Mi(t,48208,j);Fl(j,q,s);d=Tc(b,f);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Fl(c,r,t);Mi(j,c+192|0,c);n=Tc(b,n);d=n;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Fj(c,q,s);Mi(j,c+176|0,c);o=Tc(b,o);d=o;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Fj(c,r,t);Mi(j,c+160|0,c);p=Tc(b,p);d=p;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;if((u|0)!=(f|0)){continue}break}}g=g+1|0;if((y|0)!=(g|0)){continue}break}g=v[a+12>>2]}i=i<<2;f=l;m=m+2|0;if(m>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!h)){e=k>>>1|0;l=e>>>0>1?e:1;f=0;while(1){k=e+f|0;h=Tc(b,k);a=v[h+12>>2];v[c+200>>2]=v[h+8>>2];v[c+204>>2]=a;a=v[h+4>>2];v[c+192>>2]=v[h>>2];v[c+196>>2]=a;h=c+192|0;Fj(c+176|0,Tc(b,f),h);g=Tc(b,k);a=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=a;a=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=a;Cz(Tc(b,f),h);f=f+1|0;if((l|0)!=(f|0)){continue}break}}gb=c+208|0}function Fi(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=C(0);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((kb[v[v[a>>2]+152>>2]](a)|0)<1){break a}if(!BM(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}m=z[a+4196>>2];k=C(k*m);j=C(j*m);l=a+44|0;n=Nd(l,0);l=Nd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;k=z[h>>2];q=h;r=k;m=z[g+n>>2];h=c+g|0;o=z[h>>2];p=z[g+l>>2];k=C(C(C(C(k+m)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(j*z[d+g>>2])))-m);z[h>>2]=o-C(C(k+C(k-C(j*z[e+g>>2])))-p);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]-C(z[d+g>>2]-C(j*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]-C(z[e+g>>2]-C(j*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(z[d+g>>2]-C(k*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(z[e+g>>2]-C(k*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(z[g+n>>2]-C(j*z[d+g>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(z[g+l>>2]-C(j*z[e+g>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=z[h>>2]+C(C(j*z[d+g>>2])+C(k*z[g+n>>2]));h=c+g|0;z[h>>2]=z[h>>2]+C(C(j*z[e+g>>2])+C(k*z[g+l>>2]));i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=BM(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;m=C(z[d+g>>2]-z[g+n>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=z[h>>2]+C(C(j*m)+C(k*o));g=c+g|0;z[g>>2]=z[g>>2]+C(C(k*m)+C(j*o));i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(kb[v[v[a>>2]+136>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[a+n>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=lg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Jd(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Mb(o,-16777216,16776704);n=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=oqa(m,s,f,f>>31);m=jb;n=oqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function rma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=a;d=w[b+2|0];e=d-16|0;a:{b:{if((e&255)>>>0<=128){t[a+2|0]=1;d=(e&254)>>>1|0;break b}c:{switch((d+96&240)>>>4|0){case 0:t[a+2|0]=4;d=d&15;break b;case 1:t[a+2|0]=3;d=d&15;break b;case 2:t[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;d=d&15}t[c+4|0]=d}d=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=w[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}t[a+2|0]=15;c=w[b+6|0];t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;g=a,h=w[ac(b+5|0,f+15|0)|0]|208,t[g+5|0]=h;break d}c=w[b+6|0];e=w[b+5|0];if(!(c|e)){break d}t[a+5|0]=e;t[a+3|0]=c;Pf(a);d=w[b+6|0]==15;break d}t[a+3|0]=2;g=a,h=ei(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=3;g=a,h=ei(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=4;g=a,h=ei(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=5;t[a+5|0]=w[b+6|0]&240|w[b+5|0]>>>4;break d}c=w[b+5|0];if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((w[b+6|0]-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=w[b+6|0]>>>1;break d}c=w[b+6|0];if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=w[b+5|0]&15;break d}t[a+3|0]=w[b+6|0];t[a+5|0]=w[b+5|0];Uu(a,1);d=(w[a+3|0]&254)==16;break d}t[a+3|0]=18;t[a+5|0]=w[b+5|0];break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1;break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=w[b+6|0]>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}gb=f+16|0;return d|0}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb+-64|0;gb=d;u[d+62>>1]=c;yg(d+62|0,32);f=mc(a);v[22708]=0;R(711,f|0,x[d+62>>1]);a=v[22708];v[22708]=0;a:{if((a|0)!=1){b:{if(!x[d+62>>1]){break b}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;c:{d:{if((a&65535)>>>0<4e3){break d}u[d+24>>1]=1;e:{if(!x[b+480190>>1]){break e}while(1){f:{if(Md(Tl(b,x[d+24>>1]))){break f}j=d,k=bC(Vb(f),Zb(f),d+24|0),v[j+48>>2]=k;j=d,k=Zb(f),v[j+40>>2]=k;if(Gb(d+48|0,d+40|0)){break f}u[d+60>>1]=x[d+24>>1];c=1;if(!x[b+480192>>1]){break e}while(1){a=v[(((c&65535)<<2)+b|0)+900380>>2];g:{if(!a){break g}a=a+236|0;e=Ju(a);if((a|0)==(e|0)){break g}while(1){if(x[a>>1]==x[d+60>>1]){u[a>>1]=0}a=a+2|0;if((e|0)!=(a|0)){continue}break}}c=c+1|0;if(x[b+480192>>1]>=(c&65535)>>>0){continue}break}break e}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break d}c=av(d+48|0);v[22708]=0;a=Q(975,b|0,c|0)|0;e=v[22708];v[22708]=0;h:{i:{if((e|0)==1){break i}j:{if(a){v[22708]=0;Q(976,b|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}e=1;if(!x[b+480192>>1]){break j}while(1){a=v[(((e&65535)<<2)+b|0)+900380>>2];k:{if(!a){break k}a=a+236|0;g=Ju(a);if((a|0)==(g|0)){break k}while(1){l:{if(y[c+4>>2]<=x[a>>1]){break l}h=d+40|0;re(h,c,x[a>>1]);if(Cb(h)){break l}u[a>>1]=0}a=a+2|0;if((g|0)!=(a|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break j}De(c);break b}a=d+24|0;Ak(a,c);e=d+32|0;rB(e,a,1);a=d+16|0;Sl(a,c);v[22708]=0;t[d+15|0]=0;bT(d+40|0,e,a,d+15|0);a=v[22708];v[22708]=0;if((a|0)!=1){break h}}a=P()|0;O()|0;De(c);break a}Ak(d,c);j=d,k=Qj(d+40|0,d),u[j+60>>1]=k;De(c);if(x[d+60>>1]>=4e3){break c}}v[22708]=0;R(383,f|0,d+60|0);a=v[22708];v[22708]=0;if((a|0)!=1){if(x[b+480190>>1]>=x[d+60>>1]){break c}u[b+480190>>1]=x[d+60>>1];break c}a=P()|0;O()|0;break a}i=i+1|0;if(x[d+62>>1]>(i&65535)>>>0){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0}Ye(f);S(a|0);L()}function O9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{j=Wp(1,32);d:{e:{if(!j){a=ba(4)|0;lm(a);v[22708]=0;U(186,a|0,89104,1929);a=v[22708];v[22708]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1920;d=zu(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,k+16|0,c|0)|0;f=v[22708];v[22708]=0;i:{if((f|0)!=1){v[22708]=0;f=Q(1930,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break i}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22708]=0;c=Q(70,k+16|0,c|0)|0;e=v[22708];v[22708]=0;j:{if((e|0)!=1){v[22708]=0;R(1931,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22708]=0;c=T(1290,96)|0;e=v[22708];v[22708]=0;k:{l:{m:{if((e|0)!=1){v[22708]=0;e=Q(1932,j|0,j+4|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[jq(k+8|0,k+16|0)>>2];v[22708]=0;fa(2007,c|0,a|0,b|0,e|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}v[j+28>>2]=c;Dj(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Kl(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Dj(k+16|0)}Xb(c)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1912,2069,j|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){a=v[j+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}Z(i|0)|0;j=0;v[22708]=0;Y(1912,2069,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=k+48|0;return j|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function G8(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;d=gb-16|0;gb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!((a|0)>-1?a>>>0>=8388608:0)){f=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}f=C(C(c-c)/C(0));if((a|0)<=-1){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));e=C(k*k);m=C(e*e);f=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());e=C(C(C(f-c)-i)+C(k*C(i+C(C(e*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(e*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(e+c)*C(-3168997136526741e-20))))))}f=c}e=C(f*C(2e3));if(!(C(D(e))<C(2147483648))){break c}a=~~e;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=gb-16|0;gb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){d=ba(8)|0;v[22708]=0;b=Q(70,b|0,2219)|0;a=v[22708];v[22708]=0;if((a|0)==1){break k}rc(d,b);v[22708]=0;U(186,d|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break i}a=P()|0;O()|0;vb(b);break j}gb=b+16|0;a=v[(a<<24>>24<<2)+59672>>2];break h}a=P()|0;O()|0;da(d|0)}S(a|0)}L()}break b;case 3:v[d>>2]=0;g=gb-80|0;gb=g;a=v[a+24>>2]+24604|0;v[g+40>>2]=v[a+32>>2];v[g>>2]=v[a+36>>2];b=g+40|0;h=v[If(b,g)>>2];o=d;l:{if(v[a+32>>2]==v[Wq(b)+32>>2]){b=-1;if(v[a+36>>2]==v[Wq(g)+36>>2]){break l}}b=0;if((h|0)<1){break l}b=(h+500>>>0)/1e3|0}v[o>>2]=b;gb=g+80|0;a=v[d>>2];break b;default:break d}}h=ba(8)|0;v[22708]=0;d=Q(70,d|0,7655)|0;a=v[22708];v[22708]=0;m:{if((a|0)!=1){rc(h,d);v[22708]=0;U(186,h|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break m}b=P()|0;O()|0;da(h|0)}S(b|0);L()}a=-2147483648}gb=d+16|0;return a|0}L()}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;a:{b:{c:{i=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?i>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?i>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?i>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;v[f+16>>2]=i;v[f+20>>2]=e;if(d){while(1){m=1;e=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];i=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];t=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];k=0;b=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((((B(u[e+(h|-8)>>1],w)+B(u[e+(h|-12)>>1],x)|0)+B(u[e+(h|-4)>>1],t)|0)+B(u[e+h>>1],o)|0)+B(u[e+(h|4)>>1],l)|0)+B(u[e+(h|8)>>1],n)|0)+B(u[e+(h|12)>>1],i)|0)+B(j,u[e+(h|16)>>1])|0)/32768;h=b;b=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];i=v[a+60>>2];n=i;h=(f+32|0)+(k<<3)|0;k=v[h>>2];b=Mb(k,-16777216,16776704);l=v[a+64>>2];e=Mb(v[h+4>>2],-16777216,16776704);o=i>>31;i=g<<8;g=i;g=oqa(n,o,g,g>>31);n=jb;l=oqa(l,l>>31,b,b>>31);g=l+g|0;b=jb+n|0;b=g>>>0<l>>>0?b+1|0:b;o=g;g=v[a+68>>2];g=oqa(g,g>>31,e,e>>31);e=o+g|0;b=jb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Jc(e,b,24);v[h+4>>2]=k;e=v[a+72>>2];v[j>>2]=(b|0)/256;v[h>>2]=b-(e&i);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Ud(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=lg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=(((i&2147483647)<<1|g>>>31)&-2)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Jd(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Id(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Jd(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Id(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=ig(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Mb(o,-16777216,16776704);n=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=oqa(m,s,f,f>>31);m=jb;n=oqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=0,u=C(0),w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(ni(m)){B=Nd(m,0);D=Nd(m,1);E=od(m,0);F=od(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){k=a+4304|0;j=q+1|0;w=j+v[a+4272>>2]&4095;l=k+(w<<4)|0;x=j+v[a+4276>>2]&4095;h=((x<<4)+k|0)+4|0;y=j+v[a+4280>>2]&4095;n=((y<<4)+k|0)+8|0;A=j+v[a+4284>>2]&4095;f=((A<<4)+k|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;H=a+69840|0;I=a+78032|0;G=d;while(1){w=w-1&4095;j=(w<<4)+k|0;e=z[j>>2];r=r&1023;t=(r<<3)+H|0;p=z[t+4>>2];J=z[f>>2];K=z[n>>2];L=z[h>>2];M=z[l>>2];N=z[D>>2];O=z[B>>2];x=x-1&4095;l=(x<<4)+k|0;i=z[l+4>>2];u=z[a+4232>>2];g=C(C(i*C(.6180340051651001))+C(z[t>>2]*u));f=o<<3;h=f+H|0;z[h+4>>2]=i-C(g*C(.6180340051651001));i=e;e=C(C(u*p)-C(e*C(.6180340051651001)));z[h>>2]=i+C(e*C(.6180340051651001));z[j>>2]=g;z[l+4>>2]=e;s=s&1023;t=(s<<3)+I|0;p=z[t+4>>2];y=y-1&4095;n=(y<<4)+k|0;g=z[n+8>>2];A=A-1&4095;h=(A<<4)+k|0;i=z[h+12>>2];u=z[a+4236>>2];e=C(C(i*C(.6180340051651001))+C(z[t>>2]*u));f=f+I|0;z[f+4>>2]=i-C(e*C(.6180340051651001));i=g;g=C(C(u*p)-C(g*C(.6180340051651001)));z[f>>2]=i+C(g*C(.6180340051651001));z[n+8>>2]=e;z[h+12>>2]=g;g=e;e=C(O+C(1.0000000031710769e-30));z[E>>2]=g+C(C(e*z[a+4224>>2])+z[j>>2]);g=C(N+C(1.0000000031710769e-30));z[F>>2]=C(C(g*z[a+4224>>2])+z[l+4>>2])+z[h+12>>2];f=(q<<4)+k|0;i=e;e=z[a+4228>>2];p=C(i*e);z[f>>2]=p+C(C(z[j>>2]*z[a+4240>>2])+C(M*z[a+4244>>2]));e=C(g*e);z[f+4>>2]=e+C(C(z[l+4>>2]*z[a+4248>>2])+C(L*z[a+4252>>2]));z[f+8>>2]=C(C(z[n+8>>2]*z[a+4256>>2])+C(K*z[a+4260>>2]))-e;z[f+12>>2]=p+C(C(z[h+12>>2]*z[a+4264>>2])+C(J*z[a+4268>>2]));f=h+12|0;n=n+8|0;h=l+4|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=j;G=G-1|0;if(G){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;Fi(a,b,c,od(m,0),od(m,1),d)}}function Vp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Cd(b)}if(b>>>0>=4294967232){v[115189]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116623]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;As(c,b);return a}if(v[116509]==(f|0)){c=c+v[116506]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116506]=c;v[116509]=b;return a}if(v[116508]==(f|0)){c=c+v[116505]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116508]=d;v[116505]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=466012,o=v[116503]&sqa(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+466316|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=466016,o=v[116504]&sqa(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;As(b,l);return a}c=Cd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;hc(c,a,b>>>0>d>>>0?d:b);Xb(a);a=c}return a}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){e=(((g&2147483647)<<1|j>>>31)&-2)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];k=0;m=1;i=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],x)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],w)|0)+B(t[b+e|0],o)|0)+B(t[e+(b|2)|0],l)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],h)|0)+B(j,t[e+(b|8)|0])<<8)/32768;g=i;i=0;b=1;if(g){continue}break}while(1){j=(f+8|0)+(k<<2)|0;e=v[j>>2];h=v[a+60>>2];n=h;i=(f+32|0)+(k<<3)|0;k=v[i>>2];b=Mb(k,-16777216,16776704);l=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);o=h>>31;h=e<<8;e=h;e=oqa(n,o,e,e>>31);n=jb;l=oqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+n|0;b=e>>>0<l>>>0?b+1|0:b;o=e;e=v[a+68>>2];e=oqa(e,e>>31,g,g>>31);g=o+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=k;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&h);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function zL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{d:{e:{f:{j=Wp(1,28);if(!j){a=ba(4)|0;lm(a);v[22708]=0;U(186,a|0,89104,1929);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1920;d=zu(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22708]=0;c=Q(70,k+16|0,c|0)|0;f=v[22708];v[22708]=0;j:{if((f|0)!=1){v[22708]=0;f=Q(1930,d|0,c|0)|0;l=v[22708];v[22708]=0;if((l|0)==1){break j}v[22708]=0;Q(415,f|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22708]=0;c=Q(70,k+16|0,c|0)|0;e=v[22708];v[22708]=0;k:{if((e|0)!=1){v[22708]=0;R(1931,d|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22708]=0;c=T(1290,80)|0;e=v[22708];v[22708]=0;l:{m:{n:{if((e|0)!=1){v[22708]=0;e=Q(1932,j|0,j+4|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[jq(k+8|0,k+16|0)>>2];v[22708]=0;fa(1934,c|0,a|0,b|0,e|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}v[j+24>>2]=c;Dj(k+16|0);Kl(d);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Dj(k+16|0)}Xb(c)}Kl(d);Z(i|0)|0;v[22708]=0;Y(1912,12278,j|0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Xb(Ft(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);break d}i=V(0)|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22708]=0;Y(1912,12278,0,g|0,h|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=k+48|0;return i|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function US(a){a=a|0;var b=0,c=0,d=0,e=0;Qb(a,0,288);c=a+288|0;pB(c);d=a+800|0;Wo(d);t[a+2|0]=w[11426];b=w[11424]|w[11425]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[11504];b=w[11502]|w[11503]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[2591]|w[2592]<<8|(w[2593]<<16|w[2594]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[2588]|w[2589]<<8|(w[2590]<<16|w[2591]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[12793]|w[12794]<<8|(w[12795]<<16|w[12796]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[12796]|w[12797]<<8|(w[12798]<<16|w[12799]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[6426];b=w[6422]|w[6423]<<8|(w[6424]<<16|w[6425]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;a=gb-32|0;gb=a;b=Tb(a+16|0,2028);v[22708]=0;R(444,a+8|0,c|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)==1){break b}v[22708]=0;Q(401,a+8|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}vb(b);gb=a+32|0;break a}a=P()|0;O()|0;vb(b);S(a|0);L()}b=0;a=gb+-64|0;gb=a;c:{d:{e:{while(1){v[a+60>>2]=b<<3;f:{if(b>>>0<=15){Ff(a+32|0,1193);v[22708]=0;R(442,a+16|0,a+60|0);c=v[22708];v[22708]=0;g:{h:{i:{j:{if((c|0)!=1){v[22708]=0;U(443,a+48|0,a+32|0,a+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[22708]=0;R(444,a+8|0,(b<<5)+d|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;Q(401,a+8|0,a+48|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break i}vb(a+48|0);vb(a+16|0);Hb(a+32|0);break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a+48|0)}vb(a+16|0)}Hb(a+32|0);break d}c=Tb(a+48|0,18720);v[22708]=0;R(444,a+32|0,(b<<5)+d|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;Q(401,a+32|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}vb(c)}b=b+1|0;if((b|0)!=128){continue}break}gb=a- -64|0;break c}b=P()|0;O()|0;vb(c)}S(b|0);L()}}function zk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(62,a|0,d|0);d=v[22708];v[22708]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=t[pc(c,b)|0];f:{if((d|0)>=0){v[22708]=0;R(63,a|0,d&255);d=v[22708];v[22708]=0;if((d|0)!=1){break f}break e}v[22708]=0;R(63,a|0,65533);d=v[22708];v[22708]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22708]=0;R(62,a|0,d|0);d=v[22708];v[22708]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=w[pc(c,b)|0];v[22708]=0;R(63,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:Xq(a,c,20896);return;case 5:Xq(a,c,21920);return;case 4:Xq(a,c,22944);return;case 6:Xq(a,c,23968);return;default:a=ba(8)|0;v[22708]=0;Q(59,a|0,8299)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=P()|0;O()|0;da(a|0);S(b|0);L();case 0:break c}}d=gb-16|0;gb=d;e=Kb(a);f=d,g=zd(c),v[f+8>>2]=g;f=d,g=ef(c),v[f>>2]=g;i:{j:{k:{if(!Gb(d+8|0,d)){break k}c=0;a=0;while(1){b=w[v[d+8>>2]];l:{if(!c){if(!(b&128)){c=0;v[22708]=0;R(63,e|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break l}break j}if((b&224)==192){a=b&31;c=1;break l}if((b&240)==224){a=b&15;c=2;break l}if((b&248)==240){a=b&7;c=3;break l}a=0;v[22708]=0;R(63,e|0,65533);b=v[22708];v[22708]=0;c=0;if((b|0)==1){break j}break l}if((b&192)!=128){v[22708]=0;R(63,e|0,65533);a=v[22708];v[22708]=0;if((a|0)==1){break j}a=b&63;c=-1;break l}b=b&63|a<<6;c=c-1|0;if(c){a=b;break l}a=0;v[22708]=0;R(63,e|0,b|0);b=v[22708];v[22708]=0;c=0;if((b|0)==1){break j}}b=d+8|0;Pe(b);if(Gb(b,d)){continue}break}if(!c){break k}v[22708]=0;R(63,e|0,65533);a=v[22708];v[22708]=0;if((a|0)!=1){break k}break j}gb=d+16|0;break i}a=P()|0;O()|0;Ic(e);S(a|0);L()}return}ia(a|0,89224,24);L()}b=P()|0;O()|0;Ic(a);S(b|0);L()}function Dz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c=gb-208|0;gb=c;g=1;d=v[a+12>>2];i=1<<d;if(d&1){j=i>>>1|0;e=j>>>0>1?j:1;d=0;while(1){k=d+j|0;g=Tc(b,k);m=v[g+12>>2];v[c+200>>2]=v[g+8>>2];v[c+204>>2]=m;m=v[g+4>>2];v[c+192>>2]=v[g>>2];v[c+196>>2]=m;m=c+192|0;Fj(c+176|0,Tc(b,d),m);g=Tc(b,k);h=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=h;k=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=k;Cz(Tc(b,d),m);d=d+1|0;if((e|0)!=(d|0)){continue}break}d=v[a+12>>2];g=2;i=i>>>3|0}else{i=i>>>2|0}k=d&-2;if(k){while(1){if(g){t=B(i,3);u=i<<1;j=0;while(1){d=Tc(a,j<<1);e=v[d+12>>2];v[c+200>>2]=v[d+8>>2];v[c+204>>2]=e;e=v[d+4>>2];v[c+192>>2]=v[d>>2];v[c+196>>2]=e;d=Tc(a,j);e=v[d+12>>2];v[c+184>>2]=v[d+8>>2];v[c+188>>2]=e;e=v[d+4>>2];v[c+176>>2]=v[d>>2];v[c+180>>2]=e;Mi(c+160|0,c+176|0,c+192|0);d=j<<k;m=i+d|0;if(d>>>0<m>>>0){while(1){e=Tc(b,d);h=v[e+12>>2];v[c+152>>2]=v[e+8>>2];v[c+156>>2]=h;h=v[e+4>>2];v[c+144>>2]=v[e>>2];v[c+148>>2]=h;h=c+128|0;q=d+i|0;Mi(h,c+192|0,Tc(b,q));e=c+112|0;r=d+u|0;Mi(e,c+176|0,Tc(b,r));f=c+96|0;s=d+t|0;Mi(f,c+160|0,Tc(b,s));n=c+80|0;l=c+144|0;Fl(n,l,e);o=c- -64|0;Fj(o,l,e);l=c+48|0;Fl(l,h,f);e=c+16|0;Tm(e,-A[6026],-A[6027]);Fj(c,h,f);h=c+32|0;Mi(h,e,c);Fl(e,n,l);f=Tc(b,d);p=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=p;p=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=p;Fj(e,n,l);f=Tc(b,q);l=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=l;n=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=n;Fl(e,o,h);f=Tc(b,r);l=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=l;n=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=n;Fj(e,o,h);e=Tc(b,s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;h=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=h;d=d+1|0;if((m|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(g|0)){continue}break}}i=i>>>2|0;g=g<<2;k=k-2|0;if(k){continue}break}}gb=c+208|0}function W7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-96|0;gb=e;a:{if(gd(c)){break a}f=w[mL(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;Os(f,c,0,Ab(c)-1|0);Eb(c,f);vb(f)}f=e+80|0;Ld(f);g=v[e+80>>2];Ld(e+72|0);g=lL(g,v[e+76>>2],c);Ld(f);b:{c:{d:{e:{f:{if((g|0)==v[e+84>>2]){if(qe(c,18720)){a=ba(8)|0;v[22708]=0;b=Q(70,e+80|0,7752)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(!d){break f}a=ba(8)|0;v[22708]=0;U(2054,e+80|0,14758,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,e+80|0);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(e+80|0);break c}c=P()|0;O()|0;da(a|0);break c}f=Kb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Dg(e- -64|0,c);v[22708]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(1997,b|0,e+8|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;t[e+72|0]=b;R(2057,a|0,e+72|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}break i;case 1:Dg(e+56|0,c);v[22708]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=nG(b,e+16|0,d);c=jb;d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2060,a|0,e+72|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}break i;case 2:Dg(e+48|0,c);v[22708]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(1999,b|0,e+24|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;A[e+72>>3]=h;R(2061,a|0,e+72|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Dg(e+40|0,c);v[22708]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;Y(2e3,a|0,b|0,e+32|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;vb(f);break c}Dc(a,f)}vb(f);break e}Kb(a)}gb=e+96|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;t=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){s=(g+8|0)+(f<<2)|0;f=f<<1;v[s>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],q)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],w)+B(u[e+(f|-12)>>1],x)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],m)|0)/2|0)|0)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Mb(q,-16777216,16776704);m=v[a+64>>2];i=Mb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=oqa(l,r,h,h>>31);l=jb;m=oqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=oqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=e+o|0;l=o>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}l=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb+-64|0;gb=d;u[d+62>>1]=b;e=Si(a);b=e;f=d+48|0;g=Hg(f);a:{if(!b){break a}v[22708]=0;R(814,f|0,b|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;R(1085,f|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;cs(g);S(a|0);L()}b:{c:{if(!e){break c}b=0;while(1){j=sc(f,b),k=b-c|0,u[j>>1]=k;v[22708]=0;g=Q(1084,a|0,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break b}c=(x[g>>1]==x[d+62>>1])+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}if(!(c&65535)){break c}e=Vb(a);c=Zb(a);b=gb-32|0;gb=b;v[b+16>>2]=c;j=b,k=bC(e,c,d+62|0),v[j+24>>2]=k;d:{if(!Gb(b+24|0,b+16|0)){break d}v[b+8>>2]=v[b+24>>2];if(!Gb(nf(b+8|0),b+16|0)){break d}while(1){if(x[v[b+8>>2]>>1]!=x[d+62>>1]){c=b+24|0;u[v[c>>2]>>1]=x[v[b+8>>2]>>1];nf(c)}if(Gb(nf(b+8|0),b+16|0)){continue}break}}gb=b+32|0;v[d+32>>2]=v[b+24>>2];g=d+32|0;b=Gd(d+40|0,g);j=d,k=Zb(a),v[j+16>>2]=k;h=d+16|0;e=Gd(d+24|0,h);b=v[b>>2];c=gb-32|0;gb=c;v[c+16>>2]=v[e>>2];v[c+24>>2]=b;b=a;e=v[b>>2];j=c,k=Vb(b),v[j+8>>2]=k;i=c+24|0;e=e+(rp(i,c+8|0)<<1)|0;if(Gb(i,c+16|0)){xn(b,Rg(e+(rp(c+16|0,c+24|0)<<1)|0,v[b+4>>2],e))}Gg(e);gb=c+32|0;j=d,k=Vb(a),v[j+32>>2]=k;j=d,k=Zb(a),v[j+16>>2]=k;if(Gb(g,h)){while(1){b=x[v[d+32>>2]>>1];c=v[a+24>>2];v[22708]=0;c=me(c+484344|0,b);e=v[22708];v[22708]=0;if((e|0)==1){break b}e:{if(!c){break e}b=_b(v[a+24>>2]+484344|0,b);j=d,k=Vb(b),v[j+8>>2]=k;j=d,k=Zb(b),v[j>>2]=k;if(!Gb(d+8|0,d)){break e}while(1){b=v[d+8>>2];f:{if(w[b+3|0]!=12){break f}c=w[b+5|0];if(tc(f)>>>0<=c>>>0){break f}j=b,k=w[sc(f,w[b+5|0])|0],t[j+5|0]=k}b=d+8|0;ak(b);if(Gb(b,d)){continue}break}}b=d+32|0;nf(b);if(Gb(b,d+16|0)){continue}break}}b=x[a+28>>1];if(tc(f)>>>0<=b>>>0){break c}j=a,k=x[sc(f,x[a+28>>1])>>1],u[j+28>>1]=k}Ye(f);gb=d- -64|0;return}a=P()|0;O()|0;Ye(f);S(a|0);L()}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+s|0;n=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],q)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],w)+B(t[e+(f|-6)|0],x)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],m)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Mb(q,-16777216,16776704);m=v[a+64>>2];i=Mb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=oqa(l,r,h,h>>31);l=jb;m=oqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=oqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;l=p>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);o=e+o|0;f=o>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}f=o>>12;l=p>>12}v[a+40>>2]=o;v[a+20>>2]=l;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function h3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-432|0;gb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=Ks(i+424|1,11164,v[c+4>>2]);v[i+380>>2]=i+384;a=ye();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=Hf(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Hf(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2457;k=ge(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22708]=0;a=ga(2477)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[22708]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=ca(2496,i+380|0,a|0,i+424|0,i|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break e}break c}v[22708]=0;a=ga(2477)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22708]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ca(2496,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Fe(k,v[i+380>>2]);j=v[i+380>>2]}f=a+j|0;g=Tg(j,f,c);v[i+116>>2]=2457;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;break g}a=Cd(a<<3);if(!a){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Fe(e,a);l=v[i+380>>2]}v[22708]=0;Fc(i+104|0,c);h=v[22708];v[22708]=0;h:{i:{if((h|0)!=1){v[22708]=0;ja(2505,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}Wb(i+104|0);v[22708]=0;a=la(2506,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(e);Hc(k);gb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function r3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-256|0;gb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=Ks(i+248|1,11164,v[c+4>>2]);v[i+204>>2]=i+208;a=ye();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=Hf(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Hf(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2457;k=ge(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22708]=0;a=ga(2477)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[22708]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=ca(2496,i+204|0,a|0,i+248|0,i|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){break e}break c}v[22708]=0;a=ga(2477)|0;j=v[22708];v[22708]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22708]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ca(2496,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Fe(k,v[i+204>>2]);j=v[i+204>>2]}f=a+j|0;g=Tg(j,f,c);v[i+116>>2]=2457;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;break g}a=Cd(a<<1);if(!a){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Fe(e,a);l=v[i+204>>2]}v[22708]=0;Fc(i+104|0,c);h=v[22708];v[22708]=0;h:{i:{if((h|0)!=1){v[22708]=0;ja(2497,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}Wb(i+104|0);v[22708]=0;a=la(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(e);Hc(k);gb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(i+104|0);break f}c=P()|0;O()|0}Hc(e);break b}L()}c=P()|0;O()|0}Hc(k);S(c|0);L()}function Mi(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0;e=A[b+8>>3];f=A[c>>3];m=e*f;g=A[b>>3];h=A[c+8>>3];p=g*h;i=m+p;q=g*f;r=e*h;k=q-r;a:{if(!Oi(k)){break a}if(!Oi(i)){break a}b:{if(!$g(g)){b=0;if(!$g(e)){break b}}o(+($g(g)?1:0));b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=+n();o(+($g(e)?1:0));b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=+n();o(0);b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=(s=+n(),t=f,u=Oi(f),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=(s=+n(),t=h,u=Oi(h),u?s:t);b=1}c:{d:{if(!$g(f)){if(!$g(h)){break d}}o(+($g(f)?1:0));b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=+n();o(+($g(h)?1:0));b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=+n();o(0);b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=(s=+n(),t=g,u=Oi(g),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=(s=+n(),t=e,u=Oi(e),u?s:t);break c}if(b){break c}e:{if($g(q)){break e}if($g(r)){break e}if($g(p)){break e}if(!$g(m)){break a}}o(0);b=j(1)|0;d=j(0)|0;o(+g);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);g=(s=+n(),t=g,u=Oi(g),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+e);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);e=(s=+n(),t=e,u=Oi(e),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+f);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);f=(s=+n(),t=f,u=Oi(f),u?s:t);o(0);b=j(1)|0;d=j(0)|0;o(+h);c=j(1)|0;j(0)|0;l(0,d|0);l(1,b&2147483647|c&-2147483648);h=(s=+n(),t=h,u=Oi(h),u?s:t)}i=(f*e+h*g)*N;k=(f*g-h*e)*N}Tm(a,k,i)}function kg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;b=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=b+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=b+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((b^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=b+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>=1){break b}}v[a+16>>2]=c;u[a+20>>1]=h}i=((b+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+34704>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+34704>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+34704>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+34704>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+34704>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+34704>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+i|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+34192>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function v6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}f=(b|0)==1?2:b;if(f>>>0>4|!(1<<f&21)){break a}h=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}b=v[c+11004>>2];if((f|0)!=4?b:0){break a}i=v[c+11008>>2]>0?9:8;v[c+11004>>2]=b|(f|0)==4;b=(f|0)!=4;if(!(b|!h)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];h=oJ(c,v[a>>2],e+12|0,b,b,e+8|0,i|4);v[c+43780>>2]=h;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=-3;if((h|0)<0){break a}if(!h){g=1;break a}v[c+43780>>2]=-1;g=-5;break a}h=v[c+10996>>2];if(!h){i=b?i|2:i;j=c+11012|0;d=v[c+10992>>2];h=(f|0)!=4;while(1){b=v[a+4>>2];v[e+8>>2]=32768-d;v[e+12>>2]=b;f=oJ(c,v[a>>2],e+12|0,j,d+j|0,e+8|0,i);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[c+10996>>2]=d;b=v[a+16>>2];d=b>>>0>d>>>0?d:b;hc(v[a+12>>2],v[c+10992>>2]+j|0,d);v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];b=v[c+10996>>2]-d|0;v[c+10996>>2]=b;d=d+v[c+10992>>2]&32767;v[c+10992>>2]=d;if((f|0)<0){break b}g=-5;if(k?0:(f|0)==1){break a}if(!h){if(!f){g=b?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){g=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if(!b){continue}break a}break}g=!b;break a}b=v[a+16>>2];b=b>>>0>h>>>0?h:b;hc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;g=0;if(v[c+43780>>2]){break a}g=!a;break a}g=-3}gb=e+16|0;return g|0}function gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb+-64|0;gb=g;k=c+484344|0;zg(k,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){h=v[a+8>>2];d=sg(a);Rb(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Be(a)+1|0;break b}c=Ng(a)}e=Ng(a);Zc(a,d+h|0);d=g+16|0;Td(d,a,e);h=jc(g+40|0,d);xb(d);v[22708]=0;c=W(331,k|0,j&65535,(c?c>>>0<1024?c:1024:64)|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}c:{if(!c|!e){break c}c=_b(k,j);l=g,m=Vb(c),v[l+16>>2]=m;l=g,m=Zb(c),v[l+8>>2]=m;if(!Gb(g+16|0,g+8|0)){break c}while(1){e=v[g+16>>2];v[22708]=0;c=T(374,h|0)|0;d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){if(!(c&128)){break f}if(c&1){v[22708]=0;d=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e|0]=d}if(c&2){break e}break d}break a}t[e|0]=c;c=255}v[22708]=0;d=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e+1|0]=d}d=0;if(c&4){v[22708]=0;d=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}}if(c&8){v[22708]=0;f=T(374,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}t[e+3|0]=f}if(c&16){v[22708]=0;c=T(374,h|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e+5|0]=c}c=e;g:{h:{f=w[e|0];if(!f){break h}i=255;if((f|0)==97){break g}if(f>>>0>96){break h}i=f+12|0;break g}i=0}t[c|0]=i;i:{if(w[e+5|0]|w[e+3|0]){v[22708]=0;Pf(e);c=v[22708];v[22708]=0;if((c|0)!=1){break i}break a}t[e+3|0]=0}if(w[e+1|0]==255){t[e+1|0]=0}c=d-16|0;j:{if((c&255)>>>0<=64){t[e+4|0]=c;t[e+2|0]=1;break j}if(d>>>0<96){break j}c=d&15;t[e+4|0]=c;d=d-96>>4;t[e+2|0]=w[d+33439|0];if((d|0)!=6){break j}t[e+4|0]=c<<2}c=g+16|0;ak(c);if(Gb(c,g+8|0)){continue}break}}xb(g+40|0);j=j+1|0;if(j>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}gb=g- -64|0;return}a=P()|0;O()|0;xb(g+40|0);S(a|0);L()}function Fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=gb-32|0;gb=i;o=i,p=ar(b),v[o+16>>2]=p;l=i+24|0;n=l;g=gb-32|0;gb=g;c=b;e=a;b=Yd(e);h=fc(e);a:{b:{if(b){wb(e);c:{while(1){d:{e=b+14|0;e:{if(Lu(c,e)){if(!v[b>>2]){break b}h=b;break e}if(!Lu(e,c)){break c}h=b+4|0;if(!v[b+4>>2]){break d}b=h;h=b}b=v[b>>2];continue}break}v[g+28>>2]=b;b=h;break a}v[g+28>>2]=b;b=h;break a}b=fc(e)}v[g+28>>2]=b}h=b;b=v[b>>2];t[g+27|0]=0;if(!b){k=gb-16|0;gb=k;b=fc(a);e=g+8|0;m=Uj(e,Nc(48,4),Vj(k+8|0,b));b=v[m>>2];j=gb-16|0;gb=j;v[j+8>>2]=v[i+16>>2];c=v[j+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+14|0]=f;t[b+15|0]=f>>>8;t[b+16|0]=f>>>16;t[b+17|0]=f>>>24;t[b+18|0]=d;t[b+19|0]=d>>>8;t[b+20|0]=d>>>16;t[b+21|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);f=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+38|0]=f;t[b+39|0]=f>>>8;t[b+40|0]=f>>>16;t[b+41|0]=f>>>24;t[b+42|0]=d;t[b+43|0]=d>>>8;t[b+44|0]=d>>>16;t[b+45|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);f=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+30|0]=f;t[b+31|0]=f>>>8;t[b+32|0]=f>>>16;t[b+33|0]=f>>>24;t[b+34|0]=d;t[b+35|0]=d>>>8;t[b+36|0]=d>>>16;t[b+37|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+22|0]=c;t[b+23|0]=c>>>8;t[b+24|0]=c>>>16;t[b+25|0]=c>>>24;t[b+26|0]=d;t[b+27|0]=d>>>8;t[b+28|0]=d>>>16;t[b+29|0]=d>>>24;u[b+46>>1]=0;gb=j+16|0;o=fc(m),p=1,t[o+4|0]=p;gb=k+16|0;Gk(a,v[g+28>>2],h,v[e>>2]);b=be(e);t[g+27|0]=1;a=v[e>>2];v[e>>2]=0;if(a){fc(e);if(a){tT(a)}}}Wj(n,yc(g+8|0,b),g+27|0);gb=g+32|0;a=Wl(l);gb=i+32|0;return a+32|0}function rk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{if(!v[c>>2]|!d){break a}j=c;f=v[c>>2]+B(d,20)|0;b:{c:{if(v[a+480180>>2]==64){break c}f=v[c>>2]+((B(d,36318)|0)/1024|0)|0;if(v[a+480180>>2]==512){break c}d:{e:{f:{f=v[a+480208>>2];if(f&16){if(v[a+480180>>2]!=4){break f}f=v[a+480208>>2]}if(f&16){break d}Db(i,a+1074312|0,7);if(!Cb(i)){break d}f=v[c>>2];if((d|0)>-1){break e}g=oqa(f,0,14317456,0);h=jb;f=oqa(f,0,0-d|0,0)+14317456|0;d=jb;f=jP(rqa(g,h,f,f>>>0<14317456?d+1|0:d),jb);break c}k=v[c>>2];f=d>>31;v[i+12>>2]=f+d^f;qc(i+12|0,1020);h=v[i+12>>2];f=c;l=f;g=v[f>>2];m=g;n=g>>31;g:{if((d|0)>=1){if(h>>>0<=15){g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h<<2)+(f?43456:43520)>>2];break g}g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h>>>2<<2)+(f?43584:44608)>>2];break g}if(h>>>0<=15){g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h<<2)+(f?43520:43456)>>2];break g}g=gb-16|0;gb=g;f=g+8|0;Db(f,a+1074312|0,7);f=Cb(f);gb=g+16|0;h=v[(h>>>2<<2)+(f?44608:43584)>>2]}h=oqa(m,n,h,h>>31)+32768|0;f=jb;f=Ac(pqa(h,h>>>0<32768?f+1|0:f,65536,0),jb);v[l>>2]=f;if((f|0)!=(k|0)){break b}Db(i,a+1074312|0,7);h=Cb(i);f=v[c>>2];if(!(h^(d|0)>0)){d=(f|0)==2147483647;f=v[c>>2];if(d){break b}f=f+1|0;break c}if((f|0)<2){break b}f=f-1|0;break c}d=oqa(f,f>>31,d,0);h=jb;g=h;if((g|0)>0?1:(g|0)>=0?d>>>0>=14317456:0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}f=jP(rqa(oqa(f,0,14317456,0),jb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),jb);break c}f=v[c>>2]-d|0}v[j>>2]=f}if((f|0)>0){break a}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}gb=i+16|0}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=gb-144|0;gb=c;e=Fm(c+40|0,a);v[22708]=0;d=Q(620,c+24|0,49645)|0;a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[22708]=0;v[c>>2]=19923024;v[c+4>>2]=0;U(621,e|0,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break n}Hb(d);if(v[e>>2]&1073741824){break e}v[22708]=0;d=Q(620,c+24|0,10677)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;ca(1478,e|0,b|0,d|0,1479)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}Hb(d);v[c+20>>2]=0;v[c+16>>2]=0;v[22708]=0;d=Q(620,c+24|0,13818)|0;a=v[22708];v[22708]=0;if((a|0)==1){break k}v[22708]=0;W(1480,e|0,c+20|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break j}Hb(d);v[22708]=0;d=Q(620,c+24|0,13808)|0;a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;W(1480,e|0,c+16|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break h}Hb(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[ro(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[ro(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Go(c+24|0);v[22708]=0;f=Q(620,c|0,11383)|0;a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;U(1481,e|0,d|0,f|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}Hb(f);if(cd(d)){break f}a=v[b+16>>2];v[22708]=0;U(1305,d|0,a|0,16777216);a=v[22708];v[22708]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;Hb(f);break b}v[22708]=0;R(1482,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Lc(d)}gh(e);gb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(d)}gh(e);S(a|0);L()}function rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;m=gb-16|0;gb=m;n=c;k=d;g=gb-32|0;gb=g;l=g+28|0;f=g+24|0;h=c;e=gb-32|0;gb=e;v[e+24>>2]=b;a:{b:{c:{d:{i=a;if(!Rj(e+24|0,yc(e+16|0,Dh(i)))){j=wb(i);if(!Ml(j,h,ve(e+24|0))){break d}}v[e+16>>2]=b;if(!Rj(e+16|0,yc(e+8|0,sC(i)))){o=wb(i);j=e+16|0;p=j;c=v[j>>2];f=v[c>>2];e:{if(f){c=f;while(1){f=c;c=v[c+4>>2];if(c){continue}break}break e}if(ng(c)){while(1){c=v[c+8>>2];if(ng(c)){continue}break}}f=v[c+8>>2]}v[p>>2]=f;if(!Ml(o,ve(j),h)){break c}}if(!v[b>>2]){v[l>>2]=b;break a}b=v[e+16>>2];v[l>>2]=b;b=b+4|0;break a}if(!Ml(j,ve(e+24|0),h)){break b}c=gb-16|0;gb=c;v[c+8>>2]=b;Tj(c+8|0);gb=c+16|0;c=v[c+8>>2];v[e+16>>2]=c;if(!Rj(e+16|0,yc(e+8|0,Dh(i)))){if(!Ml(j,h,ve(e+16|0))){break c}}if(!v[v[e+24>>2]+4>>2]){v[l>>2]=b;b=b+4|0;break a}v[l>>2]=c;b=c;break a}b=cR(i,l,h);break a}v[l>>2]=b;v[f>>2]=b;b=f}gb=e+32|0;c=b;b=v[b>>2];t[g+23|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);h=g+8|0;f=Uj(h,bR(),Vj(i+8|0,b));b=v[f>>2];v[22708]=0;b=b+16|0;e=v[22708];v[22708]=0;f:{if((e|0)!=1){e=v[n+4>>2];v[b>>2]=v[n>>2];v[b+4>>2]=e;wb(k);n=vh(b+8|0);v[b+8>>2]=v[k>>2];v[b+12>>2]=v[k+4>>2];b=wb(k);q=wb(n),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[k>>2]=0;v[k+4>>2]=0;q=fc(f),r=1,t[q+4|0]=r;gb=i+16|0;break f}a=P()|0;O()|0;NA(f);S(a|0);L()}Gk(a,v[g+28>>2],c,v[h>>2]);b=be(h);t[g+23|0]=1;NA(h)}Wj(m,yc(g+8|0,b),g+23|0);gb=g+32|0;a=m;if(!w[fc(a)|0]){c=ve(a)+8|0;b=c;if(v[b>>2]){rf(b);dR(b);tg(b);rf(b);OA(wb(b),v[b>>2],tg(b));q=wb(b),r=0,v[q>>2]=r;v[b>>2]=0;v[b+4>>2]=0}kp(c,d);v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];b=wb(d);q=wb(c),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[yc(m+8|0,v[a>>2])>>2];gb=m+16|0;return a|0}function coa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;v[g+24>>2]=d;k=fg(a,c);te(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!k){if(nd(a,5)){break a}}j=v[g+24>>2];d=gb-160|0;gb=d;h=Fm(d+56|0,v[a+28>>2]);v[22708]=0;e=Q(620,d+8|0,34111)|0;f=v[22708];v[22708]=0;b:{c:{d:{e:{if((f|0)!=1){v[22708]=0;v[d+48>>2]=19923024;v[d+52>>2]=0;U(621,h|0,e|0,d+48|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}Hb(e);if(!(v[h>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}t[d+48|0]=0;t[d+47|0]=0;v[22708]=0;e=Q(620,d+8|0,7364)|0;f=v[22708];v[22708]=0;f:{if((f|0)!=1){v[22708]=0;U(1095,h|0,d+48|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}Hb(e);if(!w[d+48|0]){break b}zf(d+48|0,50);v[22708]=0;e=Q(620,d+8|0,10558)|0;f=v[22708];v[22708]=0;g:{h:{i:{j:{if((f|0)!=1){v[22708]=0;U(1095,h|0,d+47|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}Hb(e);e=Qi(b);f=w[d+48|0];if(e>>>0<f>>>0){e=fB(d+8|0,v[b+12>>2]);v[22708]=0;U(1096,b|0,f|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}Xm(e)}e=0;f=x[Sj(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){i=e&255;bf(Sj(b,i),f);i=Sj(b,i);v[22708]=0;R(1097,d+8|0,d+7|0);l=v[22708];v[22708]=0;if((l|0)==1){break h}v[22708]=0;Y(1098,h|0,i|0,d+8|0,j|0);i=v[22708];v[22708]=0;if((i|0)==1){break g}Hb(d+8|0);e=e+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];j=Qi(b);t[b+16|0]=e>>>0<j>>>0?w[d+47|0]:0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}a=P()|0;O()|0;Xm(e);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(d+8|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e)}gh(h);S(a|0);L()}gh(h);gb=d+160|0}Zf(a,k,c,g+16|0);gb=g+32|0}function Jq(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);Rd(e+12|0,0,127);Rd(e+8|0,0,127);l=a+1074312|0;Db(e,l,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+780>>1]=0;t[b+837|0]=i;j=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=j}Db(e,l,36);i=B(i,d+256|0);j=(i|0)/256|0;k=Cb(e);m=v[e+8>>2];a:{if(!(m|!k|(i|0)<65024)){j=-1;a=b+788|0;if(!ce(a)){break a}if(tu(a)|x[b+786>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=oe(C(10),C(C(0-m|0)*C(.00937500037252903)));i=gb-16|0;gb=i;g=C(B(v[e+12>>2],d+256|0)>>>0);d=a;b:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Xh(C(h*oe(C(2),g))),v[n+12>>2]=o;Rd(i+12|0,120,2e4);k=v[i+12>>2];d=v[d+24620>>2];gb=i+16|0;Db(e,l,36);g=C(C(((d|0)<k<<1?d>>>1|0:k)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){h=f;f=C(C(y[a+24620>>2])/g);g=C(C(h+C(h*f))+C(-1));z[e>>2]=g;f=C(f*f);break c}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;TP(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(g+f))/h);f=C(C(-f)/h);h=C(C(1)/h);d:{if(w[b+845|0]==1){n=b,o=Xh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Xh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Xh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break d}n=b,o=Xh(C(h*C(16777216))),v[n+60>>2]=o;n=b,o=Xh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Xh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}gb=e+16|0;return j}function H2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-624|0;gb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2508;b=ge(a+200|0,a+208|0,a+16|0);v[22708]=0;Fc(a+192|0,e);h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22708]=0;h=T(2481,a+192|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}t[a+191|0]=0;e=v[e+4>>2];v[22708]=0;c=ra(2516,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(!c){break e}c=w[11849]|w[11850]<<8|(w[11851]<<16|w[11852]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[11846]|w[11847]<<8|(w[11848]<<16|w[11849]<<24);v[a+176>>2]=w[11842]|w[11843]<<8|(w[11844]<<16|w[11845]<<24);v[a+180>>2]=c;v[22708]=0;Y(2493,h|0,a+176|0,a+186|0,a+128|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[a+4>>2]=2457;d=ge(a+8|0,0,a+4|0);h=v[a+196>>2];c=h-v[b>>2]|0;e=a+16|0;if((c|0)<393){break h}Fe(d,Cd((c>>>2|0)+2|0));if(v[d>>2]){break i}v[22708]=0;X(2458);c=v[22708];v[22708]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+168|0;while(1){i=a+128|0;j=e,k=w[(a+176|0)+(rx(i,h,c)-i>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;if(c>>>0<y[a+196>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((pH(a+16|0,a)|0)==1){break f}v[22708]=0;_(2510,5133);c=v[22708];v[22708]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[22708]=0;c=Q(2487,a+616|0,a+608|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Wb(a+192|0);Hc(b);gb=a+624|0;return c|0}e=P()|0;O()|0}Wb(a+192|0)}Hc(b);S(e|0);L()}L()}function zo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){d=f+8|0;Db(d,a+1074312|0,15);if(Cb(d)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}c:{if(Kj(b)){d=x[b+768>>1];if(!d){break c}e=v[b+856>>2];c=b;g=v[a+1074392>>2];i=0-d|0;j=d;d=v[b+708>>2];h=(+(g>>>0)+1)*+(((d|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[c+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?e:0)|0;c=a>>31;e=d>>31;if((e+d^e)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+852>>2]=d+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}v[b+708>>2]=d-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}c=1;e:{if(!(t[b+851|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){d=f+8|0;Db(d,a+1074312|0,6);if(Cb(d)){break e}}c=0;if(v[a+480180>>2]!=8){break e}c=(w[a+480208|0]&2)>>>1|0}d=x[b+768>>1];e=v[a+480180>>2];f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}e=(e|0)==268435456&d>>>0>239;if(!(e?t[b+851|0]&1:c)){break f}c=b+700|0;d=B(v[a+480180>>2]==64?2:4,e?d-240|0:d);d=sk(a)?d:0-d|0;e=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&8?0:(e|0)>=(g|0))){rk(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((e|0)<=(g|0)){break f}rk(a,b,c,0-d|0,1);e=v[b+700>>2];d=v[b+708>>2];g:{if((e|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(e|0)){break f}}c=f+8|0;Db(c,a+1074312|0,112);if(!Cb(c)){break f}t[b+851|0]=w[b+851|0]|8}if(v[b+700>>2]!=v[b+708>>2]){break c}c=f+8|0;Db(c,a+1074312|0,25);if(!(k=Cb(c),l=1,m=v[a+480180>>2]!=1,m?k:l)){break c}v[b+708>>2]=0}gb=f+16|0}function Q2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2508;b=ge(a+152|0,a+160|0,a+16|0);v[22708]=0;Fc(a+144|0,e);h=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22708]=0;h=T(21,a+144|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break k}t[a+143|0]=0;e=v[e+4>>2];v[22708]=0;c=ra(2509,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(!c){break e}c=w[11849]|w[11850]<<8|(w[11851]<<16|w[11852]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[11846]|w[11847]<<8|(w[11848]<<16|w[11849]<<24);v[a+128>>2]=w[11842]|w[11843]<<8|(w[11844]<<16|w[11845]<<24);v[a+132>>2]=c;v[22708]=0;Y(2473,h|0,a+128|0,a+138|0,a+118|0);c=v[22708];v[22708]=0;if((c|0)==1){break j}v[a+4>>2]=2457;d=ge(a+8|0,0,a+4|0);h=v[a+148>>2];e=a+16|0;if((h-v[b>>2]|0)<99){break h}Fe(d,Cd((h-v[b>>2]|0)+2|0));if(v[d>>2]){break i}v[22708]=0;X(2458);c=v[22708];v[22708]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+128|0;while(1){j=e,k=w[((Vm(a+118|0,h,c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;if(c>>>0<y[a+148>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((pH(a+16|0,a)|0)==1){break f}v[22708]=0;_(2510,5133);c=v[22708];v[22708]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Hc(d);break c}Hc(d)}v[22708]=0;c=Q(2460,a+280|0,a+272|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Wb(a+144|0);Hc(b);gb=a+288|0;return c|0}e=P()|0;O()|0}Wb(a+144|0)}Hc(b);S(e|0);L()}L()}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;q=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;n=v[a+56>>2];v[f+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;if(d){while(1){n=1;i=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];t=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];k=0;e=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[i+(h|8)>>1],o)+B(u[i+(h|4)>>1],l)|0)+B(u[i+(h|12)>>1],m)|0)+B(j,u[i+(h|16)>>1])|0)/2|0)+((((B(u[i+(h|-8)>>1],w)+B(u[i+(h|-12)>>1],x)|0)+B(u[i+(h|-4)>>1],t)|0)+B(u[i+h>>1],p)|0)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];m=v[a+60>>2];o=m;h=(f+32|0)+(k<<3)|0;k=v[h>>2];e=Mb(k,-16777216,16776704);l=v[a+64>>2];i=Mb(v[h+4>>2],-16777216,16776704);p=m>>31;m=g<<8;g=m;g=oqa(o,p,g,g>>31);o=jb;l=oqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+o|0;e=g>>>0<l>>>0?e+1|0:e;p=g;g=v[a+68>>2];g=oqa(g,g>>31,i,i>>31);i=p+g|0;e=jb+e|0;e=i>>>0<g>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Jc(i,e,24);v[h+4>>2]=k;i=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(i&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];n=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function u2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;u=gb-16|0;gb=u;v[c>>2]=a;A=d&512;B=h<<2;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=Vs(g,32);h=v[c>>2];v[c>>2]=h+4;v[h>>2]=p;break a;case 3:if(gd(n)){break a}p=v[yk(n,0)>>2];h=v[c>>2];v[c>>2]=h+4;v[h>>2]=p;break a;case 2:if(gd(m)|!A){break a}D=c,E=Wi(zd(m),vi(m),v[c>>2]),v[D>>2]=E;break a;case 4:break b;default:break a}}C=v[c>>2];e=e+B|0;h=e;c:{if(h>>>0>=f>>>0){break c}while(1){if(!jl(g,2048,v[h>>2])){break c}h=h+4|0;if(h>>>0<f>>>0){continue}break}}if((o|0)>=1){d:{e:{if(e>>>0>=h>>>0){q=o;break e}r=v[c>>2];q=o;while(1){f:{h=h-4|0;v[r>>2]=v[h>>2];p=q;q=p-1|0;r=r+4|0;if(e>>>0>=h>>>0){break f}if((p|0)>1){continue}}break}v[c>>2]=r;if((p|0)>1){break e}p=v[c>>2];r=p+4|0;break d}z=Vs(g,48);s=v[c>>2];r=s+4|0;while(1){v[s>>2]=z;p=r;r=p+4|0;x=(q|0)>1;q=q-1|0;s=p;if(x){continue}break}}v[c>>2]=r;v[p>>2]=j}g:{if((e|0)==(h|0)){p=Vs(g,48);h=v[c>>2];r=h+4|0;v[c>>2]=r;v[h>>2]=p;break g}if(gd(l)){p=-1}else{p=t[pc(l,0)|0]}s=0;q=0;while(1){h:{if((p|0)!=(q|0)){break h}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;q=0;s=s+1|0;if(Ab(l)>>>0<=s>>>0){break h}if(w[pc(l,s)|0]==127){p=-1;break h}p=t[pc(l,s)|0]}h=h-4|0;z=v[h>>2];x=v[c>>2];r=x+4|0;v[c>>2]=r;v[x>>2]=z;q=q+1|0;if((e|0)!=(h|0)){continue}break}}qx(C,r)}y=y+1|0;if((y|0)!=4){continue}break}if(Ab(n)>>>0>1){D=u,E=zd(n),v[D+8>>2]=E;e=gb-16|0;gb=e;v[e+8>>2]=v[u+8>>2];Qe(e+8|0);gb=e+16|0;D=c,E=Wi(v[e+8>>2],vi(n),v[c>>2]),v[D>>2]=E}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=u+16|0}function $M(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){if(!ng(d)){while(1){d=v[d+8>>2];if(!ng(d)){continue}break}}d=v[d+8>>2];break c}d=UV(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(ng(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){v[d+8>>2]=v[b+8>>2];f:{if(ng(b)){f=v[d+8>>2];break f}f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;ep(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){ep(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=ng(c);d=w[c+12|0];g:{h:{if(!b){if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;vr(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];i:{if(!(w[b+12|0]?0:b)){b=v[c+4>>2];if(w[b+12|0]?0:b){break i}t[c+12|0]=0;j:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break j}a=b}t[a+12|0]=1;return}if(!ng(b)){break h}b=v[b+8>>2]+4|0;break g}a=v[c+4>>2];if(w[a+12|0]?0:a){break i}t[b+12|0]=1;t[c+12|0]=0;ur(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;vr(v[c+8>>2]);return}if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;ur(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];k:{if(w[d+12|0]?0:d){break k}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(ng(b)){b=v[b+8>>2]+4|0;break g}b=v[b+8>>2];break g}if(w[d+12|0]?0:d){break k}t[b+12|0]=1;t[c+12|0]=0;vr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;ur(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function e8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;g=mc(a);a=b+24|0;f=Sb(v[a>>2]+484360|0);v[22708]=0;h=Si(f);f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)==1){break c}v[22708]=0;R(1421,g|0,h|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}d:{e:{if(h){f=0;while(1){c=x[sc(Sb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[22708]=0;d=am(d+484344|0,c);i=v[22708];v[22708]=0;if((i|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[sc(Sb(v[a>>2]+484360|0),f)>>1]);v[22708]=0;R(2099,e|0,c|0);c=v[22708];v[22708]=0;g:{h:{i:{if((c|0)!=1){v[22708]=0;U(2093,e+16|0,b|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}v[22708]=0;R(1423,g|0,e+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}vb(e+16|0);vb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(e+16|0)}vb(e);break a}v[22708]=0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if((c|0)==65534){v[22708]=0;c=Q(70,e+16|0,6397)|0;d=v[22708];v[22708]=0;j:{if((d|0)!=1){v[22708]=0;R(1423,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break j}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22708]=0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if((c|0)==65535){v[22708]=0;c=Q(70,e+16|0,6359)|0;d=v[22708];v[22708]=0;k:{if((d|0)!=1){v[22708]=0;R(1423,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break k}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22708]=0;c=Q(70,e+16|0,11811)|0;d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;R(1423,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}vb(c)}f=f+1|0;if((h|0)!=(f|0)){continue}break}}gb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}j=a,k=Hu(t[a+36|0],t[a+37|0]),v[j+24>>2]=k;u[a+36>>1]=0;if((b|0)!=1){break a}e=oqa(v[a+24>>2],0,8272,0)+4181|0;d=jb;j=a,k=Qc(rqa(e,e>>>0<4181?d+1|0:d,8363,0),jb),v[j+24>>2]=k;break a}if(d){break a}if((c|0)==1){e=oqa(v[a+24>>2],0,8363,0)+4136|0;d=jb;j=a,k=Qc(rqa(e,e>>>0<4136?d+1|0:d,8272,0),jb),v[j+24>>2]=k}e=gb-16|0;gb=e;g=e+8|0;h=g;d=gb-16|0;gb=d;i=v[a+24>>2];b:{if(!i){t[h|0]=0;t[h+1|0]=0;break b}kt(d+8|0,Mb(Po(Tp(+(i>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];gB(h,d+7|0,d+6|0)}gb=d+16|0;yc(e,a+36|0);d=e+4|0;yc(d,a+37|0);sS(e,g);sS(d,g+1|0);gb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}d=c&4;if(d){e=x[a+34>>1];if(!(e&32)){u[a+28>>1]=128;u[a+34>>1]=e|32}zf(a+40|0,15);zf(a+41|0,63)}c:{if(!(!d|!(b&16777248)?c&16777248?b&4:0:1)|!w[a+41|0]){break c}e=w[a+40|0];if(!e){break c}b=a;d=w[a+39|0];if(d){g=dm(Qc(((e<<8|d>>>1)>>>0)/(d>>>0)|0,0))}else{g=255}t[b+39|0]=g}d:{e:{if((c|0)!=4){if((c|0)==16777216){break d}if((c|0)!=32|w[a+38|0]!=2){break e}t[a+38|0]=3;break e}if(w[a+38|0]!=4){break e}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}f:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Qo(a,0,f);break f}if(!(w[a+35|0]&2)|(c|0)!=2){break f}a=a+68|0;b=lc(a,8);t[b|0]=w[b|0]&3;a=lc(a,9);t[a|0]=w[a|0]&3}gb=f+32|0}function C_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-80|0;gb=e;vc(b);rs(a);a:{if(!Jh(b,e+72|0)){break a}if(!sF(e+72|0)){break a}if(!c){j=1;break a}if(!Pb(b,4)){break a}Ww(a);p=e,q=Vw(),v[p+48>>2]=q;c=e+48|0;Uw(lj(a)+32|0,c);ps(c);k=v[lj(a)+32>>2];c=jm(b);if(c&1){break a}d=c-4|0;Zc(b,d);g=gb-16|0;gb=g;c=g+8|0;Ew(c,b);f=w[lc(c,0)|0];i=w[lc(c,1)|0];c=w[lc(c,2)|0];gb=g+16|0;g=c|(i<<8|f<<16);if(!g){break a}v[22708]=0;R(271,k|0,g|0);c=v[22708];v[22708]=0;j=1;if((c|0)==1){a=V(89104)|0;if((O()|0)==(ea(89104)|0)){Z(a|0)|0;$();j=0;break a}S(a|0);L()}Zc(b,4);l=e+48|0;rF(l,b);i=v[k>>2];f=gb-32|0;gb=f;b=v[l>>2];t[f+24|0]=w[b|0];t[f+25|0]=w[b+1|0];t[f+26|0]=w[b+2|0];t[f+27|0]=w[b+3|0];c=qF(f+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;ek(c,w[d-1|0]);b=g;while(1){b:{if(!ek(c,1)){v[f+4>>2]=1;while(1){d=ek(c,2);v[f+4>>2]=d+v[f+4>>2];if((d|0)==3){continue}break}qc(f+4|0,b);d=0;if(v[f+4>>2]){while(1){b=b-1|0;p=i+b|0,q=ek(c,8),t[p|0]=q;d=d+1|0;if(d>>>0<y[f+4>>2]){continue}break}}if(!b){break b}}d=ek(c,2);v[f+4>>2]=d+2;c:{if((d|0)==3){d=c;if(ek(c,1)){h=w[lc(f+24|0,3)|0]}else{h=7}m=ek(d,h);while(1){d=ek(c,3);v[f+4>>2]=d+v[f+4>>2];if((d|0)==7){continue}break}break c}m=ek(c,w[lc(f+24|0,d)|0])}qc(f+4|0,b);h=0;n=v[f+4>>2];if(n){while(1){d=0;o=b+m|0;if(g>>>0>o>>>0){d=w[i+o|0]}b=b-1|0;t[i+b|0]=d;h=h+1|0;if((n|0)!=(h|0)){continue}break}}if(b){continue}}break}gb=f+32|0;Vd(e+32|0,k);b=v[e+36>>2];v[e+16>>2]=v[e+32>>2];v[e+20>>2]=b;rh(e+40|0,e+16|0);b=Ud(e+24|0);c=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;b=os(l,e+8|0,e);Vc(lj(a)+12|0,b);xb(b)}gb=e+80|0;return j|0}function qz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;h=b,i=w[ac(b,f+15|0)|0],t[h|0]=i;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){e=w[d+39104|0];m:{n:{if(c){if(e>>>0>=g>>>0){break n}break m}if((e|0)!=(g|0)){break m}}t[a|0]=11;t[b|0]=d;e=1;break a}e=0;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[ac(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}gb=f+16|0;return e}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(j>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;j=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];r=v[a+60>>2];b=Mb(m,-16777216,16776704);o=v[a+64>>2];g=Mb(g,-16777216,16776704);b=oqa(o,o>>31,b,b>>31);o=jb;q=b;j=(((((((B(i,n)+B(f,j)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=j;f=oqa(r,r>>31,b,b>>31);e=q+f|0;b=jb+o|0;b=e>>>0<f>>>0?b+1|0:b;q=e;e=v[a+68>>2];e=oqa(e,e>>31,g,g>>31);g=q+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];e=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;n=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,n);k=e+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,i);b=b-(g&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}r=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(j>>>16&65520)+p|0;j=u[e+14>>1];i=t[b+3|0];o=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Mb(m,-16777216,16776704);n=v[a+64>>2];g=Mb(g,-16777216,16776704);b=oqa(n,n>>31,b,b>>31);n=jb;J=b;b=v[a+68>>2];q=oqa(b,b>>31,g,g>>31);g=J+q|0;b=jb+n|0;b=g>>>0<q>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,o)|0)+B(f,j)<<8)/32768<<8;f=oqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];j=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;o=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,o);k=j+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,i);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;q=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;e=v[a+48>>2];v[g+36>>2]=e;k=v[a+52>>2];v[g+40>>2]=k;n=v[a+56>>2];v[g+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];i=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=i;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;if(d){while(1){f=(((i&2147483647)<<1|j>>>31)&-2)+q|0;n=1;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];w=u[e+28>>1];x=u[e+26>>1];y=u[e+24>>1];k=0;e=1;h=0;while(1){v[(g+8|0)+(h<<2)>>2]=(((((B(t[f+(h|4)|0],o)+B(t[f+(h|2)|0],l)|0)+B(t[f+(h|6)|0],m)|0)+B(j,t[f+(h|8)|0])<<8)/2|0)+((((B(t[f+(h|-4)|0],x)+B(t[f+(h|-6)|0],y)|0)+B(t[f+(h|-2)|0],w)|0)+B(t[h+f|0],p)<<8)/2|0)|0)/16384;i=e;e=0;h=1;if(i){continue}break}while(1){j=(g+8|0)+(k<<2)|0;f=v[j>>2];m=v[a+60>>2];o=m;i=(g+32|0)+(k<<3)|0;k=v[i>>2];e=Mb(k,-16777216,16776704);l=v[a+64>>2];h=Mb(v[i+4>>2],-16777216,16776704);p=m>>31;m=f<<8;f=m;f=oqa(o,p,f,f>>31);o=jb;l=oqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+o|0;e=f>>>0<l>>>0?e+1|0:e;l=f;f=v[a+68>>2];f=oqa(f,f>>31,h,h>>31);h=l+f|0;e=jb+e|0;e=h>>>0<f>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Jc(h,e,24);v[i+4>>2]=k;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[i>>2]=e-(h&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],r);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];i=v[g+28>>2];continue}break}j=v[g+24>>2];i=v[g+28>>2];n=v[g+44>>2];k=v[g+40>>2];h=v[g+32>>2];e=v[g+36>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=h;v[a>>2]=j;v[a+4>>2]=i;gb=g+48|0}function y2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=gb-16|0;gb=x;v[c>>2]=a;A=d&512;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=pn(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(gd(n)){break a}q=w[pc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(gd(m)|!A){break a}C=c,D=Wi(zd(m),ef(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+h|0;r=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!nh(g,2048,t[r|0])){break c}r=r+1|0;if(r>>>0<f>>>0){continue}break}}if((o|0)>=1){q=o;d:{if(e>>>0<r>>>0){while(1){e:{r=r-1|0;p=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=p;s=q;q=q-1|0;if(e>>>0>=r>>>0){break e}if((s|0)>1){continue}}break}u=0;p=0;if((s|0)<2){break d}}u=pn(g,48);p=q}q=v[c>>2];v[c>>2]=q+1;if((p|0)>=1){while(1){t[q|0]=u;q=v[c>>2];v[c>>2]=q+1;s=(p|0)>1;p=p-1|0;if(s){continue}break}}t[q|0]=j}f:{if((e|0)==(r|0)){q=pn(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break f}if(gd(l)){q=-1}else{q=t[pc(l,0)|0]}u=0;p=0;while(1){g:{if((p|0)!=(q|0)){break g}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;p=0;u=u+1|0;if(Ab(l)>>>0<=u>>>0){break g}if(w[pc(l,u)|0]==127){q=-1;break g}q=t[pc(l,u)|0]}r=r-1|0;s=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=s;p=p+1|0;if((e|0)!=(r|0)){continue}break}}nm(B,v[c>>2])}y=y+1|0;if((y|0)!=4){continue}break}if(Ab(n)>>>0>1){C=x,D=zd(n),v[C+8>>2]=D;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];v[e+8>>2]=v[e+8>>2]+1;gb=e+16|0;C=c,D=Wi(v[e+8>>2],ef(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function Ns(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Pp(c,d);v[i+4>>2]=2457;n=gH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break b}Fe(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!gd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22708]=0;h=Q(2459,a|0,i+120|0)|0;b=v[22708];v[22708]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22708]=0;b=Q(2460,a|0,i+120|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[22708]=0;p=T(2461,a|0)|0;b=v[22708];v[22708]=0;f:{if((b|0)!=1){if(g){break f}v[22708]=0;p=Q(2462,e|0,p|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=t[pc(h,r)|0];h:{if(g){break h}v[22708]=0;q=Q(2462,e|0,q<<24>>24)|0;u=v[22708];v[22708]=0;if((u|0)!=1){break h}break b}i:{if((p&255)==(q&255)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22708]=0;T(2463,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);S(a|0)}L()}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;g=v[a+52>>2];v[b+40>>2]=g;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;h=j>>>21&2040;j=u[h+46166>>1];i=u[h+46164>>1];k=u[h+46162>>1];p=u[h+46160>>1];h=0;g=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],p)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;l=g&1;g=0;f=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;g=v[j>>2];i=v[a+60>>2];k=i;h=(b+32|0)+(h<<3)|0;p=v[h>>2];e=Mb(p,-16777216,16776704);l=v[a+64>>2];f=Mb(v[h+4>>2],-16777216,16776704);q=i>>31;i=g<<8;g=i;g=oqa(k,q,g,g>>31);k=jb;l=oqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+k|0;e=g>>>0<l>>>0?e+1|0:e;k=g;g=v[a+68>>2];g=oqa(g,g>>31,f,f>>31);f=k+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[h+4>>2]=p;f=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(f&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);n=e+n|0;k=n>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];g=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}k=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function vfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=gb-48|0;gb=g;h=Li(b)^-1;a:{if(Nb(d)>>>0<=h>>>0){_t(a);break a}Li(b);c=c+4|0;if((w[c|0]|w[c+1|0]<<8)>>>0>=60){Rb(b,4)}k=g,l=Li(b),v[k+44>>2]=l;Rb(b,4);i=Li(b);j=Li(b);if(!((j|0)>36?(i|0)>=1:0)){_t(a);break a}b:{if(!f){break b}if(!yr(Ad(e,v[Lb(d,h)>>2]),f)){break b}_t(a);break a}Sw(g,b,j,i);b=jc(g+24|0,g);xb(g);v[22708]=0;d=T(275,b|0)|0;e=v[22708];v[22708]=0;c:{if((e|0)==1){break c}d:{e:{if(!d){v[22708]=0;T(1427,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break e}break c}if((w[c|0]|w[c+1|0]<<8)>>>0<=39){v[22708]=0;Q(318,b|0,8)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}}if((w[c|0]|w[c+1|0]<<8)>>>0<=59){v[22708]=0;Q(318,b|0,16)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}}v[22708]=0;T(1419,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}f:{if((w[c|0]|w[c+1|0]<<8)>>>0>=120){v[22708]=0;T(1419,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;Q(318,b|0,8)|0;break f}if((w[c|0]|w[c+1|0]<<8)>>>0>=100){v[22708]=0;Q(318,b|0,4)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;T(1419,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;Q(318,b|0,4)|0;break f}if((w[c|0]|w[c+1|0]<<8)>>>0>=62){v[22708]=0;T(1419,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;Q(318,b|0,4)|0;break f}v[22708]=0;T(1419,b|0)|0}c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=T(1419,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;U(288,g|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break d}jc(a,g);v[a+20>>2]=v[g+44>>2];xb(g)}xb(b);break a}}a=P()|0;O()|0;xb(b);S(a|0);L()}gb=g+48|0}function HS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-32|0;gb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;d=!(b&2);b=w[a+14|0];if(d|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}while(1){d=Cc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Nb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}d=x[Cc(a,w[a+14|0])>>1];e=Cc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Cc(a,b)>>1]-1&65535;d=Vq(a,b,64,64);q=f,r=Vb(a),v[q+8>>2]=r;q=f,r=Zo(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Gd(f+24|0,f+16|0);h=rr(f,b,d&255);g=gb-32|0;gb=g;v[g+24>>2]=v[e>>2];b=a;d=v[a>>2];q=g,r=Vb(a),v[q>>2]=r;d=d+(mv(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[wb(a)>>2]){i=v[b+4>>2];if((i|0)!=(d|0)){break d}sW(b,h);break c}e=wb(b);e=zp(g,fh(b,Nb(b)+1|0),d-v[b>>2]>>2,e);v[22708]=0;R(1078,e|0,h|0);l=v[22708];v[22708]=0;e:{if((l|0)==1){break e}v[22708]=0;d=W(1079,b|0,e|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}gj(e);break c}a=P()|0;O()|0;gj(e);S(a|0);L()}m=gb-16|0;gb=m;l=d;o=b;p=v[b+4>>2];b=(p-(d+4|0)|0)+d|0;j=Eg(m,o,i-b>>2);f:{g:{if(b>>>0<i>>>0){k=v[j+4>>2];e=b;while(1){n=wb(o);v[22708]=0;gn(n,k,e);n=v[22708];v[22708]=0;if((n|0)==1){break g}k=k+4|0;v[j+4>>2]=k;e=e+4|0;if(i>>>0>e>>>0){continue}break}}$b(j);Ar(l,b,p);gb=m+16|0;break f}a=P()|0;O()|0;$b(j);S(a|0);L()}u[d>>1]=x[h>>1];t[d+2|0]=w[h+2|0]}Gg(d);gb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}gb=f+32|0}function Ms(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Pp(c,d);v[i+4>>2]=2457;n=gH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Cd(k);if(!j){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break a}break b}Fe(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!gd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22708]=0;h=Q(2486,a|0,i+120|0)|0;b=v[22708];v[22708]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22708]=0;b=Q(2487,a|0,i+120|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Hc(n);gb=i+128|0;return d|0}break b}v[22708]=0;p=T(2488,a|0)|0;b=v[22708];v[22708]=0;f:{if((b|0)!=1){if(g){break f}v[22708]=0;p=Q(2489,e|0,p|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=v[yk(h,r)>>2];h:{if(g){break h}v[22708]=0;q=Q(2489,e|0,q|0)|0;u=v[22708];v[22708]=0;if((u|0)!=1){break h}break b}i:{if((p|0)==(q|0)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22708]=0;T(2490,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Hc(n);S(a|0)}L()}function h8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(Bj(b)){Ah(c+56|0);break n}v[22708]=0;R(2097,c+40|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;a=T(2085,c+40|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break l}v[c+56>>2]=a;Yf(c+40|0)}if(Bj(b)){a=b+36|0}else{a=v[c+56>>2]}e=io(a);v[22708]=0;R(1421,f|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break k}h=c,i=Vb(a),v[h+32>>2]=i;h=c,i=Zb(a),v[h+24>>2]=i;if(Gb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Sj(v[a>>2]+484360|0,w[e+16|0]);v[22708]=0;R(2098,c+8|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break j}v[22708]=0;R(2040,c+40|0,c+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}v[22708]=0;R(1423,f|0,c+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}vb(c+40|0);vb(c+8|0);o:{if(!gd(DK(f))){break o}d=w[e+12|0];v[22708]=0;d=Q(472,b|0,d|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[22708]=0;d=Jk(d);g=v[22708];v[22708]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[sc(b,v[e+12>>2])>>1]);v[22708]=0;R(2099,c+8|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Y(360,c+40|0,0,d|0,c+8|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=c+40|0;Eb(DK(f),b);vb(b);vb(c+8|0)}b=c+32|0;YK(b);if(Gb(b,c+24|0)){continue}break}}wl(c+56|0);gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Yf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(c+40|0)}vb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(c+8|0);break b}b=P()|0;O()|0}wl(c+56|0)}yd(f);S(b|0);L()}function Xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=gb-32|0;gb=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;d=0;l=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(l>>>0<=b>>>0){break a}if(!c|Si(a)>>>0>=l>>>0){break a}yg(e+28|0,l-b&65535);s=e,t=Zl(a),u[s+8>>1]=t;b=Le(e+30|0,e+8|0);fW(a,x[e+28>>1]+x[b>>1]|0);b=x[e+30>>1];if(tc(a)>>>0<b>>>0){Bf(a,x[e+30>>1])}s=e,t=Vb(a),v[s>>2]=t;c=x[e+30>>1];b=gb-16|0;gb=b;v[b+8>>2]=v[e>>2];v[b+8>>2]=v[b+8>>2]+(c<<1);gb=b+16|0;v[e+8>>2]=v[b+8>>2];b=v[Gd(e+16|0,e+8|0)>>2];f=x[e+28>>1];i=e+26|0;j=gb-32|0;gb=j;v[j+24>>2]=b;c=a;b=v[c>>2];s=j,t=Vb(c),v[s>>2]=t;d=b+(rp(j+24|0,j)<<1)|0;b:{c:{d:{if(!f){break d}b=v[wb(c)>>2];g=v[c+4>>2];if(f>>>0<=b-g>>1>>>0){b=f;k=g-d|0;h=k>>1;if(b>>>0>h>>>0){tp(c,f-h|0,i);b=h;if(!k){break d}}p=gb-16|0;gb=p;k=c;m=g;n=d;r=v[c+4>>2];h=(r-((f<<1)+d|0)|0)+d|0;q=mi(p,c,g-h>>1);if(g>>>0>h>>>0){o=v[q+4>>2];g=h;while(1){wb(k);Ro(o,g);o=o+2|0;v[q+4>>2]=o;g=g+2|0;if(m>>>0>g>>>0){continue}break}}$b(q);Ar(n,h,r);gb=p+16|0;lv(d,b,i+((d>>>0<=i>>>0?i>>>0<y[c+4>>2]?f:0:0)<<1)|0);break d}b=wb(c);g=En(j,Uk(c,tc(c)+f|0),d-v[c>>2]>>1,b);v[22708]=0;U(312,g|0,f|0,i|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=c;Ep(c);f=g;k=v[f+4>>2];h=d;n=f+4|0;Ck(wb(c),v[c>>2],d,n);wb(c);i=f+8|0;m=i;d=v[c+4>>2];if((h|0)!=(d|0)){c=v[m>>2];while(1){Ro(c,h);c=v[m>>2]+2|0;v[m>>2]=c;h=h+2|0;if((d|0)!=(h|0)){continue}break}}xc(b,n);xc(b+4|0,i);xc(wb(b),dc(f));v[f>>2]=v[f+4>>2];$r(b,tc(b));d=k;Ih(g)}Gg(d);gb=j+32|0;break b}a=P()|0;O()|0;Ih(g);S(a|0);L()}if(tc(a)>>>0>l>>>0){Bf(a,l)}d=x[e+28>>1]}gb=e+32|0;return d&65535}function mO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;f=B(b,872)+a|0;a:{if(w[f+1075082|0]&2){h=1;b:{if(!(w[a+480209|0]&16)){break b}h=0;if(!(v[a+480180>>2]&16777248)){break b}h=!(w[a+480208|0]&4)}if(v[a+480180>>2]==64){a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1;break a}k=f+1074992|0;c:{if(!h){break c}f=g+8|0;Db(f,a+1074312|0,21);if(!Cb(f)){break c}f=B(b,872)+a|0;e=f+1075811|0;t[e|0]=w[e|0]+(w[f+1075815|0]<<2)}e=B(b,872)+a|0;i=e+1075814|0;j=e+1075811|0;f=Pz(a,w[i|0],w[j|0]);d:{if(Kj(k)){z[d>>2]=z[d>>2]+C(C(C(B(w[e+1075816|0],f)|0)*C(.05000000074505806))/C(7680));c=e+1075843|0;d=w[c|0];t[c|0]=d&207|32;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break d}t[c|0]=d|48;break d}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}f=v[a+480180>>2]&5?(w[i|0]&3)==1?0-f|0:f:f;d=g+8|0;i=a+1074312|0;Db(d,i,21);d=Cb(d);e=v[a+480208>>2];e:{if(d){d=e&4;f=d?f:0-f|0;d=d?5:6;break e}d=5;f:{if(e&131072){break f}d=8;if(v[a+480180>>2]==1024){break f}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break f}d=6}e=g+8|0;Db(e,i,80);if(!Cb(e)){break e}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}e=B(b,872)+a|0;d=(0-B(w[e+1075816|0],f)|0)/(1<<d)|0;rk(a,k,c,d,0);c=mu(a,b);if(!c){break d}f=c;e=v[e+1075648>>2];if(e){e=w[e+33|0]}else{e=2}kb[v[v[c>>2]+88>>2]](f,d,e<<24>>24,b)}if(!h){break a}c=g+8|0;Db(c,a+1074312|0,21);if(Cb(c)){break a}t[j|0]=w[j|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[f+1075662|0]&2)){break a}a=mu(a,b);if(!a){break a}kb[v[v[a>>2]+88>>2]](a,0,0,b)}gb=g+16|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;f=v[a+52>>2];v[b+40>>2]=f;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;g=j>>>21&2040;j=u[g+46166>>1];i=u[g+46164>>1];k=u[g+46162>>1];p=u[g+46160>>1];h=0;m=1;f=1;g=0;while(1){v[(b+8|0)+(g<<2)>>2]=(((B(t[e+g|0],k)+B(t[e+(g|-2)|0],p)|0)+B(i,t[e+(g|2)|0])|0)+B(j,t[e+(g|4)|0])<<8)/16384;l=f&1;f=0;g=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;f=v[j>>2];i=v[a+60>>2];k=i;g=(b+32|0)+(h<<3)|0;p=v[g>>2];e=Mb(p,-16777216,16776704);l=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=oqa(k,r,f,f>>31);k=jb;l=oqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=v[a+68>>2];f=oqa(f,f>>31,h,h>>31);h=k+f|0;e=jb+e|0;e=f>>>0>h>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Jc(h,e,24);v[g+4>>2]=p;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[g>>2]=e-(h&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;g=n>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];f=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}g=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=f;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=g;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function C3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Kb(a+208|0);v[22708]=0;Fc(a+16|0,d);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[22708]=0;b=T(2481,a+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[22708]=0;Y(2493,b|0,83408,83434,a+224|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22708]=0;d=Q(2486,a+344|0,a+336|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22708]=0;R(76,c|0,b<<1);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[22708]=0;d=T(2488,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(om(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22708]=0;T(2490,a+344|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22708]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22708]=0;d=ga(2477)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[a>>2]=f;v[22708]=0;b=ca(2478,b|0,d|0,a|0,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22708]=0;b=Q(2487,a+344|0,a+336|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(c);vb(h);gb=a+352|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function Sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-16|0;gb=e;a:{if(!Pb(a,2)){wh(c+484344|0,b,64);break a}j=c+484344|0;h=Fd(Mr(a),1,1024);if(!wh(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){m=Uf(_b(j,b),i);g=0;if(k){while(1){d=e+8|0;vn(d,a);n=qd(d);o=Ve(d);c=B(g,6)+m|0;f=w[ej(d)|0];t[c+5|0]=f;l=0;d=w[d|0];if((d-1&255)>>>0<=35){t[c|0]=d+48;l=w[n|0]+1|0}d=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[d|0]=f&15;break b;case 2:t[c+3|0]=3;t[d|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=39;t[e+7|0]=15;p=d,q=w[ac(e+7|0,d)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=38;t[e+6|0]=15;p=d,q=w[ac(e+6|0,d)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=39;t[e+5|0]=15;p=d,q=w[ac(e+5|0,d)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=38;t[e+4|0]=15;p=d,q=w[ac(e+4|0,d)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[d|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:_o(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[d|0]=f&15;break b;case 5:t[d|0]=f<<4;break b;case 6:t[e+3|0]=f&15;t[e+2|0]=14;p=d,q=w[ac(e+3|0,e+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[e+1|0]=f&15;t[e|0]=14;p=d,q=w[ac(e+1|0,e)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[d|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=e+16|0}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;ud(b,2);d=e+16|0;Lk(d,2,a+1|0);f=e+32|0;Bc(f,d);v[22708]=0;Q(303,b+43|0,f|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;f=e+32|0;h=b,i=v[Fb(f,e+16|0)>>2],v[h+4>>2]=i;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=b,i=v[Fb(f,b)>>2],v[h+8>>2]=i;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>y[b+4>>2]?d>>>0>=2:0){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}f=e+16|0;Ai(f,a+16|0);d=e+32|0;g=v[f>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d|0]=g;t[d+1|0]=g>>>8;t[d+2|0]=g>>>16;t[d+3|0]=g>>>24;Ai(f,a+20|0);g=v[e+16>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d+4|0]=g;t[d+5|0]=g>>>8;t[d+6|0]=g>>>16;t[d+7|0]=g>>>24;Ai(f,a+24|0);f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Qo(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;h=b,i=w[ac(e+32|0,e+16|0)|0]<<2,u[h+30>>1]=i;d=a+32|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(w[a|0]==2){d=x[b>>1];v[b>>2]=d;break b}a=b;if(y[b>>2]>=65536){v[a>>2]=65535}d=v[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}v[b>>2]=a}gb=e+48|0;return}a=P()|0;O()|0;vb(e+32|0);S(a|0);L()}function P3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Kb(a+208|0);v[22708]=0;Fc(a+16|0,d);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[22708]=0;b=T(21,a+16|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[22708]=0;Y(2473,b|0,83408,83434,a+224|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}Wb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22708]=0;d=Q(2459,a+264|0,a+256|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22708]=0;R(76,c|0,b<<1);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=Kc(c);v[22708]=0;R(76,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=pc(c,0);v[a+188>>2]=d+b}v[22708]=0;d=T(2461,a+264|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}if(pm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22708]=0;T(2463,a+264|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Wb(a+16|0);break a}v[22708]=0;R(76,c|0,v[a+188>>2]-b|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22708]=0;d=ga(2477)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[a>>2]=f;v[22708]=0;b=ca(2478,b|0,d|0,a|0,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22708]=0;b=Q(2460,a+264|0,a+256|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(c);vb(h);gb=a+272|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function hha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0;f=gb+-64|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}x=l-4|0;n=B(b,e);o=n-8|0;while(1){v[22708]=0;b=Q(191,c|0,l|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(!(b&m>>>0<n>>>0)){break g}v[22708]=0;U(288,f+16|0,c|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}g=f+40|0;b=f+16|0;p=jc(g,b);xb(b);v[22708]=0;R(757,b|0,g|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;y=Sd(f+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}q=v[f+16>>2];if(e){r=q-4|0;g=0;while(1){v[22708]=0;b=T(746,p|0)|0;i=v[22708];v[22708]=0;h:{if((i|0)!=1){v[f+12>>2]=b;v[22708]=0;b=T(374,p|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}v[f+8>>2]=b;Rd(f+8|0,0,89);v[22708]=0;Q(318,f+40|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}i=g+m|0;if(o>>>0<i>>>0){break h}k=0;b=e+g<<2;if(r>>>0<b>>>0){break h}while(1){j=zb(w[b+y|0]);s=k&1;j=s?j>>>4|0:j&15;h=v[f+8>>2];v[f+8>>2]=t[(j&7)+36568|0]+h;h=u[(h<<1)+36576>>1];h=(((0-(j&1)&h>>2)+(h>>3)|0)+(j<<30>>31&h>>1)|0)+(h&j<<29>>31)|0;v[f+12>>2]=v[f+12>>2]+(j&8?0-h|0:h);Rd(f+8|0,0,88);Rd(f+12|0,-32768,32767);u[(i<<1)+a>>1]=v[f+12>>2];i=e+i|0;b=b+s|0;k=k+1|0;if((k|0)!=8){continue}if(i>>>0>o>>>0){break h}k=0;b=b+x|0;if(r>>>0>=b>>>0){continue}break}break h}break f}g=g+1|0;if((g|0)!=(e|0)){continue}break}}m=(q-l<<1)+m|0;zc(f+16|0);xb(f+40|0);continue}}xb(c);gb=f- -64|0;return}b=P()|0;O()|0;zc(f+16|0);break d}b=P()|0;O()|0}xb(f+40|0);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}xb(c);S(b|0);L()}
function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Ud(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=lg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=(h<<1)+p|0;b:{if((b|0)<=0){break b}while(1){Jd(v[i+8>>2],u[(e<<1)+h>>1]/4<<16>>16);Id(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Jd(b,u[h+(v[f+44>>2]<<1)>>1]/4<<16>>16);Id(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=ig(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Mb(o,-16777216,16776704);k=v[a+64>>2];g=Mb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=oqa(j,l,e,e>>31);j=jb;k=oqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=oqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb+-64|0;gb=d;c=x[a+480190>>1];t[d+48|0]=0;uR(b,c+1|0,d+48|0);if(x[a+480192>>1]){i=mc(d+48|0);c=a+484344|0;l=d,m=Vb(c),v[l+40>>2]=m;l=d,m=Zb(c),v[l+32>>2]=m;if(Gb(d+40|0,d+32|0)){while(1){a:{h=v[d+40>>2];if(!ii(h)){break a}c=x[a+480188>>1];v[22708]=0;t[d+8|0]=0;U(1128,i|0,c|0,d+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){b:{l=d,m=Vb(h),v[l+24>>2]=m;j=0;if(!v[h+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{c=v[d+24>>2];v[22708]=0;c=ce(c);e=v[22708];v[22708]=0;if((e|0)==1){break d}e:{if(!c){break e}c=w[v[d+24>>2]+1|0];t[d+23|0]=c;if(!w[v[d+24>>2]+1|0]){c=w[kc(i,f)|0];t[d+23|0]=c}if(c&255){u[d+8>>1]=0;f:{if(x[d+8>>1]>w[d+23|0]){break f}e=v[((w[v[d+24>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=x[wd(e+236|0,w[v[d+24>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}g=d+8|0;re(g,b,e);Df(g,1)}l=kc(i,f),m=c,t[l|0]=m;break e}c=x[a+480192>>1];if(!c){break e}e=c;while(1){g=v[((c<<2)+a|0)+900380>>2];g:{if(!g){break g}g=x[wd(g+236|0,w[v[d+24>>2]]-1|0)>>1];if(g>>>0>x[a+480190>>1]){break g}k=d+8|0;re(k,b,g);Df(k,1)}c=c-1|0;e=e-1|0;if(e&65535){continue}break}}ak(d+24|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[h+12>>2]){continue}break}break a}}a=P()|0;O()|0;gc(i);S(a|0);L()}c=d+40|0;TO(c);if(Gb(c,d+32|0)){continue}break}}c=x[a+480190>>1];h:{if(!c){f=0;break h}f=0;e=c;while(1){h=d+8|0;re(h,b,c);if(!Cb(h)){f=Md((B(c,104)+a|0)+484380|0)+f|0}c=c-1|0;e=e-1|0;if(e&65535){continue}break}}gc(i)}gb=d- -64|0;return f&65535}function j3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-384|0;gb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Ks(f+376|1,18720,v[c+4>>2]);v[f+332>>2]=f+336;a=ye();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Hf(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=Hf(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2457;i=ge(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22708]=0;a=ga(2477)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22708]=0;A[f+8>>3]=e;a=ca(2496,f+332|0,a|0,f+376|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break e}break c}v[22708]=0;a=ga(2477)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22708]=0;a=ca(2496,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Fe(i,v[f+332>>2]);g=v[f+332>>2]}h=a+g|0;k=Tg(g,h,c);v[f+68>>2]=2457;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;break g}a=Cd(a<<3);if(!a){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Fe(g,a);j=v[f+332>>2]}v[22708]=0;Fc(f+56|0,c);l=v[22708];v[22708]=0;h:{i:{if((l|0)!=1){v[22708]=0;ja(2505,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22708];v[22708]=0;if((h|0)==1){break i}Wb(f+56|0);v[22708]=0;a=la(2506,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(g);Hc(i);gb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function v3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-208|0;gb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Ks(f+200|1,18720,v[c+4>>2]);v[f+156>>2]=f+160;a=ye();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Hf(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=Hf(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2457;i=ge(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22708]=0;a=ga(2477)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22708]=0;A[f+8>>3]=e;a=ca(2496,f+156|0,a|0,f+200|0,f|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){break e}break c}v[22708]=0;a=ga(2477)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22708]=0;a=ca(2496,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)==1){break c}break d}Fe(i,v[f+156>>2]);g=v[f+156>>2]}h=a+g|0;k=Tg(g,h,c);v[f+68>>2]=2457;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;break g}a=Cd(a<<1);if(!a){v[22708]=0;X(2458);a=v[22708];v[22708]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Fe(g,a);j=v[f+156>>2]}v[22708]=0;Fc(f+56|0,c);l=v[22708];v[22708]=0;h:{i:{if((l|0)!=1){v[22708]=0;ja(2497,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22708];v[22708]=0;if((h|0)==1){break i}Wb(f+56|0);v[22708]=0;a=la(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break h}Hc(g);Hc(i);gb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Wb(f+56|0);break f}c=P()|0;O()|0}Hc(g);break b}L()}c=P()|0;O()|0}Hc(i);S(c|0);L()}function tL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=gb-48|0;gb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}c=d+8|0;hc(c,v[a>>2]+24604|0,40);v[d+8>>2]=b;Wz(v[a>>2],c);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=gb-16|0;gb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}b=ba(8)|0;v[22708]=0;c=Q(70,g|0,8063)|0;a=v[22708];v[22708]=0;i:{if((a|0)!=1){rc(b,c);v[22708]=0;U(186,b|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break g}a=P()|0;O()|0;vb(c);break i}a=P()|0;O()|0;da(b|0)}S(a|0);L()}gb=g+16|0;break f}L()}t[e+8|0]=b;if(!My(d+8|0,v[f>>2]+24648|0)){break d}Vz(v[f>>2],d+8|0);break d;case 3:b=d+8|0;a=a+24|0;hc(b,v[a>>2]+24604|0,40);e=gb-48|0;gb=e;j:{if((c|0)==-1){It(b,v[Wq(e+8|0)+32>>2]);Ko(b,v[Wq(e+8|0)+36>>2]);break j}if((c|0)<=0){It(b,0);Ko(b,0);break j}c=B(c,1e3);It(b,c);Ko(b,c)}gb=e+48|0;if(v[v[a>>2]+24640>>2]==v[d+44>>2]?v[v[a>>2]+24636>>2]==v[d+40>>2]:0){break d}Wz(v[a>>2],d+8|0);break d;default:a=ba(8)|0;v[22708]=0;b=Q(70,d+8|0,7655)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b;case 0:break e}}h=a,i=oe(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[h+48>>2]=i}gb=d+48|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function gM(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=gb-16|0;gb=d;k=d,l=C(Vy(z[a+4216>>2])/C(wf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=Qp(C(z[Em(d+12|0,d+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=oe(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))/C(20)));k=d,l=C(Vy(z[a+4220>>2])/C(wf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[Em(d+12|0,d+8|0)>>2];k=d,l=C(Vy(z[a+4224>>2])/C(wf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(C(z[Em(d+12|0,d+8|0)>>2]*C(6.2831854820251465))*C(.5));e=gb-16|0;gb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=_n(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=_n(((f|0)>-1?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=_n(((f|0)>-1?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=_n(((f|0)>-1?-4.71238898038469:4.71238898038469)+g,1);break c}b=_n(((f|0)>-1?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=$x(b,e+8|0);b=_n(A[e+8>>3],c&1)}gb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=Qp(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+51648>>2];gb=d+16|0}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Ud(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=lg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=h+p|0;b:{if((b|0)<=0){break b}while(1){Jd(v[i+8>>2],t[e+h|0]<<6);Id(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Jd(b,t[h+v[f+44>>2]|0]<<6);Id(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=ig(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Mb(o,-16777216,16776704);k=v[a+64>>2];g=Mb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=oqa(j,l,e,e>>31);j=jb;k=oqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=oqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Jc(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22708]=0;R(456,f|0,j|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[pc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22708]=0;W(457,f|0,1,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22708]=0;W(457,f|0,1,123)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(vs(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22708]=0;Q(458,f|0,g|0)|0;h=v[22708];v[22708]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(vs(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22708]=0;Q(458,f|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22708]=0;W(457,f|0,1,125)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if((l?k:0)|a){break c}}return}a=ba(8)|0;v[22708]=0;T(185,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(186,a|0,27304,24);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;da(a|0)}vb(f);S(e|0)}L()}function p$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22708]=0;R(182,f|0,j|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[pc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22708]=0;W(183,f|0,1,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22708]=0;W(183,f|0,1,123)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(vs(c)>>>0<=g>>>0){g=d;break h}g=Ad(c,g);v[22708]=0;Q(184,f|0,g|0)|0;h=v[22708];v[22708]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(vs(c)>>>0<=i>>>0){break h}d=Ad(c,i);v[22708]=0;Q(184,f|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22708]=0;W(183,f|0,1,125)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if((l?k:0)|a){break c}}return}a=ba(8)|0;v[22708]=0;T(185,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;U(186,a|0,27304,24);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;da(a|0)}vb(f);S(e|0)}L()}function mH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-272|0;gb=g;i=v[b>>2];v[g+12>>2]=i;m=a?a:g+16|0;e=0;a:{b:{c:{d=a?d:256;if(!i|!d){break c}f=c>>>0>=d>>>0;j=f;if(!(f|c>>>0>32)){break b}while(1){j=j?d:c;c=c-j|0;i=0;n=gb-16|0;gb=n;d:{e:{f:{g:{f=m;if(f){if(j>>>0>=4){break g}h=j;break f}j=0;f=v[g+12>>2];h=v[f>>2];if(!h){break d}while(1){l=1;if(h>>>0>=128){i=-1;l=pl(n+12|0,h,0);if((l|0)==-1){break d}}h=v[f+4>>2];f=f+4|0;j=j+l|0;i=j;if(h){continue}break}break d}l=v[g+12>>2];h=j;while(1){k=v[l>>2];h:{if(k-1>>>0>=127){if(!k){t[f|0]=0;v[g+12>>2]=0;break e}i=-1;k=pl(f,k,0);if((k|0)==-1){break d}h=h-k|0;f=f+k|0;break h}t[f|0]=k;h=h-1|0;l=v[g+12>>2];f=f+1|0}l=l+4|0;v[g+12>>2]=l;if(h>>>0>3){continue}break}}if(h){l=v[g+12>>2];while(1){k=v[l>>2];i:{if(k-1>>>0>=127){if(!k){t[f|0]=0;v[g+12>>2]=0;break e}i=-1;k=pl(n+12|0,k,0);if((k|0)==-1){break d}if(h>>>0<k>>>0){break e}pl(f,v[l>>2],0);h=h-k|0;f=f+k|0;break i}t[f|0]=k;h=h-1|0;l=v[g+12>>2];f=f+1|0}l=l+4|0;v[g+12>>2]=l;if(h){continue}break}}i=j;break d}i=j-h|0}gb=n+16|0;if((i|0)==-1){d=0;i=v[g+12>>2];e=-1;break c}f=(g+16|0)==(m|0)?0:i;m=f+m|0;e=e+i|0;i=v[g+12>>2];d=d-f|0;if(!i|!d){break c}f=c>>>0>=d>>>0;j=f;if(f|c>>>0>32){continue}break}break b}if(!i){break a}}if(!d|!c){break a}j=e;while(1){j:{f=pl(m,v[i>>2],0);k:{if(f+1>>>0<=1){e=-1;if(f){break a}v[g+12>>2]=0;break k}i=v[g+12>>2]+4|0;v[g+12>>2]=i;j=f+j|0;d=d-f|0;if(d){break j}}e=j;break a}m=f+m|0;e=j;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=v[g+12>>2]}gb=g+272|0;return e|0}function Qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{j=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?j>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?j>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?j>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?j>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];g=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=(i>>>16&65520)+m|0;f=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Mb(k,-16777216,16776704);l=v[a+64>>2];g=Mb(g,-16777216,16776704);b=oqa(l,l>>31,b,b>>31);l=jb;n=b;i=(((((((B(j,s)+B(f,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;f=oqa(o,o>>31,b,b>>31);e=n+f|0;b=jb+l|0;b=e>>>0<f>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=oqa(e,e>>31,g,g>>31);g=n+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,r);v[c+4>>2]=v[c+4>>2]+B(e,q);b=b-(g&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=e+o|0;f=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Mb(k,-16777216,16776704);l=v[a+64>>2];g=Mb(g,-16777216,16776704);b=oqa(l,l>>31,b,b>>31);l=jb;J=b;b=v[a+68>>2];n=oqa(b,b>>31,g,g>>31);g=J+n|0;b=jb+l|0;b=g>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(f,j)<<8)/32768<<8;f=oqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);g=v[a+72>>2];f=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function hA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=nA(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!((b|0)!=32?a:1)){break c}Ob(c,0,1);Ob(c,7,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,11,1);Ob(c,12,1);Ob(c,13,1);Ob(c,14,1);Ob(c,15,1);Ob(c,16,1);Ob(c,17,1);Ob(c,18,1);Ob(c,19,1);Ob(c,20,1);Ob(c,21,1);Ob(c,22,1);Ob(c,23,1);Ob(c,24,1);Ob(c,25,1);Ob(c,26,1);Ob(c,27,1);Ob(c,28,1);Ob(c,29,1);Ob(c,30,1);Ob(c,31,1);Ob(c,32,1);Ob(c,33,1);Ob(c,34,1);Ob(c,35,1);Ob(c,36,1);Ob(c,37,1);Ob(c,38,1);Ob(c,39,1);Ob(c,40,1);Ob(c,41,1);Ob(c,42,1);Ob(c,43,1);Ob(c,44,1);Ob(c,45,1);Ob(c,46,1);Ob(c,47,1);Ob(c,48,1);Ob(c,103,1);Ob(c,50,1);Ob(c,87,1);Ob(c,88,1);Ob(c,100,1);Ob(c,102,1);Ob(c,104,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Ob(c,0,1);Ob(c,4,1);Ob(c,8,1);Ob(c,9,1);Ob(c,10,1);Ob(c,17,1);Ob(c,40,1);Ob(c,51,1);Ob(c,52,1);Ob(c,53,1);Ob(c,54,1);Ob(c,55,1);Ob(c,56,1);Ob(c,57,1);Ob(c,58,1);Ob(c,59,1);Ob(c,60,1);Ob(c,61,1);Ob(c,62,1);Ob(c,63,1);Ob(c,64,1);Ob(c,65,1);Ob(c,66,1);Ob(c,67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Ob(c,g,1);Ob(c,e,1);Ob(c,d,1);Ob(c,A,1);Ob(c,z,1);Ob(c,y,1);Ob(c,x,1);Ob(c,w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Ob(c,o,1);Ob(c,n,1);Ob(c,m,1);Ob(c,l,1);g=k;f=j;e=i;d=h}Ob(c,g,1)}Ob(c,f,1);Ob(c,e,1);Ob(c,d,1)}}function oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;j=v[a+48>>2];v[b+36>>2]=j;k=v[a+52>>2];v[b+40>>2]=k;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;g=0;k=1;f=0;while(1){i=f<<1;h=u[i+e>>1];v[(b+8|0)+(f<<2)>>2]=h+((B(j,u[e+(i|4)>>1]-h|0)|0)/16384|0);h=k&1;k=0;f=1;if(h){continue}break}while(1){k=(b+8|0)+(g<<2)|0;f=v[k>>2];j=v[a+60>>2];i=j;h=(b+32|0)+(g<<3)|0;p=v[h>>2];e=Mb(p,-16777216,16776704);o=v[a+64>>2];g=Mb(v[h+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=oqa(i,r,f,f>>31);i=jb;o=oqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+i|0;e=f>>>0<o>>>0?e+1|0:e;i=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=i+f|0;e=jb+e|0;e=f>>>0>g>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=Jc(g,e,24);v[h+4>>2]=p;g=v[a+72>>2];v[k>>2]=(e|0)/256;v[h>>2]=e-(g&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];k=v[b+40>>2];j=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;gb=b+48|0}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;k=v[a+52>>2];v[b+40>>2]=k;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){j=i>>>10&4194048;e=(((e&2147483647)<<1|i>>>31)&-2)+r|0;g=0;l=1;k=1;f=0;while(1){i=t[e+f|0];v[(b+8|0)+(f<<2)>>2]=((B(j,t[e+(f|2)|0]-i|0)|0)/16384|0)+(i<<8);i=k&1;k=0;f=1;if(i){continue}break}while(1){k=(b+8|0)+(g<<2)|0;j=v[k>>2];h=v[a+60>>2];o=h;i=(b+32|0)+(g<<3)|0;q=v[i>>2];e=Mb(q,-16777216,16776704);g=v[a+64>>2];f=Mb(v[i+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=oqa(o,p,h,h>>31);o=jb;p=h;h=oqa(g,g>>31,e,e>>31);g=p+h|0;e=jb+o|0;e=g>>>0<h>>>0?e+1|0:e;h=g;g=v[a+68>>2];g=oqa(g,g>>31,f,f>>31);f=h+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[i+4>>2]=q;f=v[a+72>>2];v[k>>2]=(e|0)/256;v[i>>2]=e-(f&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];k=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}f=m>>12;g=n>>12}v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=k;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=i;v[a+4>>2]=e;gb=b+48|0}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-112|0;gb=c;d=c+88|0;Rm(d,b,1413829443);v[22708]=0;b=T(275,d|0)|0;d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[22708]=0;U(1430,c- -64|0,a+140|0,1413894985);a=v[22708];v[22708]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[22708]=0;a=Q(1435,c- -64|0,10945)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);v[22708]=0;a=T(467,c- -64|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break m}v[22708]=0;W(413,c- -64|0,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break m}v[22708]=0;d=Q(69,c+16|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;_(1436,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}v[22708]=0;U(1437,c+32|0,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break j}a=c+32|0;Eb(b,a);vb(a);vb(c);vb(d);v[22708]=0;U(13,a|0,2,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}v[22708]=0;a=T(970,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}vb(c+32|0);vb(b);b=a-1>>>0<19398657?1252:28591}xb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(c)}vb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+32|0)}vb(b);break d}a=P()|0;O()|0}xb(c- -64|0);break b}v[22708]=0;a=Q(191,c+88|0,2)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[22708]=0;b=T(287,c+88|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}xb(c+88|0);S(a|0);L()}xb(c+88|0);gb=c+112|0;return b|0}function cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=h;i=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=i;if(d){while(1){l=1;i=((((h&2147483647)<<1|k>>>31)&2147483646)<<1)+o|0;b=k>>>21&2040;k=u[b+46166>>1];j=u[b+46164>>1];m=u[b+46162>>1];n=u[b+46160>>1];f=0;b=1;g=0;while(1){h=g<<1;v[(e+8|0)+(g<<2)>>2]=(((B(u[h+i>>1],m)+B(u[i+(h|-4)>>1],n)|0)+B(u[i+(h|4)>>1],j)|0)+B(k,u[i+(h|8)>>1])|0)/16384;h=b;b=0;g=1;if(h){continue}break}while(1){k=(e+8|0)+(f<<2)|0;i=v[k>>2];j=v[a+60>>2];m=j;h=(e+32|0)+(f<<3)|0;n=v[h>>2];b=Mb(n,-16777216,16776704);f=v[a+64>>2];g=Mb(v[h+4>>2],-16777216,16776704);j=j>>31;i=i<<8;j=oqa(m,j,i,i>>31);m=jb;r=j;j=oqa(f,f>>31,b,b>>31);f=r+j|0;b=jb+m|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=j+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[h+4>>2]=n;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&i);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];h=v[e+28>>2];continue}break}k=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=k;v[a+4>>2]=h;gb=e+48|0}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-384|0;gb=a;v[a+368>>2]=c;v[a+376>>2]=b;tx(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=v[a+232>>2];h=v[a+236>>2];while(1){d:{v[22708]=0;g=Q(2486,a+376|0,a+368|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+196>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+196>>2]=g+c}v[22708]=0;g=T(2488,a+376|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(sx(g,a+23|0,a+22|0,c,a+196|0,h,b,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22708]=0;T(2490,a+376|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22708]=0;Y(2476,a|0,c|0,v[a+196>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;gf(a+216|0,a+32|0,v[a+28>>2],e);v[22708]=0;b=Q(2487,a+376|0,a+368|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];vb(d);vb(a+216|0);gb=a+384|0;break a}}b=P()|0;O()|0;vb(d);vb(a+216|0);S(b|0);L()}return b|0}function R3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;wx(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=t[a+238|0];h=t[a+239|0];while(1){d:{v[22708]=0;g=Q(2459,a+280|0,a+272|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+204>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+204>>2]=g+c}v[22708]=0;g=T(2461,a+280|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(vx(g,a+23|0,a+22|0,c,a+204|0,h,b,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22708]=0;T(2463,a+280|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22708]=0;Y(2476,a|0,c|0,v[a+204>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;gf(a+224|0,a+32|0,v[a+28>>2],e);v[22708]=0;b=Q(2460,a+280|0,a+272|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];vb(d);vb(a+224|0);gb=a+288|0;break a}}b=P()|0;O()|0;vb(d);vb(a+224|0);S(b|0);L()}return b|0}function XU(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-16|0;gb=f;a:{if((b|0)==(c|0)){break a}v[f+12>>2]=-1953789045;RB(b,c,f+12|0);c=c-b>>2;v[f+8>>2]=c;e=1;j=Nb(a);h=j+1|0;v[f+4>>2]=h;k=v[Mc(f+4|0,f+8|0)>>2];g=v[((v[f+8>>2]<<2)+b|0)-4>>2];i=c;d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}l=i-d>>>1|0;c=(l<<2)+b|0;i=B(Zu(g^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=i+v[c>>2];m=d+l|0;c=(m<<2)+b|0;d=c;g=v[c>>2];c=j+i|0;v[d>>2]=g+c;v[b>>2]=c;c=v[f+8>>2];if(j){while(1){g=e-1|0;d=((e+l>>>0)%(c>>>0)<<2)+b|0;n=(e>>>0)%(c>>>0)|0;o=(n<<2)+b|0;i=B(Zu(v[((g>>>0)%(c>>>0)<<2)+b>>2]^(v[d>>2]^v[o>>2])),1664525);v[d>>2]=i+v[d>>2];d=Lb(a,g);c=v[f+8>>2];g=((e+m>>>0)%(c>>>0)<<2)+b|0;d=v[d>>2]+(i+n|0)|0;v[g>>2]=d+v[g>>2];v[o>>2]=d;e=e+1|0;if(j>>>0>=e>>>0){continue}break}}if(h>>>0<k>>>0){while(1){a=((h+l>>>0)%(c>>>0)<<2)+b|0;d=(h>>>0)%(c>>>0)|0;j=(d<<2)+b|0;e=B(Zu(v[((h-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[j>>2])),1664525);v[a>>2]=e+v[a>>2];c=v[f+8>>2];a=((h+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=e+d|0;v[i>>2]=g+a;v[j>>2]=a;h=h+1|0;if((k|0)!=(h|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}e=k;while(1){a=((e+l>>>0)%(c>>>0)<<2)+b|0;d=(e>>>0)%(c>>>0)|0;j=(d<<2)+b|0;h=B(Zu(v[((e-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[j>>2]|0)|0),1566083941);v[a>>2]=h^v[a>>2];c=v[f+8>>2];a=((e+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=h-d|0;v[i>>2]=g^a;v[j>>2]=a;e=e+1|0;if(e>>>0<c+k>>>0){continue}break}}gb=f+16|0}function dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;b=v[a+48>>2];v[e+36>>2]=b;g=v[a+52>>2];v[e+40>>2]=g;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];j=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=j;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;if(d){while(1){h=(((j&2147483647)<<1|k>>>31)&-2)+o|0;b=k>>>21&2040;k=u[b+46166>>1];i=u[b+46164>>1];m=u[b+46162>>1];n=u[b+46160>>1];g=0;l=1;b=1;f=0;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+h|0],m)+B(t[h+(f|-2)|0],n)|0)+B(t[h+(f|2)|0],i)|0)+B(k,t[h+(f|4)|0])<<8)/16384;j=b;b=0;f=1;if(j){continue}break}while(1){k=(e+8|0)+(g<<2)|0;h=v[k>>2];i=v[a+60>>2];m=i;j=(e+32|0)+(g<<3)|0;n=v[j>>2];b=Mb(n,-16777216,16776704);g=v[a+64>>2];f=Mb(v[j+4>>2],-16777216,16776704);i=i>>31;h=h<<8;i=oqa(m,i,h,h>>31);m=jb;r=i;i=oqa(g,g>>31,b,b>>31);g=r+i|0;b=jb+m|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=v[a+68>>2];g=oqa(g,g>>31,f,f>>31);f=i+g|0;b=jb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Jc(f,b,24);v[j+4>>2]=n;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[j>>2]=b-(f&h);g=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];j=v[e+28>>2];continue}break}k=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];g=v[e+40>>2];f=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=g;v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=k;v[a+4>>2]=j;gb=e+48|0}function iO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=gb-16|0;gb=c;e=B(b,872)+a|0;a:{if(v[e+1075080>>2]&134218752){break a}if(!tk(e+1074992|0)){break a}h=v[(B(b,872)+a|0)+1075648>>2];if(w[h+15|0]&2){break a}e=Jm(a,b,2,1);if(e-251>>>0<5|!e){break a}g=v[(B(e,160)+a|0)+906140>>2];if(!g){break a}d=B(b,872)+a|0;e=w[d+1075780|0];b:{if(w[d+1075782|0]==1){t[c+8|0]=64;f=w[ac(d+1075784|0,c+8|0)|0];break b}f=255;if(w[d+1075783|0]!=13){break b}t[c+8|0]=64;f=w[ac((B(b,872)+a|0)+1075785|0,c+8|0)|0]}d=c+8|0;j=a+1074312|0;Db(d,j,2);if(Cb(d)){if(e){d=a;f=b;if(we(e)){e=w[lc(h+108|0,e-1|0)|0]}Km(d,f,e,x[(B(b,872)+a|0)+1075680>>1]);break a}if((f|0)==255){break a}kb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(e){d=k<<2;v[c+4>>2]=d;if(!w[h+35|0]){d=v[(B(b,872)+a|0)+1075680>>2];v[c+4>>2]=d}i=u[(B(b,872)+a|0)+1075768>>1];l=c+8|0;Db(l,j,28);m=c,n=(Cb(l)?i<<2:i)+d|0,v[m+4>>2]=n;Rd(c+4|0,0,256);d=e;i=b;if(we(e)){d=w[lc(h+108|0,e-1|0)|0]}Km(a,i,d&255,x[c+4>>1])}d=w[h+35|0];a=c+8|0;Db(a,j,101);i=(f|0)!=255;if(Cb(a)){a=(e|0)!=0}else{a=we(e)}if(!(!a|(d|0)!=1?a?0:i:1)){break a}c:{switch(w[h+36|0]){case 1:if((f|0)!=255){CM(g,f<<1);break a}CM(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;n=g,o=7,p=w[ac(c+8|0,c+4|0)|0],q=b,m=v[v[g>>2]+76>>2],kb[m](n|0,o|0,p|0,q|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;q=g,p=7,o=w[Fb(c+8|0,c+4|0)|0],n=b,m=v[v[g>>2]+76>>2],kb[m](q|0,p|0,o|0,n|0)}gb=c+16|0}function Sz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=gb-16|0;gb=j;k=j;a:{if(!Kj(c)){h=b;i=v[c+704>>2];g=gb-16|0;gb=g;v[g+12>>2]=d;f=0;b:{if(!d){break b}if(v[h+480180>>2]&20){e=h+1074312|0;Db(g,e,73);if(Cb(g)){d=d&65535;v[g+12>>2]=d}if(w[h+480208|0]&16){Db(g,e,73);e=Cb(g)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;f=v[((d>>>0)%768<<2)+40384>>2]<<6>>>e|0;break b}if(!d){v[g+12>>2]=1;d=1}f=229079296/(d>>>0)|0;break b}f=227001280/(d>>>0)|0;if(hp(h)){break b}f=(d+i<<4)-133808|0;if(v[h+480180>>2]==64){break b}d=v[h+480180>>2];qc(g+12|0,16777215);if(d&17408){f=Qc(rqa(oqa(i?i:8363,0,3506176,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}if(sk(h)){f=e>>31;d=v[g+12>>2];h=d>>>24|0;i=d<<8;e=i+e|0;d=h+f|0;d=e>>>0<i>>>0?d+1|0:d;f=(d&15)<<28|e>>>4;break b}if(w[h+480208|0]&16){f=Qc(rqa(oqa(i?i:8363,0,7012352,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}f=Qc(rqa(-1485242368,13,(v[g+12>>2]<<8)+e|0,0),jb)}gb=g+16|0;e=f;break a}e=v[c+700>>2]}v[k+12>>2]=e;d=v[c+656>>2];c=u[c+774>>1];c:{if(!c){break c}c=d?B(t[d+33|0],c):c;if(!c){break c}e=Bh(Dk(+(c|0)/393216)*+(e>>>0));v[j+12>>2]=e}d:{if(!d){break d}c=v[d+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];f=oqa(f,f>>31,e,e>>31);e=d+f|0;d=jb+(d>>31)|0;l=j,m=Ac(pqa(e,e>>>0<f>>>0?d+1|0:d,c,c>>31),jb),v[l+12>>2]=m}qc(j+12|0,2147483647);c=j;l=c,m=pqa(0,v[c+12>>2],v[b+24620>>2]<<4,0),v[l>>2]=m;v[c+4>>2]=jb;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;v[a+8>>2]=v[c+12>>2];gb=c+16|0}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Ud(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=lg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[h+8>>2],u[(e<<1)+g>>1]/4<<16>>16);Id(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Jd(b,u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Id(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=ig(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Mb(k,-16777216,16776704);l=v[a+64>>2];i=Mb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=oqa(j,p,e,e>>31);j=jb;l=oqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=oqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function Noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-32|0;gb=f;t[f+24|0]=44;v[f+16>>2]=-1;v[f+20>>2]=0;v[f+8>>2]=1042;v[f+12>>2]=2;n=a;o=b;c=gb+-64|0;gb=c;p=c;j=f+8|0;b=v[j>>2]&2?16:10;g=gb-32|0;gb=g;d=He(g+16|0,1,0);a:{b:{c:{while(1){i=g+8|0;k=Jb(d);l=Jb(d)+Ab(d)|0;h=x[o>>1];e=b;d:{if((e|0)!=10){a=l;while(1){e:{if((a|0)==(k|0)){a=k;break e}m=h&65535;h=(m|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(m-B(e,h)|0)+1991|0];if(h&65535){continue}}break}f:{if(!(h&65535)){e=l-a|0;if(e){break f}}v[i+4>>2]=61;v[i>>2]=l;break d}a=zh(k,a,e);v[i+4>>2]=0;v[i>>2]=a+e;break d}vA(i,k,l,h)}if(!v[g+12>>2]){break c}a=Ab(d);v[22708]=0;v[g+4>>2]=a;e=xf(g+4|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;U(75,d|0,e|0,0);a=v[22708];v[22708]=0;if((a|0)!=1){continue}}break}break b}b=v[g+8>>2];a=Jb(d);v[22708]=0;R(76,d|0,b-a|0);a=v[22708];v[22708]=0;g:{if((a|0)!=1){v[22708]=0;R(86,p|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){break g}break b}break b}vb(d);gb=g+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}a=c+16|0;Ll(a,c,j);v[22708]=0;U(93,c+32|0,a|0,j|0);a=v[22708];v[22708]=0;h:{i:{j:{k:{l:{if((a|0)!=1){v[22708]=0;U(94,c+48|0,c+32|0,j|0);a=v[22708];v[22708]=0;if((a|0)==1){break l}v[22708]=0;R(85,n|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break k}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function Ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=c;d=v[a+4>>2];v[22708]=0;R(871,d|0,b|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+56;$b(a);gb=c+16|0;break a}b=P()|0;O()|0;$b(a);S(b|0);L()}return}l=gb-32|0;gb=l;j=a;e=wb(a);f=l+8|0;g=a;d=dr(a)+1|0;h=gb-16|0;gb=h;v[h+12>>2]=d;i=gb-16|0;gb=i;v[i+12>>2]=76695844;v[22708]=0;v[i+8>>2]=2147483647;k=Fb(i+12|0,i+8|0);c=v[22708];v[22708]=0;b:{if((c|0)!=1){gb=i+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=FU(g);if(d>>>0<c>>>1>>>0){v[h+8>>2]=d<<1;c=v[Mc(h+8|0,h+12|0)>>2]}gb=h+16|0;break c}Sc();L()}d=dr(a);a=0;g=gb-16|0;gb=g;v[g+12>>2]=0;hf(f+12|0,e);if(c){a=c;if(a>>>0>=76695845){rd(8445);L()}a=Nc(B(a,56),4)}v[f>>2]=a;d=B(d,56)+a|0;v[f+8>>2]=d;v[f+4>>2]=d;m=dc(f),n=B(c,56)+a|0,v[m>>2]=n;gb=g+16|0;a=f;c=v[a+8>>2];v[22708]=0;R(871,c|0,b|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){v[a+8>>2]=v[a+8>>2]+56;b=a;f=a+4|0;k=f;c=v[j+4>>2];g=v[j>>2];if((c|0)!=(g|0)){d=v[k>>2];while(1){e=d-56|0;c=c-56|0;Vu(e,c);Vu(e+12|0,c+12|0);QB(e+24|0,c+24|0);u[e+52>>1]=x[c+52>>1];d=v[c+48>>2];v[e+44>>2]=v[c+44>>2];v[e+48>>2]=d;d=v[c+40>>2];v[e+36>>2]=v[c+36>>2];v[e+40>>2]=d;d=v[k>>2]-56|0;v[k>>2]=d;if((c|0)!=(g|0)){continue}break}}wc(j,f);wc(j+4|0,b+8|0);wc(wb(j),dc(b));v[b>>2]=v[b+4>>2];EU(a);gb=l+32|0;break d}b=P()|0;O()|0;EU(a);S(b|0);L()}}function PZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;vc(c);a:{if(!Pb(c,3)){break a}while(1){e=g+24|0;Vr(e,c);f=qd(e);i=Ve(e);if(y[a+12>>2]<=w[e|0]){break a}h=Xc(a,w[e|0],b);e=w[f|0];b:{if(e>>>0<=126){if(!(e|w[i|0])){t[h|0]=254;break b}t[h|0]=e+1;if(w[i|0]==255){break b}t[h+2|0]=1;t[h+4|0]=w[i|0];break b}c:{switch(e-127|0){case 1:t[h+1|0]=w[i|0]+1;break b;case 0:break b;default:break c}}d=t[i|0];t[g+23|0]=d;i=0;e=e&127;if(e>>>0<=23){i=w[e+28432|0]}e=g;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=w[f|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((d|0)>-1){break g}f=0-d&15;break f}t[g+16|0]=64;d=w[ac(g+23|0,g+16|0)|0];if(w[h+2|0]>1){break e}t[h+4|0]=d;t[h+2|0]=1;break b}f=3;if((d|0)>-1){break d}f=0-d&127;break f}if(!d){break b}f=0-d|-16;if((d|0)<=-1){break f}f=d<<4|15;break f}if(!d){break b}e=(d|0)>-1;if(!e){d=0-d&15;t[g+23|0]=d;j=w[f|0]}f=e?3:2;d=((j|0)==22?-32:-16)|d;t[g+23|0]=d;break d}f=d&15|-48;break f}f=d&15|-64;break f}f=164;if((d|0)==100){break f}v[g+16>>2]=d- -64;v[g+12>>2]=0;v[g+8>>2]=128;d=v[dj(g+16|0,g+12|0,g+8|0)>>2];if(!w[h+3|0]){break e}p:{switch(w[h+2|0]){case 0:case 2:break p;default:break b}}t[h+2|0]=2;t[h+4|0]=(d&254)>>>1;break b}f=d<<4}d=f;t[e+23|0]=d}f=i;if(!i){break b}}t[h+5|0]=d;t[h+3|0]=f}if(Pb(c,3)){continue}break}}gb=g+32|0}function Uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=lc(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=wd(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=wd(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}gC(a+484|0,b+48|0,0);gC(a+590|0,b+68|0,0);gC(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<=-1){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[ac(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[Pc(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[Pc(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;fm(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;em(b,w[a|0]&127,w[a|0]>>>7|0);gb=e+16|0}function rJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{b:{c:{g=(b|0)>=0;f=a+8|0;d:{if(vl(f)){f=vl(f);break d}f=hq(f)}if(!((f|0)>(b|0)?g:0)){c=ba(8)|0;v[22708]=0;b=Q(70,i|0,3092)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(c,b);v[22708]=0;U(186,c|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}if(c>>>0>=120){c=ba(8)|0;v[22708]=0;b=Q(70,i|0,8608)|0;a=v[22708];v[22708]=0;if((a|0)!=1){rc(c,b);v[22708]=0;U(186,c|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}a=P()|0;O()|0;da(c|0);break b}h=a+32|0;a=rA(v[h>>2],65535);j=(a|0)==65535?255:a;u[i>>1]=j;f=v[h>>2]+B(j,872)|0;g=f+1074992|0;_m(g,7,v[h>>2],65535,1024);a=c+1|0;t[f+1075794|0]=a;t[f+1075791|0]=a;u[f+1075778>>1]=0;Lm(g);Do(v[h>>2],g,b+1|0,0,1,1);v[f+1075688>>2]=65536;qu(v[h>>2],g,a,0,1,1,65535);m=f+1075684|0,n=Po(BA(e*128,-128,128)+128),v[m>>2]=n;m=f+1075680|0,n=Po(BA(d*256,0,256)),v[m>>2]=n;a=v[h>>2]+1074478|0;k=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;l=f;g=i;c=i;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((l|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[g>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=$q(k,b);u[v[h>>2]+480212>>1]=a;gb=i+16|0;return j|0}a=P()|0;O()|0;da(c|0)}S(a|0)}L()}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Ud(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=lg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[h+8>>2],t[e+g|0]<<6);Id(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Jd(b,t[g+v[f+44>>2]|0]<<6);Id(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=ig(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Mb(k,-16777216,16776704);l=v[a+64>>2];i=Mb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=oqa(j,p,e,e>>31);j=jb;l=oqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=oqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Jc(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+r|0;n=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=u[e-4>>1];p=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Mb(m,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];q=oqa(e,e>>31,f,f>>31);e=I+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=oqa(G,H,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function mM(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=gb-16|0;gb=e;c=wf(v[a+16>>2]);o=a,r=oe(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))/C(20))),z[o+4232>>2]=r;f=C(C(c>>>0)/C(1e3));o=a,r=oe(C(10),C(C(-1)/C(f*C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))))),z[o+4236>>2]=r;o=a,r=oe(C(10),C(C(-1)/C(f*C(C(z[a+4216>>2]*C(2950))+C(50))))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(oe(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))/C(20)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!((c|0)>-1?c>>>0>=8388608:0)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<=-1){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(C(d*C(67108864))/C(.6931471824645996))+C(67108864);o=a,r=C(z[Em(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(f*C(z[a+4228>>2]*C(4)))+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;gb=e+16|0}function fJ(a){var b=0,c=0,d=0,e=0;he(a,v[a+20>>2]);if(v[a+24>>2]>=1){while(1){he(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}he(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<1){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=1){he(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){he(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}he(d,b)}he(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>=1){c=0;while(1){b=B(c,2096)+b|0;he(a,v[b+8>>2]);he(a,v[b+28>>2]);he(a,v[b+32>>2]);he(a,v[b+2084>>2]);b=v[b+2088>>2];he(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}he(d,b)}he(a,v[a+260>>2]);he(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>=1){he(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){he(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}he(c,d)}c=1;b:{if(v[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;he(a,v[d+800>>2]);he(a,v[d+928>>2]);he(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;he(a,v[b+1068>>2]);he(a,v[b+1076>>2]);he(a,v[b+1084>>2]);he(a,v[b+1092>>2]);he(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;d=b+1298264|0;if(!Dd(d)){e=i;f=gb-16|0;gb=f;c=sf(12);v[22708]=0;h=T(1645,c|0)|0;g=v[22708];v[22708]=0;a:{if((g|0)!=1){c=gb-16|0;gb=c;v[c+12>>2]=h;xq(f+8|0,c+12|0);gb=c+16|0;gb=f+16|0;c=v[f+8>>2];break a}a=P()|0;O()|0;Xb(c);S(a|0);L()}v[e+8>>2]=c;e=i+8|0;WO(d,be(e));iu(e)}e=v[d>>2];f=0;c=gb-48|0;gb=c;d=c+16|0;RO(d,a);v[22708]=0;U(9,c+32|0,0,d|0);d=v[22708];v[22708]=0;b:{c:{d:{e:{f:{if((d|0)!=1){vb(c+16|0);k=c,l=Vb(e),v[k+8>>2]=l;k=c,l=Zb(e),v[k>>2]=l;g:{if(Gb(c+8|0,c)){e=0;while(1){h=0;d=v[c+8>>2];if(v[v[d>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){h=v[v[d>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}g=v[d>>2];v[22708]=0;R(1646,c+16|0,g+8|0);g=v[22708];v[22708]=0;if((g|0)==1){break g}v[22708]=0;g=OS(c+16|0,c+32|0);j=v[22708];v[22708]=0;h:{i:{if((j|0)!=1){vb(c+16|0);g=!g;if(!(g&h)){break i}f=v[d>>2];e=3;break h}e=P()|0;O()|0;vb(c+16|0);break d}if((e|0)<2&h){f=v[d>>2];e=2;break h}h=v[d>>2];d=g&(e|0)<1;f=d?h:f;e=d?1:e}d=c+8|0;Qe(d);if(Gb(d,c)){continue}break}break f}e=0;break e}e=P()|0;O()|0;break d}e=P()|0;O()|0;vb(c+16|0);break c}e=0;if(!f){break e}d=v[f+4>>2];if(!d){break e}v[22708]=0;a=W(d|0,f|0,b|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){e=(a|0)!=0;break e}e=P()|0;O()|0;break d}vb(c+32|0);gb=c+48|0;break b}vb(c+32|0)}S(e|0);L()}gb=i+16|0;return e|0}function g1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!v[i>>2]){break a}i=i+4|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}m=1;while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];n=wi(l+8|0,l+12|0);v[22708]=0;j=mH(f,e,i-c>>2,g-f|0,b);o=v[22708];v[22708]=0;d:{if((o|0)!=1){ff(n);gb=l+16|0;break d}a=P()|0;O()|0;ff(n);S(a|0);L()}e:{f:{g:{h:{i:{j:{switch(j+1|0){case 0:v[h>>2]=f;k:{if(v[e>>2]==(c|0)){break k}while(1){b=lx(f,v[c>>2],k+8|0,v[a+8>>2]);if((b|0)==-1){break k}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break i;case 1:break b;default:break j}}f=j+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break g}if((d|0)==(i|0)){c=v[e>>2];i=d;break e}j=lx(k+4|0,0,b,v[a+8>>2]);if((j|0)!=-1){break h}}m=2;break b}f=v[h>>2];if(j>>>0>g-f>>>0){break b}if(!j){break f}c=w[k+4|0];v[h>>2]=f+1;t[f|0]=c;i=k+4|0;c=j-1|0;if(!c){break f}while(1){j=w[i+1|0];f=v[h>>2];v[h>>2]=f+1;t[f|0]=j;i=i+1|0;c=c-1|0;if(c){continue}break}break f}c=v[e>>2];break c}c=v[e>>2]+4|0;v[e>>2]=c;f=c;i=d;l:{if((d|0)==(f|0)){break l}while(1){i=f;if(!v[f>>2]){break l}f=f+4|0;if((f|0)!=(d|0)){continue}break}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}m=(c|0)!=(d|0)}gb=k+16|0;return m|0}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+r|0;n=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=t[e-2|0];p=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Mb(m,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];q=oqa(e,e>>31,f,f>>31);e=J+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=oqa(H,I,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;f=u[e>>1];v[b+8>>2]=f;v[b+12>>2]=u[e+2>>1];j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Mb(p,-16777216,16776704);o=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=oqa(k,r,f,f>>31);k=jb;o=oqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=oqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;tx(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22708]=0;g=Q(2486,a+360|0,a+352|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[22708]=0;g=T(2488,a+360|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(sx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2490,a+360|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=C(ya(2472,c|0,v[a+180>>2],e|0));b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}z[f>>2]=j;gf(a+200|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+360|0,a+352|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;j=fg(a,c);te(g+8|0,v[a+28>>2]);d=v[g+20>>2];v[g+24>>2]=v[g+16>>2];v[g+28>>2]=d;a:{if(!j){if(nd(a,5)){break a}}d=gb-144|0;gb=d;h=Fm(d+40|0,v[a+28>>2]);v[22708]=0;f=Q(620,d+24|0,49650)|0;e=v[22708];v[22708]=0;b:{c:{d:{e:{if((e|0)!=1){v[22708]=0;v[d+16>>2]=19923024;v[d+20>>2]=0;U(621,h|0,f|0,d+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}Hb(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f);break c}k=d,l=Te(b),u[k+16>>1]=l;u[d+14>>1]=65535;v[22708]=0;f=Q(620,d+24|0,7375)|0;e=v[22708];v[22708]=0;f:{if((e|0)!=1){v[22708]=0;e=W(1092,h|0,d+14|0,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}Hb(f);if((e|0)!=1){u[d+16>>1]=x[d+14>>1]}yg(d+16|0,4e3);g:{if(x[d+16>>1]<=Te(b)>>>0){break g}v[22708]=0;R(330,b|0,x[d+16>>1]);e=v[22708];v[22708]=0;if((e|0)!=1){break g}e=P()|0;O()|0;break c}e=0;u[d+12>>1]=0;if(!x[d+16>>1]){break b}h:{while(1){i:{f=_b(b,e&65535);v[22708]=0;R(1494,d+24|0,d+12|0);i=v[22708];v[22708]=0;if((i|0)==1){break i}v[22708]=0;ca(1478,h|0,f|0,d+24|0,1495)|0;f=v[22708];v[22708]=0;if((f|0)==1){break h}Hb(d+24|0);e=e+1|0;u[d+12>>1]=e;if(x[d+16>>1]>(e&65535)>>>0){continue}break b}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(d+24|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f)}gh(h);S(e|0);L()}gh(h);gb=d+144|0}Zf(a,j,c,g+24|0);gb=g+32|0}function V3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;wx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2459,a+264|0,a+256|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2461,a+264|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(vx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2463,a+264|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=C(ya(2472,c|0,v[a+188>>2],e|0));b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}z[f>>2]=j;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+264|0,a+256|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=(((e&2147483647)<<1|g>>>31)&-2)+q|0;f=t[e|0]<<8;v[b+8>>2]=f;v[b+12>>2]=t[e+1|0]<<8;j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Mb(p,-16777216,16776704);o=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=oqa(k,r,f,f>>31);k=jb;o=oqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=oqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function NH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-96|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{b=v[b>>2];j:{if(!b){Tb(a,6892);break j}if(!(b&65535)){d=gb-16|0;gb=d;e=Tb(d,1508);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22708]=0;v[c+24>>2]=b>>>24;R(134,c- -64|0,c+24|0);d=v[22708];v[22708]=0;k:{l:{m:{n:{if((d|0)!=1){v[22708]=0;v[c+8>>2]=b>>>16&255;R(135,c+48|0,c+8|0);b=v[22708];v[22708]=0;if((b|0)==1){break n}v[22708]=0;Y(136,a|0,c+80|0,c- -64|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break m}vb(c+48|0);vb(c- -64|0);Hb(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(c+48|0)}vb(c- -64|0)}break a}d=gb-16|0;gb=d;e=Tb(d,1232);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22708]=0;v[c+44>>2]=b>>>24;R(134,c- -64|0,c+44|0);d=v[22708];v[22708]=0;if((d|0)==1){break i}v[22708]=0;v[c+40>>2]=b>>>16&255;R(135,c+48|0,c+40|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}v[22708]=0;v[c+20>>2]=b>>>8&255;R(135,c+24|0,c+20|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;v[c+4>>2]=b&255;R(135,c+8|0,c+4|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;ka(137,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}vb(c+8|0);vb(c+24|0);vb(c+48|0);vb(c- -64|0);Hb(c+80|0)}gb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+8|0)}vb(c+24|0)}vb(c+48|0)}vb(c- -64|0)}Hb(c+80|0);S(b|0);L()}function E3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;tx(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22708]=0;g=Q(2486,a+360|0,a+352|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+180>>2]=g+c}v[22708]=0;g=T(2488,a+360|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(sx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2490,a+360|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=+oa(2475,c|0,v[a+180>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}A[f>>3]=j;gf(a+200|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+360|0,a+352|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function T3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;wx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22708]=0;R(76,d|0,b|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2459,a+264|0,a+256|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2461,a+264|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}if(vx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22708]=0;T(2463,a+264|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22708]=0;j=+oa(2475,c|0,v[a+188>>2],e|0);b=v[22708];v[22708]=0;f:{if((b|0)==1){break f}A[f>>3]=j;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+264|0,a+256|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;p=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;j=v[a+48>>2];v[e+36>>2]=j;k=v[a+52>>2];v[e+40>>2]=k;g=v[a+56>>2];v[e+44>>2]=g;q=v[a+24>>2];r=v[a+20>>2];b=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=b;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;s=a;if(d){while(1){l=i>>>18|0;k=1;g=((((b&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;f=0;b=1;j=0;while(1){h=j<<1;i=u[h+g>>1];v[(e+8|0)+(j<<2)>>2]=i+((B(l,u[g+(h|4)>>1]-i|0)|0)/16384|0);i=b;b=0;j=1;if(i){continue}break}while(1){j=(e+8|0)+(f<<2)|0;l=v[j>>2];h=v[a+60>>2];m=h;i=(e+32|0)+(f<<3)|0;o=v[i>>2];b=Mb(o,-16777216,16776704);f=v[a+64>>2];g=Mb(v[i+4>>2],-16777216,16776704);n=h>>31;l=l<<8;h=l;h=oqa(m,n,h,h>>31);m=jb;n=h;h=oqa(f,f>>31,b,b>>31);f=n+h|0;b=jb+m|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=h+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&l);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];b=v[e+28>>2];continue}break}i=v[e+24>>2];b=v[e+28>>2];k=v[e+40>>2];j=v[e+36>>2];f=v[e+32>>2];g=v[e+44>>2]}v[s+56>>2]=g;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=b;gb=e+48|0}function Z4(){var a=0,b=0,c=0;a=gb-16|0;gb=a;ct(463600);v[115910]=463656;v[115908]=90520;v[115900]=78556;v[115912]=-1;t[463652]=0;b=a+8|0;Ys(b,463600);c=v[v[115900]+8>>2];v[22708]=0;R(c|0,463600,b|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break a}b=P()|0;O()|0;Wb(a+8|0);wm(463600);S(b|0);L()}gu(462928);v[115732]=77164;v[115730]=77144;v[115731]=0;v[22708]=0;R(2404,462928,463600);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;oh(462928);S(a|0);L()}a=gb-16|0;gb=a;dI(463664);v[115926]=463720;v[115924]=90520;v[115916]=78656;v[115928]=-1;t[463716]=0;b=a+8|0;Ys(b,463664);c=v[v[115916]+8>>2];v[22708]=0;R(c|0,463664,b|0);b=v[22708];v[22708]=0;b:{if((b|0)!=1){Wb(a+8|0);gb=a+16|0;break b}b=P()|0;O()|0;Wb(a+8|0);aq(463664);S(b|0);L()}BH(463016);v[115754]=77212;v[115752]=77192;v[115753]=0;v[22708]=0;R(2405,463016,463664);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;oh(463016);S(a|0);L()}FH(463728,90664,463776);Jx(463096,463728);EH(463784,90664,463832);Ix(463180,463784);FH(463840,90144,463888);Jx(463264,463840);Jx(463432,v[(v[v[115816]-12>>2]+463264|0)+24>>2]);EH(463896,90144,463944);Ix(463348,463896);Ix(463516,v[(v[v[115837]-12>>2]+463348|0)+24>>2]);DH(v[v[115730]-12>>2]+462920|0);CH(v[v[115752]-12>>2]+463008|0);XN(v[v[115816]-12>>2]+463264|0);XN(v[v[115837]-12>>2]+463348|0);DH(v[v[115816]-12>>2]+463264|0);CH(v[v[115837]-12>>2]+463348|0)}function q8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-176|0;gb=b;d=Tb(b+8|0,8890);v[22708]=0;Q(70,b+20|0,8238)|0;e=v[22708];v[22708]=0;c=1;a:{b:{if((e|0)==1){break b}v[22708]=0;Q(70,b+32|0,8720)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=2;break b}v[22708]=0;Q(70,b+44|0,8230)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=3;break b}v[22708]=0;Q(70,b+56|0,5376)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=4;break b}v[22708]=0;Q(70,b+68|0,8215)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=5;break b}v[22708]=0;Q(70,b+80|0,5442)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=6;break b}v[22708]=0;Q(70,b+92|0,2712)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=7;break b}v[22708]=0;Q(70,b+104|0,9258)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=8;break b}v[22708]=0;Q(70,b+116|0,8663)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=9;break b}v[22708]=0;Q(70,b+128|0,9459)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=10;break b}v[22708]=0;Q(70,b+140|0,2564)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=11;break b}v[22708]=0;Q(70,b+152|0,4379)|0;c=v[22708];v[22708]=0;if((c|0)==1){c=12;break b}v[b+172>>2]=13;v[b+168>>2]=d;v[22708]=0;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2087,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){a=b+164|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}gb=b+176|0;return}a=b+164|0;break a}a=(b+8|0)+B(c,12)|0}b=P()|0;O()|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}S(b|0);L()}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=gb-16|0;gb=g;m=a+44|0;if(ni(m)){j=Nd(m,0);k=Nd(m,1);h=od(m,0);i=od(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Fb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){e=0;if(!f){break b}while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}break b}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}n=C(C(1)/C(y[a+4220>>2]));while(1){o=C(e>>>0);z[h>>2]=n*C(z[j>>2]*o);z[i>>2]=n*C(z[k>>2]*o);i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Fb(g+12|0,g+4|0)>>2];c:{d:{e:{if(!(r<C(1))){e=0;if(f){break e}break d}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}n=C(C(1)/C(y[a+4220>>2]));while(1){o=C(e>>>0);z[h>>2]=n*C(z[j>>2]*o);z[i>>2]=n*C(z[k>>2]*o);i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}Fi(a,b,c,od(m,0),od(m,1),d)}gb=g+16|0}function uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;j=v[a+56>>2];v[e+44>>2]=j;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;j=1;b=1;f=0;while(1){h=t[f+g|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){k=(e+8|0)+(i<<2)|0;f=v[k>>2];l=v[a+60>>2];m=l;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Mb(i,-16777216,16776704);n=v[a+64>>2];g=Mb(v[h+4>>2],-16777216,16776704);r=l>>31;l=f<<8;f=l;f=oqa(m,r,f,f>>31);m=jb;n=oqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=oqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Jc(g,b,24);v[h+4>>2]=i;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&l);i=1;b=j&1;j=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];j=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=j;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Yh(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;return}d=b&224;a:{if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;g=c&d;b:{if(g){Ko(e,f);break b}Ko(e,0)}t[f+40|0]=!g;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){$A((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(B(b&256?d+9|0:d,44)+a|0)+16|0;d=v[a+36>>2];c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}b=c&32;YR(a,b>>>5|0);f=c>>>2&7;XR(a,f);e=a;a=c&3;WR(e,a);if(!d){break a}YR(d,(b|0)!=0);XR(d,f);WR(d,a);return}VR(a,c);if(!d){break a}VR(d,c);return}t[a+42|0]=(c&32)>>>5;t[a+41|0]=(c&16)>>>4;b=c>>>1&7;u[a+30>>1]=b?9-b|0:0;u[a+32>>1]=c&1;return}if(-4144960>>>b&1|((d|0)!=224?d>>>0>=129:0)){break a}e=a;a=t[(b&31)+35296|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;Lo(a);u[a+14>>1]=x[((c&15)<<1)+35328>>1];return;case 1:u[a+68>>1]=w[(c>>>6|0)+18705|0];UR(a);u[a+22>>1]=(c&63)<<2;return;case 2:u[a+24>>1]=c>>>4;Lo(a);u[a+26>>1]=c&15;Lo(a);return;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;Lo(a);return;case 6:break d;default:break a}}u[a+12>>1]=c&7}}function SR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(wk(a)){h=gb-16|0;gb=h;j=h+8|0;f=sf(3848);k=v[e+12>>2];c=f+808|0;b=f+16|0;while(1){v[b+16>>2]=0;v[b+20>>2]=0;v[b+36>>2]=0;t[b+42|0]=1;u[b+40>>1]=257;v[b+24>>2]=0;v[b+28>>2]=0;u[b+32>>1]=0;b=b+44|0;if((c|0)!=(b|0)){continue}break}c=f+3832|0;b=f+808|0;while(1){v[b>>2]=0;v[b+4>>2]=0;v[b+68>>2]=0;v[b+72>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;u[b+20>>1]=511;v[b+16>>2]=-1;u[b+14>>1]=1;u[b+6>>1]=0;u[b+8>>1]=0;u[b+10>>1]=0;u[b+12>>1]=0;t[b+73|0]=0;t[b+74|0]=0;t[b+75|0]=0;t[b+76|0]=0;t[b+77|0]=0;t[b+78|0]=0;t[b+79|0]=0;t[b+80|0]=0;b=b+84|0;if((c|0)!=(b|0)){continue}break}b=f;v[b+3832>>2]=0;v[b+3836>>2]=0;c=b+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){cf((b+B(g,84)|0)+808|0,b);g=g+1|0;if((g|0)!=36){continue}break}while(1){v[(b+B(d,44)|0)+32>>2]=b;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=(b+B(d,44)|0)+16|0;g=v[(d<<2)+35216>>2];b:{if(!(!(1<<d&3591)|d>>>0>11)){i=c;c=b+B(g,84)|0;_R(i,c+808|0,c+1060|0,c+1312|0,c+1564|0);break b}i=c;c=b+B(g,84)|0;_R(i,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Lo((b+B(d,84)|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}ZR(b,k);b=v[Xi(j,f)>>2];gb=h+16|0;v[e+8>>2]=b;b=e+8|0;TC(a,b);kn(b);break a}ZR(v[a>>2],b)}ZA(a);gb=e+16|0}function Poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=gb-16|0;gb=e;f=Tb(e,1547);Dc(d- -64|0,f);vb(f);gb=e+16|0;v[22708]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=oqa(e,e>>31,1e4,0)+14780|0;b=jb;b=pqa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(112,d+48|0,d+44|0);g=v[22708];v[22708]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[22708]=0;v[d+28>>2]=(e-B(f,12)|0)+1;R(114,d+32|0,d+28|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}v[22708]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(114,d+16|0,d+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}v[22708]=0;ha(556,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}vb(d+16|0);vb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}break a}Ff(d- -64|0,1527);v[22708]=0;R(557,d+48|0,d+78|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;U(167,a|0,d- -64|0,d+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}}vb(d+48|0);Hb(d- -64|0);gb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d+48|0)}Hb(d- -64|0);S(b|0);L()}function K3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Nh(d);g=Tn(d,a+224|0);Sn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;h=Q(2486,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2488,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(om(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22708]=0;T(2490,a+344|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2467,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function G3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Nh(d);g=Tn(d,a+224|0);Sn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;h=Q(2486,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2488,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(om(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22708]=0;T(2490,a+344|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2471,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Nz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;i=lO(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}e=v[i>>2];f=g+8|0;j=a+1074312|0;Db(f,j,31);f=Cb(f);d=lw(v[b+656>>2],c);if(cd(d)){break a}f=e+(f^1)|0;e=g+8|0;Db(e,j,31);h=Cb(e);e=w[d+12|0];b:{c:{if(!h){d:{if(!(e&2)){break d}e=x[Lb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){h=g+8|0;Db(h,j,70);k=Cb(h)}if((e|0)!=(f|0)|k){break d}f=x[Lb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Lb(d,w[d+16|0])>>1]+1|0)!=(f|0)){break b}f=x[Lb(d,w[d+15|0])>>1];a=g+8|0;Db(a,j,93);if(!Cb(a)|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;e=x[uo(d)>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}e=g+8|0;Db(e,j,97);if(Cb(e)){break f}e=w[d+12|0]}if(e&2){e=x[Lb(d,w[d+13|0])>>1];h=x[Lb(d,w[d+14|0])>>1]+1|0;break e}e=x[uo(d)>>1];k=f>>>0>e>>>0;h=e;break e}e=x[Lb(d,w[d+15|0])>>1];h=x[Lb(d,w[d+16|0])>>1]+1|0}e=f>>>0<h>>>0?f:e}g:{if(!k|c){break g}if(!(w[b+89|0]&8)|v[a+480180>>2]==16384?v[a+480180>>2]&16777248:1){v[b+88>>2]=v[b+88>>2]|4096}if(w[uo(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}f=e}a=g+8|0;Db(a,j,31);l=i,m=Cb(a)+f|0,v[l>>2]=m}gb=g+16|0}function L3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Nh(d);h=Tn(d,a+224|0);Sn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2486,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2488,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2490,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2464,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function J3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Nh(d);h=Tn(d,a+224|0);Sn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2486,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2488,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2490,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2468,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}u[f>>1]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Nh(d);h=Tn(d,a+224|0);Sn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2486,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2488,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2490,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2469,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function H3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Nh(d);h=Tn(d,a+224|0);Sn(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22708]=0;g=Q(2486,a+344|0,a+336|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2488,a+344|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22708]=0;T(2490,a+344|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2470,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2487,a+344|0,a+336|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function b4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Nh(d);Un(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22708]=0;h=Q(2459,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2461,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(pm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2463,a+232|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2467,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function X3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Nh(d);Un(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22708]=0;h=Q(2459,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=h+c}v[22708]=0;h=T(2461,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(pm(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2463,a+232|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22708]=0;b=zs(2471,c,v[a+188>>2],e,b);c=jb;g=v[22708];v[22708]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;gb=g+32|0}function n3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;m=Ox(g);g=ux(g);Ug(k,g);a:{b:{c:{d:{if(gd(k)){v[22708]=0;Y(2493,m|0,a|0,c|0,d|0);g=v[22708];v[22708]=0;if((g|0)==1){break d}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;e:{f:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break f;default:break e}}v[22708]=0;j=Q(2503,m|0,h<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break d}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22708]=0;h=Q(2503,m|0,48)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[22708]=0;h=Q(2503,m|0,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}nm(j,c);v[22708]=0;n=T(2491,g|0)|0;g=v[22708];v[22708]=0;g:{if((g|0)!=1){if(c>>>0>j>>>0){break g}g=v[f>>2];break b}break d}o=(c-j|0)+j|0;g=j;h=0;i=0;while(1){h:{if(!w[pc(k,h)|0]){break h}if(t[pc(k,h)|0]!=(i|0)){break h}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=n;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}l=t[g|0];v[22708]=0;p=Q(2503,m|0,l|0)|0;l=v[22708];v[22708]=0;if((l|0)!=1){l=v[f>>2];v[f>>2]=l+4;v[l>>2]=p;i=i+1|0;g=g+1|0;if((o|0)==(g|0)){break c}continue}break}}a=P()|0;O()|0;vb(k);S(a|0);L()}g=l+4|0}qx((j-a<<2)+d|0,g);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;vb(k);gb=k+16|0}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Z0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{if(d>>>0<=b>>>0){break a}b:{while(1){if(f>>>0>=g>>>0){break b}j=t[b|0];c=j&255;l=a;c:{if((j|0)>=0){u[f>>1]=c;b=b+1|0;break c}j=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-b|0)<2){break b}i=w[b+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|c<<6&1984;b=b+2|0;break c}if(c>>>0<=239){if((d-b|0)<3){break b}k=w[b+2|0];i=w[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|c<<12);b=b+3|0;break c}if(c>>>0>244){break a}if((d-b|0)<4){break b}k=w[b+3|0];i=w[b+2|0];b=w[b+1|0];f:{g:{switch(c-240|0){case 0:if((b+112&255)>>>0<48){break f}break a;case 4:if((b&240)==128){break f}break a;default:break g}}if((b&192)!=128){break a}}if((i&192)!=128|(k&192)!=128){break a}if((g-f|0)<4){break b}c=c&7;if((b<<12&196608|c<<18)>>>0>1114111){break a}b=b<<2;u[f>>1]=(i>>>4&3|(b&192|c<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[l+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;b=v[a+12>>2];if(d>>>0>b>>>0){continue}break}j=0;break a}j=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return j|0}function e4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Nh(d);Un(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2459,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2461,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(pm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2463,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2464,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Nh(d);Un(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2459,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2461,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(pm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2463,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2469,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Y3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Nh(d);Un(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2459,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2461,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(pm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2463,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2470,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function $3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Nh(d);Un(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22708]=0;g=Q(2459,a+232|0,a+224|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22708]=0;R(76,d|0,c<<1);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=Kc(d);v[22708]=0;R(76,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=pc(d,0);v[a+188>>2]=g+c}v[22708]=0;g=T(2461,a+232|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}if(pm(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83408)){break c}v[22708]=0;T(2463,a+232|0)|0;g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22708]=0;b=ca(2468,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22708];v[22708]=0;f:{if((c|0)==1){break f}u[f>>1]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22708]=0;b=Q(2460,a+232|0,a+224|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function m_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){ud(b,32);li(d,1,a+4|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}vb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;yg(b+30|0,256);u[b+32>>1]=w[a+17|0];yg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;yg(b+28|0,256);if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);xk(b);t[b+38|0]=w[(w[a+79|0]&7)+46144|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=d+32|0;return c|0}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=gb-144|0;gb=k;PB(a);a:{b:{if(!Wf(a,64)){break b}c:{d:{if(!Ul(a,60)){break d}if(!qU(a,11401)){break d}h=15;e=450;break c}PB(a);if(!Wf(a,128)){break b}b=0;if(!Ul(a,124)){break a}if(!qU(a,12499)){break a}h=31;e=930}PB(a);b=0;while(1){j=0;f=gb-16|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;Ai(d,f+8|0);g=yb(d);d=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=d;v[c>>2]=i;v[c+4>>2]=d;d=a;i=c+16|0;hd(i,a,c);i=yb(i);if((i|0)==(g|0)){bd(d,yb(c+24|0))}gb=c+32|0;if((g|0)==(i|0)){d=f+8|0;j=Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))}gb=f+16|0;if(j>>>0>131072){break a}l=l+1|0;if((l&65535)>>>0<h>>>0){continue}break}bd(a,4);if(!Wf(a,2)){break b}h=0;f=gb-16|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;An(d,f+8|0);j=yb(d);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;g=c+16|0;hd(g,a,c);g=yb(g);if((g|0)==(j|0)){bd(d,yb(c+24|0))}gb=c+32|0;if((g|0)==(j|0)){d=f+8|0;h=Ib(w[d|0]|w[d+1|0]<<8)}gb=f+16|0;if(h>>>0<178){break a}b=-1;if(!Wf(a,e)){break a}bd(a,e);e=gb-32|0;gb=e;d=e+24|0;h=k+8|0;oV(d,h);d=yb(d);c=v[e+28>>2];f=v[e+24>>2];v[e+8>>2]=f;v[e+12>>2]=c;v[e>>2]=f;v[e+4>>2]=c;c=e+16|0;hd(c,a,e);c=yb(c);if((c|0)==(d|0)){bd(a,yb(e+24|0))}gb=e+32|0;a=(c|0)==(d|0);if(!a){XB(h)}if(!a){break a}b=pU(k+8|0);break a}b=-1}gb=k+144|0;return b|0}function u_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-1088|0;gb=e;Kh(a);Qb(a+20|0,0,1040);i=a;v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;g=a+1072|0;v[g>>2]=0;v[g+4>>2]=0;v[a+1080>>2]=0;t[a+1084|0]=d;a:{if(fd(c)){g=a+1064|0;while(1){v[a+1064>>2]=0;v[a+1068>>2]=0;b:{if(!v[c>>2]){break b}while(1){v[22708]=0;d=Q(191,b|0,2)|0;f=v[22708];v[22708]=0;c:{d:{e:{if((f|0)!=1){if(!d){break b}v[22708]=0;d=T(287,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break e}if(!d){break c}v[22708]=0;U(288,e|0,b|0,d|0);d=v[22708];v[22708]=0;f:{g:{if((d|0)!=1){v[22708]=0;d=Lp(e+24|0,e);f=v[22708];v[22708]=0;if((f|0)==1){break g}Vc(i,d);hc(i+20|0,d+20|0,1040);xb(e+24|0);xb(e);v[a+1076>>2]=0;v[a+1080>>2]=0;f=ij(v[a+1060>>2]);d=v[a+1060>>2];if(f>>>0<2){break f}d=v[d+20>>2];v[22708]=0;R(289,a|0,d+(h<<1)|0);d=v[22708];v[22708]=0;if((d|0)!=1){break c}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;xb(e);break a}d=v[d+20>>2];v[22708]=0;R(290,a|0,d+h|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}break c}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break a}Z(d|0)|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){break c}d=P()|0;O()|0;break a}if(y[g>>2]<y[c>>2]){continue}break}}h=h+1|0;if(fd(v[a+1060>>2])>>>0>h>>>0){continue}break}}gb=e+1088|0;return a|0}xb(a);S(d|0);L()}function aJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0);d=(b<<2)+a|0;g=d+1068|0;l=c<<1&-4;q=g,r=_d(a,l),v[q>>2]=r;i=d+1076|0;q=i,r=_d(a,l),v[q>>2]=r;k=_d(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}i=v[i>>2];if(!i|!k){break a}d=c;b:{if((d|0)<4){break b}j=C(d|0);p=d>>>2|0;while(1){m=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))/j);q=m+g|0,s=C(Me(f)),z[q>>2]=s;n=e|1;o=n<<2;q=o+g|0,s=C(-C(si(f))),z[q>>2]=s;f=+C(C(C(C(n|0)*C(3.1415927410125732))/j)*C(.5));q=i+m|0,s=C(C(Me(f))*C(.5)),z[q>>2]=s;q=i+o|0,s=C(C(si(f))*C(.5)),z[q>>2]=s;e=e+2|0;h=h+1|0;if((p|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;e=0;h=0;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);q=k+(e<<2)|0,s=C(Me(f)),z[q>>2]=s;q=k+(g<<2)|0,s=C(-C(si(f))),z[q>>2]=s;e=e+2|0;h=h+1|0;if((d|0)!=(h|0)){continue}break}}e=(b<<2)+a|0;d=_d(a,l);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;f=+(b|0);h=(b|0)>1?b:1;b=0;while(1){j=C(si((+(b|0)+.5)/f*.5*3.1415927410125732));q=d+(b<<2)|0,s=C(si(+C(j*j)*1.5707963705062866)),z[q>>2]=s;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=_d(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=Bm(a);if((a|0)>=8){c=36-d|0;d=a>>>3|0;a=0;while(1){q=b+(a<<1)|0,r=zm(a)>>>c<<2,u[q>>1]=r;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}ec(a,3);return 0}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=gb-32|0;gb=i;v[i+24>>2]=b;b=v[a>>2];p=i,q=Vb(a),v[p>>2]=q;b=b+B(Wt(i+24|0,i),6)|0;a:{b:{if(!c){break b}e=v[wb(a)>>2];f=v[a+4>>2];if((e-f|0)/6>>>0>=c>>>0){g=c;h=f-b|0;e=(h|0)/6|0;if(e>>>0<c>>>0){QC(a,c-e|0,d);g=e;if(!h){break b}}l=gb-16|0;gb=l;j=a;e=b;o=f;n=v[a+4>>2];h=B((n-(B(c,6)+e|0)|0)/6|0,6)+e|0;m=Cr(l,a,(f-h|0)/6|0);if(f>>>0>h>>>0){k=v[m+4>>2];f=h;while(1){wb(j);AN(k,f);k=k+6|0;v[m+4>>2]=k;f=f+6|0;if(o>>>0>f>>>0){continue}break}}$b(m);f=h-e|0;if(f){zh(n+B((f|0)/-6|0,6)|0,e,f)}gb=l+16|0;a=B(b>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;if(g){while(1){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;e=e+6|0;g=g-1|0;if(g){continue}break}}break b}g=wb(a);g=MW(i,BC(a,Jg(a)+c|0),(b-v[a>>2]|0)/6|0,g);v[22708]=0;U(643,g|0,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}OC(a);c=v[g+4>>2];f=g+4|0;KW(wb(a),v[a>>2],b,f);wb(a);h=g+8|0;d=h;j=v[a+4>>2];if((j|0)!=(b|0)){e=v[d>>2];while(1){AN(e,b);e=v[d>>2]+6|0;v[d>>2]=e;b=b+6|0;if((j|0)!=(b|0)){continue}break}}xc(a,f);xc(a+4|0,h);xc(wb(a),dc(g));v[g>>2]=v[g+4>>2];DC(a,Jg(a));b=c;pv(g)}Gg(b);gb=i+32|0;return}a=P()|0;O()|0;pv(g);S(a|0);L()}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;gb=f+32|0}function C2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-448|0;gb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2508;h=ge(a+24|0,a+32|0,a+20|0);v[22708]=0;Fc(a+16|0,e);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[22708]=0;i=T(2481,a+16|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[22708]=0;b=ra(2516,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!b){break c}c=gb-16|0;gb=c;b=g;e:{if(Ee(b)){d=v[b>>2];v[c+12>>2]=0;Ge(d,c+12|0);de(b,0);break e}v[c+8>>2]=0;Ge(b,c+8|0);Ze(b,0)}gb=c+16|0;if(!w[a+15|0]){break d}v[22708]=0;b=Q(2503,i|0,45)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(63,g|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22708]=0;b=Q(2503,i|0,48)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;f:{if(e>>>0>=d>>>0){break f}while(1){if((b|0)!=v[e>>2]){break f}e=e+4|0;if(d>>>0>e>>>0){continue}break}}v[22708]=0;U(2521,g|0,e|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break c}break b}v[22708]=0;b=Q(2487,a+440|0,a+432|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Wb(a+16|0);Hc(h);gb=a+448|0;return b|0}e=P()|0;O()|0;Wb(a+16|0)}Hc(h);S(e|0);L()}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Mb(k,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];l=oqa(e,e>>31,f,f>>31);e=I+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;h=oqa(G,H,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-1072|0;gb=e;v[e+1068>>2]=c;l=Be(b);g=lD(e+8|0,b);v[22708]=0;m=mn(g);c=v[22708];v[22708]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22708]=0;c=T(467,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}v[e+4>>2]=c;v[22708]=0;v[e>>2]=536870911;c=Fb(e+4|0,e);d=v[22708];v[22708]=0;if((d|0)==1){break c}qc(e+1068|0,v[c>>2]<<3);v[22708]=0;k=Q(513,a|0,v[e+1068>>2])|0;a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;c=8;f=Q(200,g|0,8)|0;d=v[22708];v[22708]=0;a=1;e:{f:{if((d|0)==1){break f}d=zb(f&255);n=kc(k,0),o=d,t[n|0]=o;g:{if(y[e+1068>>2]<2){break g}while(1){v[22708]=0;j=c&255;d=Q(200,g|0,j|0)|0;h=v[22708];v[22708]=0;h:{i:{j:{k:{if((h|0)!=1){if(d){break k}if(j>>>0>8){break g}c=c+1|0;break j}break f}h=f;f=d>>>1|0;f=h+(d&1?0-f|0:f)|0;h=zb(f&255);n=kc(k,a),o=h,t[n|0]=o;a=a+1|0;if(!(d<<1>>>j|0)){break i}}i=0;break h}i=i+1|0;d=i&255;c=c-(j>>>0>1&d>>>0>=l>>>0)|0;i=d>>>0<l>>>0?i:0}if(y[e+1068>>2]>a>>>0){continue}break}}v[22708]=0;a=mn(g);c=v[22708];v[22708]=0;if((c|0)==1){break f}v[22708]=0;Q(190,b|0,((a-m|0)+3&-4)+m|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break e}}c=P()|0;O()|0;gc(k);break a}xb(g);gb=e+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}xb(g);S(c|0);L()}function _0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<1){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;if(c>>>0<d>>>0){continue}break}}f=0;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return f|0}function Du(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{f=a;d=b;b:{c:{i=a+58|0;h=lc(i,b);b=t[h|0];if((b|0)==-1){break c}if((b|0)>-1){break b}b=b&127;e=wd(f+22|0,b);g=x[e>>1];if((d|0)!=(g|0)?(g|0)!=65535:0){break c}u[e>>1]=d;t[h|0]=b;break b}m=f+4|0;j=f+22|0;g=255;b=0;e=255;while(1){k=wd(j,b);l=x[k>>1];if((l|0)==65535){u[k>>1]=d;t[h|0]=b;break b}if(!(w[lc(m,b)|0]&32)){g=t[lc(i,l)|0]>-1?g:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(g&255)==255?e:g;e=wd(j,b&255);n=lc(i,x[e>>1]),o=255,t[n|0]=o;u[e>>1]=d;t[h|0]=b}b=Nl(f,d)}e=b&255;if((e|0)==255){break a}if(wk(a)){break a}d=XA(a+314|0,e);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=b;t[d+9|0]=b>>>8;t[d+10|0]=b>>>16;t[d+11|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=b;t[d+5|0]=b>>>8;t[d+6|0]=b>>>16;t[d+7|0]=b>>>24;g=RR(e);h=g+3|0;b=0;d=1;while(1){f=d;d=d?g:h;Yh(v[a>>2],(d|32)&65535,w[lc(c,b)|0]);Yh(v[a>>2],(d|64)&65535,w[lc(c,b|2)|0]);Yh(v[a>>2],(d|96)&65535,w[lc(c,b|4)|0]);Yh(v[a>>2],(d|128)&65535,w[lc(c,b|6)|0]);Yh(v[a>>2],(d|224)&65535,w[lc(c,b|8)|0]);d=0;b=1;if(f){continue}break}Yh(v[a>>2],Eu(e)|192,w[lc(c,10)|0])}}function z3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;l=wD(g);g=yx(g);Ug(k,g);a:{b:{if(gd(k)){v[22708]=0;Y(2473,l|0,a|0,c|0,d|0);g=v[22708];v[22708]=0;if((g|0)==1){break a}g=(c-a|0)+d|0;v[f>>2]=g;break b}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22708]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22708]=0;h=Q(22,l|0,48)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[22708]=0;h=Q(22,l|0,h|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}nm(j,c);v[22708]=0;o=T(2465,g|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}if(c>>>0>j>>>0){p=(c-j|0)+j|0;g=j;h=0;i=0;while(1){e:{if(!w[pc(k,h)|0]){break e}if(t[pc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22708]=0;n=Q(22,l|0,n|0)|0;m=v[22708];v[22708]=0;if((m|0)==1){break a}m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;i=i+1|0;g=g+1|0;if((p|0)!=(g|0)){continue}break}}nm((j-a|0)+d|0,v[f>>2]);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);S(a|0);L()}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Mb(k,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];l=oqa(e,e>>31,f,f>>31);e=J+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;h=oqa(H,I,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function Jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;e=u[f>>1];v[b+8>>2]=e;v[b+12>>2]=u[f+2>>1];i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Mb(n,-16777216,16776704);m=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=oqa(l,r,e,e>>31);l=jb;m=oqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=oqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=c>>>4;v[e+16>>2]=v[a>>2];j=v[Fb(e+24|0,e+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){d=b;f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[bh(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=ee(h);a:{if(D(h)<2147483648){f=~~h;break a}f=-2147483648}m=d,n=Uc(f),u[m>>1]=n;d=b;f=w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24);g=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[bh(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=ee(h);b:{if(D(h)<2147483648){f=~~h;break b}f=-2147483648}m=d,n=Uc(f),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=e+32|0;return j<<4}function t2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-496|0;gb=a;g=a+488|0;Fc(g,d);v[22708]=0;m=T(2481,g|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=v[yk(f,0)>>2];v[22708]=0;h=Q(2503,m|0,45)|0;k=v[22708];v[22708]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);v[22708]=0;na(2525,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}v[a+4>>2]=2457;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+420>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Fe(c,Cd(j<<2));i=v[c>>2];if(i){break e}v[22708]=0;X(2458);b=v[22708];v[22708]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22708]=0;qa(2526,i|0,a+4|0,a|0,j|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;b=la(2506,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}Ic(h);Ic(g);vb(k)}Wb(a+488|0);S(f|0);L()}Hc(c);Ic(h);Ic(g);vb(k);Wb(a+488|0);gb=a+496|0;return b|0}function f1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;i=d;j=(c|0)==(d|0);a:{if(j){break a}i=c;while(1){if(!w[i|0]){break a}i=i+1|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];m=wi(l+8|0,l+12|0);v[22708]=0;j=lH(f,e,i-c|0,g-f>>2,b);n=v[22708];v[22708]=0;d:{if((n|0)!=1){ff(m);gb=l+16|0;break d}a=P()|0;O()|0;ff(m);S(a|0);L()}e:{f:{g:{h:{i:{j:{k:{if((j|0)==-1){v[h>>2]=f;if(v[e>>2]!=(c|0)){while(1){g=1;l:{m:{n:{b=CG(f,c,i-c|0,k+8|0,v[a+8>>2]);switch(b+2|0){case 0:break i;case 2:break l;case 1:break n;default:break m}}v[e>>2]=c;break k}g=b}f=v[h>>2]+4|0;v[h>>2]=f;c=c+g|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break c}f=v[h>>2]+(j<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break h}c=v[e>>2];if((d|0)==(i|0)){i=d;break e}if(!CG(f,c,1,b,v[a+8>>2])){break j}}a=2;break b}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;if((c|0)==(d|0)){break g}while(1){if(!w[i|0]){break f}i=i+1|0;if((i|0)!=(d|0)){continue}break}break g}v[e>>2]=c;a=1;break b}c=v[e>>2];break c}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}a=(c|0)!=(d|0)}gb=k+16|0;return a|0}function Ana(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=ov(a);if(b>>>0<=63){k=gb-32|0;gb=k;a:{b:{j=64-b|0;c:{if(j>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/33>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(j,33);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){AC(a);a=a+33|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}i=wb(a);f=k+8|0;d=a;c=ov(a)+j|0;h=gb-16|0;gb=h;v[h+12>>2]=c;e=gb-16|0;gb=e;v[e+12>>2]=130150524;v[22708]=0;v[e+8>>2]=2147483647;g=Fb(e+12|0,e+8|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){gb=e+16|0;b=v[g>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0>=c>>>0){c=tW(d);if(c>>>0<b>>>1>>>0){v[h+8>>2]=c<<1;b=v[Mc(h+8|0,h+12|0)>>2]}gb=h+16|0;break e}Sc();L()}d=ov(a);e=0;g=gb-16|0;gb=g;v[g+12>>2]=0;hf(f+12|0,i);if(b){c=b;if(b>>>0>=130150525){rd(8445);L()}e=Nc(B(c,33),1)}v[f>>2]=e;c=B(d,33)+e|0;v[f+8>>2]=c;v[f+4>>2]=c;l=dc(f),m=B(b,33)+e|0,v[l>>2]=m;gb=g+16|0;v[22708]=0;xW(f,j);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=a;c=f;i=c+4|0;d=v[a+4>>2];a=v[a>>2];g=d-a|0;d=v[i>>2]+B((g|0)/-33|0,33)|0;v[i>>2]=d;if((g|0)>=1){hc(d,a,g)}wc(b,i);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];wW(f)}gb=k+32|0;break a}a=P()|0;O()|0;wW(f);S(a|0);L()}return}if((b|0)!=64){Zk(a,v[a>>2]+2112|0)}}function Kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+o|0;e=t[f|0]<<8;v[b+8>>2]=e;v[b+12>>2]=t[f+1|0]<<8;i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Mb(n,-16777216,16776704);m=v[a+64>>2];h=Mb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=oqa(l,r,e,e>>31);l=jb;m=oqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=oqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function uea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);i=gb-16|0;gb=i;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Nb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}h=u[d+2>>1];if((h|0)<(g|0)){break a}if((Nb(b)-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Nb(b)){break b}while(1){if(!(z[Lb(b,f)>>2]<C(0))){f=f+1|0;if(Nb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=nN(Nb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;Dl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=Vb(b);f=Zb(b);l=i,m=Vb(g),v[l+8>>2]=m;h=Zo(i+8|0,u[e>>1]-u[d>>1]|0);b=gb-16|0;gb=b;yc(b+8|0,Kn(Yl(c),Yl(f),Yl(h)));gb=b+16|0;b=u[a+28>>1];c=u[e>>1];c:{if((b|0)>=(c|0)){break c}f=c;while(1){f=f-1|0;j=z[Lb(g,u[a+30>>1]+(f-b|0)|0)>>2];k=z[a+32>>2];l=Lb(g,f-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;c=u[e>>1];b=u[a+28>>1];if((f|0)<=(b|0)){break c}if((c|0)!=-32768){continue}break}}d:{h=u[a+30>>1];f=h+c|0;if((f|0)>u[d+2>>1]|(32767-h|0)<(c|0)){break d}while(1){j=z[a+32>>2];k=z[Lb(g,f-((b<<16>>16)+h|0)|0)>>2];l=Lb(g,f-u[a+28>>1]|0),n=C(j*k),z[l>>2]=n;if(u[d+2>>1]<=(f|0)){break d}h=u[a+30>>1];if(u[e>>1]>(32767-h|0)){break d}f=f+1|0;b=x[a+28>>1];continue}}nq(a);f=1}gb=i+16|0;return f|0}function nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function rga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;b=a+8|0;ku(b,Yd(b));l=wb(b),m=0,v[l>>2]=m;l=b,m=fc(b),v[l>>2]=m;l=fc(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;d=a+4|0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];j=x[b+480188>>1];v[h+8>>2]=0;v[h+12>>2]=0;i=h+8|0;u[i+4>>1]=65280;v[i>>2]=0;g=gb-16|0;gb=g;v[g+12>>2]=j;f=a+20|0;a:{if(tg(f)>>>0>=j>>>0){l=g,m=rf(f),v[l+8>>2]=m;c=v[f>>2];b=i;e=v[Fb(g+12|0,g+8|0)>>2];if(e){while(1){v[c>>2]=v[b>>2];u[c+4>>1]=x[b+4>>1];c=c+8|0;e=e-1|0;if(e){continue}break}}b=v[g+12>>2];c=v[g+8>>2];if(b>>>0>c>>>0){dP(f,b-c|0,i);break a}Zk(f,v[f>>2]+(b<<3)|0);break a}b=f;if(v[b>>2]){Od(b);eP(v[b>>2],tg(b));l=wb(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}c=gs(f,j);if(Hw()>>>0<c>>>0){Sc();L()}e=c;if(c>>>0>=536870912){rd(8445);L()}e=Nc(e<<3,4);v[b>>2]=e;v[b+4>>2]=e;l=wb(b),m=e+(c<<3)|0,v[l>>2]=m;dP(f,j,i)}gb=g+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(k,872);_m((b+v[d>>2]|0)+616|0,7,v[a>>2],k&65535,134217728);t[(b+v[d>>2]|0)+1433|0]=0;t[(b+v[d>>2]|0)+1432|0]=0;t[(b+v[d>>2]|0)+1415|0]=0;t[(b+v[d>>2]|0)+1418|0]=0;t[(b+v[d>>2]|0)+1413|0]=0;k=k+1|0;if(k>>>0<x[v[a>>2]+480188>>1]){continue}break}}gb=h+16|0}function mqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;hb=a-B(b,c)|0;ib=0;jb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}hb=a;ib=f&g;a=g>>>nqa(e)|0;jb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}hb=0;a=(g>>>0)/(e>>>0)|0;ib=g-B(a,e)|0;jb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}hb=a&f;ib=0;if((e|0)==1){break a}c=a;a=nqa(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}jb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;f=i>>31;e=f;i=e;f=c&e;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}hb=l;ib=f;e=b<<1|a>>>31;a=k|a<<1;jb=e|m;return a}hb=a;ib=b;a=0;b=0}jb=b;return a}function yga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;g=gb-32|0;gb=g;s=g,t=B(v[a>>2],fd(a)),v[s+4>>2]=t;qc(g+4|0,c>>>3|0);c=zb(b);j=A[e+8>>3];k=v[g+4>>2];a:{if(!k){break a}e=k;while(1){m=0;f=c;o=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);q=h<<24|h<<8&16711680;p=m;m=o<<24|h>>>8;f=o<<8|h>>>24;p=p|0;m=m&65280|f&255|q;f=o;l(0,((f&255)<<24|h>>>8)&-16777216|((f&16777215)<<8|h>>>24)&16711680|(f>>>8&65280|f>>>24)|p);l(1,m&2147483647);i=+n();j=j<i?i:j;c=c+8|0;e=e-1|0;if(e){continue}break}if(j==0){break a}r=1/j;c=v[a+20>>2];while(1){e=b;a=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=h<<24;q=0;o=h<<8&16711680|f;p=a<<24|h>>>8;f=a<<8|h>>>24;e=a;l(0,((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|q);l(1,o|(p&65280|f&255));s=g,x=r*+n(),A[s+24>>3]=x;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;i=A[bh(g+24|0,g+16|0,g+8|0)>>3]*32768;A[g+24>>3]=i;a=c;i=ee(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}s=a,t=Uc(e),u[s>>1]=t;b=b+8|0;c=c+2|0;k=k-1|0;if(k){continue}break}}if(d){A[d>>3]=j}gb=g+32|0;return v[g+4>>2]<<3}function x2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-192|0;gb=a;g=a+184|0;Fc(g,d);v[22708]=0;m=T(21,g|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=w[pc(f,0)|0];v[22708]=0;h=Q(22,m|0,45)|0;k=v[22708];v[22708]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);v[22708]=0;na(2523,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}v[a+4>>2]=2457;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+124>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Fe(c,Cd(j));i=v[c>>2];if(i){break e}v[22708]=0;X(2458);b=v[22708];v[22708]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22708]=0;qa(2524,i|0,a+4|0,a|0,j|0,o|0,f+p|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;b=la(17,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Hc(c)}vb(h);vb(g);vb(k)}Wb(a+184|0);S(f|0);L()}Hc(c);vb(h);vb(g);vb(k);Wb(a+184|0);gb=a+192|0;return b|0}function yW(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+28896|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[ac(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[ac(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}gb=c+16|0}function XY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-144|0;gb=g;v[22708]=0;l=T(416,a|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){a:{if(l){e=g+8|0;o=e|4;p=e|6;q=e|5;k=e|2;m=e|3;while(1){v[22708]=0;R(445,a|0,g+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}e=g+8|0;e=Ib(w[e|0]|w[e+1|0]<<8);b:{if(!e|e>>>0>x[c+480192>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}v[22708]=0;e=ki(e,b);f=v[22708];v[22708]=0;if((f|0)==1){break a}c:{if(!w[m|0]){break c}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break c}t[e+12|0]=w[e+12|0]|2}t[g+4|0]=w[m|0];v[22708]=0;t[g+7|0]=31;f=ac(g+4|0,g+7|0);i=v[22708];v[22708]=0;if((i|0)==1){break a}f=w[f|0];v[22708]=0;i=f+1&255;R(446,e|0,i|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}t[e+13|0]=w[q|0];t[e+14|0]=w[p|0];f=w[o|0];t[e+15|0]=f;t[e+16|0]=f;f=0;if(!i){break b}while(1){h=(g+8|0)+(f<<2)|0;j=h+8|0;j=Ib(w[j|0]|w[j+1|0]<<8);r=Lb(e,f),s=j,u[r>>1]=s;h=h+10|0;h=Ib(w[h|0]|w[h+1|0]<<8);u[g+4>>1]=d?h+128>>>2|0:h;yg(g+4|0,64);h=w[g+4|0];r=Lb(e,f),s=h,t[r+2|0]=s;f=f+1|0;if((i|0)!=(f|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<l>>>0){continue}break}}xb(a);gb=g+144|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function Gx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;r=a;j=gb-1040|0;gb=j;s=v[115189];a:{b:{c:{a=j+16|0;m=a;e=b;g=v[22614];d:{e:{while(1){if((e|0)!=w[d+74896|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=74992;break d}d=74992;while(1){h=w[d|0];e=d+1|0;d=e;if(h){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[g+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];i=v[f>>2]+1794895138|0;l=rm(v[f+8>>2],i);g=rm(v[f+12>>2],i);h=rm(v[f+16>>2],i);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((g|h)&3|(c>>>0<=g>>>0|c>>>0<=h>>>0)){break f}u=h>>>2|0;x=g>>>2|0;while(1){n=l>>>1|0;g=n+o|0;h=g<<1;c=(h+x<<2)+f|0;p=rm(v[c>>2],i);c=rm(v[c+4>>2],i);if(c>>>0>=k>>>0|k-c>>>0<=p>>>0|w[(c+p|0)+f|0]){break f}c=wj(d,c+f|0);if(!c){d=(h+u<<2)+f|0;c=rm(v[d>>2],i);d=rm(v[d+4>>2],i);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}q=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?n:l-n|0;o=c?o:g;continue}}}d=q?q:e;e=Of(d);g:{if(e>>>0>=1024){hc(m,d,1023);t[m+1023|0]=0;e=68;break g}hc(m,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[115189]}a=18720;if((e|0)==28){break a}Da();L()}if(!w[a|0]){v[j>>2]=b;a=j+16|0;Wx(a,1024,10345,j)}v[115189]=s;Tb(r,a);gb=j+1040|0}function zI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=gb-16|0;gb=k;a:{b:{c:{if((c|0)<=36){g=w[a|0];if(g){break c}f=a;break b}v[115189]=28;d=0;e=0;break a}f=a;d:{while(1){if(!ym(g<<24>>24)){break d}g=w[f+1|0];h=f+1|0;f=h;if(g){continue}break}f=h;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=-48;h=t[f|0];h:{if((h-48&255)>>>0<10){break h}g=-87;if((h-97&255)>>>0<26){break h}g=-55;if((h-65&255)>>>0>25){break g}}h=g+h|0;if((h|0)>=(l|0)){break g}qf(k,p,q,0,0,j,i,0,0);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=oqa(j,i,p,q);n=jb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[115189]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[115189]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[115189]=68;break a}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^i)-((a>>>0>b>>>0)+c|0)|0}gb=k+16|0;jb=e;return d}function GP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;d=v[b+64>>2];a:{b:{h=v[b+60>>2];e=x[b+68>>1];if(!((e|0)==65535?(h|0)==-1:0)){c:{if((d|0)==-1){break c}g=f+24|0;d=a+1074312|0;Db(g,d,68);if(Cb(g)){break c}g=f+16|0;Db(g,d,103);if(i=Cb(g),j=0,k=(e|0)!=65535,k?i:j){break c}g=f+8|0;Db(g,d,49);if(i=Cb(g),j=0,k=(e|0)!=65535,k?i:j){break c}d=v[b+64>>2];break b}if((e|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}d=x[b+68>>1];e=a+484360|0;d:{if(tc(Sb(e))>>>0>d>>>0){d=x[b+68>>1];break d}d=x[Sb(e)+28>>1];u[b+68>>1]=d}e:{if(x[b+72>>1]==(d&65535)){break e}d=f+24|0;e=a+1074312|0;Db(d,e,26);if(Cb(d)){break e}d=f+16|0;Db(d,e,68);if(Cb(d)|v[a+480180>>2]==1|!x[a+480188>>1]){break e}d=0;while(1){t[(B(d,872)+b|0)+1457|0]=0;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[b+52>>2]=v[b+60>>2];if(c){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((d|0)!=-1){break b}c=0;break a}v[b+52>>2]=d;u[b+74>>1]=x[b+72>>1];f:{if(!v[b+20>>2]){break f}if(v[a+480180>>2]==32){c=f+24|0;Db(c,a+1074312|0,103);if(Cb(c)){break f}}if(v[a+480180>>2]==2){break f}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[_b(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}gb=f+32|0;return c}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb-2160|0;gb=b;Qb(b+112|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[22708]=0;b=Q(70,b+96|0,7723)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}g=v[c>>2];d=v[c+12>>2];h=v[c+8>>2];v[b+88>>2]=h;v[b+92>>2]=d;c=v[b+92>>2];v[b+40>>2]=v[b+88>>2];v[b+44>>2]=c;v[b+84>>2]=f;v[b+80>>2]=g;c=v[b+84>>2];v[b+32>>2]=v[b+80>>2];v[b+36>>2]=c;c=b;j=b;i=_K(b+32|0);if(i){e=b- -64|0;v[e>>2]=h;v[b+68>>2]=d;d=v[e+4>>2];v[b+24>>2]=v[e>>2];v[b+28>>2]=d;v[b+60>>2]=f;v[b+56>>2]=g;d=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=d;d=ZK(b+16|0)}else{d=0}v[j+72>>2]=d;v[c+76>>2]=0;c=0;d=2048;while(1){d:{e=kb[f|0](g,(b+112|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}c=vd(b+48|0,zb(b+112|0),c);f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;a=gA(a,b+8|0,i?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[22708]=0;b=Q(70,b+96|0,5190)|0;c=v[22708];v[22708]=0;if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;da(a|0);break b}gb=b+2160|0;return a|0}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function Soa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;e=a;g=a+3|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=w[a+3|0];switch(b-14|0){case 0:break j;case 2:case 3:case 4:case 5:break b;case 8:break g;case 6:case 7:break h;case 1:break i;default:break k}}switch(b-31|0){case 2:break e;case 0:break f;default:break b}}c=w[a+5|0];if(!c){c=14;break d}l:{if((c|0)!=15){if((c|0)!=240){break l}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(c>>>0>=16){t[a+5|0]=c|15;break c}t[a+5|0]=c|240;break c}t[a+5|0]=w[a+5|0]^128;break c}c=w[a+5|0];if(c>>>0>=16){t[d+15|0]=c>>>4;t[d+14|0]=15;h=a,i=w[ac(d+15|0,d+14|0)|0]|240,t[h+5|0]=i;break c}t[a+5|0]=c|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}h=a,i=ei(w[a+5|0]<<1),t[h+5|0]=i;break c}b=32;m:{n:{o:{p:{q:{r:{s:{f=w[a+5|0];switch(f>>>4|0){case 12:case 13:break m;case 3:break n;case 5:break o;case 14:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break d}}b=64;break n}b=176;break n}b=224;break n}t[a+5|0]=119;break c}b=48}t[a+5|0]=f&15|b;break c}if(f){break c}}t[e+3|0]=w[c+28832|0];break a}b=w[e+3|0]}if(b>>>0<36){t[e+3|0]=w[b+28832|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;t[a+4|0]=w[a+5|0];g=a+5|0}t[g|0]=0}gb=d+16|0}function LO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{d=a+484360|0;if(tc(Sb(d))>>>0<=b>>>0){break b}if(No(Sb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(tc(Sb(d))>>>0<=c>>>0){break a}if(!No(Sb(d),b&65535)){continue}break}break a}c=b}if(tc(Sb(d))>>>0>c>>>0){d=a+1074312|0;g=a+1298224|0;c=a+1074992|0;while(1){t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;f=e+8|0;Db(f,d,23);if(Cb(f)){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;if((g|0)!=(c|0)){continue}break}KO(a);c:{if(!(b&65535)){b=a;c=0;while(1){_m((b+B(c,872)|0)+1074992|0,7,b,c&65535,134217728);c=c+1|0;if((c|0)!=256){continue}break}Io(b+1298224|0,1);v[b+1074456>>2]=v[b+480200>>2];v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;tA(b+1074376|0);u[b+1074450>>1]=0;v[b+1074392>>2]=-2;c=b+1074428|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074396|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074376>>2]=0;v[b+1074380>>2]=0;break c}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}gb=e+16|0}function vpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-32|0;gb=h;v[h+24>>2]=b;b=v[a>>2];m=h,n=Vb(a),v[m>>2]=n;b=bk(h+24|0,h)+b|0;a:{g=VX(c,d);b:{if((g|0)<1){break b}i=v[wb(a)>>2];e=v[a+4>>2];if((g|0)<=(i-e|0)){v[h>>2]=d;i=e-b|0;if((i|0)<(g|0)){v[h>>2]=c;kw(h,i);l=v[h>>2];k=gb-16|0;gb=k;j=Bi(k,a,g-i|0);wb(a);f=gb-16|0;gb=f;v[f>>2]=d;v[f+8>>2]=l;if(Gb(f+8|0,f)){while(1){d=f+8|0;lp(v[j+4>>2],v[d>>2]);Pe(d);v[j+4>>2]=v[j+4>>2]+1;if(Gb(d,f)){continue}break}}gb=f+16|0;$b(j);gb=k+16|0;if((i|0)<1){break b}}k=gb-16|0;gb=k;f=e;j=b;i=a;l=v[a+4>>2];a=(l-(b+g|0)|0)+b|0;g=Bi(k,i,e-a|0);if(a>>>0<e>>>0){e=v[g+4>>2];d=a;while(1){wb(i);lp(e,d);e=e+1|0;v[g+4>>2]=e;d=d+1|0;if(f>>>0>d>>>0){continue}break}}$b(g);Ar(j,a,l);gb=k+16|0;Wi(c,v[h>>2],b);break b}e=wb(a);e=Zg(h,qh(a,oc(a)+g|0),b-v[a>>2]|0,e);v[22708]=0;UX(e,c,d);c=v[22708];v[22708]=0;if((c|0)==1){break a}ut(a);c=v[e+4>>2];j=e+4|0;Ck(wb(a),v[a>>2],b,j);wb(a);i=e+8|0;d=i;g=v[a+4>>2];if((g|0)!=(b|0)){f=v[d>>2];while(1){lp(f,b);f=v[d>>2]+1|0;v[d>>2]=f;b=b+1|0;if((g|0)!=(b|0)){continue}break}}xc(a,j);xc(a+4|0,i);xc(wb(a),dc(e));v[e>>2]=v[e+4>>2];tt(a,oc(a));b=c;ae(e)}Gg(b);gb=h+32|0;return}a=P()|0;O()|0;ae(e);S(a|0);L()}function zq(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=Vb(a),v[f+8>>2]=g;f=c,g=Zb(a),v[f>>2]=g;d=1;if(!Gb(c+8|0,c)){break a}while(1){a=v[c+8>>2];if(!(!ii(a)|v[a+12>>2]==64)){d=4;break a}a=c+8|0;TO(a);if(Gb(a,c)){continue}break}break a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}gb=c+16|0;return d}function r8(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-80|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(Bj(a)){Ah(d+72|0);break g}c=d+32|0;no(c,a);v[22708]=0;c=T(2085,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+72>>2]=c;Yf(d+32|0)}if(Bj(a)){e=a+36|0}else{e=v[d+72>>2]}c=v[a+8>>2];if((c|0)!=-1){break c}c=v[e+4>>2]-24|0;h=io(e);if(h){break e}break d}g=P()|0;O()|0;Yf(d+32|0);break a}j=A[c>>3];while(1){f=Vl(e,g);if(i+A[f>>3]>b){c=f;break d}i=i+j;g=g+1|0;if((h|0)!=(g|0)){continue}break}}b=b-i;break b}c=Vl(e,c)}e=a+24|0;f=v[e>>2];g=x[c+12>>1];v[22708]=0;R(2086,f|0,g|0);f=v[22708];v[22708]=0;if((f|0)!=1){h:{f=v[e>>2];g=w[a+64|0];c=sL(xV(d+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[22708]=0;h=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=h;h=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=h;h=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=h;Y(2050,d+56|0,f|0,(g?7:1)|0,d+8|0);c=v[22708];v[22708]=0;if((c|0)==1){break h}g=d+56|0;c=GO(g);f=t[c+26|0]&1;h=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];dn(g);u[v[e>>2]+1074448>>1]=f;u[v[e>>2]+1074450>>1]=f;v[v[e>>2]+1074428>>2]=h;v[v[e>>2]+1074392>>2]=-2;b=i+b;A[a+16>>3]=b;wl(d+72|0);gb=d+80|0;return+b}}g=P()|0;O()|0;wl(d+72|0)}S(g|0);L()}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=g+32|0}function Qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;a:{b:{if(!Md(a)){break b}if((b|0)==(c|0)|(fd(a)|0)!=2){break b}if(l=Md(b),m=0,n=(a|0)!=(b|0),n?l:m){break b}if(l=Md(c),m=0,n=(a|0)!=(c|0),n?l:m){break b}if((a|0)==(b|0)){j=v[b+20>>2]}else{j=Sq(v[a>>2],ij(a))}e=j;if((a|0)==(c|0)){f=v[c+20>>2]}else{f=Sq(v[a>>2],ij(a))}if(!(f?e:0)){if((a|0)!=(b|0)){Tq(j)}if((a|0)==(c|0)){break b}Tq(f);break b}c:{if((ij(a)|0)==2){g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){u[g>>1]=x[h>>1];u[e>>1]=x[h+2>>1];h=h+4|0;e=e+2|0;g=g+2|0;i=i-1|0;if(i){continue}break}}break c}if((ij(a)|0)!=1){break c}g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){t[g|0]=w[h|0];t[e|0]=w[h+1|0];h=h+2|0;e=e+1|0;g=g+1|0;i=i-1|0;if(i){continue}break}}}$o(b,a);v[b+20>>2]=j;u[b+34>>1]=x[b+34>>1]&65471;$o(c,a);v[c+20>>2]=f;u[c+34>>1]=x[c+34>>1]&65471;j=d+1298224|0;a=d+1074992|0;while(1){f=v[a+104>>2];if(!((c|0)!=(f|0)?(f|0)!=(b|0):0)){v[a+88>>2]=v[a+88>>2]&-65}a=a+872|0;if((j|0)!=(a|0)){continue}break}v[22708]=0;_h(b,d,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[22708]=0;_h(c,d,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}g=1}gb=k+16|0;return g|0}a=P()|0;O()|0;S(a|0);L()}function kqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;t[f+16|0]=44;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=1058;v[f+4>>2]=2;j=a;c=gb+-64|0;gb=c;k=c;a=f;h=v[a>>2]&2?16:10;g=gb-32|0;gb=g;d=He(g+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);i=Jb(d);l=Ab(d);m=v[b>>2];v[22708]=0;ha(92,g+8|0,e|0,i+l|0,m|0,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!v[g+12>>2]){break c}e=Ab(d);v[22708]=0;v[g+4>>2]=e;e=xf(g+4|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break b}b=v[g+8>>2];h=Jb(d);v[22708]=0;R(76,d|0,b-h|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,k|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=g+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=c+16|0;Ll(b,c,a);v[22708]=0;U(89,c+32|0,b|0,a|0);b=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(90,c+48|0,c+32|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}v[22708]=0;R(72,j|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function mZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;t[g+12|0]=0;l=QD(g+16|0,d,g+12|0);h=v[l>>2];v[g+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){m=g;i=b-1|0;f=w[a|0];b:{c:{if(!(!i|(f|0)!=(e&255))){f=w[a+1|0];v[22708]=0;v[g+8>>2]=f;f=Fb(g+8|0,g+12|0);i=v[22708];v[22708]=0;d:{if((i|0)!=1){k=a+2|0;i=b-2|0;if(!i){break d}j=v[f>>2];if(!(j&255)){break d}i=w[k|0];while(1){t[h|0]=i;f=v[g+12>>2]-1|0;v[g+12>>2]=f;h=h+1|0;j=j-1|0;if(j&255){continue}break}i=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;gc(l);S(a|0);L()}t[h|0]=e;f=v[g+12>>2]-1|0;break c}k=a+1|0;t[h|0]=f;f=v[g+12>>2]-1|0}v[m+12>>2]=f;h=h+1|0}if(!i){break a}a=k;b=i;if(f){continue}break}}k=v[l>>2];e=d-f|0;if(e){h=128;i=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+i|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-j&7);a=i+1|0;i=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(B(h,257)&65535)>>>f&255;k=k+1|0;n=n+1|0;if((n|0)!=(e|0)){continue}break}j=0;while(1){d=c;f=d;m=j<<24>>24;b=t[d|0];d=128;e:{if((b|0)==-128){break e}a=b;d=a;if((a|0)>-1){break e}d=0-(b&127)|0}j=m-(d&255)|0;t[f|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}gc(l);gb=g+32|0}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=gb-48|0;gb=j;l=-1;e=gb-32|0;gb=e;f=e+24|0;i=j+8|0;mF(f,i);g=yb(f);f=v[e+28>>2];d=v[e+24>>2];v[e+8>>2]=d;v[e+12>>2]=f;v[e>>2]=d;v[e+4>>2]=f;d=e+16|0;f=a;hd(d,f,e);d=yb(d);if((d|0)==(g|0)){bd(f,yb(e+24|0))}gb=e+32|0;f=(d|0)==(g|0);if(!f){nF(i)}a:{if(!f){break a}l=0;if(!VN(j+8|0)){break a}if(c){e=a;d=j+8|0;b:{if(!c){break b}m=Of(c);if(!m){break b}q=v[e+12>>2];if(Ul(e,w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24))){c:{if(!(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))){break c}while(1){if(!Wf(e,5)){break c}d:{if((w[d+4|0]|w[d+5|0]<<8)>>>0>=64){f=e;i=aw(e);h=i&63;e:{if(!(i&64)){break e}g=6;while(1){k=aw(f);h=(k&127)<<g|h;if(!(k&128)){break e}k=g>>>0<25;g=g+7|0;if(k){continue}break}}if(((i&128?0-h|0:h)|0)<1){break d}}h=0;g=1;while(1){f=aw(e);if(f){k=Zq(f<<24>>24);o=h>>>0>=m>>>0;i=o&g;f=i;f:{if(o){break f}f=i;if(!(g&1)){break f}f=w[c+h|0]==(k&255)}g=f;h=h+1|0;continue}break}bd(e,4);n=(h|0)==(m|0)?g?1:n:n}p=p+1|0;if(p>>>0<(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))>>>0){continue}break}}h=n&1}Ul(e,q)}if(!h){break a}}l=Oe(a,b,UN(j+8|0),0)}gb=j+48|0;return l|0}function O$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(Sg(a,v[b+8>>2],e)){bx(b,c,d);return}a:{if(Sg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}d=v[a+12>>2];if((d|0)<=0){v[b+44>>2]=4;break b}i=((d<<3)+a|0)+16|0;f=a+16|0;j=b;c:{d:{while(1){e:{u[b+52>>1]=0;ax(f,b,c,c,1,e);if(w[b+54|0]){break e}f:{if(!w[b+53|0]){break f}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break d}h=1;g=1;if(w[a+8|0]&2){break f}break d}h=1;d=g;if(!(t[a+8|0]&1)){break d}}f=f+8|0;if(i>>>0>f>>>0){continue}}break}d=g;a=4;if(!h){break c}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;Bs(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(v[b+36>>2]!=1?a&2:1){while(1){if(w[b+54|0]){break a}Bs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Bs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|(v[b+24>>2]==1?v[b+36>>2]==1:0)){break a}Bs(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function GM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=gb-96|0;gb=c;d=v[b+4>>2];v[c+64>>2]=v[b>>2];v[c+68>>2]=d;b=Ud(c+56|0);d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;d=os(c+72|0,c+8|0,c);v[22708]=0;b=T(467,d|0)|0;e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}v[22708]=0;b=W(1596,d|0,c+16|0,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}b:{if(!b|v[c+16>>2]!=542066252){break b}b=c+16|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}b=c+24|0;f=a,g=Fo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+28|0;f=a,g=Fo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+32|0;f=a,g=Fo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+36|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+40|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+44|0]!=0;t[a+4241|0]=w[c+45|0]!=0;t[a+4242|0]=w[c+46|0]!=0;t[a+4243|0]=w[c+47|0]!=0;t[a+4244|0]=w[c+48|0]!=0;Qt(a)}xb(d);gb=c+96|0;return}a=P()|0;O()|0;xb(d);S(a|0);L()}function K2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-160|0;gb=h;v[h+144>>2]=c;v[h+152>>2]=b;v[h+20>>2]=2508;b=ge(h+24|0,h+32|0,h+20|0);v[22708]=0;Fc(h+16|0,e);a=v[22708];v[22708]=0;a:{b:{c:{d:{if((a|0)!=1){v[22708]=0;a=T(21,h+16|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break b}t[h+15|0]=0;e=v[e+4>>2];v[22708]=0;c=ra(2509,h+152|0,c|0,d|0,h+16|0,e|0,f|0,h+15|0,a|0,b|0,h+20|0,h+132|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!c){break c}Se(g);if(!w[h+15|0]){break d}v[22708]=0;c=Q(22,a|0,45)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;R(61,g|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22708]=0;d=Q(22,a|0,48)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}e=v[b>>2];c=v[h+20>>2];e:{if(e>>>0>=c-1>>>0){break e}a=(c+(e^-1)|0)+e|0;d=d&255;while(1){if((d|0)!=w[e|0]){break e}e=e+1|0;if((a|0)!=(e|0)){continue}break}e=a}v[22708]=0;U(2515,g|0,e|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}v[22708]=0;a=Q(2460,h+152|0,h+144|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}if(a){v[f>>2]=v[f>>2]|2}a=v[h+152>>2];Wb(h+16|0);Hc(b);gb=h+160|0;return a|0}e=P()|0;O()|0;Wb(h+16|0)}Hc(b);S(e|0);L()}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;a:{b:{if(!Pb(b,9)){break b}i=a+484344|0;j=a+480280|0;while(1){gp(b,c+44|0);d=sg(b);c:{e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);d:{if((e|0)==1229999433|(e|0)==1397771593){break d}e=w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break d}if(Pb(b,d)){break c}}pg(b,8);break b}Td(c,b,d);g=jc(c+24|0,c);xb(c);d=j;e:{if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))==1481001027){while(1){v[22708]=0;e=T(192,g|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[d+8|0]=e;d=d+32|0;if((i|0)!=(d|0)){continue}break e}}f:{if(w[c+44|0]!=70){break f}d=w[c+45|0];e=(d|0)==88;if(!((d-48&255)>>>0>9?e:1)){break f}f=w[c+46|0];if((f-48&255)>>>0>9){break f}h=w[c+47|0];if((h-48&255)>>>0>9){break f}d=(B(f,10)+(e?-16:B(d,100)+48|0)|0)+h&255;if(d>>>0>249){break e}v[22708]=0;R(605,g|0,(B(d,160)+a|0)+906300|0);d=v[22708];v[22708]=0;if((d|0)!=1){break e}break a}if((w[c+44|0]|w[c+45|0]<<8|(w[c+46|0]<<16|w[c+47|0]<<24))!=1430540109){break e}v[a+1074308>>2]=0;k=1}xb(c+24|0);if(Pb(b,9)){continue}break}}gb=c+48|0;return k|0}a=P()|0;O()|0;xb(c+24|0);S(a|0);L()}function W0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){if(f>>>0>=g>>>0){break b}k=t[c|0];b=k&255;c:{if((k|0)>-1){i=1;break c}k=2;if(b>>>0<194){break a}if(b>>>0<=223){if((d-c|0)<2){break b}i=w[c+1|0];if((i&192)!=128){break a}b=i&63|b<<6&1984;i=2;break c}if(b>>>0<=239){if((d-c|0)<3){break b}j=w[c+2|0];i=w[c+1|0];d:{e:{if((b|0)!=237){if((b|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}b=j&63|(b<<12&61440|(i&63)<<6);i=3;break c}if(b>>>0>244){break a}if((d-c|0)<4){break b}l=w[c+3|0];m=w[c+2|0];j=w[c+1|0];f:{g:{switch(b-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;b=l&63|(m<<6&4032|(b<<18&1835008|(j&63)<<12));if(b>>>0>1114111){break a}}v[f>>2]=b;v[a+12>>2]=c+i;f=v[a+8>>2]+4|0;v[a+8>>2]=f;c=v[a+12>>2];if(d>>>0>c>>>0){continue}break}}k=0;break a}k=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return k|0}function bT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(w[d|0]){e=ne(g+8|0,b);b=Qj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Fb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){td(a,c,nqa(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){rB(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){td(a,c,nqa(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}td(a,c,nqa(e));break b}td(a,c,b)}break a}e=ne(g,b);b=Qj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Fb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){td(a,c,nqa(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){rB(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){td(a,c,nqa(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}td(a,c,nqa(e));break d}td(a,c,b)}}gb=d+16|0;gb=g+16|0}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=e;h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=e;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(d){while(1){e=i+q|0;i=t[e+2|0];m=t[e+1|0];n=t[e|0];o=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];p=oqa(e,e>>31,f,f>>31);e=w+p|0;f=jb+j|0;f=e>>>0<p>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(n,u[e+46162>>1])+B(o,u[e+46160>>1])|0)+B(m,u[e+46164>>1])|0)+B(i,u[e+46166>>1])<<8)/16384<<8;e=i;h=oqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=h+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function _g(a,b,c,d){var e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+12>>2]=d;e=b-1|0;f=0;a:{if(e>>>0>249){break a}h=hp(a);f=v[a+480180>>2];if(!h){if(f&17408){a=((e&255)>>>0)/12|0;f=x[((e-B(a,12)&255)<<1)+39696>>1]<<4>>>a|0;break a}if(!d){v[g+12>>2]=8363;d=8363}if(sk(a)){a=((e&255)>>>0)/12|0;b=oqa(v[(e-B(a,12)<<6&960)+43584>>2]<<a,0,d,0);a=jb;c=a>>>21|0;f=Qc((a&2097151)<<11|b>>>21,c);break a}if(w[a+480208|0]&16){a=e&255;f=x[((a>>>0)%12<<1)+39696>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;qc(g+12|0,-1>>>a|0);f=Qc(rqa(oqa(x[((e-B(a,12)&255)<<1)+39696>>1],0,267616,0),jb,v[g+12>>2]<<a,0),jb);break a}if(f&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Db(g,a+1074312|0,76);b=Cb(g)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;f=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;d=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[g>>2]=d+8;Rd(g,0,103);c=b;b=b>>31;c=(c+b^b)&15;b=d+(b|1)|0;b=(b|0)>-8?b:-8;f=B(c,x[(((b|0)<95?b:95)<<1)+40192>>1])+B(x[(v[g>>2]<<1)+40176>>1],16-c|0)<<1>>>a|0;break a}a=c>>>4&15;if(e>>>0<108?a|e>>>0<24:1){b=B(a,12);a=((e&255)>>>0)/12|0;f=x[(b+(e-B(a,12)&255)<<1)+39296>>1]<<5>>>a|0;break a}f=x[(b<<1)+39070>>1]<<2}gb=g+16|0;return f}function Mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;d=e+8|0;f=a+1074312|0;Db(d,f,96);d=Cb(d);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[a+480180>>2]==16384?v[b+88>>2]&1:0)|0;b:{if(ce(b+788|0)){d=v[b+656>>2];if(d){d=x[wd(d+236|0,w[b+788|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if(!(w[b+88|0]&2)|y[b+84>>2]>c>>>0?y[b+76>>2]>c>>>0:0){break b}c=e+8|0;Db(c,f,57);if(h=Cb(c),i=1,j=v[a+480180>>2]!=16,j?h:i){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){c=e+8|0;Db(c,f,27);if(Cb(c)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}gb=e+16|0}function hda(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-32|0;gb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=kb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[pd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[22708]=0;R(440,d+4|0,b+4|0);b=v[22708];v[22708]=0;c:{if((b|0)!=1){b=v[a+20>>2];v[22708]=0;Vd(c+8|0,b+4|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[c>>2]=0;v[c+4>>2]=0;d=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;v[22708]=0;_(1634,b|0);b=v[22708];v[22708]=0;d:{e:{if((b|0)==1){break e}b=v[v[a>>2]+180>>2];v[22708]=0;R(b|0,a|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break e}b=0;if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[22708]=0;f=C(Za(d|0,a|0,b|0));d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;z[c+8>>2]=f;R(1635,c+16|0,c+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+184>>2];v[22708]=0;_(b|0,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(89104)|0;break c}b=V(89104)|0;break c}b=V(89104)|0;break c}b=V(89104)|0}if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;zr(v[a+20>>2]+4|0);$()}gb=c+32|0;return}S(b|0);L()}function Hd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;v[a+480180>>2]=b;b=zq(a);jA(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;eu(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Xb(nv(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;iA(a,4);e=gb+-64|0;gb=e;b=a+484344|0;zN(b);f=Tf(b);c=lz(e+8|0,b);v[22708]=0;U(1488,b|0,f|0,c|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){Im(c);gb=e- -64|0;break a}a=P()|0;O()|0;Im(c);S(a|0);L()}lS(a+484360|0);Se(a+1298268|0);Se(a+1298280|0);Se(a+1298292|0);c=a+1298304|0;d=Qb(d,0,64);b=ZO(d);Eb(c,b);Eb(c+12|0,b+12|0);Eb(c+24|0,b+24|0);Eb(c+36|0,b+36|0);Eb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];ju(b);qD(a+1298368|0);Fg(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}gb=d- -64|0}function DV(a,b){var c=0,d=0,e=0;d=b;a:{b:{c:{d:{if(je(a,13813)){break d}if(je(a,14595)){break d}if(je(a,10883)){break d}if(je(a,11020)){break d}if(!je(a,11470)){break c}}v[b>>2]=9290;a=4;break b}e:{f:{if(je(a,14590)){break f}if(je(a,10888)){break f}if(!je(a,13803)){break e}}t[b+10|0]=1;v[b>>2]=5538;a=4;break b}g:{if(!je(a,11505)){if(!je(a,11510)){break g}}v[b>>2]=5302;a=8;break b}h:{if(!je(a,12489)){if(!je(a,12494)){break h}}v[b>>2]=14167;a=t[a+2|0]-48|0;break b}i:{if(!je(a,33192)){if(!je(a,33197)){break i}}v[b+4>>2]=1;v[b>>2]=13973;a=w[a|0]==56?8:4;break b}if(!(sd(a,12590,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=5656;a=t[a+3|0]-48|0;break b}j:{if(sd(a,10953,3)){if(sd(a,11077,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+13|0]=1;t[b+11|0]=1;v[b>>2]=5401;a=t[a+3|0]-48|0;break b}k:{if((w[a|0]-49&255)>>>0>8){break k}c=a;if(!sd(a+1|0,11098,3)){t[b+12|0]=1;v[b>>2]=5704;a=t[a|0]-48|0;break b}e=(w[c+1|0]-48&255)>>>0>9;c=w[a+2|0]|w[a+3|0]<<8;if(e|((c|0)!=20035?(c|0)!=18499:0)){break k}t[b+12|0]=1;v[b>>2]=5704;a=(t[a+1|0]+B(t[a|0],10)|0)-528|0;break b}c=0;if(sd(a,10774,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=5565;a=t[a+3|0]-48|0}u[d+8>>1]=a;c=1}return c}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=gb-32|0;gb=e;a:{b:{c:{f=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;gb=e+32|0}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;i=g;c=gb-160|0;gb=c;e=c+24|0;h=gu(e+56|0);v[e>>2]=78016;v[h>>2]=78036;v[22708]=0;f=e+4|0;W(95,e|0,78048,f|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)!=1){b:{v[e>>2]=78016;v[h>>2]=78036;v[22708]=0;Q(96,f|0,16)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}break a}}a=P()|0;O()|0;oh(h);S(a|0);L()}h=v[v[e>>2]-12>>2];v[22708]=0;f=ga(79)|0;d=v[22708];v[22708]=0;c:{d:{e:{f:{g:{h:{if((d|0)==1){break h}v[22708]=0;U(80,c+16|0,h+(c+24|0)|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}Wb(c+16|0);v[22708]=0;f=Gg(17);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;v[c>>2]=f;f=kP(e,c);d=v[22708];v[22708]=0;if((d|0)==1){break g}j=A[b>>3];v[22708]=0;_a(83,f|0,+j)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;R(84,c|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;R(77,i|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c);Cq(e);gb=c+160|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(c)}Cq(e);S(a|0);L()}v[22708]=0;R(72,a|0,g|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(g);gb=g+16|0;return}a=P()|0;O()|0;vb(g);S(a|0);L()}function aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=(g<<1)+q|0;i=u[f>>1];m=u[f-2>>1];n=u[f+2>>1];r=u[f+4>>1];p=v[a+60>>2];f=Mb(b,-16777216,16776704);o=v[a+64>>2];g=Mb(e,-16777216,16776704);e=oqa(o,o>>31,f,f>>31);o=jb;f=e;e=j>>>21&2040;j=(((B(i,u[e+46162>>1])+B(m,u[e+46160>>1])|0)+B(n,u[e+46164>>1])|0)+B(r,u[e+46166>>1])|0)/16384<<8;e=j;i=oqa(p,p>>31,e,e>>31);f=f+i|0;e=jb+o|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=oqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);k=g+k|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,m);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=k>>12;i=l>>12;f=b}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function mka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;k=gb-48|0;gb=k;if(Te(b)>>>0>c>>>0){while(1){f=l&65535;if(ii(af(b,f))){n=k+24|0;r=n;e=Vb(af(b,f));f=Zb(af(b,f));o=kT(k,d);p=o;h=gb-16|0;gb=h;v[h>>2]=f;v[h+8>>2]=e;if(Gb(h+8|0,h)){while(1){f=p;j=gb-16|0;gb=j;m=h+8|0;e=v[m>>2];if(!(w[e+3|0]!=4|w[e+5|0])){g=j+8|0;re(g,f,x[f+14>>1]);Df(g,0);t[e+3|0]=0}g=w[e+2|0];a:{if((g|0)!=11){break a}g=11;if(w[e+4|0]){break a}i=j+8|0;re(i,f,x[f+14>>1]);g=0;Df(i,0);t[e+2|0]=0}b:{c:{d:{if(!w[e|0]){g=j+8|0;re(g,f,x[f+14>>1]);if(Cb(g)){break d}g=w[e+2|0]}i=w[e+3|0];q=j+8|0;re(q,f,x[f+14>>1]);Df(q,(i|0)==4|(g|0)==11);g=w[e+3|0];break c}g=w[e+3|0];i=w[e+2|0];if(!(g|(i|0)==11)){t[e+5|0]=0;t[e+3|0]=4;break b}if(i|(g|0)==4){break c}t[e+4|0]=0;t[e+2|0]=11}e:{if(!(!w[f+16|0]|g)){t[e+5|0]=125;t[e+3|0]=17;break e}f:{switch(g-16|0){case 1:break e;case 0:break f;default:break b}}if(w[e+5|0]){break b}t[e+5|0]=6;t[f+16|0]=1;break b}t[f+16|0]=0}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];gb=j+16|0;ak(m);if(Gb(m,h)){continue}break}}jT(r,p);gb=h+16|0;De(n);De(o)}l=l+1|0;if((l&65535)>>>0<=c>>>0){continue}break}}jT(a,d);gb=k+48|0}function Fna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(ov(c)>>>0>d>>>0){g=zW(c,d);h=gb-16|0;gb=h;c=a;t[c+12|0]=0;Fg(c);f=gb-32|0;gb=f;a:{b:{d=c;if(pe(d)>>>0<=14){e=wb(d);e=zp(f+8|0,15,Nb(d),e);v[22708]=0;R(300,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}gj(e)}gb=f+32|0;break a}a=P()|0;O()|0;gj(e);S(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=rr(h+8|0,f&65535,w[ac(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[wb(d)>>2]){sW(d,j);break d}k=gb-32|0;gb=k;e=d;l=wb(d);d=zp(k+8|0,fh(d,Nb(d)+1|0),Nb(d),l);m=v[d+8>>2];v[22708]=0;gn(l,m,j);j=v[22708];v[22708]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[22708]=0;R(300,e|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break f}gj(d);gb=k+32|0;break e}a=P()|0;O()|0;gj(d);S(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}gb=h+16|0}g:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break g}b=cd(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c}function bK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Lf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(Kf(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=ee(A[Wg(a,h,k)>>3]*134217728);c=Lb(b,h);m=c;c=Ym(f)+(v[c>>2]>>1)|0;n=c;c=yt(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=eo(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=d- -64|0}function WJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Lf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(Kf(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=ee(A[Wg(a,h,k)>>3]*134217728);c=Lb(b,h);m=c;c=Ym(f)+(v[c>>2]>>1)|0;n=c;c=yt(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Uc(c);o=co(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=d- -64|0}function tI(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=md(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}b=c-48|0;break a}f=(c|0)==45;g=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=md(a)}b=c-48|0;if(!(g|b>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(b>>>0<10){while(1){e=B(d,10)+c|0;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=md(a)}b=c-48|0;d=e-48|0;if((d|0)<214748364?b>>>0<=9:0){continue}break}e=d;d=d>>31;h:{if(b>>>0>=10){break h}while(1){e=oqa(e,d,10,0);c=e+c|0;b=jb;b=c>>>0<e>>>0?b+1|0:b;e=c-48|0;d=b-(c>>>0<48)|0;b=v[a+4>>2];i:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break i}c=md(a)}b=c-48|0;if(b>>>0>9){break h}if((d|0)<21474836?1:(d|0)<=21474836?e>>>0<2061584302:0){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];j:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break j}b=md(a)}if(b-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;jb=-2147483648;return 0}jb=d;return e}function Lu(a,b){var c=0,d=0,e=0,f=0;f=gb-48|0;gb=f;e=f+24|0;sT(e,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);sT(f,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=1;a=v[e>>2];d=Ib(w[a|0]|w[a+1|0]<<8);a=f;c=v[a>>2];a:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=0;c=v[a>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=1;c=v[e+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+4>>2];b:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=0;c=v[a+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+4>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=1;c=v[e+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+8>>2];c:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=0;c=v[a+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+8>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=1;c=v[e+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[a+12>>2];d:{if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=0;c=v[a+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[e+12>>2];if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=v[e+16>>2];c=Ib(w[b|0]|w[b+1|0]<<8);b=v[a+16>>2];b=c>>>0<Ib(w[b|0]|w[b+1|0]<<8)>>>0;if(!b){a=v[a+16>>2];Ib(w[a|0]|w[a+1|0]<<8);a=v[e+16>>2];Ib(w[a|0]|w[a+1|0]<<8)}}}}}gb=f+48|0;return b}function no(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;g=dd(a);e=b+24|0;a:{b:{if(Qi(v[e>>2]+484360|0)){if(Qi(v[e>>2]+484360|0)){b=0;while(1){f=v[e>>2];a=sL(yV(c+40|0,1),b&255,0,0);v[22708]=0;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;Y(2050,c- -64|0,f|0,0,c|0);a=v[22708];v[22708]=0;c:{d:{if((a|0)!=1){a=c- -64|0;i=c,j=Vb(a),v[i+32>>2]=j;i=c,j=Zb(a),v[i+24>>2]=j;if(Gb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{a=v[c+32>>2];h=A[a>>3];f=v[a+16>>2];d=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=d;v[a+8>>2]=f;A[a>>3]=h;v[22708]=0;R(2051,g|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}a=c+32|0;v[a>>2]=v[a>>2]+32;if(Gb(a,c+24|0)){continue}break c}break}a=P()|0;O()|0;dn(c- -64|0);break b}dn(c- -64|0);b=b+1|0;if(Qi(v[e>>2]+484360|0)>>>0>b>>>0){continue}break}}gb=c+80|0;return}b=ba(8)|0;v[22708]=0;c=Q(70,c+40|0,4354)|0;a=v[22708];v[22708]=0;if((a|0)!=1){rc(b,c);v[22708]=0;U(186,b|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;da(b|0)}Yf(g);S(a|0)}L()}function Pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(y[a+4>>2]<y[wb(a)>>2]){h=gb-16|0;gb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+28;a=wb(a);d=v[c+4>>2];v[22708]=0;xu(a,d,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+28;$b(c);gb=h+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}return}i=gb-32|0;gb=i;h=a;j=wb(a);e=i+8|0;c=_i(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=c;d=c;c=gb-16|0;gb=c;g=a;wb(a);v[c+12>>2]=153391689;v[22708]=0;v[c+8>>2]=2147483647;k=Fb(c+12|0,c+8|0);l=v[22708];v[22708]=0;b:{if((l|0)!=1){gb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=$i(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break c}Sc();L()}g=_i(a);a=0;d=gb-16|0;gb=d;v[d+12>>2]=0;Ch(e+12|0,j);if(c){a=c;if(a>>>0>153391689){rd(8445);L()}a=Nc(B(a,28),4)}v[e>>2]=a;g=B(g,28)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=dc(e),n=B(c,28)+a|0,v[m>>2]=n;gb=d+16|0;a=v[e+8>>2];v[22708]=0;xu(j,a,b);a=v[22708];v[22708]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+28;v[22708]=0;QQ(h,e);a=v[22708];v[22708]=0;if((a|0)==1){break e}PQ(e);gb=i+32|0;break d}a=P()|0;O()|0;PQ(e);S(a|0);L()}}function Sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;ud(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Bh(Dk(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[ac(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+46144|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[ac(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=e+16|0}function Kpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-2608|0;gb=f;d=f;lD(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[22708]=0;_(490,d|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((a|0)!=1){if(!(u[d+1068>>1]<0|u[d+1070>>1]<0)){if(!c){break d}while(1){v[22708]=0;j=Q(200,d|0,1)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}a=0;while(1){v[22708]=0;k=Q(200,d|0,1)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}a=u[(B(a,6)+d|0)+(k?1070:1068)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break h}if(u[e+1070>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break}break d}v[22708]=0;a=mn(d);b=v[22708];v[22708]=0;if((b|0)!=1){break c}}a=V(27364)|0;break e}a=V(27364)|0;break e}a=V(27364)|0}if((O()|0)!=(ea(27364)|0)){break a}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}v[22708]=0;a=mn(d);b=v[22708];v[22708]=0;if((b|0)!=1){break c}a=P()|0;O()|0;break a}xb(d);gb=f+2608|0;return a|0}a=P()|0;O()|0}xb(d);S(a|0);L()}function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[f+8>>2],u[(i<<1)+g>>1]/4<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Jd(b,u[g+(v[e+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function VN(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}d=a+16|0;b=d;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}e=a+24|0;b=e;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}f=a+32|0;b=f;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}c=a+12|0;b=c;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=c;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>858993459){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>536870911){break a}a=a+28|0;g=w[a+1|0]<<8;h=w[a+2|0]<<16|w[a+3|0]<<24;if(!(w[a|0]|g|h)|(h|(g|w[a|0]))>>>0>1073741823|B(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24),-5)-1>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<<3^-1)>>>0){break a}i=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))<<2^-1)>>>0}return i}function zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;if(!w[a+4242|0]){cz(a);a:{if(!w[a+4240|0]){break a}e=MO(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Pt(a)}f=a+4256|0;b:{if(w[a+4244|0]){g=f;if(A[f>>3]>1){v[g>>2]=0;v[g+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<1)){az(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=si(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];UP(h+8|0,1);f=ok(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){k=f,l=g>>>8&15|176|(g&127)<<8|fn(A[h+8>>3]*127)<<16,j=v[v[f>>2]+68>>2],kb[j](k|0,l|0)|0;break f}kb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}g=a;a=a+44|0;Fi(g,b,c,Nd(a,0),Nd(a,1),d);gb=h+16|0}function hv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;t[e+16|0]=44;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=1058;v[e+4>>2]=2;i=a;c=gb+-64|0;gb=c;j=c;a=e;h=v[a>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);a:{b:{c:{while(1){dO(f+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],h);if(!v[f+12>>2]){break c}g=Ab(d);v[22708]=0;v[f+4>>2]=g;g=xf(f+4|0);k=v[22708];v[22708]=0;if((k|0)!=1){v[22708]=0;U(75,d|0,g|0,0);g=v[22708];v[22708]=0;if((g|0)!=1){continue}}break}break b}b=v[f+8>>2];h=Jb(d);v[22708]=0;R(76,d|0,b-h|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){v[22708]=0;R(77,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=f+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}b=c+16|0;Ll(b,c,a);v[22708]=0;U(89,c+32|0,b|0,a|0);b=v[22708];v[22708]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22708]=0;U(90,c+48|0,c+32|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break i}v[22708]=0;R(72,i|0,c+48|0);a=v[22708];v[22708]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=e+32|0}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=lg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Jd(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Jd(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;o=k,p=Zb(a),v[o>>2]=p;d=v[Gd(k+8|0,k)>>2];h=gb-32|0;gb=h;v[h+24>>2]=d;d=v[a>>2];o=h,p=Vb(a),v[o>>2]=p;d=d+(rp(h+24|0,h)<<1)|0;a:{b:{f=$q(b,c);c:{if((f|0)<1){break c}i=v[wb(a)>>2];e=v[a+4>>2];if((f|0)<=i-e>>1){j=e-d|0;i=j>>1;d:{if((i|0)>=(f|0)){g=c;break d}v[h>>2]=b;iS(h,i);g=v[h>>2];bS(a,g,c,f-i|0);if((j|0)<1){break c}}m=gb-16|0;gb=m;i=e;j=d;l=a;n=v[a+4>>2];a=(n-((f<<1)+d|0)|0)+d|0;f=mi(m,l,e-a>>1);if(a>>>0<e>>>0){e=v[f+4>>2];c=a;while(1){wb(l);Ro(e,c);e=e+2|0;v[f+4>>2]=e;c=c+2|0;if(i>>>0>c>>>0){continue}break}}$b(f);Ar(j,a,n);gb=m+16|0;Kn(b,g,d);break c}g=wb(a);e=En(h,Uk(a,tc(a)+f|0),d-v[a>>2]>>1,g);v[22708]=0;XQ(e,b,c);b=v[22708];v[22708]=0;if((b|0)==1){break b}b=a;Ep(a);c=e;i=v[c+4>>2];g=d;l=c+4|0;Ck(wb(a),v[a>>2],d,l);wb(a);f=c+8|0;j=f;d=v[a+4>>2];if((g|0)!=(d|0)){a=v[j>>2];while(1){Ro(a,g);a=v[j>>2]+2|0;v[j>>2]=a;g=g+2|0;if((d|0)!=(g|0)){continue}break}}xc(b,l);xc(b+4|0,f);xc(wb(b),dc(c));v[c>>2]=v[c+4>>2];$r(b,tc(b));d=i;Ih(e)}Gg(d);gb=h+32|0;break a}a=P()|0;O()|0;Ih(e);S(a|0);L()}gb=k+16|0}function dda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;g=dd(a);v[22708]=0;_(1648,g|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=50400;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=wg(44);if(d){h=v[b>>2];f=v[b+4>>2];v[22708]=0;f=Q(70,c+32|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break k}v[22708]=0;R(1649,c+48|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break j}e=v[b+8>>2];v[22708]=0;e=Q(70,c|0,e|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break i}v[22708]=0;R(1649,c+16|0,e|0);i=v[22708];v[22708]=0;if((i|0)==1){break h}v[22708]=0;ca(1650,d|0,h|0,c+48|0,c+16|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break g}Hb(c+16|0);vb(e);Hb(c+48|0);vb(f);v[c+60>>2]=d;v[22708]=0;R(1651,g|0,c+60|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=50712){continue}break}gb=c- -64|0;return a|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;Hb(c+16|0)}vb(e)}Hb(c+48|0)}vb(f)}Xb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}Gl(g);S(b|0);L()}
function hc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){$a(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if((c|0)<1){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Vf(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>11>>>0){c=gb-16|0;gb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){wb(g);v[22708]=0;bz(a);e=v[22708];v[22708]=0;if((e|0)==1){break d}a=a+2048|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}h=wb(a);i=f+8|0;b=Vf(a)+e|0;d=gb-16|0;gb=d;v[d+12>>2]=b;c=b;b=gb-16|0;gb=b;g=a;wb(a);v[b+12>>2]=2097151;v[22708]=0;v[b+8>>2]=2147483647;j=Fb(b+12|0,b+8|0);k=v[22708];v[22708]=0;e:{if((k|0)!=1){gb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Bb();L()}f:{if(b>>>0>=c>>>0){c=Cl(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Mc(d+8|0,d+12|0)>>2]}gb=d+16|0;break f}Sc();L()}b=NM(i,b,Vf(a),h);v[22708]=0;R(1542,b|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(1538,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Rt(b)}gb=f+32|0;break a}a=P()|0;O()|0;Rt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;Vf(a);MM(a,b);OM(a)}}function Ika(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;i=gb-16|0;gb=i;ud(d,32);g=i+8|0;KT(g,a+20|0,b);p=g;g=fc(g);KT(i,a+36|0,c);q=i;a=0;g=v[g>>2];if(g-1>>>0<=838859){a=v[fc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;l=Zm(d);if(l){k=g<<2;e=+(k>>>0);r=+(a>>>0)/e;s=+(g>>>0)/e;z=1/+y[d>>2];g=0;while(1){m=+(g>>>0);a=v[p>>2];n=0;o=0;if(Md(b)){e=s*m+ +(a>>>0);a:{if(e<4294967296&e>=0){a=~~e>>>0;break a}a=0}f=fd(b);h=B(a,f);e=e-+(a>>>0);b:{if(t[b+34|0]&1){j=v[b+20>>2];a=x[j+(h<<1)>>1];f=u[j+(f+h<<1)>>1];break b}a=v[b+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}o=(1-e)*+(a<<16>>16)+e*+(f<<16>>16)}a=v[q>>2];if(Md(c)){e=r*m+ +(a>>>0);c:{if(e<4294967296&e>=0){a=~~e>>>0;break c}a=0}f=fd(c);h=B(a,f);e=e-+(a>>>0);d:{if(t[c+34|0]&1){j=v[c+20>>2];a=x[j+(h<<1)>>1];f=u[j+(f+h<<1)>>1];break d}a=v[c+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}n=(1-e)*+(a<<16>>16)+e*+(f<<16>>16)}f=0;a=g;while(1){e=z*+(a>>>0);h=JT(n*e+o*(1-e));u[v[d+20>>2]+(a<<1)>>1]=h;a=a+k|0;f=f+1|0;if((f|0)!=80){continue}break}g=g+1|0;if((k|0)!=(g|0)){continue}break}}a=(l|0)!=0}gb=i+16|0;return a|0}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0);a:{if(!v[a+4272>>2]){break a}i=a+44|0;if(!ni(i)){break a}k=Nd(i,0);l=Nd(i,1);m=od(i,0);n=od(i,1);if(d){j=a+4256|0;e=v[a+4268>>2];o=d;while(1){f=z[l>>2];g=z[k>>2];s=Lb(j,e<<1),t=g,z[s>>2]=t;s=Lb(j,v[a+4268>>2]<<1|1),t=f,z[s>>2]=t;f=C(C(D(hM(C(C(C(D(g))+C(D(f)))*C(536870912)),31,5)))*C(4.656612873077393e-10));g=z[a+4276>>2];f=C(f+C(C(g-f)*z[(f>=g?4236:4240)+a>>2]));z[a+4276>>2]=f;p=z[a+4232>>2];g=z[a+4244>>2];f=C(C(C(z[a+4248>>2]*C(g-(f<g?g:f)))+C(.9999998807907104))*C(2147483648));b:{if(f<C(4294967296)&f>=C(0)){e=~~f>>>0;break b}e=0}h=e<<5;q=h;r=h|-2147483648;h=e>>>0<67108864;f=C(p*C(C((h?q:r)>>>(h?31:32-(e>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));e=v[a+4272>>2];e=(((e+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(e|0)<<1;s=m,t=C(z[Lb(j,e)>>2]*f),z[s>>2]=t;s=n,t=C(z[Lb(j,e|1)>>2]*f),z[s>>2]=t;h=v[a+4268>>2];e=h-1|0;v[a+4268>>2]=e;if(!h){e=v[a+4272>>2]+e|0;v[a+4268>>2]=e}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}Fi(a,b,c,od(i,0),od(i,1),d)}}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Jd(v[f+8>>2],t[g+i|0]<<6);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Jd(b,t[g+v[e+44>>2]|0]<<6);Id(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=dh(a);if(c>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{i=b-c|0;c:{if(i>>>0<=v[wb(a)>>2]-v[a+4>>2]>>8>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(i<<8);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){yB(a);a=a+256|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}k=wb(a);e=j+8|0;d=a;b=dh(a)+i|0;f=gb-16|0;gb=f;v[f+12>>2]=b;g=gb-16|0;gb=g;v[g+12>>2]=16777215;v[22708]=0;v[g+8>>2]=2147483647;h=Fb(g+12|0,g+8|0);c=v[22708];v[22708]=0;d:{if((c|0)!=1){gb=g+16|0;c=v[h>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0<=c>>>0){b=CB(d);if(b>>>0<c>>>1>>>0){v[f+8>>2]=b<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break e}Sc();L()}d=dh(a);b=0;h=gb-16|0;gb=h;v[h+12>>2]=0;hf(e+12|0,k);if(c){b=c;if(b>>>0>=16777216){rd(8445);L()}b=Nc(b<<8,1)}v[e>>2]=b;d=(d<<8)+b|0;v[e+8>>2]=d;v[e+4>>2]=d;l=dc(e),m=(c<<8)+b|0,v[l>>2]=m;gb=h+16|0;v[22708]=0;vT(e,i);b=v[22708];v[22708]=0;if((b|0)==1){break b}Yk(a,e);uT(e)}gb=j+32|0;break a}a=P()|0;O()|0;uT(e);S(a|0);L()}return}if(b>>>0<c>>>0){Zk(a,v[a>>2]+(b<<8)|0)}}function t7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Lf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(Kf(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(Ym(ee(A[Wg(g,b,i)>>3]*134217728))+id(xt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[bh(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=co(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=c- -64|0}function C7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Lf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(Kf(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(Ym(ee(A[Wg(g,b,i)>>3]*134217728))+id(xt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[bh(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=ee(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Uc(a);l=eo(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=c- -64|0}function Bc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=w[b+8|0];d=v[b>>2];c=v[b+4>>2];f=gb-48|0;gb=f;b=Kb(a);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((e|0)!=1){if(!c|(e|0)!=4){break k}break l}if(c){break l}c=0;break j}c=c-1|0}switch(e-1|0){case 0:case 1:break j;case 2:case 3:break i;default:break h}}t[f+32|0]=0;a=Vm(d,c+d|0,f+32|0);v[22708]=0;U(68,b|0,d|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}v[22708]=0;U(68,b|0,d|0,c+d|0);a=v[22708];v[22708]=0;if((a|0)==1){break g}c=zd(b);d=ef(b);e=zd(b);a=gb-32|0;gb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=e;if(Gb(a+24|0,a+16|0)){while(1){d=a+8|0;c=a+24|0;e=t[v[c>>2]];t[v[d>>2]]=e?e:32;Pe(c);Pe(d);if(Gb(c,a+16|0)){continue}break}}gb=a+32|0;v[22708]=0;c=Q(69,f+16|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;d=Q(70,f|0,14905)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}v[22708]=0;U(71,f+32|0,c|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}a=f+32|0;Eb(b,a);vb(a);vb(d);vb(c)}gb=f+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d)}vb(c)}vb(b);S(a|0);L()}}function RZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-32|0;gb=h;d=b;e=tc(d);f=c;a:{if(e>>>0<f>>>0){l=gb-32|0;gb=l;b:{c:{i=f-e|0;d:{if(i>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){e=gb-16|0;gb=e;e:{f=mi(e,d,i);g=v[f+4>>2];i=v[f+8>>2];if((g|0)!=(i|0)){while(1){wb(d);v[22708]=0;Ok(g);j=v[22708];v[22708]=0;if((j|0)==1){break e}g=g+2|0;v[f+4>>2]=g;if((g|0)!=(i|0)){continue}break}}$b(f);gb=e+16|0;break d}a=P()|0;O()|0;$b(f);S(a|0);L()}k=wb(d);f=Uk(d,tc(d)+i|0);m=tc(d);j=gb-16|0;gb=j;v[j+12>>2]=0;e=l+8|0;Ch(e+12|0,k);if(f){g=f;if(f>>>0>2147483647){rd(8445);L()}g=Nc(g<<1,1)}v[e>>2]=g;k=(m<<1)+g|0;v[e+8>>2]=k;v[e+4>>2]=k;n=dc(e),o=(f<<1)+g|0,v[n>>2]=o;gb=j+16|0;v[22708]=0;R(345,e|0,i|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}v[22708]=0;R(346,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}eE(e)}gb=l+32|0;break b}a=P()|0;O()|0;eE(e);S(a|0);L()}break a}if(e>>>0>f>>>0){xn(d,v[d>>2]+(f<<1)|0)}}c=Pb(a,c<<1);if(c){d=gb-16|0;gb=d;bc(h+24|0,v[b>>2],tc(b)<<1);gb=d+16|0;b=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=b;kd(h+16|0,a,h+8|0)}gb=h+32|0;return c|0}function sK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;v[a+4>>2]=c;v[a>>2]=b;b=(c>>>0)/48|0;g=((B(b,48)|0)!=(c|0))+b|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;j=b>>>0<64;e=a;h=a;d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}f=j?0:0;v[h+24>>2]=f;h=e;e=j?d&65536:0;v[h+28>>2]=e;a:{b:{d=f;j=0-d|0;f=rqa(d,e,g,0);e=65536-(e+((d|0)!=0)|0)|0;d=jb;if((e|0)==(d|0)&f>>>0<j>>>0|d>>>0<e>>>0){g=g+1|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;if(b>>>0>63){break b}d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}v[a+24>>2]=0;v[a+28>>2]=d&65536}v[a+16>>2]=g-((c>>>0)%(g>>>0)|0);if(b>>>0>62){break a}i=1;c=b+1|0;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}k=d&65536;break a}v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=(B(b,g)-c|0)+g}v[a+32>>2]=l;v[a+36>>2]=k;c=a;h=a;d=63-b|0;e=d&31;if((d&63)>>>0>=32){d=0;e=-1>>>e|0}else{f=-1>>>e|0;d=f;e=d|(1<<e)-1<<32-e}v[h+48>>2]=i?e:-1;v[c+52>>2]=i?d:-1;i=b;f=a;b=64-b|0;d=b&31;if((b&63)>>>0>=32){b=0;d=-1>>>d|0}else{e=-1>>>d|0;b=e;d=b|(1<<d)-1<<32-d}v[f+40>>2]=i?d:0;v[c+44>>2]=i?b:0;return a}function Uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;gb=g+16|0}function _m(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;if(b&2){t[a+841|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;g=f+8|0;Db(g,c+1074312|0,23);if(Cb(g)){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&240;_o(a+788|0)}if(b&4){v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+845|0]=0;t[a+838|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+820>>1]=0;t[a+819|0]=0;u[a+836>>1]=32512;u[a+842>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&207}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|e;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0}gb=f+16|0}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=f+32|0}function sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+q|0;m=t[e+1|0];e=t[e|0];g=v[a+60>>2];n=g;o=g>>31;g=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);g=oqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=oqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=((B(m-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=oqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function _I(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>=1){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){rl(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=Am(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<=-1){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}ec(a,21);return 0}k=B(d,l);m=(k+(j+m|0)|0)>(p|0)?(j+p|0)-k|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(n+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=n+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}ec(a,21);return 0}aa(4596,10528,1887,3608);L()}function rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+q|0;m=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];n=g;o=g>>31;g=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);g=oqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=oqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=e+((B(m-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=oqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Tt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22708]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22708]=0;v[f+4>>2]=e;e=xf(f+4|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(93,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(94,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(85,i|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Mw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);b:{c:{d:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22708]=0;ha(92,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!v[f+12>>2]){break d}e=Ab(d);v[22708]=0;v[f+4>>2]=e;e=xf(f+4|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break c}b=v[f+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d);gb=f+32|0;break b}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(93,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(94,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(85,i|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break a}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function MV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=He(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22708]=0;ha(91,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22708]=0;v[f+4>>2]=e;e=xf(f+4|0);h=v[22708];v[22708]=0;if((h|0)!=1){v[22708]=0;U(75,d|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,j|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(89,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22708]=0;U(90,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;R(72,i|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(ZE(b)){j=b>>>0>4?b:4;b=a?a:1;a:{b:{while(1){h=gb-16|0;gb=h;v[h+12>>2]=0;e=b;c:{d:{a=j;if((a|0)!=8){if(a&3|a>>>0<4){break c}c=a>>>2|0;if(c-1&c|e>>>0>-64-a>>>0){break c}c=16;d=a>>>0>16?a:16;e:{if(!(d-1&d)){a=d;break e}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}if(e>>>0>=-64-a>>>0){v[115189]=48;break c}i=e>>>0<11?16:e+11&-8;f=Cd((i+a|0)+12|0);if(!f){break c}c=f-8|0;f:{if(!(f&a-1)){a=c;break f}e=f-4|0;d=v[e>>2];g=a;a=((a+f|0)-1&0-a)-8|0;a=(a-c>>>0>15?0:g)+a|0;g=a-c|0;f=(d&-8)-g|0;if(!(d&3)){c=v[c>>2];v[a+4>>2]=f;v[a>>2]=c+g;break f}v[a+4>>2]=f|v[a+4>>2]&1|2;d=a+f|0;v[d+4>>2]=v[d+4>>2]|1;v[e>>2]=g|v[e>>2]&1|2;d=c+g|0;v[d+4>>2]=v[d+4>>2]|1;As(c,g)}d=v[a+4>>2];g:{if(!(d&3)){break g}c=d&-8;if(c>>>0<=i+16>>>0){break g}v[a+4>>2]=i|d&1|2;e=a+i|0;d=c-i|0;v[e+4>>2]=d|3;c=a+c|0;v[c+4>>2]=v[c+4>>2]|1;As(e,d)}a=a+8|0;break d}a=Cd(e);if(a){break d}break c}v[h+12>>2]=a}gb=h+16|0;a=v[h+12>>2];if(!a){a=v[116502];if(!a){break b}kb[a|0]();continue}break}break a}a=ba(4)|0;lm(a);ia(a|0,89104,1929);L()}return a}return sf(a)}function Via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;gb=f+16|0}function lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=Vb(a),v[m>>2]=n;b=b+(rp(f+24|0,f)<<1)|0;d=v[a+4>>2];a:{b:{if(d>>>0<y[wb(a)>>2]){if((b|0)!=(d|0)){break b}d=gb-16|0;gb=d;a=mi(d,a,1);Gr(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;$b(a);gb=d+16|0;break a}d=wb(a);e=xD(f,PY(a,tc(a)+1|0),b-v[a>>2]>>1,d);v[22708]=0;R(447,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=v[e+4>>2];j=e+4|0;ol(v[a>>2],b,j);h=e+8|0;i=h;g=v[a+4>>2];if((g|0)!=(b|0)){d=v[i>>2];while(1){Gr(d,b);d=v[i>>2]+2|0;v[i>>2]=d;b=b+2|0;if((g|0)!=(b|0)){continue}break}}wc(a,j);wc(a+4|0,h);wc(wb(a),dc(e));v[e>>2]=v[e+4>>2];b=c;qp(e);break a}a=P()|0;O()|0;qp(e);S(a|0);L()}l=gb-16|0;gb=l;j=d;k=v[a+4>>2];i=b;e=b+(k-(b+2|0)|0)|0;h=mi(l,a,d-e>>1);if(d>>>0>e>>>0){g=v[h+4>>2];d=e;while(1){Gr(g,d);g=g+2|0;v[h+4>>2]=g;d=d+2|0;if(j>>>0>d>>>0){continue}break}}$b(h);if((e|0)!=(i|0)){while(1){k=k-2|0;e=e-2|0;FY(k,e);if((e|0)!=(i|0)){continue}break}}gb=l+16|0;a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;t[b|0]=w[a|0];t[b+1|0]=w[a+1|0]}Gg(b);gb=f+32|0}function KV(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!kf(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!kf(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}gb=f+16|0}function sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-432|0;gb=e;vc(b);vC(b,e+376|0,e+296|0,e+8|0);d=e;f=e+408|0;if(Yb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){f=w[e+427|0]+1|0}else{f=1}n=d,o=ei(f),t[n+4|0]=o;h=w[ac(29024,e+4|0)|0];t[e+7|0]=h;u[e+4>>1]=4;a:{b:{if(!h){break b}f=e+392|0;k=e+291|0;while(1){d=e+8|0;d=Ib(w[d|0]|w[d+1|0]<<8);c:{d:{if(w[k|0]>63){break d}d=d<<16>>16;if((d|0)<0){break d}if(d){l=d&65535;g=0;while(1){d=f;e:{if(!Zc(b,Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(g<<2)|0)){break e}if(!Zc(b,Kr(b))){break e}d=e;f:{if(!c){j=Be(b);break f}j=Mr(b)}u[d+2>>1]=j;n=e,o=x[Le(e+4|0,e+2|0)>>1],u[n+4>>1]=o}g=g+1|0;if((l|0)!=(g|0)){continue}break}}d=e+296|0;if(Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>m>>>0){d=e+296|0;if(Zc(b,Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)))){break c}}t[e+7|0]=i+1;break b}Xr(a);break a}d=e+296|0;m=Yb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));vC(b,e+376|0,d,e+8|0);i=i+1|0;if((i&255)>>>0<h>>>0){continue}break}}tC(a,e+4|0,e+7|0)}gb=e+432|0}function FD(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((w[a|0]-1&255)>>>0>14){break a}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<=-2){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){b:{h=0;f=B(d,13)+a|0;if(w[f+14|0]){break b}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}c=e+422|0;if(w[f+942|0]|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048575){break b}b=B(d,11)+a|0;f=b+1346|0;if(w[f|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break b}c:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break c}b=e+430|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>1048574){break c}if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break b}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break b}}h=1;b=1;d:{if(g){break d}e:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break e}if(sd(f,28493,11)){break e}b=0;break d}b=1}g=b;d=d+1|0;if((d|0)!=32){continue}}break}g=g&h}return g}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=C(0);h=a+44|0;g=Nd(h,0);k=Nd(h,1);m=od(h,0);n=od(h,1);p=B(w[a+4233|0],v[v[a+16>>2]+1074404>>2]);e=p<<1;i=a+4208|0;if(Nb(i)>>>0<e>>>0){Dl(i,e)}j=yM(a);a:{if(j){if(!d){break a}e=v[a+4220>>2];x=j-1|0;j=0;while(1){if(e>>>0>=p>>>0){v[a+4220>>2]=0;e=0}s=z[k>>2];t=z[g>>2];o=e;e=e-p|0;e=((e|0)<0?o:e)<<1;u=z[Lb(i,e)>>2];f=z[Lb(i,e|1)>>2];q=C(t+u);z[m>>2]=q;r=C(s+f);z[n>>2]=r;f=C(0);l=C(0);b:{c:{switch(x|0){case 0:f=z[a+4224>>2];l=C(r*f);f=C(q*f);break b;case 1:case 2:f=z[a+4224>>2];l=C(q*f);f=C(r*f);break b;case 3:break c;default:break b}}f=C(C(u+C(C(t+s)*C(.5)))*z[a+4224>>2]);l=f}n=n+4|0;m=m+4|0;k=k+4|0;g=g+4|0;y=Lb(i,v[a+4220>>2]<<1),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=Lb(i,v[a+4220>>2]<<1|1),A=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[y>>2]=A;e=v[a+4220>>2]+1|0;v[a+4220>>2]=e;j=j+1|0;if((j|0)!=(d|0)){continue}break}break a}o=g;g=d<<2;xM(o,o+g|0,m);xM(k,g+k|0,n)}Fi(a,b,c,od(h,0),od(h,1),d)}function ipa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;ud(b,32);e=a+4|0;h=b,i=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;e=b;if(c?d:1){c=a+46|0;c=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!Ib(w[d|0]|w[d+1|0]<<8)){break a}if((Ib(w[d|0]|w[d+1|0]<<8)|0)==48){break a}c=(c-(Ib(w[d|0]|w[d+1|0]<<8)<<7)|0)+6144|0}Oo(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[ac(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}gb=f+16|0}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=Tf(a);if(e>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{d=b-e|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/52>>>0){kz(a,d,c);break c}f=wb(a);g=wN(a,Tf(a)+d|0);i=Tf(a);e=0;h=gb-16|0;gb=h;v[h+12>>2]=0;b=j+8|0;hf(b+12|0,f);if(g){e=sN(g)}v[b>>2]=e;f=B(i,52)+e|0;v[b+8>>2]=f;v[b+4>>2]=f;l=dc(b),m=B(g,52)+e|0,v[l>>2]=m;gb=h+16|0;v[22708]=0;U(1493,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}c=a;BO(a);wb(a);e=b;f=b+4|0;g=f;h=v[a>>2];a=v[a+4>>2];if((h|0)!=(a|0)){d=v[g>>2];while(1){d=d-52|0;a=a-52|0;i=qN(d,wb(a));v[d>>2]=v[a>>2];v[d+4>>2]=v[a+4>>2];k=v[wb(a)>>2];l=wb(i),m=k,v[l>>2]=m;l=wb(a),m=0,v[l>>2]=m;v[a>>2]=0;v[a+4>>2]=0;v[d+20>>2]=v[a+20>>2];i=v[a+16>>2];v[d+12>>2]=v[a+12>>2];v[d+16>>2]=i;Vu(d+24|0,a+24|0);Dc(d+36|0,a+36|0);v[d+48>>2]=v[a+48>>2];d=v[g>>2]-52|0;v[g>>2]=d;if((a|0)!=(h|0)){continue}break}}wc(c,f);wc(c+4|0,e+8|0);wc(wb(c),dc(e));v[e>>2]=v[e+4>>2];rN(c,Tf(c));pN(b)}gb=j+32|0;break a}a=P()|0;O()|0;pN(b);S(a|0);L()}return}if(b>>>0<e>>>0){xN(a,v[a>>2]+B(b,52)|0)}}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;gb=f+32|0}function hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;d=gb-16|0;gb=d;_W(d+8|0,b);gb=d+16|0;v[i+16>>2]=v[d+8>>2];j=i+24|0;k=j;f=gb-32|0;gb=f;c=b;e=a;b=Yd(e);d=fc(e);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(yu(wb(e),c,h)){if(!v[b>>2]){break b}d=b;break e}if(!yu(wb(e),h,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[f+28>>2]=b;b=d;break a}v[f+28>>2]=b;b=d;break a}b=fc(e)}v[f+28>>2]=b}d=b;b=v[b>>2];t[f+27|0]=0;if(!b){h=gb-16|0;gb=h;b=fc(a);e=Nc(40,4);g=h+8|0;t[g+4|0]=0;v[g>>2]=b;c=gb-16|0;gb=c;v[c+12>>2]=e;v[22708]=0;e=f+8|0;b=e;MQ(b,c+12|0,g);g=v[22708];v[22708]=0;f:{if((g|0)!=1){gb=c+16|0;break f}V(0)|0;O()|0;Bb();L()}c=v[b>>2];v[22708]=0;g=c+16|0;c=v[22708];v[22708]=0;g:{if((c|0)!=1){c=gb-16|0;gb=c;v[c+8>>2]=v[i+16>>2];Dc(g,v[c+8>>2]);Kb(g+12|0);gb=c+16|0;l=fc(b),m=1,t[l+4|0]=m;gb=h+16|0;break g}a=P()|0;O()|0;NQ(b);S(a|0);L()}AS(a,v[f+28>>2],d,v[e>>2]);b=be(e);t[f+27|0]=1;NQ(e)}l=k,m=v[yc(f+8|0,b)>>2],v[l>>2]=m;t[k+4|0]=w[f+27|0];gb=f+32|0;a=ve(j);gb=i+32|0;return a+12|0}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];i=v[a+4>>2];h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=i;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=i+n|0;i=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];k=oqa(e,e>>31,f,f>>31);e=w+k|0;f=jb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(u[e+46162>>1],p)+B(q,u[e+46160>>1])|0)+B(o,u[e+46164>>1])|0)+B(i,u[e+46166>>1])<<8)/16384<<8;e=i;h=oqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,m);v[c+4>>2]=v[c+4>>2]+B(h,l);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;f=b;d=Nb(f);e=c;a:{if(d>>>0<e>>>0){l=gb-32|0;gb=l;b:{c:{h=e-d|0;d:{if(h>>>0<=v[wb(f)>>2]-v[f+4>>2]>>2>>>0){i=gb-16|0;gb=i;e:{d=Eg(i,f,h);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){wb(f);v[22708]=0;$j(e);j=v[22708];v[22708]=0;if((j|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=i+16|0;break d}a=P()|0;O()|0;$b(d);S(a|0);L()}k=wb(f);i=fh(f,Nb(f)+h|0);m=Nb(f);e=0;j=gb-16|0;gb=j;v[j+12>>2]=0;d=l+8|0;Ch(d+12|0,k);if(i){e=TW(i)}v[d>>2]=e;k=(m<<2)+e|0;v[d+8>>2]=k;v[d+4>>2]=k;n=dc(d),o=(i<<2)+e|0,v[n>>2]=o;gb=j+16|0;v[22708]=0;R(662,d|0,h|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;R(663,f|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}UW(d)}gb=l+32|0;break b}a=P()|0;O()|0;UW(d);S(a|0);L()}break a}if(d>>>0>e>>>0){hj(f,v[f>>2]+(e<<2)|0)}}c=Pb(a,c<<2);if(c){f=gb-16|0;gb=f;bc(g+24|0,v[b>>2],Nb(b)<<2);gb=f+16|0;b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function Tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;o=d,p=mf(a)>>>5|0,u[o+32>>1]=p;u[d+16>>1]=3999;o=c,p=x[Pc(d+32|0,d+16|0)>>1],u[o+480190>>1]=p;YU(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=d+62|0;k=d+58|0;l=d+56|0;n=d+52|0;m=d+60|0;i=1;j=1;while(1){f=Tl(c,j&65535);e=d+32|0;cv(a,e);ud(f,0);Zj(d,2,e);e=d+16|0;Bc(e,d);v[22708]=0;Q(301,((i<<5)+c|0)+946304|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}e=d+16|0;vb(e);u[f+32>>1]=64;v[f+24>>2]=8287;o=d,p=Ib(w[m|0]|w[m+1|0]<<8),u[o+16>>1]=p;u[d>>1]=64;o=f,p=x[Pc(e,d)>>1]<<2,u[o+30>>1]=p;e=n;o=f,p=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))&-2,v[o>>2]=p;e=Ib(w[l|0]|w[l+1|0]<<8);g=Ib(w[k|0]|w[k+1|0]<<8);b:{if(g>>>0<2){break b}g=e+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=e<<1;u[f+34>>1]=x[f+34>>1]|8}if(Ib(w[h|0]|w[h+1|0]<<8)){e=(Ib(w[h|0]|w[h+1|0]<<8)|0)==2}else{e=1}f=d+16|0;re(f,b,i-1|0);Df(f,e);j=j+1|0;i=j&65535;if(i>>>0<=x[c+480190>>1]){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(g<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Mb(b,-16777216,16776704);k=v[a+64>>2];g=Mb(f,-16777216,16776704);f=oqa(k,k>>31,e,e>>31);k=jb;e=f;f=i>>>21&2040;i=(((B(j,u[f+46162>>1])+B(p,u[f+46160>>1])|0)+B(u[f+46164>>1],q)|0)+B(r,u[f+46166>>1])|0)/16384<<8;f=i;j=oqa(l,l>>31,f,f>>31);e=e+j|0;f=jb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];g=oqa(e,e>>31,g,g>>31);e=j+g|0;f=jb+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Jc(e,f,24);e=v[a+72>>2];g=(f|0)/256|0;v[c>>2]=v[c>>2]+B(g,n);v[c+4>>2]=v[c+4>>2]+B(g,m);e=f-(e&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-48|0;gb=g;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;d=g+44|0;gp(b,d);a:{if(!SS(d)){break a}c=w[g+46|0];f=w[g+47|0];e=w[g+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;f=f>>>0<192;u[a+2>>1]=x[(B(d,6)+(e<<1)|0)+33672>>1]<<f;e=B(B(w[(e+B(d,3)|0)+33449|0],x[((B(d,90)+B(e,30)|0)+(c>>>3&30)|0)+33456>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+(c&6)|0)+33648>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[(f|d<<1)+33684|0];if(e+8>>>0>(c&65535)>>>0){break a}d=g;c=gb-48|0;gb=c;v[c+44>>2]=e+4;v[c+24>>2]=36;f=v[Fb(c+44|0,c+24|0)>>2];if(!Pb(b,f)){f=mf(b)}h=c+24|0;ds(h,d);i=vd(c+32|0,v[h>>2],f);j=v[i+4>>2];v[c+8>>2]=v[i>>2];v[c+12>>2]=j;cc(c+16|0,b,c+8|0);ds(h,d);Qb(v[c+24>>2]+f|0,0,36-f|0);Rb(b,v[c+44>>2]);gb=c+48|0;b=2;if(e>>>0>2){while(1){if(w[b+g|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+g|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){d=1}else{d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=d}gb=g+48|0;return a|0}function ik(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Fc(b,d);v[22708]=0;j=T(2481,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(il(i+24|0,i+16|0)){break b}c:{if((Pn(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Pn(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Pn(j,v[g+8>>2])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(jl(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(jl(j,8192,v[g>>2])){continue}}break}if(!um(i+24|0,i+16|0)){break c}while(1){if(!jl(j,8192,tm(i+24|0))){break c}b=i+24|0;sm(b);if(um(b,i+16|0)){continue}break}break c}if((pn(j,tm(i+24|0))|0)==(pn(j,v[g>>2])|0)){g=g+4|0;sm(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(il(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function jk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Fc(b,d);v[22708]=0;j=T(21,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Wb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(lk(i+24|0,i+16|0)){break b}c:{if((Qn(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=Qn(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=Qn(j,t[g+2|0])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(nh(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(nh(j,8192,t[g|0])){continue}}break}if(!mk(i+24|0,i+16|0)){break c}while(1){if(!nh(j,8192,nl(i+24|0))){break c}b=i+24|0;ml(b);if(mk(b,i+16|0)){continue}break}break c}if((xx(j,nl(i+24|0))|0)==(xx(j,t[g|0])|0)){g=g+1|0;ml(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(lk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Wb(i+8|0);S(a|0);L()}function ZI(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[a>>2];j=z[d>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=f+z[b>>2];i=C(i-j);f=C(f-g);z[d>>2]=C(i*z[e>>2])-C(f*z[e+4>>2]);z[b>>2]=C(f*z[e>>2])+C(i*z[e+4>>2]);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=f+j;h=a-12|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+32>>2])-C(g*z[e+36>>2]);z[b>>2]=C(g*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=f+j;h=a-20|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+64>>2])-C(g*z[e+68>>2]);z[b>>2]=C(g*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=f+j;h=a-28|0;g=z[h>>2];z[h>>2]=g+z[b>>2];f=C(f-j);g=C(g-i);z[c>>2]=C(f*z[e+96>>2])-C(g*z[e+100>>2]);z[b>>2]=C(g*z[e+96>>2])+C(f*z[e+100>>2]);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}aa(12891,10528,2423,6368);L()}function w5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;v[22708]=0;g=Q(15,d+24|0,a|0)|0;c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=v[v[a>>2]-12>>2];v[22708]=0;Fc(d+16|0,a+c|0);c=v[22708];v[22708]=0;e:{f:{g:{if((c|0)!=1){v[22708]=0;c=T(2318,d+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}Wb(d+16|0);e=cj(d+8|0,a);f=v[v[a>>2]-12>>2];v[22708]=0;f=a+f|0;h=T(16,f|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break f}e=v[e>>2];v[22708]=0;c=Ra(2319,c|0,e|0,f|0,h|0,+b)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Zv(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+c|0,5);c=v[22708];v[22708]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Wb(d+16|0);break e}c=V(0)|0;O()|0}ll(g);break c}ll(g);break b}c=V(0)|0;O()|0}Z(c|0)|0;c=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=d+32|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;v[a+4>>2]=0;if(w[tj(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[22708]=0;b=v[(a+b|0)+24>>2];d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;b=T(2310,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}if(Ie(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!Ie(b,c)){continue}break}d=0;break a}if(v[a+4>>2]>=(b|0)){break a}while(1){d:{d=v[v[a>>2]-12>>2];v[22708]=0;d=v[(a+d|0)+24>>2];e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;e=T(2310,d|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}if(Ie(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;d=0;if(Ie(e,c)){break a}if(v[a+4>>2]<(b|0)){continue}break a}break}}b=V(0)|0;O()|0;Z(b|0)|0;d=1;sj(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break f}S(a|0);L()}$();break a}V(0)|0;O()|0;Bb()}L()}d=2}ih(v[v[a>>2]-12>>2]+a|0,d)}gb=f+16|0;return a|0}function H4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=mc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Ps(b,c,0)|0)!=-1){while(1){f=Ps(b,c,e);v[22708]=0;Y(140,d|0,b|0,e|0,f-e|0);f=v[22708];v[22708]=0;if((f|0)==1){break j}v[22708]=0;R(141,d+16|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break i}v[22708]=0;R(142,a|0,d+16|0);f=v[22708];v[22708]=0;if((f|0)==1){break h}vb(d+16|0);vb(d);e=Ps(b,c,e)+Ab(c)|0;if((Ps(b,c,e)|0)!=-1){continue}break}}k:{if(cd(a)){v[22708]=0;Y(140,d+16|0,b|0,e|0,-1);c=v[22708];v[22708]=0;if((c|0)==1){break f}c=d+16|0;f=Ab(c);vb(c);if(!f){break k}}v[22708]=0;Y(140,d|0,b|0,e|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;R(141,d+16|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;R(142,a|0,d+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+16|0);vb(d)}gb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;vb(d+16|0)}vb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0)}vb(d)}qm(a);S(e|0);L()}function Uu(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;default:break b}}t[a+3|0]=0}}function cy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Mf(g+16|0,a,b,c,e,h-15233|0);mm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}gb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function vz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;d=a+2|0;if(!(w[d|0]==255|!w[d|0])){v[f+12>>2]=w[d|0]+1;v[f+8>>2]=10;kh(b,v[pd(f+12|0,f+8|0)>>2]);d=w[a+3|0];t[b+15|0]=d;t[b+16|0]=d;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];d=0;g=511;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Nb(b)){c=g>>>1|e;while(1){h=(d<<2)+a|0;e=h+6|0;e=w[e|0]|w[e+1|0]<<8;i=Lb(b,d),j=e>>>4|0,u[i>>1]=j;e=0;c:{if(d){e=d-1|0;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break c}e=x[Lb(b,e)>>1]+1|0}i=Lb(b,d),j=e,u[i>>1]=j}e=h+8|0;v[f+12>>2]=(c+((w[e|0]|w[e+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;e=v[dj(f+12|0,f+8|0,f+4|0)>>2];i=Lb(b,d),j=e,t[i+2|0]=j;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;if(w[a|0]&2){d=w[b+15|0];e=Nb(b);d=w[b+12|0]&-5|(d>>>0<=e>>>0)<<2}else{d=w[b+12|0]&-5}t[c+12|0]=d;c=b;d:{e:{if(w[a|0]&4){a=w[b+13|0];if(a>>>0<=w[b+14|0]){break e}}a=w[b+12|0]&-3;break d}d=Nb(b);a=w[b+12|0]&-3|(a>>>0<=d>>>0)<<1}t[c+12|0]=a}gb=f+16|0}function u7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Lf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(Kf(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Wg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=ee(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=co(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function FO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=oqa(c,c>>31,5e4,0);f=jb;b=v[Mc(d+12|0,d+8|0)>>2];c=Ac(pqa(c,f,b,b>>31),jb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=oqa(c,c>>31,1e4,0);f=jb;b=v[Mc(d+12|0,d+8|0)>>2];c=Ac(pqa(c,f,b,b>>31),jb);break a;case 1:break b}}e=60/(+y[b+44>>2]/1e4*(+(oqa(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(jb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=a+484344|0;if(!me(c,x[b+70>>1])){break d}if(!(cd(_b(c,x[b+70>>1])+24|0)^1)){break d}c=_b(c,x[b+70>>1])+24|0;break c}c=a+480248|0}if(!cd(c)){e=e*+y[Lb(c,y[b+48>>2]%(Nb(c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=A[b+8>>3]+(e-+(c>>>0));A[b+8>>3]=e;if(e>=1){A[b+8>>3]=e+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=e+1;c=c-1|0}b=oqa(v[a+480244>>2],0,c,0)+32768|0;a=jb;a=b>>>0<32768?a+1|0:a;a=Qc((a&65535)<<16|b>>>16,a>>>16|0);gb=d+16|0;return(a?a:1)|0}function D7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Lf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(Kf(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Wg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[bh(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=ee(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Uc(i);k=eo(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((e|0)!=(h|0)){continue}break}}gb=c+32|0;break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function vP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=B(b,872)+a|0;a:{if(c){e=h+8|0;Db(e,a+1074312|0,90);if(!Cb(e)){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[f+1075804|0]}e=f+1074992|0;g=c&255;j=0-g|0;i=d?i:!(v[a+480180>>2]&204473357);qP(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}f=v[(B(b,872)+a|0)+1075648>>2];if(!f|!v[f+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){pP(a,e,240-g|0);break b}if(!(b>>>0<224|d)){oP(e,224-g|0);break b}nP(e,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=65535}if((c&255)>>>0>223&i){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}lP(a,e,d);break b}if(v[a+480180>>2]==524288){break d}sP(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){c=h+8|0;Db(c,a+1074312|0,6);if(Cb(c)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}rk(a,e,(B(b,872)+a|0)+1075692|0,0-(g<<2)|0,0)}gb=h+16|0}function Yv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=a;a=gb+-64|0;gb=a;i=a;g=v[c>>2]&2?16:10;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){dO(e+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],g);if(!v[e+12>>2]){break c}f=Ab(d);v[22708]=0;v[e+4>>2]=f;f=xf(e+4|0);j=v[22708];v[22708]=0;if((j|0)!=1){v[22708]=0;U(75,d|0,f|0,0);f=v[22708];v[22708]=0;if((f|0)!=1){continue}}break}break b}b=v[e+8>>2];g=Jb(d);v[22708]=0;R(76,d|0,b-g|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){v[22708]=0;R(86,i|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=e+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}b=a+16|0;Ll(b,a,c);v[22708]=0;U(93,a+32|0,b|0,c|0);b=v[22708];v[22708]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22708]=0;U(94,a+48|0,a+32|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break i}v[22708]=0;R(85,h|0,a+48|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function x_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-112|0;gb=d;vc(b);rs(a);a:{if(!kF(b,d+72|0)){break a}if(!lF(d+72|0)){break a}b:{if(!c){break b}c=d+72|4;if(!Pb(b,Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}Ww(a);g=d,h=Vw(),v[g+48>>2]=h;e=d+48|0;Uw(lj(a)+32|0,e);ps(e);f=v[lj(a)+32>>2];v[22708]=0;R(281,e|0,b|0);b=v[22708];v[22708]=0;c:{if((b|0)==1){break c}b=v[d+48>>2];c=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));e=Yb(w[d+84|0]|w[d+85|0]<<8|(w[d+86|0]<<16|w[d+87|0]<<24));v[22708]=0;b=ca(282,b|0,c-28|0,f|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}e=0;if(!b){break a}Vd(d+32|0,f);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;rh(d+40|0,d+16|0);b=Ud(d+24|0);c=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=os(d+48|0,d+8|0,d);Vc(lj(a)+12|0,b);xb(b);break b}a=Ca(89104,28304)|0;b=O()|0;d:{if((ea(89104)|0)!=(b|0)){if((ea(28304)|0)!=(b|0)){break d}}Z(a|0)|0;$();e=0;break a}S(a|0);L()}e=1}gb=d+112|0;return e|0}function nq(a){a=a|0;var b=0,c=0,d=0,e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0);b=v[a+36>>2];if(!b){Fg(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Fg(c);return}Dl(c,b);b=x[a+28>>1];d=a+4|0;Nb(d);e=Gm(a,(b<<16)+65536>>16);f=u[a+28>>1];Nb(d);b=1;e=oe(C(e/Gm(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){g=oe(e,C(b>>>0));k=Lb(c,b-1|0),l=g,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:c=a+16|0;d=x[a+30>>1];if(d>>>0>1e3/(b>>>0)>>>0){Fg(c);return}Dl(c,B(b,d));b=u[a+28>>1];Nb(a+4|0);h=b;b=x[a+30>>1];h=qo(h,b);if(!d){break b}while(1){b=qo(f+h<<16>>16,b&65535)<<16;j=b>>16;e=oe(C(Gm(a,b+65536>>16)/Gm(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));i=1;b=1;if(v[a+36>>2]){while(1){g=oe(e,C((b&65535)>>>0));k=Lb(c,(B(v[a+36>>2],j)+i|0)-1|0),l=g,z[k>>2]=l;b=b+1|0;i=b&65535;if(i>>>0<=y[a+36>>2]){continue}break}}f=f+1|0;if(d>>>0<=(f&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}Fg(a+16|0);v[a+36>>2]=0}return}Fg(a+16|0)}function M3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22708]=0;b=T(2481,g|0)|0;a=v[22708];v[22708]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22708]=0;a=T(2482,g|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}Wb(g);v[22708]=0;R(2483,g|0,a|0);d=v[22708];v[22708]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22708]=0;R(2484,g|12,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;d=g+24|0;a=sa(2485,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Ic(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Ic(g);break d}b=P()|0;O()|0;while(1){d=Ic(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function f4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Fc(g,d);v[22708]=0;b=T(21,g|0)|0;a=v[22708];v[22708]=0;d:{e:{f:{g:{if((a|0)!=1){Wb(g);Fc(g,d);v[22708]=0;a=T(2453,g|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break g}Wb(g);v[22708]=0;R(2454,g|0,a|0);d=v[22708];v[22708]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22708]=0;R(2455,g|12,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;d=g+24|0;a=sa(2456,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;Wb(g);break d}b=P()|0;O()|0;vb(g);break d}b=P()|0;O()|0;while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function dC(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;wV(a,b);i=gb-16|0;gb=i;ud(c,1);a=b+22|0;k=c,l=Ib(w[a|0]|w[a+1|0]<<8)<<1,v[k>>2]=l;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[ac(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;j=Ib(w[a|0]|w[a+1|0]<<8);a=j<<1;f=b+28|0;g=Ib(w[f|0]|w[f+1|0]<<8);f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(f-a>>>0>3?f>>>0<4|a>>>0>f>>>0:1){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}gb=i+16|0;Qk(h,3,b);a=h+16|0;Bc(a,h);v[22708]=0;Q(301,d|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){a=d+32|0;vb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=eC(b);gb=h+32|0;return a}a=P()|0;O()|0;vb(h+16|0);S(a|0);L()}function dq(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[a>>2];k=z[d>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=g+z[c>>2];j=C(j-k);g=C(g-h);z[d>>2]=C(j*z[e>>2])-C(g*z[e+4>>2]);z[c>>2]=C(g*z[e>>2])+C(j*z[e+4>>2]);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=g+k;i=a-12|0;h=z[i>>2];z[i>>2]=h+z[f>>2];i=c;g=C(g-k);c=b+e|0;h=C(h-j);z[i>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[f>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=g+k;i=a-20|0;h=z[i>>2];z[i>>2]=h+z[e>>2];g=C(g-k);c=b+c|0;h=C(h-j);z[f>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[e>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=g+k;i=a-28|0;h=z[i>>2];z[i>>2]=h+z[e>>2];g=C(g-k);c=b+c|0;h=C(h-j);z[f>>2]=C(g*z[c>>2])-C(h*z[c+4>>2]);z[e>>2]=C(h*z[c>>2])+C(g*z[c+4>>2]);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=(h<<1)+j|0;a:{if((b|0)<=0){break a}while(1){Jd(v[f+8>>2],u[(i<<1)+h>>1]/4<<16>>16);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Jd(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function wP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;h=gb-16|0;gb=h;g=B(b,872)+a|0;a:{if(c){e=h+8|0;Db(e,a+1074312|0,90);if(!Cb(e)){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[g+1075803|0]}e=g+1074992|0;f=c&255;i=d?i:!(v[a+480180>>2]&204473357);qP(a,b,f,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,872)+a|0)+1075648>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){pP(a,e,f-240|0);break b}if(!(b>>>0<224|d)){oP(e,f-224|0);break b}nP(e,f);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=1}if((c&255)>>>0>223&i){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}mP(a,e,d);break b}if(v[a+480180>>2]==524288){break d}rP(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){c=h+8|0;Db(c,a+1074312|0,6);if(Cb(c)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}rk(a,e,(B(b,872)+a|0)+1075692|0,f<<2,0)}gb=h+16|0}function Hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=u[(g<<1)+o>>1];i=v[a+60>>2];f=Mb(b,-16777216,16776704);n=v[a+64>>2];g=Mb(e,-16777216,16776704);j=j<<8;e=j;e=oqa(i,i>>31,e,e>>31);i=jb;k=oqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=oqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Wd(a){var b=0,c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;v[c+12>>2]=0;v[c+8>>2]=2560;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;d=gb-16|0;gb=d;e=a;if(v[a>>2]!=-1){yc(d,rT(d+8|0,b));b=d;a:{b:{c:{if(!v[e>>2]){d:{cf(e,1);v[22708]=0;f=v[22708];v[22708]=0;e:{if((f|0)==1){break e}v[22708]=0;_(2566,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[e>>2]=-1;v[22708]=0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;a=v[22708];v[22708]=0;f:{if((a|0)==1){break f}cf(e,0);v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break f}v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)==1){break c}S(a|0);L()}}break a}V(0)|0;O()|0;Bb()}L()}}gb=d+16|0;gb=c+32|0;return v[a+4>>2]-1|0}function DO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-560|0;gb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=GS(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;$z(b+48|0,c+48|0);$z(b+68|0,c+68|0);$z(b+88|0,c+88|0);hc(b+108|0,c+108|0,448);nv(c);break c}b=wg(556);if(!b){f=0;v[d>>2]=0;break b}v[22708]=0;f=Q(1324,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}v[d>>2]=b}h=a,i=x[Le(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}gb=e+560|0;return f|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function Ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=t[g+o|0];i=v[a+60>>2];f=Mb(b,-16777216,16776704);n=v[a+64>>2];g=Mb(e,-16777216,16776704);j=j<<16;e=j;e=oqa(i,i>>31,e,e>>31);i=jb;k=oqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=oqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function X0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{b=v[a+12>>2];d:{if(d>>>0>b>>>0){while(1){c=v[b>>2];if(c>>>0>1114111|(c&-2048)==55296){break b}e:{if(c>>>0<=127){f=v[a+8>>2];b=1;if((g-f|0)<1){break d}v[a+8>>2]=f+1;t[f|0]=c;break e}if(c>>>0<=2047){b=v[a+8>>2];if((g-b|0)<2){break c}v[a+8>>2]=b+1;t[b|0]=c>>>6|192;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}b=v[a+8>>2];f=g-b|0;if(c>>>0<=65535){if((f|0)<3){break c}v[a+8>>2]=b+1;t[b|0]=c>>>12|224;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}if((f|0)<4){break c}v[a+8>>2]=b+1;t[b|0]=c>>>18|240;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>12&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;if(b>>>0<d>>>0){continue}break}}b=0}break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return b|0}function XK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(Bj(a)){Ah(d+24|0);break g}c=d+8|0;no(c,a);v[22708]=0;c=T(2085,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}v[d+24>>2]=c;Yf(d+8|0)}if(Bj(a)){c=a+36|0}else{c=v[d+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((io(c)|0)>(b|0)){break d}}b=ba(8)|0;v[22708]=0;c=Q(70,d+8|0,8199)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}rc(b,c);v[22708]=0;U(186,b|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break c}a=P()|0;O()|0;Yf(d+8|0);break b}a=P()|0;O()|0;da(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|f;b=v[b>>2];f=w[Vl(c,e)+16|0];v[22708]=0;Ri(b+484360|0,f);b=v[22708];v[22708]=0;h:{if((b|0)==1){break h}b=Vl(c,e);c=v[b+8>>2];b=v[b+12>>2];v[22708]=0;+oa(1945,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;wl(d+24|0);gb=d+32|0;return}a=P()|0;O()|0}wl(d+24|0)}S(a|0)}L()}function Tfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=d;b=gb-32|0;gb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;v[b+12>>2]=15;c=sf(64);v[22708]=0;f=T(1316,c|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{if((g|0)!=1){c=ns(b+8|0,f);f=v[c>>2];v[22708]=0;R(1317,f|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=v[c>>2];v[22708]=0;a=W(1318,a|0,b+22|0,b+16|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}d:{if(!a){bA(b+24|0);break d}a=v[c>>2];v[22708]=0;R(1319,a|0,b+12|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}qi(b+24|0,c)}Ig(c);gb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;Xb(c);break b}a=P()|0;O()|0;Ig(c)}S(a|0);L()}v[e+24>>2]=a;a=0;e:{f:{g:{while(1){b=v[d+24>>2];v[22708]=0;u[d+22>>1]=a;e=Q(2,d+8|0,(a<<2)+38432|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;U(1315,b|0,d+22|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}vb(e);a=a+1|0;if((a|0)!=12){continue}break}gb=d+32|0;return v[d+24>>2]}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e)}Ig(d+24|0);S(a|0);L()}function AM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-16|0;gb=f;Ai(f+8|0,b);b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;h=gb-32|0;gb=h;c=v[f+4>>2];b=h;d=v[f>>2];v[b+8>>2]=d;v[b+12>>2]=c;v[b+16>>2]=d;v[b+20>>2]=c;rh(b+24|0,b+8|0);c=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=c;c=gb-32|0;gb=c;i=c,j=Gg(a),v[i+24>>2]=j;a=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=a;v[c+16>>2]=b;v[c+20>>2]=a;d=c+8|0;b=gb-16|0;gb=b;g=v[c+24>>2];e=g;a=v[e+12>>2];e=v[e+8>>2];a:{if((a|0)<0){break a}if(i=1,j=(l=yb(g)>>>0<e>>>0,m=0,n=(a|0)>=0,n?l:m),k=(a|0)>0,k?i:j){break a}g=yb(v[c+24>>2]);e=v[c+24>>2];a=v[e+8>>2];e=0-((g>>>0<a>>>0)+v[e+12>>2]|0)|0;v[b+8>>2]=g-a;v[b+12>>2]=e;i=b,j=yb(d),v[i>>2]=j;v[b+4>>2]=0;a=Pr(b+8|0,b);a=JA(v[a>>2],v[a+4>>2]);if((yb(d)|0)!=(a|0)){break a}Rg(v[d>>2],a+v[d>>2]|0,zb(v[v[c+24>>2]>>2]+v[v[c+24>>2]+8>>2]|0));d=v[c+24>>2];e=d;g=a+v[d+8>>2]|0;d=v[d+12>>2];v[e+8>>2]=g;v[e+12>>2]=a>>>0>g>>>0?d+1|0:d}gb=b+16|0;gb=c+32|0;gb=h+32|0;gb=f+16|0}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;g=gb-16|0;gb=g;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;QN(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);QN(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);h=d+236|0;while(1){j=w[c+e|0];k=wd(h,e+12|0),l=j,u[k>>1]=l;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;h=w[d+31|0];a:{b:{if(!h){e=1;break b}e=16;if(h>>>0<17){break a}}t[d+31|0]=e}u[g+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[g+12>>1]=127;k=d,l=w[Pc(g+14|0,g+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];gb=g+16|0;c=b+236|0;while(1){d=0;e=a+i|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=wd(c,i+12|0),l=d,u[k>>1]=l;i=i+1|0;if((i|0)!=96){continue}break}Qk(f,3,a+4|0);d=f+16|0;Bc(d,f);v[22708]=0;Q(301,b+492|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}gb=f+32|0;return}a=P()|0;O()|0;vb(f+16|0);S(a|0);L()}function Wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;ud(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[Pc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[Pc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49050|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}gb=e+16|0}function $8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;tK(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;$b(c);gb=c+16|0;return}i=gb-32|0;gb=i;j=wb(a);d=i+8|0;e=a;h=io(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=h;a:{c=GV();if(h>>>0<=c>>>0){e=gv(e);if(e>>>0<c>>>1>>>0){v[f+8>>2]=e<<1;c=v[Mc(f+8|0,f+12|0)>>2]}gb=f+16|0;break a}Sc();L()}h=io(a);f=gb-16|0;gb=f;v[f+12>>2]=0;hf(d+12|0,j);if(c){e=c;if(c>>>0>=178956971){rd(8445);L()}g=Nc(B(e,24),8)}v[d>>2]=g;e=B(h,24)+g|0;v[d+8>>2]=e;v[d+4>>2]=e;k=dc(d),l=B(c,24)+g|0,v[k>>2]=l;gb=f+16|0;c=d;tK(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=a;e=c+4|0;g=v[a>>2];a=v[a+4>>2]-g|0;f=v[e>>2]+B((a|0)/-24|0,24)|0;v[e>>2]=f;if((a|0)>=1){hc(f,g,a)}wc(b,e);wc(b+4|0,d+8|0);wc(wb(b),dc(d));v[d>>2]=v[d+4>>2];a=c;b=v[c+8>>2];d=v[c+4>>2];if((b|0)!=(d|0)){v[a+8>>2]=b+B(((b-d|0)-24>>>0)/24^-1,24)}a=v[c>>2];if(a){Dy(a,(v[dc(c)>>2]-v[c>>2]|0)/24|0)}gb=i+32|0}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Ud(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=jg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=lg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=h+j|0;a:{if((b|0)<=0){break a}while(1){Jd(v[f+8>>2],t[h+i|0]<<6);Id(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Jd(b,t[h+v[e+44>>2]|0]<<6);Id(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=ig(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function m0(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb+-64|0;gb=c;a=Kb(a);v[22708]=0;b=ga(147)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[22708]=0;d=Q(2,c+32|0,6094)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;b=ga(147)|0;e=v[22708];v[22708]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[22708]=0;v[c+12>>2]=b;R(153,c+16|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break h}v[22708]=0;U(3,c+48|0,d|0,c+16|0);b=v[22708];v[22708]=0;if((b|0)==1){break g}b=c+48|0;Eb(a,b);vb(b);vb(c+16|0);vb(d);v[22708]=0;b=ga(149)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!b){break e}v[22708]=0;Q(154,a|0,14598)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(c+16|0)}vb(d);break a}v[22708]=0;b=ga(148)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!b){break d}v[22708]=0;Q(154,a|0,13869)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}}gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}vb(a);S(b|0);L()}function Vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=zb(b);a:{b:{c:{d:{e:{f:{g:{while(1){b=c;if(!c){break g}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break e}c=0;break f}if((d|0)==4){break d}f=(d|0)==2;break c}while(1){h:{i:{j:{d=c+h|0;i=w[d|0];switch(i-10|0){case 0:break i;case 3:break j;default:break h}}e=e+1|0;break h}f=f+1|0}g=c?(w[d-1|0]==13&(i|0)==10)+g|0:g;c=c+1|0;if((c|0)!=(b|0)){continue}break}break d}f=(d|0)==2;break b}k:{if((e|0)==(f|0)){d=2;if((e|0)==(g|0)){break k}}if(e){d=0;if(!f){break k}}d=e?3:f?1:3}f=(d|0)==2;if(b){break b}}b=0;g=1;e=0;break a}g=0;c=0;e=0;while(1){e=e+1|0;c=((w[c+h|0]==13&f)+c|0)+1|0;if(c>>>0<b>>>0){continue}break}}Se(a);Rq(a,e);if(!g){g=(d|0)==1?32:13;d=d&-3?13:32;c=0;while(1){l:{m:{n:{o:{e=t[c+h|0];switch(e-10|0){case 1:case 2:break l;case 0:break m;case 3:break n;default:break o}}if(e){break l}e=32;break l}c=c+f|0;e=g;break l}e=d}Mo(a,e);c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function ru(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;e=f+8|0;g=a+1074312|0;Db(e,g,77);a:{if(j=Cb(e),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{i=c;if(d){e=w[c+841|0];if(!e){break c}d=e-1|0;t[c+841|0]=d;if(d&255){break b}c=f+8|0;Db(c,g,16);if(!(j=Cb(c),k=1,l=v[a+480180>>2]!=2,l?j:k)){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[i+764>>2]=a;break a}e=f+8|0;Db(e,g,17);if(!(Cb(e)|v[a+480180>>2]&3|!x[a+480188>>1])){e=b+616|0;while(1){if(w[e+841|0]?(c|0)!=(e|0):0){break a}e=e+872|0;h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;d:{if((d|0)==-1){break d}e:{if(v[b+60>>2]==-1){break e}e=f+8|0;Db(e,g,68);if(!Cb(e)){break e}v[b+60>>2]=d}v[b+64>>2]=d;d=f+8|0;Db(d,g,103);if(!Cb(d)){break d}u[b+68>>1]=65535}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break a}d=0;while(1){e=B(d,872)+b|0;v[e+1380>>2]=v[c+764>>2];t[e+1457|0]=w[c+841|0];d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}gb=f+16|0}function pL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){v[22708]=0;b=c;T(1291,b|0)|0;a=v[22708];v[22708]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;Ek(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=wb(f);v[22708]=0;d=d-4|0;R(1326,e|0,d|0);e=v[22708];v[22708]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[f+4>>2]=g;ai(wb(a),v[a>>2],pe(a))}Xb(c)}v[b+4>>2]=0;mA(b+1298368|0);ju(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);iu(b+1298264|0);hu(b+1298260|0);Eq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Bq(a-160|0);if((c|0)!=(a|0)){continue}break}Gu(b+484360|0);kA(b+484344|0);Lc(b+480248|0);break a}V(0)|0;O()|0;mA(b+1298368|0);ju(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);iu(b+1298264|0);hu(b+1298260|0);Eq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Bq(a-160|0);if((c|0)!=(a|0)){continue}break}Gu(b+484360|0);kA(b+484344|0);Lc(b+480248|0);Bb();L()}Xb(b)}}}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;gb=f+32|0}function wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=e+o|0;p=t[g+1|0];g=t[g|0];e=v[a+60>>2];q=e;r=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=oqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=((B(p-g|0,i>>>10&4194048)|0)/16384|0)+(g<<8)<<8;i=oqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function IS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;h=gb-16|0;gb=h;if(Kj(a)){e=w[(we(w[a+797|0])?a+797|0:a+799|0)|0];f=h+8|0;Db(f,d+1074312|0,34);a:{if(!Cb(f)){break a}d=e;if(e){if(d>>>0>120){break a}e=w[lc(v[a+656>>2]+108|0,d-1|0)|0];break a}e=0}d=a;k=C(C(v[a+704>>2]<<4)*b);e=(c+e<<16)-3997696>>16;c=v[v[a+656>>2]+44>>2];i=v[c+36>>2];a=v[a+852>>2]+u[a+772>>1]|0;b:{if(!(a?i:0)){b=Gm(c,a+e<<16>>16);break b}j=i+1|0;l=gz(a,j);f=qo(a,j);a=u[c+28>>1];g=c+4|0;Nb(g);b=C(1);e=e+l<<16>>16;c:{if((e|0)<(a|0)){break c}if((e|0)>(x[c+28>>1]+Nb(g)<<16)-65536>>16){break c}if(!f){b=z[Lb(g,e-u[c+28>>1]|0)>>2];break b}a=x[c>>1];d:{if((a|0)==3){a=c+16|0;if(Nb(a)){b=z[Lb(a,f-1|0)>>2];break d}a=x[c>>1]}e:{if((a&65535)!=1){break e}a=c+16|0;if(!Nb(a)){break e}b=z[Lb(a,(B(i,qo(e,x[c+30>>1])<<16>>16)+f|0)-1|0)>>2];break d}b=oe(C(Gm(c,(e<<16)+65536>>16)/Gm(c,e)),C(C(f|0)/C(j|0)))}b=C(b*z[Lb(g,e-u[c+28>>1]|0)>>2])}}m=d,n=Jj(C(k*b)),v[m+700>>2]=n}gb=h+16|0}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=(e<<1)+o|0;p=u[g+2>>1];g=u[g>>1];e=v[a+60>>2];q=e;r=e>>31;e=Mb(b,-16777216,16776704);j=v[a+64>>2];f=Mb(f,-16777216,16776704);e=oqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=oqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=g+((B(p-g|0,i>>>18|0)|0)/16384|0)<<8;i=oqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Jc(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function _y(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=gb+-64|0;gb=b;d=v[a+20>>2];a:{if(!d){break a}if(oc(d+4|0)>>>0<4){break a}Vd(b+32|0,v[a+20>>2]+4|0);d=Ud(b+24|0);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[d+4>>2];v[b+8>>2]=v[d>>2];v[b+12>>2]=c;d=XX(b+40|0,b+16|0,b+8|0);v[22708]=0;c=T(192,d|0)|0;f=v[22708];v[22708]=0;b:{if((f|0)!=1){if(c){break b}c=v[v[a>>2]+40>>2];v[22708]=0;c=T(c|0,a|0)|0;f=v[22708];v[22708]=0;c:{if((f|0)==1){break c}if(oc(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}e=v[v[a>>2]+172>>2];f=0;v[22708]=0;R(e|0,a|0,-1);e=v[22708];v[22708]=0;if((e|0)==1){break c}if(c){while(1){v[22708]=0;g=C(Ba(635,d|0));e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[v[a>>2]+44>>2];v[22708]=0;Aa(e|0,a|0,f|0,C(g));e=v[22708];v[22708]=0;if((e|0)==1){break c}f=f+1|0;if((c|0)!=(f|0)){continue}break}}c=v[v[a>>2]+176>>2];v[22708]=0;_(c|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;xb(d);S(a|0);L()}xb(d)}gb=b- -64|0}function JI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-208|0;gb=d;v[d+8>>2]=1;v[d+12>>2]=0;a:{h=b<<2;if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;e=4;g=2;while(1){f=e;e=b;b=(b+4|0)+f|0;v[(d+16|0)+(g<<2)>>2]=b;g=g+1|0;if(b>>>0<h>>>0){continue}break}e=(a+h|0)-4|0;b:{if(e>>>0<=a>>>0){g=1;b=1;break b}g=1;b=1;while(1){c:{if((g&3)==3){_x(a,c,b,d+16|0);jt(d+8|0,2);b=b+2|0;break c}f=b-1|0;d:{if(y[(d+16|0)+(f<<2)>>2]>=e-a>>>0){it(a,c,d+8|0,b,0,d+16|0);break d}_x(a,c,b,d+16|0)}if((b|0)==1){ht(d+8|0,1);b=0;break c}ht(d+8|0,f);b=1}g=v[d+8>>2]|1;v[d+8>>2]=g;a=a+4|0;if(e>>>0>a>>>0){continue}break}}it(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(g|0)!=1)){if(v[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=d+8|0;e=HI(f);jt(f,e);g=v[d+8>>2];b=b+e|0;break e}f=d+8|0;ht(f,2);v[d+8>>2]=v[d+8>>2]^7;jt(f,1);i=a-4|0;h=d+16|0;e=b-2|0;it(i-v[h+(e<<2)>>2]|0,c,f,b-1|0,1,h);ht(f,1);g=v[d+8>>2]|1;v[d+8>>2]=g;it(i,c,f,e,1,h);b=e}a=a-4|0;continue}}gb=d+208|0}function Pf(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function sx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=rx(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+83408|0];d:{e:{switch(sqa(f-88|0,30)|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function fg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;d=v[a+28>>2];mo(v[v[d>>2]-12>>2]+d|0,0);if(!nd(a,4)){Qy(a)}a:{if(!v[a+4>>2]){break a}if(nd(a,6)){break a}if(nd(a,7)){break a}g=v[a+28>>2];e=v[a+84>>2];h=B(v[a+20>>2],v[a+4>>2]);f=h+v[a+80>>2]|0;e=sh(c- -64|0,f,f>>>0<h>>>0?e+1|0:e);f=v[e+12>>2];v[c+24>>2]=v[e+8>>2];v[c+28>>2]=f;d=v[e+4>>2];v[c+16>>2]=v[e>>2];v[c+20>>2]=d;kk(g,c+16|0)}d=0;b:{if(!nd(a,5)){break b}g=0;e=a+44|0;h=uf(e);d=0;if(!h){break b}d=a+32|0;while(1){c:{f=(v[a+96>>2]+g>>>0)%(h>>>0)|0;if(y[Tc(e,f)>>2]>=oc(d)>>>0){break c}i=oo(c+48|0,kc(d,v[Tc(e,f)>>2]),x[Tc(e,f)+12>>1]);j=Ty(b,i);Hb(i);if(!j){break c}v[a+96>>2]=(f+1>>>0)%(h>>>0);b=v[Tc(e,f)+4>>2];if(b){h=v[a+28>>2];g=b+v[a+8>>2]|0;a=v[a+12>>2];a=sh(c+32|0,g,b>>>0>g>>>0?a+1|0:a);b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;kk(h,c)}d=Tc(e,f);break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}d=0}gb=c+80|0;return d}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function J8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;v[e+72>>2]=c;c=qi(a,e+72|0);g=Ah(a+4|0);h=Ah(a+24|0);i=Ah(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22708]=0;R(2080,a|0,d|0);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];l=v[b+4>>2];m=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=m;v[e+32>>2]=f;v[e+36>>2]=l;b=Ud(e+24|0);f=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=f;v[22708]=0;f=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;U(2074,e+48|0,e+8|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;U(2081,a|0,e+48|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}xb(e+48|0);v[22708]=0;_(2082,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}eg(e+72|0);gb=e+80|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(e+48|0);break a}a=P()|0;O()|0}yd(k);Yf(j);iq(i);Ei(h);Di(g);eg(c);eg(e+72|0);S(a|0);L()}function cK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Lf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(Kf(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Xg(a,g,j);c=Lb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=yt(f)+c&-4096;v[l>>2]=e-c;c=id(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=eo(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=d- -64|0}function XJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Lf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(Kf(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Xg(a,g,j);c=Lb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=yt(f)+c&-4096;v[l>>2]=e-c;c=id(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=co(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=d- -64|0}function qT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{d=gb-16|0;gb=d;e=Kb(a);i=b;b:{if(Ab(b)){while(1){a=v[yk(i,g)>>2];c:{if(a>>>0>=2097152){v[22708]=0;R(66,e|0,63);a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}c=0;d:{e:{while(1){f=a&63;t[(d+10|0)+c|0]=f;if(a>>>0<64){break e}a=a>>>6|0;c=c+1|0;if((c|0)!=6){continue}break}b=7;c=6;break d}f:{if(!c){v[22708]=0;R(66,e|0,t[d+10|0]);break f}b=c+1|0;if((b|0)!=2){break d}c=1;b=2;if((f|0)!=1){break d}v[22708]=0;R(66,e|0,t[d+10|0]|64)}a=v[22708];v[22708]=0;if((a|0)!=1){break c}break b}f=(-1<<b^-1)<<7-c;c=b-1|0;j=c+(d+10|0)|0;a=b;while(1){g:{if((a|0)==(b|0)){a=w[j|0];v[22708]=0;R(66,e|0,(a|f)<<24>>24);h=v[22708];v[22708]=0;a=c;if((h|0)!=1){break g}break b}v[22708]=0;a=a-1|0;R(66,e|0,t[a+(d+10|0)|0]|-128);h=v[22708];v[22708]=0;if((h|0)==1){break b}}if(a){continue}break}}g=g+1|0;if(Ab(i)>>>0>g>>>0){continue}break}}gb=d+16|0;break a}a=P()|0;O()|0;vb(e);S(a|0);L()}}function eJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];b=v[a+1380>>2];a:{b:{if((b|0)==-1){h=1;b=-1;break b}d=v[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){ec(a,1);break a}b=(b|0)==(d|0)?-1:b}d:{while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){ec(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[90128]|w[90129]<<8|(w[90130]<<16|w[90131]<<24))){ec(a,21);break a}if(w[c+4|0]){ec(a,21);break a}e:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break e}ec(a,21);break a}if(t[c+5|0]&1){break e}ec(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break d}h=0;b=0;f=0;f:{if(!e){break f}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break f}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}ec(a,1);break a}ec(a,1)}return 0}function vx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Vm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+83408|0];d:{e:{switch(f-22|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;gb=f+32|0}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=0,B=0,E=C(0);f=gb-16|0;gb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!ni(g)){break a}l=z[a+4220>>2];A=f,B=Nd(g,0),v[A+8>>2]=B;A=f,B=Nd(g,1),v[A+12>>2]=B;A=f,B=od(g,0),v[A>>2]=B;A=f,B=od(g,1),v[A+4>>2]=B;if(d){m=a+4208|0;t=C(C(1)-l);j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;u=v[((n<<2)+a|0)+4248>>2];x=v[a+4240>>2];y=v[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=v[p>>2];v[p>>2]=e+4;q=z[e>>2];e=y-u|0;r=z[Lb(m,n+((e>>31&x)+e<<1)|0)>>2];s=C(C(q*z[a+4260>>2])+C(r*z[a+4224>>2]));A=Lb(m,v[a+4244>>2]<<1|h),E=C(D(s))<C(1.0000000195414814e-24)?C(0):s,z[A>>2]=E;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=C(t*q)+C(l*r);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}Fi(a,b,c,od(g,0),od(g,1),d)}gb=f+16|0}function Dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>4;v[d+16>>2]=v[a>>2];h=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=ee(e);a:{if(D(e)<2147483648){g=~~e;break a}g=-2147483648}i=f,j=Uc(g),u[i>>1]=j;f=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[d+24>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=ee(e);b:{if(D(e)<2147483648){g=~~e;break b}g=-2147483648}i=f,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return h<<4}function sI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-32|0;gb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;Mf(h+16|0,a,b,g,e,f-16129|0);mm(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}gb=h+32|0;return l(2,d&-2147483648|e),q()}function zH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[If(c+24|0,a+44|0)>>2];if((e|0)>=1){f=(e|0)>0?e:0;while(1){g=Us(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;if((f|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(MH(v[a+36>>2],d,h,f,c+16|0,c+23|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=Us(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Ts(Lg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Lg(t[c+23|0]),v[k+48>>2]=l}d=Lg(t[c+23|0]);break a}d=-1}gb=c+32|0;return d}function RT(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;b=v[a>>2];yc(g+8|0,b);a:{b:{c:{d:{e=b+16|0;e:{if(Dd(e)){while(1){f:{d=v[e>>2];v[22708]=0;d=T(56,d|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break f}f=d|f;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(89080)|0;if((O()|0)!=(ea(89080)|0)){break c}Z(c|0)|0;t[b+20|0]=0;v[22708]=0;_(38,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break d}v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break c}t[b+20|0]=0}if(!w[b+20|0]){b=v[b+24>>2];c=v[b+2496>>2];e=(c<<2)+b|0;h=v[b+((c+397>>>0)%624<<2)>>2];d=(c+1>>>0)%624|0;c=v[b+(d<<2)>>2];c=h^(c&2147483647|v[e>>2]&-2147483648)>>>1^B(c&1,-1727483681);v[e>>2]=c;v[b+2496>>2]=d;b=c^c>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;f=f^(b>>>18^b)}gb=g+16|0;break a}c=P()|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Bb();L()}return v[a+28>>2]&f}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);c=0;while(1){if((l|0)>=1){j=(k<<1)+b|0;n=j+(l<<1)|0;while(1){o=c;u[e+6>>1]=0;KV(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{if(!i){h=x[e+6>>1];break a}h=x[e+6>>1];c=x[e+12>>1];g=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!kf(a,e+5|0)){break a}f=w[e+5|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}h=f|h<<1;g=g-1|0;if(g&255){continue}break}}c=1;m=h&65535;b:{if(m>>>0<4){break b}g=15;while(1){c=g;f=c&255;if(m>>>f&1){break b}g=c-1|0;if(f>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=h&1;t[e+14|0]=c;g=c-1^(h&65534)>>>1;c=g+x[e+8>>1]|0;u[e+6>>1]=c;u[j>>1]=c;v[e+8>>2]=((g>>1)-(o<<16>>16)|0)+(c<<16>>16<<1);Rd(e+8|0,-32768,32767);j=(d<<1)+j|0;if(n>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function lT(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+33392|0];a:{b:{c:{switch(d|0){case 0:if(c>>>0>50?w[b|0]:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&240)!=32?(d&15)!=2:0)){t[a|0]=20;t[b|0]=159;d=159}if((d&15)!=12&(d&240)!=192|c>>>0<51){break b}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:d:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break d;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function Y0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){i=d;f=t[a|0];b=1;b:{if((f|0)>-1){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}b=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}b=3;if((h&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break a}h=w[a+3|0];j=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((j&192)!=128|(h&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}g=g+1|0;b=4}a=b+a|0;if(i>>>0<=a>>>0){break a}g=g+1|0;if(g>>>0<e>>>0){continue}break}}return a-c|0}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=C(0);if(v[a+4220>>2]){f=a+44|0;i=Nd(f,0);j=Nd(f,1);k=od(f,0);l=od(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[i>>2];o=z[j>>2];e=e-v[a+4228>>2]|0;e=(v[a+4220>>2]&e>>31)+e<<1;p=z[Lb(h,e)>>2];e=Lb(h,e|1);r=z[a+4256>>2];s=z[a+4248>>2];t=z[a+4252>>2];q=z[e>>2];u=z[a+4244>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(q*u));w=Lb(h,v[a+4224>>2]<<1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;g=C(C(C(C(o*r)+C(n*s))+C(q*t))+C(p*u));w=Lb(h,v[a+4224>>2]<<1|1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(n*z[a+4240>>2])+C(p*z[a+4236>>2]);z[l>>2]=C(o*z[a+4240>>2])+C(q*z[a+4236>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}Fi(a,b,c,od(f,0),od(f,1),d)}}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=g>>>21&2040;g=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;gb=e+32|0}function QN(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;t[k+15|0]=c;t[k+14|0]=12;kh(b,w[ac(k+15|0,k+14|0)|0]);if(Nb(b)){c=0;while(1){a:{b:{c:{switch(h|0){case 0:i=(c<<2)+a|0;j=i+96|0;j=w[j|0]|w[j+1|0]<<8;m=Lb(b,c),n=j,u[m>>1]=n;i=i+98|0;break b;case 1:break c;default:break a}}i=(c<<2)+a|0;j=i+144|0;j=w[j|0]|w[j+1|0]<<8;m=Lb(b,c),n=j,u[m>>1]=n;i=i+146|0}i=w[i|0];m=Lb(b,c),n=i,t[m+2|0]=n}d:{if(!c){break d}i=c-1|0;if(x[Lb(b,c)>>1]>=x[Lb(b,i)>>1]){break d}if(x[Lb(b,c)>>1]>255){break d}j=w[Lb(b,i)+1|0];l=Lb(b,c);u[l>>1]=x[l>>1]|j<<8;if(x[Lb(b,c)>>1]>=x[Lb(b,i)>>1]){break d}i=Lb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(cd(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}gb=k+16|0}function J1(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=Nb(465840);if(b>>>0<a>>>0){g=gb-32|0;gb=g;e=a-b|0;a:{if(e>>>0<=v[116462]-v[116461]>>2>>>0){KG(e);break a}f=ix(465840);b=g+8|0;d=Nb(465840)+e|0;c=gb-16|0;gb=c;v[c+12>>2]=d;b:{a=mp();if(d>>>0<=a>>>0){d=pe(465840);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;break b}Sc();L()}h=Nb(465840);c=0;d=gb-16|0;gb=d;v[d+12>>2]=0;hf(b+12|0,f);if(a){c=xG(v[b+16>>2],a)}v[b>>2]=c;f=(h<<2)+c|0;v[b+8>>2]=f;v[b+4>>2]=f;i=dc(b),j=(a<<2)+c|0,v[i>>2]=j;gb=d+16|0;d=gb-16|0;gb=d;a=Sk(d,b+8|0,e);c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Xo(c);c=v[a>>2]+4|0;v[a>>2]=c;if(v[a+4>>2]!=(c|0)){continue}break}}_c(a);gb=d+16|0;a=b+4|0;ol(v[116460],v[116461],a);wc(465840,a);wc(465844,b+8|0);wc(465848,dc(b));v[b>>2]=v[b+4>>2];a=b;pC(a);b=v[a>>2];if(b){wG(v[a+16>>2],b,Bk(a))}}gb=g+32|0;return}if(a>>>0<b>>>0){de(465840,v[116460]+(a<<2)|0)}}function Bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=Kb(d+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[22708]=0;c=T(1419,b|0)|0;e=v[22708];v[22708]=0;d:{if((e|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[22708]=0;Q(70,a|0,18720)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}v[22708]=0;c=T(467,b|0)|0;e=v[22708];v[22708]=0;e:{if((e|0)==1){break e}c=Ui(c);v[22708]=0;v[d+8>>2]=c;c=pd(d+12|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}c=v[c>>2];v[22708]=0;R(60,f|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[22708]=0;c=T(374,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break g}if(!c){break f}v[22708]=0;W(1420,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break a}v[22708]=0;Q(318,b|0,4)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}Dc(a,f)}vb(f);gb=d+32|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function GS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=hB(a+48|0);e=hB(a+68|0);f=hB(a+88|0);v[22708]=0;Uq(a+492|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Uq(a+524|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;fm(a,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;em(a,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[22708]=0;qr(a,b);b=v[22708];v[22708]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=lc(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;bp(f);bp(e);bp(d);S(a|0);L()}function zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=uf(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>4>>>0){f=gb-16|0;gb=f;d=cq(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){Ev(e);e=e+16|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=dy(e,uf(e)+i|0);m=uf(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;hf(d+12|0,j);if(f){h=f;if(f>>>0>=268435456){rd(8445);L()}h=Nc(h<<4,1)}v[d>>2]=h;j=(m<<4)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<4)+h|0,v[n>>2]=o;gb=l+16|0;v[22708]=0;yT(d,i);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(e,d);xT(d)}gb=k+32|0;break b}a=P()|0;O()|0;xT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Zk(e,v[e>>2]+(d<<4)|0)}}if(Pb(a,c<<4)){bc(g+24|0,v[b>>2],uf(b)<<4);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function V0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){f=1;b=t[a|0];b:{if((b|0)>-1){break b}b=b&255;if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}f=3;if((g&192)==128){break b}break a}if((d-a|0)<4|b>>>0>244){break a}f=w[a+3|0];i=w[a+2|0];g=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((g+112&255)>>>0<48){break e}break a;case 4:if((g&240)==128){break e}break a;default:break f}}if((g&192)!=128){break a}}if((i&192)!=128|(f&192)!=128){break a}f=4;if((b<<18&1835008|(g&48)<<12)>>>0>1114111){break a}}a=a+f|0;if(d>>>0<=a>>>0){break a}h=h+1|0;if(h>>>0<e>>>0){continue}break}}return a-c|0}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Ae(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>5>>>0){f=gb-16|0;gb=f;d=AB(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){UB(e);e=e+32|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=_q(e,Ae(e)+i|0);m=Ae(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;hf(d+12|0,j);if(f){h=f;if(f>>>0>=134217728){rd(8445);L()}h=Nc(h<<5,1)}v[d>>2]=h;j=(m<<5)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=dc(d),o=(f<<5)+h|0,v[n>>2]=o;gb=l+16|0;v[22708]=0;CT(d,i);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(e,d);BT(d)}gb=k+32|0;break b}a=P()|0;O()|0;BT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Zk(e,v[e>>2]+(d<<5)|0)}}if(Pb(a,c<<5)){bc(g+24|0,v[b>>2],Ae(b)<<5);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb+-64|0;gb=e;g=ro(a);a:{b:{if(b-1>>>0>1023){break b}f=v[a+12>>2];if((f|0)==(b|0)){break b}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break b}f=v[a+12>>2]}f=B(Ki(a),b>>>0>f>>>0?b-f|0:f-b|0);c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=Zb(a);break d}d=Vb(a)}v[c+48>>2]=d;c=Gd(e+56|0,e+48|0);d=e+40|0;hi(d);c=v[c>>2];v[22708]=0;Y(1476,a|0,c|0,f|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(a|0)|0;$();break b}if(d){i=e,j=Zb(a),v[i+48>>2]=j;i=e,j=WC(e+48|0,f),v[i+40>>2]=j;c=Gd(e+32|0,e+40|0);i=e,j=Zb(a),v[i+16>>2]=j;d=Gd(e+24|0,e+16|0);IN(a,v[c>>2],v[d>>2]);break c}i=e,j=Vb(a),v[i+40>>2]=j;c=Gd(e+8|0,e+40|0);i=e,j=Vb(a),v[i+16>>2]=j;i=e,j=EX(e+16|0,f),v[i+48>>2]=j;d=Gd(e,e+48|0);IN(a,v[c>>2],v[d>>2])}v[a+12>>2]=b;h=1}gb=e- -64|0;return h|0}S(a|0);L()}function J5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[tj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{g:{h:{if((d|0)!=1){v[22708]=0;d=T(2303,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break h}e=cj(c+8|0,a);f=Vi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2306,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[22708];v[22708]=0;if((d|0)==1){break h}Wb(c+16|0);break f}b=V(0)|0;O()|0;break g}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;sj(v[v[a>>2]-12>>2]+a|0,b);if(!(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1)){break e}v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function zga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;f=gb-32|0;gb=f;m=f,o=B(v[a>>2],fd(a)),v[m+4>>2]=o;qc(f+4|0,c>>>3|0);c=zb(b);g=A[e+8>>3];h=v[f+4>>2];a:{if(!h){break a}e=h;while(1){k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&2147483647;l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,k|0);j=+n();g=g<j?j:g;c=c+8|0;e=e-1|0;if(e){continue}break}if(g==0){break a}j=1/g;c=v[a+20>>2];while(1){a=b;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);l(0,w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24));l(1,e|0);m=f,p=j*+n(),A[m+24>>3]=p;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;i=A[bh(f+24|0,f+16|0,f+8|0)>>3]*32768;A[f+24>>3]=i;a=c;i=ee(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}m=a,o=Uc(e),u[m>>1]=o;b=b+8|0;c=c+2|0;h=h-1|0;if(h){continue}break}}if(d){A[d>>3]=g}gb=f+32|0;return v[f+4>>2]<<3}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Uc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function xH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[If(c+24|0,a+44|0)>>2];if((e|0)>=1){f=(e|0)>0?e:0;while(1){g=Us(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;if((f|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(MH(v[a+36>>2],d,h,f,c+16|0,c+20|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=Us(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Ts(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}gb=c+32|0;return d}function L9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22708]=0;_(2008,a|0);e=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[22708]=0;_(1961,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}e=0;v[22708]=0;_(2009,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}a=Qb(c,0,d);if(!w[b|0]){break b}if(wj(b,4310)|(d|0)!=8){break d}v[a+4>>2]=2010;v[a>>2]=2011;break c}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,9520,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();return 0}if(wj(b,8531)|(d|0)!=64){break b}v[a+60>>2]=2012;v[a+56>>2]=2013;v[a+52>>2]=2014;v[a+48>>2]=2015;v[a+44>>2]=2016;v[a+40>>2]=2017;v[a+36>>2]=2018;v[a+32>>2]=2019;v[a+28>>2]=2020;v[a+24>>2]=2021;v[a+20>>2]=2022;v[a+16>>2]=2023;v[a+12>>2]=2024;v[a+8>>2]=2025;v[a+4>>2]=2026;v[a>>2]=2027}e=1}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;v[g+12>>2]=1;a:{if(bi(a)){n=g,o=Ae(a),v[n+8>>2]=o;f=v[a>>2];c=b;k=v[Fb(g+12|0,g+8|0)>>2];if(k){while(1){d=c;if((c|0)!=(f|0)){h=Vb(d);l=Zb(d);i=gb-16|0;gb=i;j=sD(h,l);e=f;b:{if(j>>>0<=Og(e)>>>0){if(tc(e)>>>0<j>>>0){v[i+8>>2]=h;iS(i+8|0,tc(e));m=h;h=v[i+8>>2];Wi(m,h,v[e>>2]);rS(e,h,l,j-tc(e)|0);break b}xn(e,Wi(h,l,v[e>>2]));break b}qS(e);VB(e,Uk(e,j));rS(e,h,l,j)}gb=i+16|0;hk(f+12|0,d+12|0);u[f+28>>1]=x[d+28>>1]}f=f+32|0;k=k-1|0;if(k){continue}break}}d=v[g+12>>2];c=v[g+8>>2];if(d>>>0>c>>>0){eB(a,d-c|0,b);break a}kS(a,v[a>>2]+(d<<5)|0);break a}c=a;if(v[c>>2]){Ae(c);fS(c);dS(c);Xk(wb(c),v[c>>2],bi(c));n=wb(c),o=0,v[n>>2]=o;v[c>>2]=0;v[c+4>>2]=0}f=_q(a,1);if(AT()>>>0<f>>>0){Sc();L()}wb(c);d=cS(f);v[c>>2]=d;v[c+4>>2]=d;n=wb(c),o=d+(f<<5)|0,v[n>>2]=o;dB(c,0);eB(a,1,b)}gb=g+16|0}function hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=h>>>21&2040;h=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;gb=e+32|0}function eoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;g=fg(a,c);te(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!g){if(nd(a,5)){break a}}d=gb-48|0;gb=d;h=v[a+28>>2];ag(h,d+46|0);b:{c:{d:{e:{f:{if(x[d+46>>1]>=4001){k=v[b+12>>2];e=gb-16|0;gb=e;i=d+16|0;j=Tb(e,13027);Dc(i,j);vb(j);gb=e+16|0;v[22708]=0;U(1090,d+32|0,i|0,d+46|0);e=v[22708];v[22708]=0;if((e|0)==1){break f}v[22708]=0;U(560,k|0,2,d+32|0);e=v[22708];v[22708]=0;if((e|0)==1){break e}vb(d+32|0);Hb(d+16|0);u[d+46>>1]=4e3}Bf(Sj(b,0),x[d+46>>1]);b=Sj(b,0);l=d,m=Vb(b),v[l+32>>2]=m;l=d,m=Zb(b),v[l+16>>2]=m;if(Gb(d+32|0,d+16|0)){break c}break b}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d+32|0)}Hb(d+16|0);S(a|0);L()}while(1){b=d+32|0;e=v[b>>2];ag(h,d+14|0);u[e>>1]=x[d+14>>1];nf(b);if(Gb(b,d+16|0)){continue}break}}gb=d+48|0}Zf(a,g,c,f+24|0);gb=f+32|0}function Am(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;rl(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=zm(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>=1){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}ec(a,21);v[a+1396>>2]=0}return-1}aa(8668,10528,1705,2537);L()}function v7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Lf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(Kf(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=id((v[Xg(a,b,g)>>2]+id(xt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=co(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=c- -64|0}function E7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Lf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(Kf(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=id((v[Xg(a,b,g)>>2]+id(xt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=eo(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=c- -64|0}function Dx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=Of(a);a:{if(!v[115992]|!w[a|0]){break a}c=a;b:{if(c&3){while(1){b=w[c|0];if(!b|(b|0)==61){break b}c=c+1|0;if(c&3){continue}break}}b=v[c>>2];c:{if((b^-1)&b-16843009&-2139062144){break c}while(1){b=b^1027423549;if((b^-1)&b-16843009&-2139062144){break c}b=v[c+4>>2];c=c+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}while(1){b=c;e=w[c|0];if(e){c=b+1|0;if((e|0)!=61){continue}}break}c=b}if(w[c|0]==61?c:0){break a}d=v[v[115992]>>2];if(!d){break a}d:{while(1){i=v[115992];c=a;e=0;g=h;b=0;e:{if(!g){break e}b=w[c|0];f:{if(!b){break f}while(1){g:{j=w[d|0];if(!j){break g}g=g-1|0;if(!g|(b|0)!=(j|0)){break g}d=d+1|0;b=w[c+1|0];c=c+1|0;if(b){continue}break f}break}e=b}b=(e&255)-w[d|0]|0}if(!b){c=v[(f<<2)+i>>2]+h|0;if(w[c|0]==61){break d}}f=f+1|0;d=v[(f<<2)+i>>2];if(d){continue}break}return 0}f=c+1|0}return f}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);n=(l|0)<1;j=4;while(1){if(!n){i=b+k|0;o=l+i|0;while(1){p=g;t[e+7|0]=0;JV(a,e+15|0,e+12|0,e+7|0);a:{if(!j){g=w[e+7|0];break a}g=w[e+7|0];c=x[e+12>>1];f=j;b:{while(1){h=c<<1;c=h&254;c:{if(c){h=(h&65534)>>>0>255;break c}if(!kf(a,e+6|0)){break b}c=w[e+6|0];h=c>>>7|0;c=c<<1&254|1}g=g<<1|h;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;m=g&255;d:{if(m>>>0<4){break d}f=7;while(1){c=f;h=c&255;if(m>>>h&1){break d}f=c-1|0;if(h>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;f=f-1^(g&254)>>>1;g=f+w[e+8|0]|0;t[e+7|0]=g;t[i|0]=g;v[e+8>>2]=((f>>1)-(p<<24>>24)|0)+(g<<24>>24<<1);Rd(e+8|0,-128,127);j=(c+j&254)>>>1|0;i=d+i|0;if(o>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function Lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(g<<1)+n>>1];j=v[a+60>>2];f=Mb(b,-16777216,16776704);k=v[a+64>>2];g=Mb(e,-16777216,16776704);i=i<<8;e=i;e=oqa(j,j>>31,e,e>>31);j=jb;k=oqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=oqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function rA(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1298260|0;while(1){e=B(d,872)+a|0;c=e+1075068|0;b:{if(v[c>>2]){break b}if(!tk(e+1074992|0)){break a}if(v[c>>2]){break b}if(w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Dd(f)){break a}if(!BP(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){d=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,872)+a|0;if(!(v[c+1075688>>2]?0:v[c+1075068>>2])){f=(v[c+1075680>>2]|v[c+1075672>>2]<<9)>>>(v[c+1075080>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075716>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075716>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=d;j=fg(a,c);te(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!j){if(nd(a,5)){break a}}l=v[e+24>>2];d=gb-48|0;gb=d;h=v[a+28>>2];yl(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>=257|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){ag(h,d+38|0);f=Kb(d+24|0);v[22708]=0;W(655,h|0,f|0,255)|0;g=v[22708];v[22708]=0;if((g|0)==1){break f}v[22708]=0;U(13,d+8|0,l|0,f|0);g=v[22708];v[22708]=0;if((g|0)==1){break e}v[22708]=0;g=Q(1516,b|0,d+38|0)|0;i=v[22708];v[22708]=0;if((i|0)==1){break d}i=g;g=d+8|0;Eb(i,g);vb(g);vb(f);f=v[d+44>>2];k=k+1|0;if(!f&k>>>0<y[d+40>>2]|f){continue}break}}gb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+8|0)}vb(f);S(a|0);L()}}Zf(a,j,c,e+16|0);gb=e+32|0}function u3(){var a=0,b=0,c=0,d=0;c=gb-32|0;gb=c;a:{a=Tb(c+16|0,12129);if(!Ab(a)){break a}b:{if((vg(a,11840)|0)!=-1){b=vg(a,11840);v[22708]=0;Y(151,c|0,a|0,b+1|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,13867)|0)!=-1){b=vg(a,13867);v[22708]=0;Y(151,c|0,a|0,b+1|0,-1);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,11157)|0)!=-1){b=vg(a,11157);v[22708]=0;Y(151,c|0,a|0,0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,11032)|0)!=-1){b=vg(a,11032);v[22708]=0;Y(151,c|0,a|0,0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((vg(a,11075)|0)!=-1){b=vg(a,11075);v[22708]=0;Y(151,c|0,a|0,0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}v[22708]=0;b=T(152,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;vb(a);S(c|0);L()}vb(a);gb=c+32|0;return b|0}function Mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[g+n|0];j=v[a+60>>2];f=Mb(b,-16777216,16776704);k=v[a+64>>2];g=Mb(e,-16777216,16776704);i=i<<16;e=i;e=oqa(j,j>>31,e,e>>31);j=jb;k=oqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=oqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Jc(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Daa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){d=Kb(c+32|0);b=v[a+24>>2];v[22708]=0;R(1960,c+16|0,b|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=Vb(b),v[e+8>>2]=f;e=c,f=Zb(b),v[e>>2]=f;if(!Gb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[22708]=0;Q(1167,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=c+8|0;tr(b);e=c,f=Zb(c+16|0),v[e>>2]=f;if(!Gb(b,c)){break b}v[22708]=0;Q(1918,d|0,11815)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(c+16|0);break d}b=V(0)|0;O()|0}vb(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=0;v[22708]=0;Y(1912,3648,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=ie(Jb(d));yd(c+16|0);vb(d)}gb=c+48|0;return b|0}function Y9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{c:{if((b|0)!=1){d=Kb(c+32|0);b=v[a+24>>2];v[22708]=0;R(1995,c+16|0,b|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=Vb(b),v[e+8>>2]=f;e=c,f=Zb(b),v[e>>2]=f;if(!Gb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[22708]=0;Q(1167,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}b=c+8|0;tr(b);e=c,f=Zb(c+16|0),v[e>>2]=f;if(!Gb(b,c)){break b}v[22708]=0;Q(1918,d|0,11815)|0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;yd(c+16|0);break d}b=V(0)|0;O()|0}vb(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=0;v[22708]=0;Y(1912,4111,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}b=ie(Jb(d));yd(c+16|0);vb(d)}gb=c+48|0;return b|0}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-32|0;gb=c;k=c,l=rL(),v[k+24>>2]=l;d=c+24|0;pL(a+24|0,be(d));Ei(d);u[a+28>>1]=0;g=eY();v[c+16>>2]=4;e=c;h=gb-16|0;gb=h;f=sf(144);j=c+16|0;i=v[j>>2];v[22708]=0;g=W(2053,f|0,g|0,i|0)|0;i=v[22708];v[22708]=0;a:{if((i|0)!=1){f=v[Xi(h+8|0,g)>>2];gb=h+16|0;break a}a=P()|0;O()|0;Xb(f);S(a|0);L()}v[e+24>>2]=f;oL(a+32|0,be(d));iq(d);k=c,l=qL(v[a>>2]),v[k+24>>2]=l;nL(a+4|0,be(d));Di(d);lo(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;k=c,l=pr(b),v[k+24>>2]=l;k=c,l=Eh(b),v[k+16>>2]=l;b:{if(og(d,j)){while(1){e=ve(c+24|0);b=gg(c,e);v[22708]=0;Y(2001,a|0,b|0,e+12|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(b);b=c+24|0;Tj(b);if(og(b,c+16|0)){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function CU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-48|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;wb(b);df(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){Yr(a,v[b+4>>2]);Ak(c+32|0,b);Sl(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=gb-80|0;gb=b;f=a;g=v[a+4>>2];d=v[c+20>>2];j=d;h=v[c+16>>2];v[b+72>>2]=h;v[b+76>>2]=d;e=v[c+12>>2];k=e;i=v[c+8>>2];v[b+64>>2]=i;v[b+68>>2]=e;v[b+24>>2]=h;v[b+28>>2]=d;v[b+16>>2]=i;v[b+20>>2]=e;d=BU(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!g){e=d-1|0;break b}e=d-1|0;if((e^g-1)>>>0<32){break a}}v[v[f>>2]+((d>>>0<33?0:e>>>5|0)<<2)>>2]=0}v[b+48>>2]=i;v[b+52>>2]=k;v[b+56>>2]=h;v[b+60>>2]=j;d=b+40|0;yp(d,f,g);f=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=f;f=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=f;WU(b+32|0,b+8|0,b,d);gb=b+80|0}gb=c+48|0;return a|0}function lN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-32|0;gb=h;l=h,m=ar(b),v[l+16>>2]=m;i=h+24|0;k=i;c=gb-32|0;gb=c;f=b;d=a;b=Yd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{g=b+16|0;e:{if(cN(d,f,g)){if(!v[b>>2]){break b}e=b;break e}if(!bN(g,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=fc(a);f=c+8|0;g=Uj(f,aX(),Vj(d+8|0,b));b=v[g>>2];v[22708]=0;j=b+16|0;b=v[22708];v[22708]=0;f:{if((b|0)!=1){b=gb-16|0;gb=b;v[b+8>>2]=v[h+16>>2];u[j>>1]=x[v[b+8>>2]>>1];Kb(j+4|0);gb=b+16|0;l=fc(g),m=1,t[l+4|0]=m;gb=d+16|0;break f}a=P()|0;O()|0;aN(g);S(a|0);L()}Gk(a,v[c+28>>2],e,v[f>>2]);b=be(f);t[c+27|0]=1;aN(f)}Wj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ve(i);gb=h+32|0;return a+4|0}function Aga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=C(0),j=C(0),k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],fd(a)),v[k>>2]=m;qc(f,c>>>2|0);c=zb(b);h=z[e+4>>2];e=v[f>>2];if(e){while(1){g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);j=C(D((l(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),q())));h=h<j?j:h;c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[f+12>>2]=j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;i=C(z[Af(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=i;a=c;i=fe(i);b:{if(C(D(i))<C(2147483648)){g=~~i;break b}g=-2147483648}k=a,m=Uc(g),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}gb=f+16|0;return v[f>>2]<<2}function Zpa(){var a=0,b=0,c=0;b=gb-16|0;gb=b;Kb(90844);a=gb-16|0;gb=a;v[a+12>>2]=0;v[22714]=v[a+12>>2];gb=a+16|0;t[90860]=0;a=gb-16|0;gb=a;v[a+12>>2]=0;v[22716]=v[a+12>>2];gb=a+16|0;v[22708]=0;a=ga(36)|0;c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[b+8>>2]=a;a=b+8|0;SX(90856,be(a));oD(a);t[90860]=0;a=0;break e}a=Ca(89104,89080)|0;c=O()|0;if((ea(89104)|0)==(c|0)){Z(a|0)|0;v[22708]=0;X(37);a=v[22708];v[22708]=0;if((a|0)==1){break c}L()}if((ea(89080)|0)!=(c|0)){break b}Z(a|0)|0;v[22708]=0;t[90860]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;break b}a=w[90860]}if(a&255){break d}v[22708]=0;_(38,90840);a=v[22708];v[22708]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}gb=b+16|0;return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break a}}kn(90864);oD(90856);vb(90844);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function H8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb+-64|0;gb=f;v[f+56>>2]=d;d=qi(a,f+56|0);g=Ah(a+4|0);h=Ah(a+24|0);i=Ah(a+32|0);j=dd(a+36|0);v[a+56>>2]=3;k=mc(a+68|0);v[22708]=0;R(2080,a|0,e|0);l=v[22708];v[22708]=0;a:{b:{c:{d:{if((l|0)!=1){v[22708]=0;bc(f+24|0,b,c);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=Ud(f+16|0);v[22708]=0;c=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=c;c=v[b+4>>2];v[f>>2]=v[b>>2];v[f+4>>2]=c;U(2084,f+32|0,f+8|0,f|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;U(2081,a|0,f+32|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}xb(f+32|0);v[22708]=0;_(2082,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;xb(f+32|0)}yd(k);Yf(j);iq(i);Ei(h);Di(g);eg(d);eg(f+56|0);S(a|0);L()}eg(f+56|0);gb=f- -64|0;return a|0}function w7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=id(v[Xg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=co(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function F7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=id(v[Xg(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=eo(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function xp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{if(!b){break a}if(c){c=ne(f+8|0,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}gb=a+16|0;break a}c=ne(f,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}gb=a+16|0}gb=f+16|0}function Gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];c=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(c){a=v[a+20>>2];h=c;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=e,j=Uc(g),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=e,j=Uc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;h=h-1|0;if(h){continue}break}}gb=d+16|0;return c<<3}function sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+32;wb(a);cP(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;f=wb(a);d=_q(a,Ae(a)+1|0);i=Ae(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=g+8|0;hf(c+12|0,f);if(d){e=d;if(d>>>0>=134217728){rd(8445);L()}e=Nc(e<<5,8)}v[c>>2]=e;f=(i<<5)+e|0;v[c+8>>2]=f;v[c+4>>2]=f;j=dc(c),k=(d<<5)+e|0,v[j>>2]=k;gb=h+16|0;cP(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;dv(a);wb(a);b=c+4|0;ol(v[a>>2],v[a+4>>2],b);wc(a,b);wc(a+4|0,c+8|0);wc(wb(a),dc(c));v[c>>2]=v[c+4>>2];dB(a,Ae(a));a=c;b=c;c=v[c+4>>2];a:{while(1){d=v[b+8>>2];if((d|0)==(c|0)){break a}v[b+8>>2]=d-32;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){nV(v[a+16>>2],b,zB(a))}gb=g+32|0}function _w(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+90032>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=ji(c,b)}return c}return a+1}function nga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;i=a;a:{b:{if(!((b|0)==(c|0)|(e|0)>-1)){t[b|0]=45;f=d;d=0-d|0;e=0-(((f|0)!=0)+e|0)|0;b=b+1|0}f=c-b|0;if((f|0)<=19){g=E(e);g=B(64-((g|0)==32?E(d|1)+32|0:g)|0,1233)>>>12|0;h=(g<<3)+27088|0;j=f;f=v[h+4>>2];if((j|0)<((g-((e|0)==(f|0)&d>>>0<y[h>>2]|e>>>0<f>>>0)|0)+1|0)){break b}}c=a;c:{if(!e&d>>>0<=99999999){a=Yx(b,d);break c}if((e|0)==2328306&d>>>0<=1874919423|e>>>0<2328306){a=rqa(d,e,1e8,0);e=jb;f=Yx(b,a);a=d-oqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=vj(vj(f,b),a-B(b,1e4)|0);break c}a=rqa(d,e,1874919424,2328306);f=jb;g=Xx(b,a);a=oqa(a,f,1874919424,2328306);b=d-a|0;a=rqa(b,e-(jb+(a>>>0>d>>>0)|0)|0,1e8,0);e=jb;f=(a>>>0)/1e4|0;d=vj(vj(g,f),a-B(f,1e4)|0);a=b-oqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=vj(vj(d,b),a-B(b,1e4)|0)}v[c>>2]=a;a=0;break a}v[a>>2]=c;a=61}v[i+4>>2]=a}function ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=gb-4112|0;gb=c;i=kb[v[v[a>>2]+116>>2]](a)|0;if(!i){kb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=gb-16|0;gb=f;h=a+44|0;if(Vf(h)){while(1){e=Gn(h,d);g=Gn(h,d);v[f+12>>2]=0;g=(g+2048|0)-e>>2;if((g|0)>=1){while(1){z[e>>2]=z[f+12>>2];e=e+4|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}d=d+1|0;if(Vf(h)>>>0>d>>>0){continue}break}}gb=f+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;qc(c+8|0,512);d=c+16|0;Wo(d);kb[v[v[a>>2]+60>>2]](a,d,f,v[c+8>>2]);e=0;d=0;if(v[c+8>>2]){while(1){e=(c+16|0)+(d<<2)|0;z[c+4>>2]=D(z[e>>2]);k=c,l=z[$y(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[e+2048>>2]);k=c,l=z[$y(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=v[c+8>>2];d=d+1|0;if(e>>>0>d>>>0){continue}break}}b=b-e|0;if(b){continue}break}}if(!i){kb[v[v[a>>2]+124>>2]](a)}gb=c+4112|0;return C(z[c+12>>2])}function O5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[tj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2303,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Vi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2304,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;sj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function L5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[tj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2303,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Vi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2305,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;sj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function H5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[tj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2303,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Vi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2307,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;sj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function F5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[tj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2303,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Vi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2308,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;sj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function D5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[tj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;Fc(c+16|0,a+d|0);d=v[22708];v[22708]=0;d:{e:{f:{if((d|0)!=1){v[22708]=0;d=T(2303,c+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}e=cj(c+8|0,a);f=Vi(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22708]=0;ka(2309,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break f}Wb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Wb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;sj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break c}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function Eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;k=f,l=ar(b),v[k+16>>2]=l;e=gb-32|0;gb=e;g=b;d=a;b=Yd(d);c=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+13|0;e:{if(Ku(g,d)){if(!v[b>>2]){break b}c=b;break e}if(!Ku(d,g)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c;c=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=c;break a}v[e+28>>2]=b;b=c;break a}b=fc(d)}v[e+28>>2]=b}g=b;b=v[b>>2];t[e+27|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);d=e+8|0;j=Uj(d,jC(),Vj(i+8|0,b));b=v[j>>2];h=gb-16|0;gb=h;v[h+8>>2]=v[f+16>>2];c=v[h+8>>2];c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+17|0]=0;t[b+13|0]=c;t[b+14|0]=c>>>8;t[b+15|0]=c>>>16;t[b+16|0]=c>>>24;gb=h+16|0;k=fc(j),l=1,t[k+4|0]=l;gb=i+16|0;Gk(a,v[e+28>>2],g,v[d>>2]);b=be(d);t[e+27|0]=1;kC(d)}Wj(f+24|0,yc(e+8|0,b),e+27|0);gb=e+32|0;gb=f+32|0;return v[f+24>>2]+17|0}function $s(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;c=v[v[a>>2]-12>>2];v[22708]=0;c=v[(a+c|0)+24>>2];b=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[22708]=0;c=Q(15,d+8|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[22708]=0;b=v[(a+b|0)+24>>2];e=v[22708];v[22708]=0;f:{if((e|0)==1){break f}v[22708]=0;b=T(2301,b|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+b|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;ll(c);break c}b=V(0)|0;O()|0;break c}ll(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jA(a,b){var c=0;c=gb-16|0;gb=c;a=nA(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Ob(a,7,1);Ob(a,9,1);Ob(a,10,1);Ob(a,13,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,20,1);Ob(a,21,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,28,1);Ob(a,30,1);Ob(a,31,1);Ob(a,33,1);Ob(a,34,1);Ob(a,39,1);Ob(a,41,1);Ob(a,44,1);Ob(a,46,1);Ob(a,45,1);Ob(a,47,1);Ob(a,48,1);Ob(a,50,1);Ob(a,99,1);Ob(a,102,1);Ob(a,104,1);Ob(a,105,1);break a;case 1:hA(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Sf(a,107);break a;case 3:hA(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Sf(a,4);break a;case 2:break b;case 0:break c}}Ob(a,88,1);break a}hA(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}gb=c+16|0}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function Iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=gb-16|0;gb=i;j=a+44|0;if(ni(j)){h=Nd(j,0);v[i+8>>2]=h;k=Nd(j,1);v[i+12>>2]=k;e=od(j,0);v[i>>2]=e;f=od(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4236>>2];r=z[a+4232>>2];s=z[a+4228>>2];t=z[a+4220>>2];u=z[a+4224>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(C(l*t)+C(u*n))+C(s*p))-C(r*o))-C(q*w));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;hc(e,g,h);hc(f,k,h)}Fi(a,b,c,od(j,0),od(j,1),d)}gb=i+16|0}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[22708]=0;_(1961,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}v[22708]=0;_(1961,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break g}f=v[a+24>>2];v[22708]=0;d=Q(70,e+16|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;c=Q(70,e|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break f}v[22708]=0;Y(2001,f|0,d|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c);vb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;vb(c)}vb(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,3466,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=e+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function YU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-80|0;gb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){h=Ud(d+72|0);f=b-e|0;b=$u(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Sl(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}wb(a);b=av(d+56|0);e=v[a+4>>2];v[22708]=0;e=Q(832,a|0,e+f|0)|0;g=v[22708];v[22708]=0;c:{if((g|0)==1){break c}v[22708]=0;R(833,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;Ak(d+40|0,a);Sl(d+32|0,a);e=d+24|0;Ak(e,b);v[22708]=0;g=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=g;g=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=g;Y(834,d+48|0,d+8|0,d|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;SB(a,b);De(b);break b}a=P()|0;O()|0;De(b);S(a|0);L()}v[a+4>>2]=b;break a}xp(ne(d+16|0,h),f,c)}gb=d+80|0}function TY(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+28528|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function Q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=gb-32|0;gb=i;a:{b:{c:{if((b|0)!=(c|0)){j=v[115189];v[115189]=0;g=gb-16|0;gb=g;ye();e=gb-16|0;gb=e;f=gb-16|0;gb=f;Tx(f,b,i+28|0,2);k=v[f>>2];h=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=h;gb=f+16|0;h=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=h;v[g+4>>2]=f;gb=e+16|0;h=v[g>>2];f=v[g+4>>2];e=v[g+12>>2];b=i;v[b+16>>2]=v[g+8>>2];v[b+20>>2]=e;v[b+8>>2]=h;v[b+12>>2]=f;gb=g+16|0;h=v[b+16>>2];f=v[b+20>>2];g=v[b+8>>2];e=v[b+12>>2];b=v[115189];if(!b){break c}if(v[i+28>>2]!=(c|0)){break b}l=g;m=e;n=h;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115189]=j;if(v[i+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;h=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=h;v[a+12>>2]=f;gb=i+32|0}function yq(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=oqa(b,d,5e4,0);e=jb;b=v[Mc(c+8|0,c)>>2];b=Ac(pqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=oqa(v[a+1074420>>2],0,oqa(v[a+1074408>>2],0,v[a+1074416>>2],0),jb),v[g>>2]=h;v[c+4>>2]=jb;d=gb-16|0;gb=d;e=c+8|0;f=rw(e,c);gb=d+16|0;d=oqa(b,0,6e5,0);b=f?c:e;b=rqa(d,jb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=oqa(b,d,1e4,0);e=jb;b=v[Mc(c+8|0,c)>>2];b=Ac(pqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=oqa(a,a>>31,b,b>>31)+32768|0;a=jb;a=Ac(pqa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[d>>2]=a?a:1;gb=c+16|0}function jaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1981,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1982,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18720;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,9165,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1983,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1982,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18720;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,9133,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function haa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1984,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1982,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18720;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,9071,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1985,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1982,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18720;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,9101,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function faa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1986,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1982,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18720;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,9036,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1987,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break i}if(Ec(d)>>>0<2147483647){break h}c=ba(8)|0;v[22708]=0;Q(1982,c|0,4473)|0;b=v[22708];v[22708]=0;if((b|0)==1){break g}v[22708]=0;U(186,c|0,89452,206);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18720;j:{if((b|0)<0){break j}if((Ec(d)|0)<=(b|0)){break j}a=Jb(Ad(d,b))}b=ie(a);yd(d);break d}b=V(0)|0;O()|0;da(c|0)}yd(d)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,9197,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function zy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Ym(ee(A[Wg(a,c,f)>>3]*134217728));i=Ay(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function wy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Ym(ee(A[Wg(a,c,f)>>3]*134217728));i=xy(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function Om(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-16|0;gb=f;if(e){v[e>>2]=0}i=a+484344|0;a:{if(!me(i,b)){break a}d=Xc(_b(i,b),c,d);g=w[d+5|0];b:{c:{d:{e:{h=w[d+3|0];switch(h-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(h-35>>>0>=2){break a}}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[f+12>>2]=2;j=0}m=f,n=v[_b(i,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;a=v[Fb(f+8|0,f+12|0)>>2];f:{g:{h:{i:{if(a){c=0;k=a;j:{while(1){d=B(Ki(_b(i,b)),6)+d|0;if(w[d+3|0]!=34){break j}l=g<<8;g=w[d+5|0]|(j?g>>>0<256?l+-8192|0:l:l);c=c+1|0;k=k-1|0;if(k){continue}break}c=a}if((h|0)!=35){break i}break h}c=0;if((h|0)==35){break g}}if((h|0)!=36){break f}}if(c){break f}}g=g<<8;c=0}if(!e){break a}v[e>>2]=c}gb=f+16|0;return g|0}function iJ(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=gb-96|0;gb=e;if((d|0)>=1){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){j=(e+48|0)+(f<<3)|0;h=(f<<4)+a|0;i=z[h+4>>2];g=z[h+8>>2];z[j+4>>2]=i+g;k=f<<1;z[(8-k<<2)+e>>2]=i-g;i=z[h+16>>2];g=z[h+12>>2];z[(7-k<<2)+e>>2]=i-g;z[j+8>>2]=-C(i+g);f=f+1|0;if((f|0)!=4){continue}break}hJ(e+48|0);hJ(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];h=0;while(1){f=h<<2;j=f+b|0;i=z[j>>2];g=z[f+(e+48|0)>>2];l=z[f+68176>>2];m=z[f+68212>>2];n=z[e+f>>2];z[j>>2]=C(g*l)-C(m*n);j=a+f|0;f=c+f|0;g=C(C(g*m)+C(n*l));z[j>>2]=C(i*z[f>>2])-C(g*z[f+36>>2]);z[(17-h<<2)+a>>2]=C(i*z[f+36>>2])+C(g*z[f>>2]);h=h+1|0;if((h|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}gb=e+96|0}function EL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=gb+-64|0;gb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[22708]=0;v[j+20>>2]=d?d:1920;a=Q(1921,j+20|0,j+60|0)|0;b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+24>>2]=a;a=v[jq(j+32|0,j+24|0)>>2];b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;v[22708]=0;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+za(1922,j|0,+c,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}Dj(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Dj(j+24|0)}Z(a|0)|0;v[22708]=0;ja(1923,12246,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}gb=j- -64|0;return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Sw(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+60>>2]=d;a:{f=v[b>>2];b:{if(!(kb[v[v[f>>2]+36>>2]](f,c,d)|0)){KF(a);break b}gm(e+40|0,b);v[22708]=0;b=v[b>>2];d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[22708]=0;b=T(d|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;v[e+36>>2]=b-c;b=Fb(e+60|0,e+36|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}g=v[b>>2];b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;b=gb-16|0;gb=b;d=e+16|0;f=gm(b+8|0,d);v[22708]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;Y(221,e+48|0,b|0,c|0,g|0);c=v[22708];v[22708]=0;c:{if((c|0)!=1){Kd(d);gb=b+16|0;break c}a=P()|0;O()|0;Kd(d);S(a|0);L()}b=Ud(e+24|0);c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;Gw(a,e+8|0,e)}gb=e- -64|0;return}a=P()|0;O()|0;Kd(e+40|0);S(a|0);L()}function Qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);while(1){if((m|0)>=1){j=(k<<1)+b|0;o=j+(m<<1)|0;while(1){u[e+10>>1]=0;KV(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{if(!i){g=x[e+10>>1];break a}g=x[e+10>>1];c=x[e+12>>1];h=i;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){f=(f&65534)>>>0>255}else{if(!kf(a,e+9|0)){break a}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}g=f|g<<1;h=h-1|0;if(h&255){continue}break}}c=1;f=g&65535;b:{if(f>>>0<4){break b}h=15;while(1){c=h;n=c&255;if(f>>>n&1){break b}h=c-1|0;if(n>>>0>1){continue}break}}i=(c+i&254)>>>1|0;t[e+15|0]=i;c=g&1;t[e+14|0]=c;l=(c-1^(g&65534)>>>1)+l|0;u[e+10>>1]=l;u[j>>1]=l;j=(d<<1)+j|0;if(o>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function RF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[22708]=0;g=Q(15,d+24|0,a|0)|0;e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=cj(d+8|0,a);f=v[v[a>>2]-12>>2];h=v[(f+a|0)+4>>2];v[22708]=0;f=a+f|0;i=T(16,f|0)|0;j=v[22708];v[22708]=0;if((j|0)==1){break d}e=v[e>>2];v[22708]=0;c=b+c|0;b=la(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Zv(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+b|0,5);b=v[22708];v[22708]=0;if((b|0)!=1){break e}break d}ll(g);break b}b=V(0)|0;O()|0;ll(g);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}$()}gb=d+32|0;return a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){V(0)|0;O()|0;Bb();L()}S(a|0);L()}function lH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;h=gb-1040|0;gb=h;i=v[b>>2];v[h+12>>2]=i;g=a?d:256;j=a?a:h+16|0;d=0;a:{b:{c:{if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(f>>>0<g>>>0?c>>>0<=131:0){break b}while(1){f=k?g:f;c=c-f|0;f=Ax(j,h+12|0,f,e);if((f|0)==-1){g=0;i=v[h+12>>2];d=-1;break c}i=(h+16|0)==(j|0)?0:f;g=g-i|0;j=(i<<2)+j|0;d=d+f|0;i=v[h+12>>2];if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(c>>>0>131|f>>>0>=g>>>0){continue}break}break b}if(!i){break a}}if(!g|!c){break a}f=d;while(1){d:{d=$p(j,i,c,e);e:{if(d+2>>>0<=2){f:{switch(d+1|0){case 1:v[h+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}i=v[h+12>>2]+d|0;v[h+12>>2]=i;f=f+1|0;g=g-1|0;if(g){break d}}d=f;break a}j=j+4|0;c=c-d|0;d=f;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}gb=h+1040|0;return d|0}function vK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;v[f+12>>2]=c;a:{if(!b){a=a+120|0;fo(a);c=v[f+12>>2];b=a;d=vh(b);b:{if(!c){break b}v[22708]=0;R(2113,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;At(b,c);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Cy(d);S(a|0);L()}t[a+20|0]=0;break a}d=gb-16|0;gb=d;v[d+12>>2]=c;c:{if((b|0)==1){b=a+120|0;fo(b);fK(b,a,d+12|0);t[b+20|0]=1;break c}e=gb-16|0;gb=e;v[e+12>>2]=c;d:{if((b|0)==2){a=a+120|0;fo(a);c=v[e+12>>2];b=a;g=b;h=vh(b);e:{if(!c){break e}v[22708]=0;R(2115,g|0,c|0);i=v[22708];v[22708]=0;if((i|0)!=1){v[22708]=0;At(g,c);c=v[22708];v[22708]=0;if((c|0)!=1){break e}}a=P()|0;O()|0;Cy(h);S(a|0);L()}Ud(b+12|0);t[a+20|0]=2;break d}b=gb-16|0;gb=b;v[b+12>>2]=c;c=a+120|0;fo(c);fK(c,a,b+12|0);t[c+20|0]=3;gb=b+16|0}gb=e+16|0}gb=d+16|0}gb=f+16|0}function kk(a,b){var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;d=v[v[a>>2]-12>>2]+a|0;f=v[d+16>>2]&-3;mo(d,f);a:{b:{if(w[tj(c+56|0,a,1)|0]){d=v[v[a>>2]-12>>2];v[22708]=0;d=v[(a+d|0)+24>>2];e=v[22708];v[22708]=0;c:{d:{if((e|0)==1){break d}v[22708]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;Y(2313,c+40|0,d|0,c+8|0,8);b=v[22708];v[22708]=0;if((b|0)==1){break d}b=sh(c+24|0,-1,-1);v[22708]=0;b=FJ(c+40|0,b);d=v[22708];v[22708]=0;if((d|0)==1){break d}b=b?f|4:f;break c}b=V(0)|0;O()|0;Z(b|0)|0;b=f|1;sj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,b)}gb=c- -64|0;return}V(0)|0;O()|0;Bb()}L()}function nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;ud(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;g=c,h=w[ac(e,d)|0]<<2,u[g+30>>1]=h;f=b+14|0;v[c+24>>2]=(w[f|0]|w[f+1|0]<<8)<<1;Lk(d,2,b+1|0);Bc(e,d);v[22708]=0;Q(303,c+43|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){vb(d+16|0);e=Rc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}Yi(e,16);Cf(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;l=g,m=cX(b),v[l+16>>2]=m;i=g+24|0;k=i;c=gb-32|0;gb=c;d=b;e=a;b=Yd(a);f=fc(a);a:{b:{if(b){e=wb(e);c:{while(1){d:{h=b+16|0;e:{if(LC(e,d,h)){if(!v[b>>2]){break b}f=b;break e}if(!KC(h,d)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=f;break a}v[c+28>>2]=b;b=f;break a}b=fc(e)}v[c+28>>2]=b}f=b;b=v[b>>2];t[c+27|0]=0;if(!b){e=gb-16|0;gb=e;b=fc(a);d=c+8|0;j=Uj(d,aX(),Vj(e+8|0,b));h=v[j>>2]+16|0;b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];u[h>>1]=x[v[b+8>>2]>>1];Kb(h+4|0);gb=b+16|0;l=fc(j),m=1,t[l+4|0]=m;gb=e+16|0;Gk(a,v[c+28>>2],f,v[d>>2]);b=be(d);t[c+27|0]=1;a=v[d>>2];v[d>>2]=0;if(a){if(w[fc(d)+4|0]){Fk(a+16|0)}if(a){$W(a)}}}Wj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ve(i);gb=g+32|0;return a+4|0}function nZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Sr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Sr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Hu(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}gb=d+16|0}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((Vf(a)|0)==(b|0)){if((Vf(a+12|0)|0)==(c|0)){break b}}v[22708]=0;R(1535,a|0,b|0);d=v[22708];v[22708]=0;c:{d:{if((d|0)==1){break d}v[22708]=0;e=a+12|0;R(1535,e|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;f=a+24|0;R(1536,f|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;g=a+36|0;R(1536,g|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=Gn(a,d);i=Lb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;XM(a);WM(a);b=a+12|0;XM(b);WM(b);b=a+24|0;Fg(b);VM(b);a=a+36|0;Fg(a);VM(a);$();return 0}a=0;while(1){b=Gn(e,a);i=Lb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=v[Xg(a,c,f)>>2];i=Ay(g,c,f),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function kW(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-48|0;gb=b;f=b,g=Yb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[f+8>>2]=g;v[b+12>>2]=0;f=b,g=Yb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[f+16>>2]=g;v[b+20>>2]=0;d=b;c=b;if(Yb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))){e=Yb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))}else{e=52}v[c+24>>2]=e;v[d+28>>2]=0;a=Yb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24));v[b+44>>2]=4;v[b+32>>2]=a+80;v[b+36>>2]=0;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;d=gb-16|0;gb=d;a=v[b>>2];e=v[b>>2]+(v[b+4>>2]<<3)|0;a:{if((a|0)==(e|0)){break a}c=a+8|0;if((e|0)==(c|0)){break a}while(1){a=rw(a,c)?c:a;c=c+8|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0;gb=b+48|0;b=v[a>>2];d=b-52|0;jb=v[a+4>>2]-(b>>>0<52)|0;return d}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;f=c+32|0;Zc(b,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));h=dd(a);f=c+28|0;a=f;e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=0;v[22708]=0;R(1424,h|0,e|0);e=v[22708];v[22708]=0;if((e|0)!=1){a:{e=f;b:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break b}e=c+4|0;while(1){v[22708]=0;c=Q(191,b|0,4)|0;i=v[22708];v[22708]=0;if((i|0)==1){break a}if(!c){break b}c=w[e|0]|w[e+1|0]<<8;v[22708]=0;c=Q(1425,b|0,c|0)|0;i=v[22708];v[22708]=0;c:{if((i|0)!=1){v[g+12>>2]=c;if(Ec(d)>>>0<=c>>>0){break c}v[22708]=0;R(1426,h|0,g+12|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}}break a}a=a+1|0;c=f;if(a>>>0<(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){continue}break}}gb=g+16|0;return}}a=P()|0;O()|0;Lc(h);S(a|0);L()}function vt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Xg(a,c,f);i=xy(g,c,f),j=C(C(v[h>>2])*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,36,5889);L()}aa(2989,6176,35,5889);L()}aa(4211,6176,34,5889);L()}aa(4246,6176,33,5889);L()}gb=b- -64|0}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb+-64|0;gb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((Si(Sb(v[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}f=x[sc(Sb(v[e>>2]+484360|0),b)>>1];c:{if(!am(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074448>>1]=b;c=b&65535;LO(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=d+48|0;su(b,e,f?7:1,d);h=a,i=A[GO(b)>>3],A[h+16>>3]=i;dn(b);a=a+16|0}gb=d- -64|0;return+A[a>>3]}function O3(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22708]=0;R(99,c+32|0,b|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22708]=0;d=ga(79)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Wb(c+8|0);v[22708]=0;b=EN(a);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;b=Q(105,b|0,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22708]=0;b=El(b+d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[c+32>>2];vf(a);gb=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;vf(a)}S(b|0);L()}return a|0}function ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;ud(b,4);u[b+30>>1]=w[a+12|0]<<2;yg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Tb(d,18720);v[22708]=0;Q(303,b+43|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){vb(a);gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function d8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=mc(a);f=b+24|0;a=v[f>>2];v[22708]=0;a=oq(a+484344|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)==1){break c}v[22708]=0;R(1421,e|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[22708]=0;c=oq(c+484344|0);g=v[22708];v[22708]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[22708]=0;R(2099,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;U(2093,d+16|0,b|0,d|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;R(1423,e|0,d+16|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}a=a+1|0;vb(d+16|0);vb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+16|0)}vb(d);break a}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Uc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=fe(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Uc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<3}function W8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=gb-16|0;gb=g;v[g+12>>2]=c;c=gb+-64|0;gb=c;m=c;j=c+16|0;k=gb-16|0;gb=k;n=fU(k+8|0);while(1){e=b;h=gb+-64|0;gb=h;d=n;f=v[d+4>>2]-v[d>>2]|0;a:{if(!f){d=v[d>>2];break a}f=f+1|0;if(!f){d=rK(sK(h+8|0,e,32));break a}i=e;e=E(f);e=sK(h+8|0,i,(f&-1>>>e+1?32:31)-e|0);while(1){i=rK(e);if(f>>>0<=i>>>0){continue}break}d=v[d>>2]+i|0}gb=h- -64|0;o=yf(j,l),p=d,v[o>>2]=p;l=l+1|0;if((l|0)!=12){continue}break}gb=k+16|0;d=oU(m,j,tU(j));v[22708]=0;b=a;OB(b,d,0);e=v[22708];v[22708]=0;b:{if((e|0)!=1){Lc(d);gb=c- -64|0;break b}a=P()|0;O()|0;Lc(d);S(a|0);L()}c=b+120|0;qK(c,b,g+12|0);t[c+20|0]=1;v[22708]=0;R(2108,b|0,v[g+12>>2]);b=v[22708];v[22708]=0;c:{if((b|0)!=1){gb=g+16|0;break c}a=P()|0;O()|0;fo(c);S(a|0);L()}return a|0}function ZM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-16|0;gb=d;a:{if(Nb(a)>>>0>511){break a}if(!_f(v[v[b>>2]-12>>2]+b|0)){break a}j=d;g=b;h=c;f=gb-16|0;gb=f;e=sf(64);v[22708]=0;i=T(1316,e|0)|0;k=v[22708];v[22708]=0;b:{c:{if((k|0)!=1){e=ns(f,i);i=v[e>>2];v[22708]=0;g=W(1530,i|0,g|0,h|0)|0;h=v[22708];v[22708]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}bA(f+8|0);break d}a=P()|0;O()|0;Ig(e);break c}qi(f+8|0,e)}Ig(e);gb=f+16|0;g=v[f+8>>2];break b}a=P()|0;O()|0;Xb(e)}S(a|0);L()}v[j+8>>2]=g;f:{g:{if(!Dd(d+8|0)){v[22708]=0;b=Q(1528,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break g}v[d>>2]=b;fX(d+8|0,be(d));Ig(d)}if(!Dd(d+8|0)){break f}b=d+8|0;l=v[b>>2];v[22708]=0;R(1529,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;Ig(d+8|0);S(a|0);L()}Ig(d+8|0)}gb=d+16|0;return l}function oH(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Dx(11159);if(w[b|0]?b:0){break a}b=Dx(B(a,12)+79456|0);if(w[b|0]?b:0){break a}b=Dx(11406);if(w[b|0]?b:0){break a}b=11948}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=11948;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!wj(d,11948)){break e}if(wj(d,10840)){break d}}if(!a){c=74820;if(w[d+1|0]==46){break c}}return 0}c=v[115995];if(c){while(1){if(!wj(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[115995];if(c){while(1){if(!wj(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=Cd(28);g:{if(!c){c=0;break g}v[c+4>>2]=20;v[c>>2]=74800;b=c+8|0;hc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[115995];v[115995]=c}c=a|c?c:74820}return c}function qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;m=g,n=ar(b),v[m+16>>2]=n;j=g+24|0;l=j;d=gb-32|0;gb=d;f=b;c=a;b=Yd(c);e=fc(c);a:{b:{if(b){wb(c);c:{while(1){d:{c=b+14|0;e:{if(bP(f,c)){if(!v[b>>2]){break b}e=b;break e}if(!bP(c,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=fc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){i=gb-16|0;gb=i;b=fc(a);f=d+8|0;k=Uj(f,jC(),Vj(i+8|0,b));b=v[k>>2];c=gb-16|0;gb=c;v[c+8>>2]=v[g+16>>2];h=v[c+8>>2];h=x[h>>1]|x[h+2>>1]<<16;u[b+18>>1]=0;u[b+14>>1]=h;u[b+16>>1]=h>>>16;gb=c+16|0;m=fc(k),n=1,t[m+4|0]=n;gb=i+16|0;Gk(a,v[d+28>>2],e,v[f>>2]);b=be(f);t[d+27|0]=1;kC(f)}Wj(l,yc(d+8|0,b),d+27|0);gb=d+32|0;a=Wl(j);gb=g+32|0;return a+4|0}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;t[e+15|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);o=(m|0)<1;j=4;while(1){if(!o){i=b+k|0;p=m+i|0;while(1){t[e+11|0]=0;JV(a,e+15|0,e+12|0,e+11|0);a:{if(!j){h=w[e+11|0];break a}h=w[e+11|0];c=x[e+12>>1];f=j;b:{while(1){g=c<<1;c=g&254;c:{if(c){g=(g&65534)>>>0>255;break c}if(!kf(a,e+10|0)){break b}c=w[e+10|0];g=c>>>7|0;c=c<<1&254|1}h=h<<1|g;f=f-1|0;if(f&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}c=1;g=h&255;d:{if(g>>>0<4){break d}f=7;while(1){c=f;n=c&255;if(g>>>n&1){break d}f=c-1|0;if(n>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&254)>>>1)+l|0;t[e+11|0]=l;t[i|0]=l;j=(c+j&254)>>>1|0;i=d+i|0;if(p>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function Ky(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;wq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=mg(g+32|0,c,eL(c),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;zt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=56252;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=55456;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Gt(c,v[Tk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function Jy(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;wq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=mg(g+32|0,c,eL(c),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;zt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=57096;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=56332;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Gt(c,v[Tk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function AW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}yW(g+15|0,g+13|0);yW(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}pz(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){so(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(to(c)>>>0<=to(w[g+14|0])>>>0){break b}gi(g+15|0,g+14|0);gi(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];gb=g+16|0}function zma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-528|0;gb=d;c=-1;a:{if(!Wf(a,1468)){break a}Ul(a,1464);b=d+524|0;FV(a,b);if(!je(b,33202)){c=0;if(!je(d+524|0,12629)){break a}}Ul(a,20);b=1;while(1){c=-1;if(!CV(a,d)){break a}e=eC(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;f=e;c=gb-32|0;gb=c;b=a;b:{if(!Wf(b,2)){t[c+16|0]=0;hE(f,c+16|0);break b}An(c+24|0,f);f=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=f;YB(c+16|0,b,c+8|0)}gb=c+32|0;f=qd(e);c=0;if(w[e|0]>128){break a}b=d;c=gb-32|0;gb=c;c:{if(!Wf(a,512)){kV(b);break c}Rv(c+24|0,b);e=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=e;YB(c+16|0,a,c+8|0)}gb=c+32|0;a=d+512|0;c=w[f|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}gb=d+528|0;return c|0}function dpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-304|0;gb=e;Se(b);if(Pb(a,1)){a:{while(1){d=e+48|0;td(e+24|0,d,d+256|0);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;d=gb-48|0;gb=d;f=v[a>>2];i=v[a+8>>2];g=v[e+12>>2];h=v[e+8>>2];v[d+16>>2]=h;v[d+20>>2]=g;v[d+24>>2]=h;v[d+28>>2]=g;rh(d+32|0,d+16|0);g=v[v[f>>2]+28>>2];h=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=h;kb[g|0](d+40|0,f,i,d+8|0);f=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=f;f=e+32|0;rh(f,d);gb=d+48|0;j=e,k=yb(f),v[j+44>>2]=k;j=e,k=c-Ab(b)|0,v[j+20>>2]=k;d=v[Fb(e+44|0,e+20|0)>>2];if(!d){break a}t[e+32|0]=0;h=d;d=e+48|0;g=h+d|0;i=e+32|0;f=Vm(d,g,i);j=e,k=ef(b),v[j+32>>2]=k;Gd(e+16|0,i);OX(b,v[e+16>>2],d,f);Rb(a,f-d|0);if(f>>>0>=g>>>0){continue}break}Rb(a,1)}d=(Ab(b)|0)!=0}gb=e+304|0;return d|0}function Cj(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-48|0;gb=f;d=a+24|0;g=v[v[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|v[v[d>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}rO(v[d>>2],1);break a}e=f+8|0;hc(e,v[d>>2]+24604|0,40);h=v[e+32>>2];i=v[e+36>>2];v[f+28>>2]=c;v[f+24>>2]=b;It(e,h);Ko(e,i);Wz(v[d>>2],e);if((b|0)==(g|0)){break a}b=v[d>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break b}kb[v[v[b>>2]+108>>2]](b,0);kb[v[v[b>>2]+96>>2]](b);kb[v[v[b>>2]+124>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}b=v[d>>2];d=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(kb[v[v[b>>2]+116>>2]](b)|0){break c}kb[v[v[b>>2]+108>>2]](b,1);kb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}t[a+29|0]=1;gb=f+48|0}function On(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;h=a;a=gb-16|0;gb=a;i=a;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);j=Ab(d);k=v[b>>2];v[22708]=0;wu(e+8|0,c,f+j|0,k);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=xf(e+4|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,i|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(85,h|0,a|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=g+16|0}function Nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;c=Ki(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((Jg(a)|0)!=(c|0)){break b}b=gb-16|0;gb=b;c=Vb(a);d=Zb(a);hi(b+8|0);a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=c;d=Wt(a,a+8|0);g=gb-16|0;gb=g;v[g+8>>2]=c;if((d|0)>=1){while(1){h=g+8|0;c=v[h>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=(d|0)>1;ak(h);d=d-1|0;if(c){continue}break}}gb=g+16|0;gb=a+16|0;gb=b+16|0;break a}d=f+8|0;hi(d);c=oX(f+16|0,c,d);BN(a);kp(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[wb(c)>>2];i=wb(a),j=d,v[i>>2]=j;i=wb(c),j=0,v[i>>2]=j;v[c>>2]=0;v[c+4>>2]=0;hn(c);v[a+12>>2]=b}a=1}else{a=0}gb=f+32|0;return a|0}function z7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=A[Wg(a,c,f)>>3];i=Ay(g,c,f),j=C(h),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function q7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Lf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Kf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Wg(a,c,f);i=xy(g,c,f),j=C(A[h>>3]),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}aa(2959,6176,80,5856);L()}aa(2989,6176,79,5856);L()}aa(4211,6176,78,5856);L()}aa(4246,6176,77,5856);L()}gb=b- -64|0}function xja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;gb=e+32|0}function vV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0>32768){break a}h=Ib(w[d+42|0]|w[d+43|0]<<8)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function O8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-96|0;gb=d;v[22708]=0;f=v[b+12>>2];v[d+40>>2]=v[b+8>>2];v[d+44>>2]=f;f=v[b+4>>2];v[d+32>>2]=v[b>>2];v[d+36>>2]=f;f=T(2076,d+32|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){a:{b:{if(f){v[22708]=0;R(2077,d+72|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=d+80|0;f=d+72|0;Fw(b,f);e=Xf(d+88|0,b);g=Xf(d- -64|0,c);h=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=h;e=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=e;Gw(a,d+8|0,d);break b}break a}v[22708]=0;R(2078,d+72|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=d+80|0;f=d+72|0;Fw(b,f);e=Xf(d+56|0,b);g=Xf(d+48|0,c);h=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=h;e=v[g+4>>2];v[d+16>>2]=v[g>>2];v[d+20>>2]=e;Gw(a,d+24|0,d+16|0)}Kd(b);Kd(f);Kd(c);gb=d+96|0;return}}a=P()|0;O()|0;Kd(c);S(a|0);L()}function nO(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-1;a:{if(!Oz(a,b,2)){break a}i=v[b+656>>2];d=e+8|0;f=a+1074312|0;Db(d,f,31);b:{if(Cb(d)){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}h=e+8|0;Db(h,f,31);f=d-Cb(h)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Vq(i+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+746|0]&16){g=Jq(a,b,!(v[b+88>>2]&32768),d);break a}if(Kj(b)){if((d|0)==u[b+772>>1]){break a}j=b,k=Uc(d),u[j+772>>1]=k;t[b+851|0]=w[b+851|0]|32;break a}b=sk(a);v[e+8>>2]=d;f=c;c:{if((d|0)<=-1){v[e+8>>2]=0-d;ck(e+8|0,255);a=(v[e+8>>2]<<2)+(b?44608:43584)|0;break c}ck(e+8|0,255);a=(v[e+8>>2]<<2)+(b?43584:44608)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];j=f,k=Ac(pqa(oqa(b,d,a,a>>31),jb,65536,0),jb),v[j>>2]=k}gb=e+16|0;return g}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];j=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){k=0;e=b;g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=g<<24|h>>>8;e=0;l=f&65280;f=e;e=g<<8|h>>>24;f=f|k;k=e&255|l|(h<<24|h<<8&16711680);v[d+24>>2]=((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24)|f;v[d+28>>2]=k;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;i=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=i;e=a;i=ee(i);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}m=e,n=Uc(f),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return j<<3}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){g=Jb(d);i=Jb(d);j=Ab(d);k=v[b+4>>2];c=v[b>>2];v[22708]=0;Pa(78,e+8|0,g|0,i+j|0,c|0,k|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=xf(e+4|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(72,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Qp(a){var b=C(0),c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=ti(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-ti(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=ui(f+1.5707963267948966);break a}b=ui(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=ti(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=ui(-4.71238898038469-+a);break a}b=ui(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch($x(a,c+8|0)&3){case 0:b=ti(A[c+8>>3]);break a;case 1:b=ui(-A[c+8>>3]);break a;case 2:b=C(-ti(A[c+8>>3]));break a;default:break b}}b=ui(A[c+8>>3])}a=b;gb=c+16|0;return a}function mN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=C(0);f=gb-16|0;gb=f;g=u[d>>1];e=u[d+2>>1];if(!(!x[b>>1]|(g|0)>(e|0)|(!(z[c>>2]>C(0))|(e-g|0)>32766))){u[a>>1]=3;h=a+4|0;Fg(h);u[a+28>>1]=65472;v[f+12>>2]=1065353216;oN(h,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Fg(a+16|0);u[a+28>>1]=x[d>>1];g=a;e=gb-16|0;gb=e;u[e+14>>1]=x[b>>1];v[22708]=0;u[e+12>>1]=32767;b=Pc(e+14|0,e+12|0);j=v[22708];v[22708]=0;a:{if((j|0)!=1){gb=e+16|0;b=u[b>>1];break a}V(0)|0;O()|0;Bb();L()}u[g+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=oe(i,C(C(1)/C(u[a+30>>1])));j=1;Dl(h,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){k=oe(i,C(b|0));l=Lb(h,b-u[a+28>>1]|0),m=k,z[l>>2]=m;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}nq(a)}gb=f+16|0;return j|0}function Gi(a,b,c,d){var e=0,f=0,g=0,h=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=50140;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;h=dd(b);f=dd(b+12|0);g=dd(b+24|0);e=dd(b+36|0);v[22708]=0;W(1533,b|0,2,0)|0;d=v[22708];v[22708]=0;if((d|0)==1){a=P()|0;O()|0;Lc(e);Lc(g);Nt(f);Nt(h);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;u[a+4204>>1]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[22708]=0;e=T(1633,a+92|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){v[c>>2]=e;g=v[a+20>>2];f=v[a+16>>2];b=w[a+4200|0];if(!((g|0)==((f+B(b,160)|0)+906300|0)|b>>>0>248)){e=a+4200|0;while(1){c=b+1|0;if((g|0)!=((f+B(c,160)|0)+906300|0)){d=b>>>0<248;b=c;if(d){continue}}break}t[e|0]=c}return a}a=P()|0;O()|0;DM(b);S(a|0);L()}function BL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);d=Ab(b);h=Jb(c);i=Ab(c);g=d+f|0;d=-1;a:{while(1){if((f|0)==(g|0)){break a}g=g-1|0;if(sp(h,i,g)){continue}break}d=g-f|0}b:{c:{if((d|0)!=-1){k=e,l=zd(b),v[k+16>>2]=l;k=e,l=xe(e+16|0,d),v[k+24>>2]=l;k=e,l=xe(e+24|0,1),v[k+32>>2]=l;c=Gd(e+40|0,e+32|0);k=e,l=ef(b),v[k>>2]=l;d=Gd(e+8|0,e);bG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}i=Jb(b);f=Ab(b);d=Jb(c);c=Ab(c);if(!c|!f){c=-1}else{g=d;j=c+d|0;d=i;f=f+d|0;d:{if((d|0)==(f|0)){break d}c=f;while(1){h=g;if((j|0)!=(g|0)){while(1){if(kb[26](t[d|0],t[h|0])|0){break d}h=h+1|0;if((j|0)!=(h|0)){continue}break}}d=d+1|0;if((c|0)!=(d|0)){continue}break}d=c}c=(d|0)==(f|0)?-1:d-i|0}if(c){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;gb=e+32|0}function pZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-208|0;gb=e;d=a;if(!Xv(c,a)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0}RD(c,e+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=e;d=gb-16|0;gb=d;v[d+12>>2]=64;v[22708]=0;v[d+8>>2]=255;f=Fb(d+12|0,d+8|0);g=v[22708];v[22708]=0;b:{if((g|0)!=1){gb=d+16|0;d=w[f|0];break b}V(0)|0;O()|0;Bb();L()}t[c+12|0]=d;kh(b,w[ac(a+4|0,e+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Nb(b)){break a}a=0;while(1){if(a){c=x[Lb(b,a-1|0)>>1];v[e+12>>2]=1;d=(e+16|0)+B(a,3)|0;v[e+8>>2]=(t[d+1|0]&1)<<8|w[d|0];d=x[If(e+12|0,e+8|0)>>1];h=Lb(b,a),i=c+d|0,u[h>>1]=i}c=w[((e+16|0)+B(a,3)|0)+2|0];h=Lb(b,a),i=c,t[h+2|0]=i;a=a+1|0;if(Nb(b)>>>0>a>>>0){continue}break}}gb=e+208|0}function Bo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=v[b+88>>2];c=e|2048;v[b+88>>2]=c;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){c=e|6144;v[b+88>>2]=c}a:{if(!v[b+76>>2]){break a}b:{if(!(c&8)){break b}d=v[b+104>>2];if(!d|e&2048){break b}e=x[d+34>>1];if(e&2){v[b+88>>2]=(e&4?c|4:c&-135)|2;c=v[d>>2];v[b+76>>2]=c;e=v[d+4>>2];v[b+80>>2]=e;d=v[d+8>>2];v[b+84>>2]=d;if(c>>>0>d>>>0){v[b+76>>2]=d;g=d}else{g=c}c=v[b+4>>2];if(g>>>0>=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=((c-e>>>0)%(d-e>>>0)|0)+e;break b}v[b+88>>2]=c&-135;v[b+76>>2]=v[d>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}a=f+48|0;h=b,i=Uc(Vq(a,v[b+724>>2],256,64)),u[h+728>>1]=i;h=b,i=x[Lb(a,w[f+65|0])>>1],v[h+724>>2]=i}}function sG(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=ui(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=C(-ti(d+1.5707963267948966));break a}a=ti(d+-1.5707963267948966);break a}a=ui(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=ti(d+4.71238898038469);break a}a=C(-ti(d+-4.71238898038469));break a}a=ui(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch($x(a,b+8|0)&3){case 0:a=ui(A[b+8>>3]);break a;case 1:a=ti(A[b+8>>3]);break a;case 2:a=ui(-A[b+8>>3]);break a;default:break b}}a=C(-ti(A[b+8>>3]))}gb=b+16|0;return a}function kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=f>>>21&2040;l=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;m=g,n=cX(b),v[m+16>>2]=n;i=g+24|0;k=i;c=gb-32|0;gb=c;f=b;d=a;b=Yd(d);e=fc(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+14|0;e:{if(LC(d,f,h)){if(!v[b>>2]){break b}e=b;break e}if(!KC(h,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=fc(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=fc(a);f=c+8|0;j=Uj(f,jC(),Vj(d+8|0,b));h=v[j>>2];b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];l=x[v[b+8>>2]>>1];u[h+16>>1]=0;u[h+14>>1]=l;gb=b+16|0;m=fc(j),n=1,t[m+4|0]=n;gb=d+16|0;Gk(a,v[c+28>>2],e,v[f>>2]);b=be(f);t[c+27|0]=1;kC(f)}Wj(k,yc(c+8|0,b),c+27|0);gb=c+32|0;a=Wl(i);gb=g+32|0;return a+2|0}function Xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Yz(c,a);wb(a);ez(v[d+4>>2],b);v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;return}f=gb-32|0;gb=f;d=wb(a);d=vo(f+8|0,lr(a,Nb(a)+1|0),Nb(a),d);ez(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+4;b=a;Ek(a);wb(a);c=d;h=c+4|0;e=h;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[e>>2];while(1){a=a-4|0;ez(g-4|0,a);g=v[e>>2]-4|0;v[e>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];cn(b,Nb(b));a=d;b=a;d=v[a+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-4|0;v[b+8>>2]=c;v[22708]=0;R(1326,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){ai(v[a+16>>2],b,Bk(a))}gb=f+32|0}function sba(){var a=0,b=0,c=0,d=0,e=0;b=gb-48|0;gb=b;c=Kb(b+32|0);v[22708]=0;_(1917,b+16|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{if((a|0)!=1){a=b+16|0;d=b,e=Vb(a),v[d+8>>2]=e;d=b,e=Zb(a),v[d>>2]=e;if(!Gb(b+8|0,b)){break c}while(1){e:{a=v[b+8>>2];v[22708]=0;Q(1167,c|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break e}a=b+8|0;tr(a);d=b,e=Zb(b+16|0),v[d>>2]=e;if(!Gb(a,b)){break c}v[22708]=0;Q(1918,c|0,11815)|0;a=v[22708];v[22708]=0;if((a|0)!=1){continue}}break}a=V(0)|0;O()|0;yd(b+16|0);break d}a=V(0)|0;O()|0}vb(c);Z(a|0)|0;a=0;v[22708]=0;Y(1912,4042,0,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$();break b}a=ie(Jb(c));yd(b+16|0);vb(c)}gb=b+48|0;return a|0}b=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}function hJ(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(d+f)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function xs(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:v[22708]=0;b=Q(2,d|0,12957)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Eb(a,b);vb(b);break b;case 1:v[22708]=0;b=Q(2,d|0,12982)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 2:v[22708]=0;b=Q(2,d|0,12930)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 3:v[22708]=0;b=Q(2,d|0,12904)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 4:v[22708]=0;b=Q(2,d|0,10311)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 5:break c;default:break b}}v[22708]=0;b=Q(2,d|0,4280)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Eb(a,b);vb(b)}gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function Bga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=C(0),j=0,k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],fd(a)),v[k>>2]=m;qc(f,c>>>2|0);c=zb(b);g=z[e+4>>2];e=v[f>>2];if(e){while(1){i=C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q())));g=g<i?i:g;c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}i=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){z[f+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;h=C(z[Af(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=h;a=c;h=fe(h);b:{if(C(D(h))<C(2147483648)){j=~~h;break b}j=-2147483648}k=a,m=Uc(j),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}gb=f+16|0;return v[f>>2]<<2}function v2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=OG(c);b:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break b}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}nj(i,k);Ic(k);l=e,m=rj(a),v[l>>2]=m;l=f,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(g,k);vb(k);Qh(k,a);nj(h,k);Ic(k);a=dl(a);break a}a=NG(c);c:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break c}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}nj(i,k);Ic(k);l=e,m=rj(a),v[l>>2]=m;l=f,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(g,k);vb(k);Qh(k,a);nj(h,k);Ic(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}function $C(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=a;a=gb-16|0;gb=a;h=a;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);i=Ab(d);j=v[b>>2];v[22708]=0;sA(e+8|0,c,f+i|0,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=xf(e+4|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(86,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(85,g|0,a|0);b=v[22708];v[22708]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}}function ww(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;g=a+1|0;d=f+15|0;kh(b,w[ac(g,d)|0]);e=w[ac(a+2|0,d)|0];t[b+13|0]=e;j=b,k=Fd(w[a+3|0],e,w[f+15|0]),t[j+14|0]=k;d=w[ac(a+4|0,d)|0];t[b+15|0]=d;j=b,k=Fd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[ac(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Mb(w[e+6|0]+c<<24>>24,0,64);j=Lb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Lb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break a}if(x[Lb(b,d)>>1]>255){break a}h=w[Lb(b,e)+1|0];i=Lb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break a}e=Lb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[ac(f+14|0,g)|0]){continue}break}}gb=f+16|0}function ll(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22708]=0;b=v[(b+c|0)+24>>2];c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22708]=0;b=_f(b+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(vH()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22708]=0;b=v[(b+c|0)+24>>2];c=v[22708];v[22708]=0;c:{if((c|0)==1){break c}v[22708]=0;b=T(2301,b|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22708]=0;R(18,a+b|0,1);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function ula(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22708]=0;R(99,c+32|0,b|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22708]=0;d=ga(79)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Wb(c+8|0);v[22708]=0;b=Q(101,a|0,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22708]=0;b=El(b+d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=x[c+32>>1];vf(a);gb=c+192|0;a=(b?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;vf(a)}S(b|0);L()}return a|0}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){a=v[a+20>>2];c=g;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);a:{if(C(D(e))<C(2147483648)){f=~~e;break a}f=-2147483648}i=h,j=Uc(f),u[i>>1]=j;v[d+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);b:{if(C(D(e))<C(2147483648)){f=~~e;break b}f=-2147483648}i=h,j=Uc(f),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return g<<3}function $ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ud(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49050|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function z2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=RG(c);b:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break b}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}Eb(i,k);vb(k);l=e,m=rj(a),t[l|0]=m;l=f,m=qj(a),t[l|0]=m;Ug(k,a);Eb(g,k);vb(k);Qh(k,a);Eb(h,k);vb(k);a=dl(a);break a}a=QG(c);c:{if(b){fl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;el(k,a);break c}Hs(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Ph(k,a)}Eb(i,k);vb(k);l=e,m=rj(a),t[l|0]=m;l=f,m=qj(a),t[l|0]=m;Ug(k,a);Eb(g,k);vb(k);Qh(k,a);Eb(h,k);vb(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0;g=gb-16|0;gb=g;j=a+44|0;if(ni(j)){o=g,p=Nd(j,0),v[o+8>>2]=p;o=g,p=Nd(j,1),v[o+12>>2]=p;o=g,p=od(j,0),v[o>>2]=p;o=g,p=od(j,1),v[o+4>>2]=p;if(d){k=d;while(1){e=0;l=1;while(1){h=e<<2;i=h+(g+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+h|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=hM(C(f*C(1073741824)),w[a+4272|0],w[a+4273|0]);i=e+4244|0;e=e+4252|0;m=z[e>>2];n=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[i>>2]*z[a+4268>>2]))-C(m*n));z[e>>2]=f;z[i>>2]=m+C(n*f);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=f*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}Fi(a,b,c,od(j,0),od(j,1),d)}gb=g+16|0}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=Gi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=52544;c=a+4960|0;e=a+4504|0;b=e;while(1){b=Go(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[22708]=0;W(1533,a+44|0,2,2)|0;b=v[22708];v[22708]=0;a:{if((b|0)!=1){v[22708]=0;Uh(d);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Lc(c);if((c|0)!=(e|0)){continue}break}jf(d);S(a|0);L()}return a|0}function Yt(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function Mq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=v[b>>2];v[22708]=0;wu(e+8|0,c,g+i|0,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=xf(e+4|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(72,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=He(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=w[b|0];v[22708]=0;wu(e+8|0,c,g+i|0,j);c=v[22708];v[22708]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22708]=0;v[e+4>>2]=c;c=xf(e+4|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[22708]=0;U(75,d|0,c|0,0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22708]=0;R(76,d|0,b-c|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[22708]=0;R(77,h|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22708]=0;R(72,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480192>>1]){break d}b=1;while(1){c=v[f>>2];v[22708]=0;c=cA(c,b&65535);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;c=Q(70,e|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=gd(c);v[22708]=0;Q(1167,a|0,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(1918,a|0,18690)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22708]=0;Q(368,h|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function l8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480190>>1]){break d}b=1;while(1){c=v[f>>2];v[22708]=0;c=dA(c,b&65535);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;c=Q(70,e|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=gd(c);v[22708]=0;Q(1167,a|0,c|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}v[22708]=0;Q(1918,a|0,18690)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22708]=0;Q(368,h|0,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function Qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;h=fg(a,c);te(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!h){if(nd(a,5)){break a}}g=v[a+28>>2];d=gb-16|0;gb=d;v[d+12>>2]=0;YM(g,d+12|0,1);e=v[d+12>>2];i=e>>>2&3;t[d+11|0]=i;if(i){t[d+4|0]=3;e=w[ac(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;b:{if(!e){break b}Wh(g,d+4|0);if((e|0)==1){break b}Wh(g,d);if(e>>>0<3){break b}Wh(g,d+10|0);j=w[d+10|0]<<24}e=w[d+12|0]|w[d+4|0]<<8|w[d|0]<<16|j;v[d+12>>2]=e}v[d+4>>2]=e>>>4;v[d>>2]=1e6;uu(b,v[Fb(d+4|0,d)>>2]);if(Ab(b)){e=0;while(1){kl(g,pc(b,e),1);e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}b=(v[d+12>>2]>>>4|0)-Ab(b)|0;v[d+12>>2]=b;if(b){vm(g,b,-1)}gb=d+16|0}Zf(a,h,c,f+24|0);gb=f+32|0}function $ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Ec(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/12>>>0){c=gb-16|0;gb=c;d=Np(c,a,e);a=v[d+4>>2];b=v[d+8>>2];if((a|0)!=(b|0)){while(1){WT(a);a=a+12|0;v[d+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(d);gb=c+16|0;break c}b=wb(a);d=Tu(f+8|0,MB(a,Ec(a)+e|0),Ec(a),b);v[22708]=0;ZT(d,e);b=v[22708];v[22708]=0;if((b|0)==1){break b}c=d;e=c+4|0;g=e;b=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){h=v[g>>2];while(1){a=a-12|0;LB(h-12|0,a);h=v[g>>2]-12|0;v[g>>2]=h;if((a|0)!=(i|0)){continue}break}}wc(b,e);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];YT(d)}gb=f+32|0;break a}a=P()|0;O()|0;YT(d);S(a|0);L()}return}if(b>>>0<c>>>0){$T(a,v[a>>2]+B(b,12)|0)}}function R2(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-192|0;gb=c;b=c+16|0;$f(b,a);v[22708]=0;R(99,c+32|0,b|0);a=v[22708];v[22708]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22708]=0;a=W(100,c+48|0,c+32|0,8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}vb(c+32|0);vb(c+16|0);b=v[v[a>>2]-12>>2];v[22708]=0;d=ga(79)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;U(80,c+8|0,b+(c+48|0)|0,d|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Wb(c+8|0);v[22708]=0;b=Q(103,a|0,c+32|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[v[b>>2]-12>>2];v[22708]=0;b=El(b+d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[c+32>>2];vf(a);gb=c+192|0;a=b?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+32|0)}vb(c+16|0);break b}b=P()|0;O()|0;vf(a)}S(b|0);L()}return a|0}function r5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=v[b+44>>2];g=v[b+24>>2];if(i>>>0<g>>>0){v[b+44>>2]=g;i=g}l=-1;g=-1;m=f&24;a:{if(!m|((e|0)==1?(m|0)==24:0)){break a}if(i){h=i-Jb(b+32|0)|0;n=h;h=h>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=n;k=h}e=d+k|0;c=c+j|0;e=j>>>0>c>>>0?e+1|0:e;d=c;c=e;if((e|0)<0|((e|0)>(h|0)?1:(h|0)<=(e|0)?d>>>0>n>>>0:0)){break a}e=f&8;d:{if(!(c|d)){break d}if(v[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(e){e=v[b+8>>2];Wn(b,e,d+e|0,v[b+44>>2])}if(f&16){Mx(b,v[b+20>>2],v[b+28>>2]);Zs(b,d)}l=d;g=c}sh(a,l,g)}function zh(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return hc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}t[d|0]=w[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[d>>2]=v[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function Gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-16|0;gb=g;i=g+8|0;k=i;h=c;e=gb-32|0;gb=e;j=b;d=Yd(b);f=fc(b);a:{b:{if(d){c:{while(1){d:{b=d+16|0;e:{if(KA(c,b)){if(!v[d>>2]){break b}b=d;break e}if(!KA(b,c)){break c}b=d+4|0;if(!v[d+4>>2]){break d}d=b;b=d}f=b;d=v[d>>2];continue}break}v[e+28>>2]=d;break a}v[e+28>>2]=d;b=f;break a}d=fc(b)}v[e+28>>2]=d;b=d}d=v[b>>2];t[e+27|0]=0;if(!d){d=gb-16|0;gb=d;f=fc(j);c=e+8|0;f=Uj(c,Nc(28,4),Vj(d+8|0,f));l=v[f>>2];v[22708]=0;R(1417,l+16|0,h|0);h=v[22708];v[22708]=0;f:{if((h|0)!=1){m=fc(f),n=1,t[m+4|0]=n;gb=d+16|0;break f}a=P()|0;O()|0;YN(f);S(a|0);L()}Gk(j,v[e+28>>2],b,v[c>>2]);d=be(c);t[e+27|0]=1;YN(c)}Wj(k,yc(e+8|0,d),e+27|0);gb=e+32|0;DS(a,i);gb=g+16|0}function lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=f>>>21&2040;l=u[b+46166>>1];m=u[b+46164>>1];n=u[b+46162>>1];o=u[b+46160>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function I7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-80|0;gb=d;a=v[a+4>>2];xz(d+16|0,b);v[22708]=0;b=Q(2,d|0,14858)|0;e=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22708]=0;U(3,d+32|0,d+16|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break h}v[22708]=0;U(652,d+48|0,d+32|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break g}v[22708]=0;R(2040,d- -64|0,d+48|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[22708]=0;R(c|0,a|0,d- -64|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}vb(d- -64|0);vb(d+48|0);vb(d+32|0);vb(b);vb(d+16|0);gb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d- -64|0)}vb(d+48|0)}vb(d+32|0)}vb(b)}vb(d+16|0);S(a|0);L()}function c8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[22708]=0;R(1421,g|0,a|0);c=v[22708];v[22708]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[22708]=0;c=cA(c,a&65535);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;c=Q(70,d|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;U(2093,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(1423,g|0,d+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function b8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=mc(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[22708]=0;R(1421,g|0,a|0);c=v[22708];v[22708]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[22708]=0;c=dA(c,a&65535);e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;c=Q(70,d|0,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break e}v[22708]=0;U(2093,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(1423,g|0,d+16|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}yd(g);S(a|0);L()}function eO(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:uq(a,C(1));tq(a,C(3.725290298461914e-9));sq(a,C(268435456));rq(a,0);break b;case 1:uq(a,C(32));tq(a,C(4.656612873077393e-10));sq(a,C(2147483648));rq(a,0);break b;case 2:uq(a,C(2));tq(a,C(7.450580596923828e-9));sq(a,C(134217728));rq(a,1);break b;default:uq(a,C(1));tq(a,C(7.450580596923828e-9));sq(a,C(134217728));rq(a,1);Kz(a,0);Jz(a,1);Iz(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}uq(a,C(.75));tq(a,C(7.450580596923828e-9));sq(a,C(134217728));rq(a,1);Kz(a,0);b=(b|0)==4;Jz(a,b?2:3);Iz(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Kz(a,1);Jz(a,0);Iz(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function cL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;wq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=mg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;zt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=57924;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57152;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Gt(c,v[Tk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function bL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;wq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=mg(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;zt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=58752;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57980;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Gt(c,v[Tk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-80|0;gb=e;c=Rf(e+48|0);v[22708]=0;d=Q(1181,b|0,c|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(d){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1182,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}if(Yb(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){d=Yb(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))}else{d=-1}v[22708]=0;U(288,e|0,b|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}f=jc(e+24|0,e);Vc(c+8|0,f);xb(f);xb(e);d:{d=d&1;if(!d){break d}v[22708]=0;Q(318,b|0,2-d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}_j(a,c)}ed(c);gb=e+80|0;return}a=P()|0;O()|0;ed(c);S(a|0);L()}function vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);li(d,1,a);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){e=d+16|0;vb(e);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Oo(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[ac(e,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<=-1){u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function QL(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=wf(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-3e3/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(gk(10,d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(gk(10,d*+y[a+4292>>2])),z[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=gk(10,l*+(j+v[(e+h|0)+16>>2]>>>0));b=gk(10,d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=(1-f)*.5;z[e+12>>2]=b*f;z[e+8>>2]=b*(1-f);b=b*+g;b=b*(b*(b*(b+1)+1)+1)+1;k=k+b*b;c=c+1|0;if((c|0)!=4){continue}break}d=gk(10,+PL(z[a+4208>>2])*.05);b=gk(10,+PL(z[a+4212>>2])*.1);z[a+4228>>2]=4/K(k)*d*K(b);z[a+4224>>2]=d*K(1-b)}function OX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=b;k=e,l=zd(a),v[k+8>>2]=l;g=bk(e+24|0,e+8|0);b=Zh(c,d);a:{b:{if(!b){break b}if(aD(c,Jb(a),Jb(a)+Ab(a)|0)){b=Oj(e+8|0,c,d);c=v[e+24>>2];d=Jb(b);g=Jb(b);h=Ab(b);v[22708]=0;c=ca(543,a|0,c|0,d|0,g+h|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}h=Ab(a);f=Kc(a);c:{if(b>>>0<=f-h>>>0){f=Jb(a);i=h-g|0;if(!i){break c}j=g+f|0;cm(b+j|0,j,i);break c}Wm(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;jh(a,b);t[e+8|0]=0;Bd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){Bd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=zd(a),v[k+8>>2]=l;c=xe(e+8|0,g)}gb=e+32|0;return c|0}function XP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b|0]);d=zb(w[b+1|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+2|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+3|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+4|0])|(f|g);k=a,l=Jc(d|0,zb(w[b+5|0])<<8|f|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[k>>1]=l;e=zb(w[b+8|0]);d=zb(w[b+9|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+10|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+11|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+12|0])|(f|g);k=a,l=Jc(d|j,zb(w[b+13|0])<<8|f|zb(w[b+14|0])<<16|zb(w[b+15|0])<<24,48),u[k+2>>1]=l;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function WP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b+7|0]);d=zb(w[b+6|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+5|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+4|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+3|0])|(f|g);k=a,l=Jc(d|0,zb(w[b+2|0])<<8|f|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[k>>1]=l;e=zb(w[b+15|0]);d=zb(w[b+14|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+13|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+12|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+11|0])|(f|g);k=a,l=Jc(d|j,zb(w[b+10|0])<<8|f|zb(w[b+9|0])<<16|zb(w[b+8|0])<<24,48),u[k+2>>1]=l;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function Coa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb+-64|0;gb=c;a:{if(rv(a)){v[b>>2]=0;a=0;break a}PW(c+32|0,c+48|0);e=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=e;e=c+40|0;cc(e,a,c+16|0);g=yb(e);d=zb(w[c+48|0]);e=d&127;v[b>>2]=e;h=d<<24>>24;i=(h|0)<0;d=1;if(e){while(1){f=f+1|0;j=e>>>0>1;e=e>>>1|0;if(j){continue}break}}e=f;b:{if(g>>>0<2|(h|0)>-1){break b}while(1){f=zb(w[(c+48|0)+d|0]);v[b>>2]=f&127|v[b>>2]<<7;e=e+7|0;f=f<<24>>24;i=(f|0)<0;d=d+1|0;if((g|0)==(d|0)){Rb(a,g);PW(c+24|0,c+48|0);d=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=d;d=c+40|0;cc(d,a,c+8|0);g=yb(d);d=0}if(d>>>0>=g>>>0){break b}if((f|0)<0){continue}break}}Rb(a,d);if(e>>>0>=33){v[b>>2]=-1;a=0;break a}a=!i}gb=c- -64|0;return a|0}function vJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{b:{c:{d:{if((b|0)>=0){if((go(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;c=Q(70,f|0,7993)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,872)|0)+1075080|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,872);if((b|0)==x[(e+v[d>>2]|0)+1075778>>1]){e=(e+v[d>>2]|0)+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}gb=f+16|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Tp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);e=j(1)|0;g=j(0)|0;a:{b:{c:{b=e;e=b;if(!((b|0)>-1?b>>>0>=1048576:0)){if(!(b&2147483647|g)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;h=-1023;if((e|0)!=1072693248){b=e;break b}if(g){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;g=j(0)|0;h=-1077}b=b+614242|0;d=+((b>>>20|0)+h|0);a=d*.6931471803691238;l(0,g|0);l(1,(b&1048575)+1072079006|0);f=+n()+-1;c=f/(f+2);i=a;k=d*1.9082149292705877e-10;m=c;a=f*(f*.5);d=c*c;c=d*d;a=i+(f+(k+m*(a+(c*(c*(c*.15313837699209373+.22222198432149784)+.3999999999940942)+d*(c*(c*(c*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-a))}return a}function pA(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}d=v[a+480180>>2]&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){e=v[a+480208>>2]&4096;if(!d){break h}if(!e){break b}c=0-(d>>>2|0)|0;break d}e=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!e){break b}c=c<<2;break c}d=0;if(!e){break f}break b}if(e){break b}if(!c){break e}}c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}d=f+8|0;Db(d,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(d)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=Mb(v[b+692>>2]+c|0,0,256);u[b+784>>1]=0;v[b+692>>2]=a}gb=f+16|0}function zF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=rf(a);if(c>>>0<b>>>0){g=gb-32|0;gb=g;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>3>>>0){c=gb-16|0;gb=c;b=fs(c,a,e);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){hm(a);a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}f=wb(a);b=gs(a,rf(a)+e|0);i=rf(a);c=0;h=gb-16|0;gb=h;v[h+12>>2]=0;d=g+8|0;hf(d+12|0,f);if(b){c=b;if(b>>>0>=536870912){rd(8445);L()}c=Nc(c<<3,1)}v[d>>2]=c;f=(i<<3)+c|0;v[d+8>>2]=f;v[d+4>>2]=f;j=dc(d),k=(b<<3)+c|0,v[j>>2]=k;gb=h+16|0;v[22708]=0;Iw(d,e);b=v[22708];v[22708]=0;if((b|0)==1){break b}Yk(a,d);xF(d)}gb=g+32|0;break a}a=P()|0;O()|0;xF(d);S(a|0);L()}return}if(b>>>0<c>>>0){Zk(a,v[a>>2]+(b<<3)|0)}}function Rea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=b+24|0;o=a+1298224|0;g=a+1074992|0;k=sk(a);p=b+4|0;q=b+12|0;r=b+8|0;s=b+16|0;while(1){if(v[g+104>>2]==(b|0)){if(v[g+16>>2]){v[g+16>>2]=c}if(y[g+4>>2]>d>>>0){v[g>>2]=0;v[g+4>>2]=0}if(v[g+76>>2]){qc(g+76|0,d)}h=hF(g);i=v[(h?q:p)>>2];v[g+84>>2]=v[(h?s:r)>>2];v[g+80>>2]=i;h=v[g+88>>2]|v[e>>2];v[g+88>>2]=h;v[g+88>>2]=h&(v[f>>2]^-1);h=g+704|0;a:{if(!v[g+704>>2]|!v[b+24>>2]){break a}if(hp(a)){break a}l=v[(k?h:j)>>2];m=oqa(v[(k?j:h)>>2],0,v[g+700>>2],0);n=m+(l>>>1|0)|0;i=jb;t=g,u=Qc(rqa(n,n>>>0<m>>>0?i+1|0:i,l,0),jb),v[t+700>>2]=u}v[h>>2]=v[j>>2]}g=g+872|0;if((o|0)!=(g|0)){continue}break}}function uV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}break a}ZB(c+8|0,b);b=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=b;kd(c+16|0,a,c)}gb=c+32|0}function n6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;a:{b:{b=d+16|0;c:{if(!gt(xa(v[a+60>>2],b|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!gt(xa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}gb=d+32|0;return a|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)==1){break c}v[22708]=0;_(1961,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;_(1961,c|0);f=v[22708];v[22708]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=uc(d+24|0,b);c=uc(d+16|0,c);v[22708]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;Y(2005,f|0,d+8|0,d|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2599,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}gb=d+32|0;return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=He(d+16|0,1,0);IP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22708]=0;v[d+4>>2]=e;e=xf(d+4|0);h=v[22708];v[22708]=0;if((h|0)==1){break c}v[22708]=0;U(75,c|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}IP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22708]=0;R(76,c|0,b-e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;R(86,g|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22708]=0;R(85,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=oqa(d,0,1,1);f=jb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function pm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0;k=gb-16|0;gb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=Vm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83408|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83408|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function om(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;k=gb-16|0;gb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=rx(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83408|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83408|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function _na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;u[d+30>>1]=0;ag(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22708]=0;u[d+14>>1]=0;f=W(655,a|0,e|0,255)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(!f){break d}v[22708]=0;Q(647,a|0,d+14|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;U(13,d|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}v[22708]=0;f=Q(654,b|0,d+14|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}_f(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function Wfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{if(qk(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[Pc(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){e=d+8|0;re(e,b,c);if(!Cb(e)){v[22708]=0;f=Q(1314,a|0,c&65535)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}if(f){v[22708]=0;f=Q(70,d+8|0,18720)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(301,((c<<5)+a|0)+946304|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}vb(f);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}gb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(f);break a}c=P()|0;O()|0}S(c|0);L()}function $na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=0;Hk(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22708]=0;u[d+14>>1]=0;f=W(653,a|0,e|0,255)|0;g=v[22708];v[22708]=0;if((g|0)==1){break b}if(!f){break d}v[22708]=0;Q(647,a|0,d+14|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}v[22708]=0;U(13,d|0,c|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break f}v[22708]=0;f=Q(654,b|0,d+14|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}_f(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function vI(a,b,c,d,e,f){var g=0;g=gb-80|0;gb=g;a:{if((f|0)>=16384){Ed(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}Ed(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Ed(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}Ed(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Ed(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;gb=g+80|0}function qR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=He(d+16|0,1,0);SP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22708]=0;v[d+4>>2]=e;e=xf(d+4|0);h=v[22708];v[22708]=0;if((h|0)==1){break c}v[22708]=0;U(75,c|0,e|0,0);e=v[22708];v[22708]=0;if((e|0)==1){break c}SP(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22708]=0;R(76,c|0,b-e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;R(86,g|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22708]=0;R(85,a|0,f|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function lA(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){d=gb-32|0;gb=d;Uq(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;gb=d+32|0;a=a+32|0;if((e|0)!=(a|0)){continue}break}}function ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46162>>1])+B(u[e-2>>1],u[f+46160>>1])|0)+B(u[e+2>>1],u[f+46164>>1])|0)+B(u[e+4>>1],u[f+46166>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function aL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=gb-16|0;gb=f;c=v[a+4>>2];d=f;a=v[a>>2];v[d>>2]=a;v[d+4>>2]=c;v[d+8>>2]=a;v[d+12>>2]=c;a=gb+-64|0;gb=a;a:{if(!v[d+4>>2]){break a}c=38480;b:{while(1){b=v[d+4>>2];v[a+56>>2]=v[d>>2];v[a+60>>2]=b;b=uc(a+48|0,v[c+8>>2]);e=v[a+60>>2];v[a+24>>2]=v[a+56>>2];v[a+28>>2]=e;e=v[b+4>>2];v[a+16>>2]=v[b>>2];v[a+20>>2]=e;if(bO(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=39044){continue}break}c=39056;while(1){b=v[d+4>>2];v[a+40>>2]=v[d>>2];v[a+44>>2]=b;b=uc(a+32|0,v[c+8>>2]);e=v[a+44>>2];v[a+8>>2]=v[a+40>>2];v[a+12>>2]=e;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;b=bO(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=39104){continue}break}break a}b=1}gb=a- -64|0;gb=f+16|0;return b|0}function Efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-80|0;gb=d;f=1;g=IR(a,1<<b-1);v[a+12>>2]=b;c=1<<b;h=c>>>2|0;a:{if(b>>>0>1){i=-6.283185307179586/+(c>>>0);b=h;while(1){A[d+40>>3]=i*+(b>>>0);e=v[12055];c=d+48|0;v[c+8>>2]=v[12054];v[c+12>>2]=e;e=v[12053];v[c>>2]=v[12052];v[c+4>>2]=e;UA(c,A[d+40>>3]);v[22708]=0;TA(d- -64|0,c);c=v[22708];v[22708]=0;if((c|0)==1){break a}c=Tc(g,f);e=v[d+76>>2];v[c+8>>2]=v[d+72>>2];v[c+12>>2]=e;e=v[d+68>>2];v[c>>2]=v[d+64>>2];v[c+4>>2]=e;f=f<<1;c=b>>>0<2;b=b>>>1|0;if(!c){continue}break}}b=Tm(d+24|0,1,0);c=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=c;c=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=c;Ez(a,0,h,d+8|0);gb=d+80|0;return a|0}a=P()|0;O()|0;Nq(g);S(a|0);L()}function Kma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0);c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[ir(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Af(c+12|0,c+8|0,c+4|0)>>2]*C(128));z[c+12>>2]=f;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=HV(g);t[v[a>>2]+(B(v[a+4>>2],d)+e|0)|0]=g;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14354,6114,28,6667);L()}aa(14404,6114,27,6667);L()}function Co(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}d=v[a+480180>>2]&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Gq(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){Fq(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288?!(t[b+851|0]&1)|w[a+480208|0]&2:1)){break c}e=d&255;d=d&15;d:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Mb(c,0,256),v[g+688>>2]=h}function wC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Nb(e);d=c;a:{if(f>>>0<d>>>0){j=gb-32|0;gb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){mr(e,h);break d}i=wb(e);k=lr(e,Nb(e)+h|0);m=Nb(e);f=0;l=gb-16|0;gb=l;v[l+12>>2]=0;d=j+8|0;hf(d+12|0,i);if(k){f=_V(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=dc(d),o=(k<<2)+f|0,v[n>>2]=o;gb=l+16|0;v[22708]=0;kv(d,h);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(e,d);$V(d)}gb=j+32|0;break b}a=P()|0;O()|0;$V(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Zk(e,v[e>>2]+(d<<2)|0)}}if(Pb(a,c<<2)){bc(g+24|0,v[b>>2],Nb(b)<<2);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;h=g+8|0;j=h;k=c;e=gb-32|0;gb=e;i=b;d=b;b=Yd(b);f=fc(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(Fn(c,d)){if(!v[b>>2]){break b}f=b;break e}if(!Fn(d,c)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=f;break a}v[e+28>>2]=b;b=f;break a}b=fc(d)}v[e+28>>2]=b}f=b;b=v[b>>2];t[e+27|0]=0;if(!b){b=gb-16|0;gb=b;d=fc(i);c=e+8|0;d=Uj(c,Nc(16,4),Vj(b+8|0,d));Ro(v[d>>2]+14|0,k);l=fc(d),m=1,t[l+4|0]=m;gb=b+16|0;AS(i,v[e+28>>2],f,v[c>>2]);b=be(c);t[e+27|0]=1;f=c;d=v[c>>2];v[c>>2]=0;if(d){c=fc(f);if(d){Xn(v[c>>2],d,1)}}}Wj(j,yc(e+8|0,b),e+27|0);gb=e+32|0;DS(a,h);gb=g+16|0}function Lma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0;c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[ir(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Af(c+12|0,c+8|0,c+4|0)>>2]*C(32768));z[c+12>>2]=f;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=Uc(g);j=IV(a,e,d),l=g,u[j>>1]=l;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}aa(14354,6114,28,6667);L()}aa(14404,6114,27,6667);L()}function f6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;if(wa(1,d+32|0)|0){Rs(v[115189],10020);L()}a=d+32|0;c=ft(d+16|0,a);g=ft(d+8|0,a|4);e=gb-32|0;gb=e;b=gb-16|0;gb=b;h=gb-16|0;gb=h;a=gb-16|0;gb=a;i=a,j=oqa(v[c>>2],v[c+4>>2],1e9,0),v[i>>2]=j;v[a+4>>2]=jb;c=Xl(a+8|0,a);f=v[c+4>>2];c=v[c>>2];gb=a+16|0;gb=h+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=a;gb=b+16|0;f=v[e+8>>2];c=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=Xl(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[d+24>>2]=a;v[d+28>>2]=b;a=Xl(d+40|0,d+24|0);b=v[a+4>>2];a=v[a>>2];gb=d+48|0;jb=b;return a|0}function RI(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}kb[d|0](a,c)}}function gC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;kh(b,w[ac(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Nb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Lb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Lb(b,d)>>1]>=x[Lb(b,e)>>1]){break a}e=x[Lb(b,e)>>1];h=Lb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Mb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Lb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=g+16|0}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=f>>>21&2040;b=(((B(t[b|0],u[f+46162>>1])+B(t[b-1|0],u[f+46160>>1])|0)+B(t[b+1|0],u[f+46164>>1])|0)+B(t[b+2|0],u[f+46166>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;gb=e+16|0}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;c=gb-16|0;gb=c;d=a;k=d;h=b;e=Yd(d);i=fc(d);f=gb-16|0;gb=f;if(e){while(1){j=yu(wb(k),e+16|0,h);i=j?i:e;e=v[(j?4:0)+e>>2];if(e){continue}break}}h=v[yc(f+8|0,i)>>2];gb=f+16|0;v[c+8>>2]=h;l=c,m=Dh(d),v[l>>2]=m;a:{b:{if(!Gb(c+8|0,c)){break b}if(yu(wb(d),b,ve(c+8|0))){break b}b=v[c+8>>2];break a}b=Dh(d)}gb=c+16|0;v[g+24>>2]=b;l=g,m=Dh(a),v[l+16>>2]=m;if(!Rj(g+24|0,g+16|0)){b=v[yc(g+8|0,b)>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;h=gb-16|0;gb=h;e=d+8|0;i=v[e>>2];c=i;f=yc(h+8|0,c);Tj(f);b=a;if((c|0)==v[b>>2]){v[b>>2]=v[f>>2]}f=wb(b);v[f>>2]=v[f>>2]-1;$M(v[fc(b)>>2],c);gb=h+16|0;fc(a);Qm(ve(e));HA(i);gb=d+16|0}gb=g+32|0}function Lca(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=wf(v[a+16>>2]);b=Ac(pqa(oqa(b,b>>31,3840,0),jb,1e3,0),jb);v[a+4316>>2]=b;v[22708]=0;v[c+12>>2]=0;U(1541,a+4264|0,b|0,c+12|0);b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[a+4260|0]){break e}b=v[a+4316>>2];v[22708]=0;v[c+12>>2]=0;U(1541,a+4276|0,b|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)!=1){break e}b=V(89104)|0;break c}v[22708]=0;v[c+12>>2]=0;Yy(a+4288|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}v[22708]=0;v[c+12>>2]=0;Yy(a+4300|0,c+12|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}b=V(89104)|0;break c}b=V(89104)|0;break c}b=V(89104)|0}if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4316>>2]=0;$()}gb=c+16|0;return}S(b|0);L()}function KN(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=gb-16|0;gb=h;t[h+15|0]=b;t[h+14|0]=10;kh(g,w[ac(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Nb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Lb(g,c),j=d>>>4|0,u[i>>1]=j;e=0;a:{if(c){d=c-1|0;if(x[Lb(g,c)>>1]>=x[Lb(g,d)>>1]){break a}e=x[Lb(g,d)>>1]+1|0}i=Lb(g,c),j=e,u[i>>1]=j}b=Fd(w[b+2|0],0,64);i=Lb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Nb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;c=g;if(a&2){b=w[g+15|0];d=Nb(g);b=w[g+12|0]&-5|(b>>>0<=d>>>0)<<2}else{b=b&251}t[c+12|0]=b;c=g;b:{c:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break c}}a=b&253;break b}b=Nb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[c+12|0]=a;gb=h+16|0}function pba(a){a=a|0;var b=0;b=5149;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=14653;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=18720;break a}b=5182;break a}b=2107;break a}b=5205;break a}b=5219;break a}b=2480;break a}b=2500;break a}b=5231;break a}b=5163;break a}b=10139;break a}b=9407;break a}b=3111;break a}if((a|0)!=357){break a}b=5116}return ie(b)|0}function UN(a){var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;v[b+12>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+16>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);v[b+28>>2]=3;v[b+20>>2]=c+(a<<2);v[b+24>>2]=b+12;a=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=a;a=v[b>>2];d=eD(b);e=gb-16|0;gb=e;a:{if((a|0)==(d|0)){break a}c=a+4|0;if((d|0)==(c|0)){break a}while(1){a=yn(a,c)?c:a;c=c+4|0;if((d|0)!=(c|0)){continue}break}}gb=e+16|0;gb=b+32|0;return v[a>>2]-36|0}function lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;d=b;f=tc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){i=gb-16|0;gb=i;e=mi(i,d,f);d=v[e+4>>2];f=v[e+8>>2];if((d|0)!=(f|0)){while(1){Ok(d);d=d+2|0;v[e+4>>2]=d;if((d|0)!=(f|0)){continue}break}}$b(e);gb=i+16|0;break d}e=wb(d);e=xD(h+8|0,PY(d,tc(d)+f|0),tc(d),e);v[22708]=0;TV(e,f);f=v[22708];v[22708]=0;if((f|0)==1){break c}Yk(d,e);qp(e)}gb=h+32|0;break b}a=P()|0;O()|0;qp(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Zk(d,v[d>>2]+(e<<1)|0)}}c=Pb(a,c<<1);if(c){bc(g+24|0,v[b>>2],tc(b)<<1);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function HM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=gb-48|0;gb=c;v[c+8>>2]=542066252;e=c+8|0;d=e|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Nk(b,33);hc(v[b>>2],e,33);Vd(c,b);ne(a,c);gb=c+48|0}function g6(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=gb-48|0;gb=b;if(wa(0,b+32|0)|0){Rs(v[115189],9983);L()}d=ft(b+16|0,b+32|0);v[b+4>>2]=v[b+36>>2]/1e3;g=ft(b+8|0,b+4|0);e=gb-32|0;gb=e;c=gb-16|0;gb=c;a=gb-16|0;gb=a;h=a,i=oqa(v[d>>2],v[d+4>>2],1e6,0),v[h>>2]=i;v[a+4>>2]=jb;d=Xl(a+8|0,a);f=v[d+4>>2];d=v[d>>2];gb=a+16|0;v[c+8>>2]=d;v[c+12>>2]=f;a=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=a;gb=c+16|0;f=v[e+8>>2];d=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;d=v[a+4>>2]+d|0;c=v[a>>2];f=f+c|0;v[a+16>>2]=f;v[a+20>>2]=c>>>0>f>>>0?d+1|0:d;a=Xl(a+24|0,a+16|0);c=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[b+24>>2]=a;v[b+28>>2]=c;a=Xl(b+40|0,b+24|0);c=v[a+4>>2];a=v[a>>2];gb=b+48|0;jb=c;return a|0}function SZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;ud(b,0);li(e,1,a+33|0);d=e+16|0;Bc(d,e);v[22708]=0;Q(303,b+43|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){f=e+16|0;vb(f);d=a+50|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+54|0;v[b+24>>2]=w[d|0]|w[d+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;g=b,h=w[ac(f,e)|0]<<2,u[g+30>>1]=h;d=a+57|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+61|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!c|!v[b+4>>2])){v[b+8>>2]=v[b>>2]}a:{if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=e+32|0;return}a=P()|0;O()|0;vb(e+16|0);S(a|0);L()}function Jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-112|0;gb=i;a:{if(!Md(a)){break a}if(Ec(b)>>>0<2){break a}f=$o(i+8|0,a);v[f+20>>2]=0;v[f>>2]=0;c=Ec(b);b:{if(!c){break b}e=v[a>>2];while(1){d=Ad(b,g);j=v[d>>2];if(e>>>0<=j>>>0){break b}d=v[d+4>>2];if(d>>>0>e-j>>>0|268435456-d>>>0<h>>>0){break b}h=d+h|0;v[f>>2]=h;g=g+1|0;if((c|0)!=(g|0)){continue}break}g=c}if(!Zm(f)){break a}if(g){h=f+68|0;c=0;e=0;while(1){d=Ad(b,c);hc(zb(v[f+20>>2])+e|0,zb(v[a+20>>2])+v[d>>2]|0,v[d+4>>2]);v[d>>2]=e;if(!(!c|c>>>0>9)){k=yf(h,c-1|0),l=e,v[k>>2]=l}e=v[d+4>>2]+e|0;c=c+1|0;if((g|0)!=(c|0)){continue}break}}Ol(a);$o(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}gb=i+112|0}function DZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Sr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Sr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Hu(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}gb=d+16|0}function X9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22708]=0;_(1961,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22708]=0;c=Q(70,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;Y(1996,d+16|0,e|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)==1){break d}a=d+16|0;b=ie(Jb(a));vb(a);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,3489,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22708]=0;_(1961,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22708]=0;c=Q(70,d|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break e}v[22708]=0;U(1962,d+16|0,e|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break d}a=d+16|0;b=ie(Jb(a));vb(a);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22708]=0;Y(1912,10637,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function JM(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;z[d+12>>2]=c;cz(a);Ii(d+12|0);a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];Qt(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);Qt(a);break a;case 4:b=gb-16|0;gb=b;f=b,g=Xh(C(z[d+12>>2]*C(32))),v[f+12>>2]=g;v[b+8>>2]=0;v[b+4>>2]=5;e=v[dj(b+12|0,b+8|0,b+4|0)>>2];gb=b+16|0;v[a+4232>>2]=e;break a;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}b=a;c=z[d+12>>2];if(c==C(0)){az(a);c=z[d+12>>2]}A[b+4256>>3]=c}gb=d+16|0}function kh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){e=gb-16|0;gb=e;d:{b=Eg(e,a,c);c=v[b+4>>2];f=v[b+8>>2];if((c|0)!=(f|0)){while(1){wb(a);v[22708]=0;Xr(c);g=v[22708];v[22708]=0;if((g|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(f|0)){continue}break}}$b(b);gb=e+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}b=wb(a);b=zp(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22708]=0;R(299,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(300,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}gj(b)}gb=d+32|0;break a}a=P()|0;O()|0;gj(b);S(a|0);L()}return}if(b>>>0<c>>>0){hj(a,v[a>>2]+(b<<2)|0)}}function hqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=a+8|0;a:{c=v[a+8>>2];i=dc(a);b:{if((c|0)!=v[i>>2]){break b}h=a+4|0;d=v[a+4>>2];f=v[a>>2];if(d>>>0>f>>>0){f=((d-f>>1)+1|0)/-2<<1;a=f+d|0;if((c|0)!=(d|0)){while(1){FY(a,d);a=a+2|0;d=d+2|0;if((d|0)!=(c|0)){continue}break}}c=a;v[g>>2]=a;v[h>>2]=f+v[h>>2];break b}v[e+24>>2]=c-f;v[e+44>>2]=1;d=e+24|0;c=v[Mc(d,e+44|0)>>2];c=xD(d,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22708]=0;GY(c,d,f);d=v[22708];v[22708]=0;if((d|0)==1){break a}wc(a,c);wc(h,c+4|0);wc(g,c+8|0);wc(i,dc(c));qp(c);c=v[a+8>>2]}Gr(c,b);v[g>>2]=v[g>>2]+2;gb=e+48|0;return}a=P()|0;O()|0;qp(c);S(a|0);L()}function p3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}a=f+24|0;Fc(a,c);v[22708]=0;a=T(2482,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Qh(f+24|0,a);break e}Ph(f+24|0,a)}a=f+24|0;g=f,h=zd(a),v[g+16>>2]=h;g=f,h=vi(a),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=v[v[f+16>>2]>>2];v[22708]=0;Q(2501,f+40|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}a=f+16|0;Qe(a);g=f,h=vi(f+24|0),v[g+8>>2]=h;if(Gb(a,f+8|0)){continue}break}b=v[f+40>>2]}Ic(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;Ic(f+24|0)}S(b|0);L()}function te(a,b){var c=0,d=0,e=0;d=gb-32|0;gb=d;a=sh(a,-1,-1);a:{b:{if(w[tj(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[22708]=0;c=v[(b+c|0)+24>>2];e=v[22708];v[22708]=0;c:{d:{if((e|0)==1){break d}v[22708]=0;Ga(2312,d+8|0,c|0,0,0,1,8);c=v[22708];v[22708]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;Z(a|0)|0;a=1;sj(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[b>>2]-12>>2]+b|0,a)}gb=d+32|0;return}V(0)|0;O()|0;Bb()}L()}function eA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb-16|0;gb=c;if(!cd(a)){m=c,n=Vb(a),v[m+8>>2]=n;m=c,n=Zb(a),v[m>>2]=n;if(Gb(c+8|0,c)){while(1){d=c+8|0;b=v[d>>2];Fp(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=h;b=f>>>0<g>>>0?b+1|0:b;h=b;Qe(d);if(Gb(d,c)){continue}break}}b=Nb(a);g=Nb(a);m=c,n=Vb(a),v[m+8>>2]=n;m=c,n=Zb(a),v[m>>2]=n;b=rqa(f,h,b,0);d=jb;f=g<<24;h=0;if(Gb(c+8|0,c)){g=b;d=((d&1)<<31|b>>>1)&2147483647;while(1){i=c+8|0;b=v[i>>2];j=b;e=v[b>>2];b=e>>>8|0;e=d+(e<<24)|0;b=b+k|0;b=Qc(rqa(e,d>>>0>e>>>0?b+1|0:b,g,l),jb);v[j>>2]=b;e=f;f=e-b|0;h=h-(b>>>0>e>>>0)|0;Qe(i);if(Gb(i,c)){continue}break}}if(!Nb(a)){Zx();L()}a=v[a>>2];v[a>>2]=f+v[a>>2]}gb=c+16|0}function bl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;a:{c=v[a+32>>2];if((c|0)>=(b|0)){f=v[a+28>>2];break a}i=a+36|0;g=v[a+24>>2];e=v[a+20>>2];h=c;while(1){b:{if(e>>>0>=g>>>0){td(d+16|0,i,i+1024|0);c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;c=d+24|0;kd(c,a,d+8|0);g=yb(c);v[a+24>>2]=g;v[a+20>>2]=0;if(!g){break b}e=0;h=v[a+32>>2]}j=e+1|0;v[a+20>>2]=j;e=w[(a+e|0)+36|0];c=h+8|0;v[a+32>>2]=c;f=v[a+28>>2]|e<<h;v[a+28>>2]=f;h=c;e=j;if((b|0)>(c|0)){continue}break a}break}a=ba(8)|0;v[22708]=0;T(205,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){b=P()|0;O()|0;da(a|0);S(b|0);L()}ia(a|0,27364,206);L()}v[a+32>>2]=c-b;v[a+28>>2]=f>>>b;gb=d+32|0;return(-1<<b^-1)&f}function YH(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[22708]=0;c=Q(2315,d+8|0,a|0)|0;b=v[22708];v[22708]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22708]=0;b=T(2316,b|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[22708]=0;_(2317,a+b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;WH(c);break c}WH(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22708]=0;_(19,a+c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function B3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}a=f+24|0;Fc(a,c);v[22708]=0;a=T(2453,a|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}Wb(f+24|0);e:{if(e){Qh(f+24|0,a);break e}Ph(f+24|0,a)}a=f+24|0;g=f,h=zd(a),v[g+16>>2]=h;g=f,h=ef(a),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=t[v[f+16>>2]];v[22708]=0;Q(2320,f+40|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}a=f+16|0;Pe(a);g=f,h=ef(f+24|0),v[g+8>>2]=h;if(Gb(a,f+8|0)){continue}break}b=v[f+40>>2]}vb(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Wb(f+24|0);break a}b=P()|0;O()|0;vb(f+24|0)}S(b|0);L()}function s5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{if(!Ie(b,-1)){h=v[a+12>>2];i=v[a+8>>2];g=v[a+24>>2];if((g|0)==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}e=v[a+20>>2];j=v[a+44>>2];v[22708]=0;c=a+32|0;R(61,c|0,0);d=v[22708];v[22708]=0;if((d|0)==1){break b}d=Kc(c);v[22708]=0;R(76,c|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}d=Jb(c);Mx(a,d,Ab(c)+d|0);Zs(a,g-e|0);v[a+44>>2]=v[a+20>>2]+(j-e|0)}v[f+12>>2]=v[a+24>>2]+1;c=a+44|0;e=f+12|0;k=a,l=v[(yn(e,c)?c:e)>>2],v[k+44>>2]=l;if(w[a+48|0]&8){c=Jb(a+32|0);Wn(a,c,c+(h-i|0)|0,v[a+44>>2])}c=ZH(a,xh(b));break a}c=Xs(b);break a}a=V(0)|0;O()|0;Z(a|0)|0;$();c=-1}gb=f+16|0;return c|0}function AZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Fb(d+4|0,d+12|0)>>2];c=gb+-64|0;gb=c;e=c+40|0;Re(e,a,f);a=v[e>>2];v[22708]=0;e=Sd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(c+8|0,3,e,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(400,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}gb=d+16|0}function $p(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=d?d:463964;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[22614]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+76800>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115189]=25;e=-1;break a}v[f>>2]=d}gb=h+16|0;return e|0}function gN(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=gb-48|0;gb=f;e=Kb(f+32|0);v[22708]=0;Q(1518,a|0,f+24|0)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)!=1){g=v[f+28>>2];d=v[f+24>>2];Se(e);v[22708]=0;g=!g&d>>>0<255?d:255;R(76,e|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=pc(e,d);v[22708]=0;Q(1519,a|0,h|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((pI(e)|0)!=-1){a=pI(e);v[22708]=0;R(76,e|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}}v[22708]=0;U(13,f+8|0,c|0,e|0);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}break a}a=f+8|0;Eb(b,a);vb(a);vb(e);gb=f+48|0;return}a=P()|0;O()|0;vb(e);S(a|0);L()}function f3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=MF(v[v[a>>2]-12>>2]+a|0,10);e=gb-16|0;gb=e;v[22708]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[22708];v[22708]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=cj(e,c);v[22708]=0;Q(2320,b|0,f|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){if(!Zv(b)){break e}b=v[v[c>>2]-12>>2];v[22708]=0;R(18,b+c|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;ll(d);break d}ll(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;d=v[v[c>>2]-12>>2];v[22708]=0;_(19,c+d|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}$()}gb=e+16|0;break a}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}$s(a);return a|0}function bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;KQ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;h=wb(a);i=g+8|0;j=a;f=LA(a)+1|0;d=gb-16|0;gb=d;v[d+12>>2]=f;e=gb-16|0;gb=e;v[e+12>>2]=613566756;v[22708]=0;v[e+8>>2]=2147483647;k=Fb(e+12|0,e+8|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){gb=e+16|0;c=v[k>>2];break a}V(0)|0;O()|0;Bb();L()}b:{if(c>>>0>=f>>>0){f=GA(j);if(f>>>0<c>>>1>>>0){v[d+8>>2]=f<<1;c=v[Mc(d+8|0,d+12|0)>>2]}gb=d+16|0;break b}Sc();L()}c=VQ(i,c,LA(a),h);KQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;UQ(a,c);TQ(c);gb=g+32|0}function JP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-112|0;gb=f;v[f+108>>2]=0;d=Om(a,x[d+70>>1],v[d+48>>2],c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=!w[b+792|0]&(c|0)==15;d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}d=(e?0:w[b+836|0]<<16)+d|0}b:{if((c|0)!=15){break b}c=w[b+792|0];if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Mc(f,f+108|0)>>2]<<3;g=oqa(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=jb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Qc(c,e);break b}gU(f,0);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[yf(c+68|0,w[b+792|0]-1|0)>>2]+d|0}Mm(a,b,d);gb=f+112|0}function dia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-48|0;gb=e;a:{b:{if(v[a+8>>2]!=v[dc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];d=v[a>>2];if(c>>>0>d>>>0){f=c;c=((c-d>>2)+1|0)/-2<<2;i=g,j=Rg(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=e,j=v[dc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[e+44>>2]=1;d=e+24|0;c=v[Mc(d,e+44|0)>>2];c=zp(d,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22708]=0;U(1080,c|0,d|0,f|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}xc(a,c);xc(h,c+4|0);xc(g,c+8|0);xc(dc(a),dc(c));gj(c)}gn(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;gb=e+48|0;return}a=P()|0;O()|0;gj(c);S(a|0);L()}function S2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=gb-416|0;gb=h;d=h+416|0;v[h+12>>2]=d;c=gb-144|0;gb=c;v[c+28>>2]=c+132;i=c+32|0;UG(a+8|0,i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;i=e;j=WV(e,v[h+12>>2]);f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];g=wi(f+8|0,f+12|0);v[22708]=0;a=Ax(e,c+12|0,j,c+16|0);j=v[22708];v[22708]=0;a:{if((j|0)!=1){ff(g);gb=f+16|0;break a}a=P()|0;O()|0;ff(g);S(a|0);L()}if((a|0)==-1){Js(9862);L()}v[h+12>>2]=i+(a<<2);gb=c+144|0;c=v[h+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;if((c|0)!=(e|0)){while(1){OH(a+8|0,v[e>>2]);e=e+4|0;if((c|0)!=(e|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=d;return b|0}function Yq(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Ab(b);v[22708]=0;R(60,d|0,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){a:{if(Ab(b)){while(1){f=v[yk(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[22708]=0;R(61,d|0,a<<24>>24);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[22708]=0;R(61,d|0,a<<24>>24);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[22708]=0;R(61,d|0,63);a=v[22708];v[22708]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;vb(d);S(a|0);L()}function e9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=cq(c,a,1);Ey(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;$b(a);gb=c+16|0;return}e=gb-32|0;gb=e;c=wb(a);c=QI(e+8|0,dy(a,uf(a)+1|0),uf(a),c);Ey(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;b=c;h=c+4|0;f=h;d=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[f>>2];while(1){a=a-16|0;Ey(g-16|0,a);g=v[f>>2]-16|0;v[f>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(d,h);wc(d+4|0,b+8|0);wc(wb(d),dc(b));v[b>>2]=v[b+4>>2];a=c;b=a;d=v[a+8>>2];c=v[a+4>>2];if((d|0)!=(c|0)){while(1){d=d-16|0;v[b+8>>2]=d;Fk(d);d=v[b+8>>2];if((c|0)!=(d|0)){continue}break}}b=v[a>>2];if(b){uK(b,Px(a))}gb=e+32|0}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;f=Rf(d+48|0);v[22708]=0;e=Q(1171,b|0,f|0)|0;g=v[22708];v[22708]=0;a:{b:{c:{if((g|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1172,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=bn(f);v[22708]=0;U(288,d|0,b|0,e|0);g=v[22708];v[22708]=0;if((g|0)==1){break a}g=jc(d+24|0,d);Vc(f+8|0,g);xb(g);xb(d);d:{if(!c){break d}e=(e>>>0)%(c>>>0)|0;if(!e){break d}v[22708]=0;Q(318,b|0,c-e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}_j(a,f)}ed(f);gb=d+80|0;return}a=P()|0;O()|0;ed(f);S(a|0);L()}function th(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=WL(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));f=z[a+4268>>2];e=oe(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/f)*C(-60))/C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(oe(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Qp(c>C(1)?C(3.1415927410125732):C(d*C(C(6.2831854820251465)/f)))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(!(C(D(g))>C(1))){break a}g=C(C(C(-d)-c)/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(c+C(d*C(d*C(e/C(C(1)-C(e*c))))))}function bV(a){var b=0,c=0,d=0;a:{b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break b}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<1108){break b}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);c=a+1104|0;if((b-1108|0)!=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|b>>>0>262144){break b}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break b}b=a+1096|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if(!(w[b|0]|c|d)|(d|(c|w[b|0]))>>>0>4){break b}if(!bv(a+8|0)){break b}c=a+1094|0;b=a+40|0;while(1){if(w[b+32|0]>15|w[b+33|0]>64){break b}if(!bv(b)){break b}a=1;b=b+34|0;if((c|0)!=(b|0)){continue}break}break a}a=0}return a}function Bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;gb=e+32|0}function Bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;b=c+24|0;e=g+8|0;mV(b,e);f=yb(b);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;d=c+16|0;b=a;hd(d,b,c);d=yb(d);if((d|0)==(f|0)){bd(b,yb(c+24|0))}gb=c+32|0;c=(d|0)==(f|0);if(!c){lV(e)}b=-1;a:{if(!c){break a}b=0;if(!vV(g+8|0)){break a}b=-1;if(!Wf(a,1024)){break a}b=0;f=gb-1024|0;gb=f;c=gb-32|0;gb=c;e=c+24|0;ZB(e,f);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;if((d|0)==(e|0)){b=aC(f,0)>>>0<17}gb=f+1024|0}gb=g+608|0;return b|0}function zla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;ud(b,0);XC(d,a+1|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,v[b>>2]);qc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Y4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=gb+-64|0;gb=g;Lh(g+16|0,c);v[22708]=0;R(144,g+28|0,d|0);d=v[22708];v[22708]=0;c=1;b:{c:{if((d|0)==1){break c}v[22708]=0;R(144,g+40|0,e|0);c=v[22708];v[22708]=0;if((c|0)==1){c=2;break c}v[22708]=0;R(144,g+52|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){c=3;break c}c=g+16|0;v[g+8>>2]=c;v[g+12>>2]=c+48;v[22708]=0;c=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=c;U(146,a|0,b|0,g|0);a=v[22708];v[22708]=0;if((a|0)==1){c=P()|0;O()|0;hG(g+16|0);break b}hG(g+16|0);gb=g- -64|0;break a}a=(g+16|0)+B(c,12)|0;c=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(g+16|0)){continue}break}}S(c|0);L()}}function xJ(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=gb-16|0;gb=d;a:{b:{c:{d:{if((b|0)>=0){if((go(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;d=Q(70,d|0,7993)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,d);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}if(c>1?1:c<0){a=ba(8)|0;v[22708]=0;d=Q(70,d|0,9006)|0;b=v[22708];v[22708]=0;if((b|0)!=1){rc(a,d);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}b=P()|0;O()|0;da(a|0);break b}e=Po(c*64);v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]=e;gb=d+16|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{d=gb-16|0;gb=d;c=b;wb(b);e=a;h=qN(a,d+8|0);b:{f=Jg(b);if(!f){break b}v[22708]=0;R(617,e|0,f|0);g=v[22708];v[22708]=0;if((g|0)!=1){g=v[c+4>>2];c=v[c>>2];v[22708]=0;Y(1497,e|0,c|0,g|0,f|0);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}a=P()|0;O()|0;uv(h);S(a|0);L()}gb=d+16|0;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[22708]=0;c=Q(1496,a+24|0,b+24|0)|0;d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){v[22708]=0;Q(69,a+36|0,b+36|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Lc(c)}hn(e);S(a|0);L()}}function jB(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function hU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=b,g=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)),v[f>>2]=g;t[d+15|0]=w[a+4|0];t[d+14|0]=64;f=b,g=w[ac(d+15|0,d+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;f=b,g=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f+4>>2]=g;a=a+10|0;a=Yb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0;v[b+8>>2]=a;e=v[b+4>>2];c=v[b>>2];if(e>>>0>=c>>>0){e=c-1|0;v[b+4>>2]=e}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<e>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2;f=yf(b+68|0,0),g=e,v[f>>2]=g}gb=d+16|0}function r4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;a:{if(nH(c)){while(1){if(a>>>d&1){i=(d<<2)+c|0,j=oH(d,b),v[i>>2]=j}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){h=(e+8|0)+(d<<2)|0;f=1<<d&a;if(f|!c){f=oH(d,f?b:18720)}else{f=v[(d<<2)+c>>2]}v[h>>2]=f;g=((f|0)!=0)+g|0;d=d+1|0;if((d|0)!=6){continue}break}c=74848;b:{c:{switch(g|0){case 0:break a;case 1:break c;default:break b}}if(v[e+8>>2]!=74820){break b}c=74872;break a}c=Cd(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}gb=e+32|0;return c|0}function md(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=v[a+112>>2];d=v[a+116>>2];b:{if(c|d){b=c>>>0<=y[a+120>>2];c=v[a+124>>2];if((d|0)<(c|0)?1:(d|0)<=(c|0)?b:0){break b}}g=Vx(a);if((g|0)>-1){break a}}v[a+104>>2]=0;return-1}h=v[a+4>>2];j=a;b=v[a+116>>2];e=b;d=v[a+8>>2];c=d;f=v[a+112>>2];c:{if(!(b|f)){break c}c=d;i=v[a+120>>2]^-1;f=i+f|0;b=(v[a+124>>2]^-1)+e|0;b=f>>>0<i>>>0?b+1|0:b;e=d-h|0;i=f>>>0>=e>>>0;e=e>>31;if((b|0)>(e|0)?1:(e|0)<=(b|0)?i:0){break c}c=f+h|0}v[j+104>>2]=c;if(d){c=a;j=(d-h|0)+1|0;b=j;d=b+v[a+120>>2]|0;a=v[a+124>>2]+(b>>31)|0;v[c+120>>2]=d;v[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=h-1|0;if(w[a|0]!=(g|0)){t[a|0]=g}return g}function I2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{b:{c:{d:{if(i=gd(b),j=1,k=v[b+12>>2],k?i:j){Kb(a);break d}f=gb-16|0;gb=f;e=Kb(c+16|0);d=Ab(b);g=Of(11515);h=Jb(b);v[22708]=0;Y(116,e|0,h|0,d|0,d+g|0);d=v[22708];v[22708]=0;e:{if((d|0)!=1){v[22708]=0;W(117,e|0,11515,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;vb(e);S(a|0);L()}gb=f+16|0;v[22708]=0;R(153,c|0,b+12|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;U(3,a|0,c+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(c);vb(c+16|0)}gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(c+16|0);S(b|0);L()}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;e=Rf(d+48|0);v[22708]=0;g=Q(1472,b|0,e|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1473,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}g=bn(e);v[22708]=0;U(288,d|0,b|0,g|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}f=jc(d+24|0,d);Vc(e+8|0,f);xb(f);xb(d);d:{if(!((g>>>0)%(c>>>0)|0)){break d}v[22708]=0;Q(318,b|0,c-1|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}_j(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-80|0;gb=d;e=Rf(d+48|0);v[22708]=0;c=Q(825,b|0,e|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(826,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}c=e+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>=9){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-8|0}else{c=0}v[22708]=0;U(288,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=jc(d+24|0,d);Vc(e+8|0,b);xb(b);xb(d);_j(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=gb+-64|0;gb=e;d=v[a+28>>2];mo(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];f=v[a+12>>2];g=d;d=v[a+8>>2]+d|0;f=g>>>0>d>>>0?f+1|0:f;d=sh(e+48|0,d,f);f=v[d+12>>2];v[e+16>>2]=v[d+8>>2];v[e+20>>2]=f;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;kk(h,e+8|0)}d=e+24|0;te(d,v[a+28>>2]);g=v[d+12>>2];v[e+40>>2]=v[d+8>>2];v[e+44>>2]=g;jS(v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=oo(d,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22708]=0;ca(1527,a|0,c|0,b|0,e+40|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;break a}a=P()|0;O()|0;Hb(b);S(a|0);L()}}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function P8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=gb-96|0;gb=d;v[d+88>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=f;v[d+48>>2]=c;v[d+52>>2]=e;a=Ud(d+40|0);c=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=c;v[22708]=0;c=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;U(2074,d- -64|0,d+16|0,d+8|0);a=v[22708];v[22708]=0;a:{b:{if((a|0)!=1){a=v[qi(d+32|0,d+88|0)>>2];v[22708]=0;b=+za(2075,d- -64|0,+b,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}xb(d- -64|0);eg(d+88|0);gb=d+96|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;xb(d- -64|0)}eg(d+88|0);S(a|0);L()}function rn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=1;j=d&2147483647;n=j;i=(j|0)==2147418112;l=c;a:{if(i&!c?a|b:i&(c|0)!=0|j>>>0>2147418112){break a}i=h&2147483647;o=i;m=(i|0)==2147418112;j=g;if(m&!g?e|f:m&(g|0)!=0|i>>>0>2147418112){break a}if(!(a|e|(j|l)|(b|f|(n|o)))){return 0}l=d&h;if((l|0)>0?1:(l|0)>=0){k=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}k=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}k=(a^e|c^g)!=0|(b^f|d^h)!=0}return k}function kl(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!w[tj(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[22708]=0;d=v[(a+d|0)+24>>2];f=v[22708];v[22708]=0;d:{if((f|0)==1){break d}v[22708]=0;b=W(2311,d|0,b|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;Z(b|0)|0;d=1;sj(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22708]=0;X(2028);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)==1){break b}S(a|0);L()}$()}ih(v[v[a>>2]-12>>2]+a|0,d);gb=e+16|0;return}V(0)|0;O()|0;Bb()}L()}function fga(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;if((c|0)!=(b|0)){continue}break}zN(a+484344|0);Se(a+1298268|0);Se(a+1298280|0);Se(a+1298292|0);qD(a+1298368|0);c=a+900380|0;b=a+484380|0;while(1){Ol(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Xb(nv(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){zM(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function Dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);li(d,1,a);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){e=d+16|0;vb(e);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;f=b,g=w[ac(e,d)|0]<<2,u[f+30>>1]=g;gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];mo(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];h=v[a+12>>2];f=v[a+8>>2]+d|0;h=f>>>0<d>>>0?h+1|0:h;f=sh(e+40|0,f,h);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;kk(g,e)}g=e+16|0;te(g,v[a+28>>2]);d=v[g+12>>2];v[e+32>>2]=v[g+8>>2];v[e+36>>2]=d;ZM(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=oo(g,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22708]=0;ca(1527,a|0,c|0,b|0,e+32|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function $da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];mo(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];h=v[a+12>>2];f=v[a+8>>2]+d|0;h=f>>>0<d>>>0?h+1|0:h;f=sh(e+40|0,f,h);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;kk(g,e)}g=e+16|0;te(g,v[a+28>>2]);d=v[g+12>>2];v[e+32>>2]=v[g+8>>2];v[e+36>>2]=d;gN(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=oo(g,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22708]=0;ca(1527,a|0,c|0,b|0,e+32|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function pG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);g=Ab(b);i=Jb(c);j=Ab(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(sp(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=zd(b),v[k+32>>2]=l;c=Gd(e+40|0,e+32|0);k=e,l=zd(b),v[k+8>>2]=l;k=e,l=xe(e+8|0,h),v[k+16>>2]=l;d=Gd(e+24|0,e+16|0);bG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}f=Jb(b);h=Ab(b);g=Jb(c);d=-1;i=Ab(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!sp(g,i,c)){continue}break}d=c-f|0}}if((Ab(b)-1|0)!=(d|0)){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function TI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-208|0;gb=f;v[f+204>>2]=c;c=f+160|0;Qb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((by(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}h=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}i=c&32;b:{if(v[a+48>>2]){b=by(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;g=f+80|0;v[a+16>>2]=g;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=by(a,b,f+200|0,g,f+160|0,d,e);b=d;if(!c){break b}kb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|i;b=a&32?-1:b;if(!h){break a}}gb=f+208|0;return b}function Nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function WA(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;h=Nl(a,b);a:{if((h|0)==255){break a}if(wk(a)){break a}b:{if(c>>>0>6208431){i=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}i=f;c=oqa(1<<20-f,0,c,0)+24858e3|0;f=jb;c=Qc(rqa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),jb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Pc(g+14|0,g+12|0)>>1]}e=Eu(h);b=lc(a+4|0,h);t[b|0]=(i<<10|c)>>>8|(d?0:32);Yh(v[a>>2],e|160,c&255);Yh(v[a>>2],e|176,w[b|0]);t[a+530|0]=1}gb=g+16|0}function UZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;ud(b,0);li(d,1,a+33|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=d+16|0;vb(c);e=a+50|0;v[b>>2]=w[e|0]|w[e+1|0]<<8;e=a+52|0;v[b+24>>2]=w[e|0]|w[e+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;f=b,g=w[ac(c,d)|0]<<2,u[f+30>>1]=g;c=a+55|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;if((c|0)!=65535){break b}v[b+4>>2]=0;v[b+8>>2]=0;break a}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0}function tJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb-16|0;gb=e;a:{b:{c:{d=a+8|0;d:{if(!vl(d)){if((b|0)<0|(hq(d)|0)<=(b|0)){break d}a=Tl(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=vl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ba(8)|0;v[22708]=0;b=Q(70,e|0,3092)|0;c=v[22708];v[22708]=0;e:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break e}c=P()|0;O()|0;da(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}gb=e+16|0;return}L()}function rY(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(c,-6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function rI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;gb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[22614]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+76800>>2];if(d<<B(c,6)-6<0?c>>>0<=3:0){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[115189]=25;e=-1}return e|0}function Vq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;g=Nb(a)-1|0;a:{if((Nb(a)|0)==1){break a}while(1){if(x[Cc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Nb(a)-1>>>0){continue}break}}h=x[Cc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Cc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Cc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Cc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((w[Cc(a,g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=oqa(d,g,a,a>>31);a=h-e|0;j=f,k=Ac(pqa(b,jb,a,a>>31),jb)+i|0,v[j+12>>2]=k}Rd(f+12|0,0,65536);gb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function AV(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){m=x[sc(b,l)>>1];n=m+1|0;i=(h&65535)>>>0>m>>>0|m>>>0>127;j=i?j:c>>>0>l>>>0?n:j;k=(k&65535)>>>0>m>>>0?k:n;h=i?h:n;l=l+1|0;if((l|0)!=128){continue}break}Bf(b,c);i=v[a+8>>2];a:{b:{c:{if(!f){break c}c=h&65535;if((i+((c<<11)+f|0)|0)!=(jm(a)&-2)){break c}Zc(a,i+(c<<10)|0);if(!cC(a,16,1)){break b}u[e>>1]=8;break b}if(!g|(h&65535)==(j&65535)){break a}Zc(a,i+((j&65535)<<10)|0);h=cC(a,64,1)?h:j}Zc(a,i)}c=k&65535;d:{if(c>>>0>(h&65535)>>>0){if(((d+i|0)+(B(c,x[e>>1])<<8)|0)==(jm(a)|0)){break d}}if(c>>>0>=255){ev(b,254,65534);ev(b,255,65535)}k=h}return k&65535}function Oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function C$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=gb-32|0;gb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;v[22708]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ka(1928,a|0,b|0,k|0)|0;b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;ja(1923,7685,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();a=-255}gb=l+32|0;break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-48|0;gb=c;f=c+24|0;d=f;g=mc(d+8|0);v[22708]=0;e=T(467,b|0)|0;h=v[22708];v[22708]=0;a:{b:{if((h|0)==1){break b}v[22708]=0;U(393,d|0,b|0,e|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}d=v[d>>2];v[22708]=0;Q(318,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;gc(g);S(a|0);L()}v[22708]=0;Or(c+16|0,f);b=v[22708];v[22708]=0;c:{if((b|0)==1){break c}v[22708]=0;b=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=b;R(640,a|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}zc(c+24|0);gb=c+48|0;return}a=P()|0;O()|0;zc(c+24|0);S(a|0);L()}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Rf(c+48|0);v[22708]=0;f=Q(1178,b|0,d|0)|0;e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)!=1){if(f){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(1179,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}f=uD(d);v[22708]=0;U(288,c|0,b|0,f|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}e=jc(c+24|0,c);Vc(d+8|0,e);xb(e);xb(c);d:{if(!(f&1)){break d}v[22708]=0;Q(318,b|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break d}break a}_j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function Hoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Yj(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=gb-16|0;gb=e;c=lY(e,a,c);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){wb(a);RW(b);b=b+48|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=e+16|0;break c}b=wb(a);b=jY(d+8|0,kY(a,Yj(a)+c|0),Yj(a),b);v[22708]=0;SW(b,c);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(485,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Fv(b)}gb=d+32|0;break a}a=P()|0;O()|0;Fv(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Yj(a);mY(a,b);tY(a)}}function CS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;qc(a,65536);qc(a+4|0,64);qc(a+8|0,256);yg(a+28|0,16384);zf(a+30|0,128);zf(a+31|0,17);if(w[a+16|0]>=4){t[a+16|0]=0}if(w[a+17|0]>=5){t[a+17|0]=0}if(w[a+18|0]>=3){t[a+18|0]=0}zf(a+19|0,64);zf(a+20|0,100);c=224;d=t[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<33){break a}}t[a+26|0]=c}zf(a+23|0,64);zf(a+24|0,64);iB(a+48|0,64);iB(a+68|0,64);iB(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(w[lc(c,b)|0]){if(w[lc(c,b)|0]<121){break b}}e=lc(c,b),f=b+1|0,t[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!up(w[a+14|0])){t[a+14|0]=5}if(w[a+34|0]>=251){t[a+34|0]=0}}function oR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;n=e,o=ar(b),v[n+16>>2]=o;i=e+24|0;l=i;c=gb-32|0;gb=c;j=cR(a,c+28|0,b);b=v[j>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=fc(a);f=c+8|0;h=Uj(f,bR(),Vj(g+8|0,b));b=v[h>>2];v[22708]=0;b=b+16|0;d=v[22708];v[22708]=0;a:{if((d|0)!=1){d=gb-16|0;gb=d;v[d+8>>2]=v[e+16>>2];k=v[d+8>>2];m=v[k+4>>2];v[b>>2]=v[k>>2];v[b+4>>2]=m;dd(b+8|0);gb=d+16|0;n=fc(h),o=1,t[n+4|0]=o;gb=g+16|0;break a}a=P()|0;O()|0;NA(h);S(a|0);L()}Gk(a,v[c+28>>2],j,v[f>>2]);b=be(f);t[c+27|0]=1;NA(f)}Wj(l,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ve(i);gb=e+32|0;return a+8|0}function tj(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;t[a|0]=0;f=_f(v[v[b>>2]-12>>2]+b|0);d=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){d=v[d+72>>2];if(d){$s(d)}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=e+24|0;Fc(c,v[v[b>>2]-12>>2]+b|0);v[22708]=0;f=T(21,c|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Wb(e+24|0);c=cj(e+16|0,b);d=Vi(e+8|0);d:{if(!mk(c,d)){break d}while(1){if(!nh(f,8192,nl(c))){break d}ml(c);if(mk(c,d)){continue}break}}if(!lk(c,d)){break c}ih(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=_f(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}ih(d,4)}gb=e+32|0;return a}a=P()|0;O()|0;Wb(e+24|0);S(a|0);L()}function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}v[22708]=0;_(1961,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22708]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;Y(2e3,c+16|0,d|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)==1){break c}a=c+16|0;b=ie(Jb(a));vb(a);break b}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1912,2627,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=c+32|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function A$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[22708]=0;_(1935,a|0);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[22708]=0;_(1961,b|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}f=v[a+24>>2];b=uc(e+8|0,b);v[22708]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ia(2003,f|0,e|0,c|0,d|0,1);c=v[22708];v[22708]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,5773,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();b=0}gb=e+16|0;break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return b|0}function F2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=OG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);nj(i,k);Ic(k);Ph(k,a);nj(h,k);Ic(k);l=d,m=rj(a),v[l>>2]=m;l=e,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(f,k);vb(k);Qh(k,a);nj(g,k);Ic(k);a=dl(a);break a}a=NG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);nj(i,k);Ic(k);Ph(k,a);nj(h,k);Ic(k);l=d,m=rj(a),v[l>>2]=m;l=e,m=qj(a),v[l>>2]=m;Ug(k,a);Eb(f,k);vb(k);Qh(k,a);nj(g,k);Ic(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}function Ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=Gi(a,b,c,d);v[a>>2]=49908;c=mc(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Qb(a+4248|0,0,48);v[22708]=0;d=ga(1284)|0;e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}v[22708]=0;d=T(1285,d|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}v[a+4296>>2]=d;Qt(a);Pt(a);v[22708]=0;W(1533,a+44|0,2,2)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;Uh(b);d=v[22708];v[22708]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;gc(c);jf(b);S(a|0);L()}function $I(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Ne(a)){ec(a,31);return 0}f=a,g=Ne(a),t[f+1375|0]=g;d=yj(a);b=yj(a);yj(a);f=a,g=yj(a),v[f+1112>>2]=g;yj(a);c=Ne(a);v[a+1116>>2]=c;if(!iy(a,a+1120|0,c)){ec(a,10);return 0}v[a+1404>>2]=-2;a:{if((b|0)==-1?(d|0)==-1:0){break a}b=v[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){e=v[a+1116>>2];if((e|0)<1){b=27}else{c=0;b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}v[a- -64>>2]=d;v[a+60>>2]=v[a+56>>2]+(b+e|0)}v[a+1380>>2]=0;return 1}function mX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Sd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,2,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(444,d|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}v[22708]=0;Q(401,d|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function UC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;kh(b,Fd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Nb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Le(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Lb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[pd(e+8|0,e+4|0)>>2];h=Lb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=e+16|0}function O2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=RG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);Eb(i,k);vb(k);Ph(k,a);Eb(h,k);vb(k);l=d,m=rj(a),t[l|0]=m;l=e,m=qj(a),t[l|0]=m;Ug(k,a);Eb(f,k);vb(k);Qh(k,a);Eb(g,k);vb(k);a=dl(a);break a}a=QG(b);fl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;el(k,a);Eb(i,k);vb(k);Ph(k,a);Eb(h,k);vb(k);l=d,m=rj(a),t[l|0]=m;l=e,m=qj(a),t[l|0]=m;Ug(k,a);Eb(f,k);vb(k);Qh(k,a);Eb(g,k);vb(k);a=dl(a)}v[j>>2]=a;gb=k+16|0}
function rt(a,b,c){var d=0,e=0;d=a,e=zj(C(C(z[c+1792>>2]*C(75038))+C(C(C(C(C(C(C(C(z[c+3584>>2]-z[c>>2])*C(29))+C(C(z[c+256>>2]+z[c+3328>>2])*C(213)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+768>>2]+z[c+2816>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))))),u[d>>1]=e;d=(b<<5)+a|0,e=zj(C(C(C(C(C(C(C(C(z[c+3592>>2]*C(104))+C(z[c+3080>>2]*C(1567)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-16|0;gb=d;b=x[b>>1];e=d;f=x[a+30>>1];if(f){b=qo(b<<16>>16,f<<16>>16)}u[e+14>>1]=b;a:{if(!gd(c)){hk(lN(a+52|0,d+14|0),c);break a}a=a+52|0;b=hz(a,d+14|0);v[d+8>>2]=b;m=d,n=Eh(a),v[m>>2]=n;if(!og(d+8|0,d)){break a}c=gb-16|0;gb=c;l=c+8|0;b=v[yc(c,b)>>2];e=gb-16|0;gb=e;v[e+8>>2]=b;f=gb-16|0;gb=f;j=e+8|0;k=v[j>>2];h=k;i=yc(f+8|0,h);Tj(i);b=a;g=b;if(v[b>>2]==(h|0)){v[g>>2]=v[i>>2]}g=wb(b);v[g>>2]=v[g>>2]-1;$M(v[fc(b)>>2],h);b=v[i>>2];gb=f+16|0;a=fc(a);Fk(ve(j));Xk(a,k,1);gb=e+16|0;yc(l,b);gb=c+16|0}gb=d+16|0}function Ofa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;a:{if(x[a+480192>>1]<b>>>0){break a}h=v[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;ES(b,h);i=g,j=sC(b),v[i+8>>2]=j;i=g,j=Dh(b),v[i>>2]=j;while(1){b:{v[22708]=0;b=Gb(g+8|0,g);h=v[22708];v[22708]=0;if((h|0)==1){break b}if(!b){or(g+16|0);break a}v[22708]=0;b=Wl(g+8|0);h=v[22708];v[22708]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Tj(g+8|0);continue}break}a=P()|0;O()|0;or(g+16|0);S(a|0);L()}gb=g+32|0}function jla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Lh(g,c);v[22708]=0;R(160,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(144,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22708]=0;us(f+16|0,f+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function Yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,24);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function Ooa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Lh(g,c);v[22708]=0;R(144,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(144,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22708]=0;us(f+16|0,f+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function x0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;On(g,c);v[22708]=0;R(160,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(160,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22708]=0;us(f+16|0,f+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(146,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function wh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb+-64|0;gb=e;a:{b:{if(c-1>>>0>1023){break b}if(me(a,b)){break b}c:{d:{if(Tf(a)>>>0<=b>>>0){d=lz(e+8|0,a);v[22708]=0;U(1490,a|0,b+1|0,d|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}Im(d)}d=af(a,b);v[22708]=0;Q(1491,d|0,c|0)|0;c=v[22708];v[22708]=0;e:{if((c|0)!=1){c=af(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=af(a,b);v[22708]=0;_(1492,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){break e}}a=V(89104)|0;b=O()|0;break c}g=ii(af(a,b));break b}a=V(89104)|0;b=O()|0;Im(d)}if((ea(89104)|0)!=(b|0)){break a}Z(a|0)|0;$()}gb=e- -64|0;return g|0}S(a|0);L()}function B$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22708]=0;_(1961,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break d}c=v[a+24>>2];e=uc(d+8|0,b);v[22708]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=nG(c,d,1);e=v[22708];v[22708]=0;c=jb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,5804,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();b=0;c=0}gb=d+16|0;a=c;break a}b=P()|0;O()|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}ma(a|0);return b|0}function yZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-32|0;gb=g;d=b;f=oc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>>0){gq(d,f);break d}e=wb(d);e=Zg(h+8|0,qh(d,oc(d)+f|0),oc(d),e);v[22708]=0;R(295,e|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break c}v[22708]=0;R(296,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}ae(e)}gb=h+32|0;break b}a=P()|0;O()|0;ae(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Cm(d,e+v[d>>2]|0)}}c=Pb(a,c);if(c){ID(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;kd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function T4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;c=Ie(b,-1);e=w[a+52|0];f=a;a:{b:{if(c){c=b;if(e){break a}b=v[a+48>>2];a=Ie(b,-1)^1;break b}if(e){g=d,h=xh(v[a+48>>2]),t[g+19|0]=h;c:{d:{e:{f:{c=d+20|0;switch(Ws(v[a+36>>2],v[a+40>>2],d+19|0,c,d+12|0,d+24|0,d+32|0,c)-1|0){case 0:case 1:break d;case 2:break f;default:break e}}c=v[a+48>>2];v[d+20>>2]=d+25;t[d+24|0]=c}while(1){c=v[d+20>>2];e=1;if(c>>>0<=d+24>>>0){break c}c=c-1|0;v[d+20>>2]=c;if((Ts(t[c|0],v[a+32>>2])|0)!=-1){continue}break}}c=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;c=b}gb=d+32|0;return c|0}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)==1){break c}v[22708]=0;_(1961,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}e=v[a+24>>2];b=uc(d+8|0,b);v[22708]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;Y(2002,e|0,d|0,(c|0)!=0|0,1);c=v[22708];v[22708]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,7275,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function RS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}Se(a);Rq(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Fb(f+12|0,f+4|0)>>2];Bp(a,zb(b)+g|0,h);ws(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[pc(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=pc(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Fb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}gb=f+16|0;return(d|0)!=0|0}function Nm(a,b,c,d){var e=0,f=0,g=0;e=gb-16|0;gb=e;f=e+8|0;g=a+1074312|0;Db(f,g,84);a:{if(Cb(f)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){f=e+8|0;Db(f,g,10);if(!Cb(f)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;a=e+8|0;Db(a,g,10);if(!Cb(a)){break a}t[b+831|0]=0;u[b+778>>1]=0}gb=e+16|0}function sJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{c:{c=a+8|0;d:{if(!vl(c)){if((b|0)<0|(hq(c)|0)<=(b|0)){break d}c=(w[Tl(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=vl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ba(8)|0;v[22708]=0;b=Q(70,d|0,3092)|0;c=v[22708];v[22708]=0;e:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break e}c=P()|0;O()|0;da(a|0)}S(c|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}gb=d+16|0;return c|0}L()}function j$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=c>>>0){break a}d=a+4|0;e=w[d+1|0]<<8;f=w[d+2|0]<<16|w[d+3|0]<<24;if((w[d|0]|e|f)>>>0>c>>>0|c-(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<(f|(e|w[d|0]))>>>0|!(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){break a}g=1;if(oc(b)>>>0>=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}Py(b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))|0)}return g|0}function tx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=f+8|0;Fc(g,b);v[22708]=0;b=T(2481,g|0)|0;g=v[22708];v[22708]=0;a:{if((g|0)==1){break a}v[22708]=0;Y(2493,b|0,83408,83440,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;b=T(2482,f+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;c=T(2494,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}v[d>>2]=c;v[22708]=0;c=T(2491,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[e>>2]=c;v[22708]=0;R(2492,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function Npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;ud(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;Mk(e,2,a+2|0);d=e+16|0;Bc(d,e);v[22708]=0;Q(301,b+492|0,d|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(e+16|0);d=b+236|0;c=c+1|0;while(1){g=w[(a+f|0)+31|0];h=wd(d,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if(f>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;f=a+2|0;d=a+3|0;g=a+4|0;KN(w[a|0]&15,w[c|0]&15,w[f|0]&15,w[d|0]&15,w[g|0]&15,a+5|0,b+48|0);KN(w[a|0]>>>4|0,w[c|0]>>>4|0,w[f|0]>>>4|0,w[d|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);gb=e+32|0;return}a=P()|0;O()|0;vb(e+16|0);S(a|0);L()}function R9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=gb-16|0;gb=e;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}v[22708]=0;_(1961,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(e+8|0,b);v[22708]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Xa(2004,d|0,e|0,+c,1);d=v[22708];v[22708]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3018,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}gb=e+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function L$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Sg(a,v[b+8>>2],f)){cx(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;ax(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;ax(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];f=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=g;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[bh(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;g=a;e=ee(e);a:{if(D(e)<2147483648){h=~~e;break a}h=-2147483648}i=g,j=Uc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return f<<3}function wx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=f+8|0;Fc(g,b);v[22708]=0;b=T(21,g|0)|0;g=v[22708];v[22708]=0;a:{if((g|0)==1){break a}v[22708]=0;Y(2473,b|0,83408,83440,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;b=T(2453,f+8|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;c=T(2474,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}t[d|0]=c;v[22708]=0;c=T(2465,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}t[e|0]=c;v[22708]=0;R(2466,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Wb(f+8|0);S(a|0);L()}function wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];g=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;a=d;f=fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Uc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return g<<2}function vY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=lY(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;U(484,a|0,e|0,b|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=jY(c+8|0,kY(a,Yj(a)+1|0),Yj(a),e);f=v[a+8>>2];v[22708]=0;U(484,e|0,f|0,b|0);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[22708]=0;R(485,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Fv(a);gb=c+32|0;break b}b=P()|0;O()|0;Fv(a);S(b|0);L()}}function z_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Jw(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;U(278,a|0,e|0,b|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+36;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=NF(c+8|0,OF(a,al(a)+1|0),al(a),e);f=v[a+8>>2];v[22708]=0;U(278,e|0,f|0,b|0);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+36;v[22708]=0;R(209,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}ls(a);gb=c+32|0;break b}b=P()|0;O()|0;ls(a);S(b|0);L()}}function Lo(a){var b=0,c=0,d=0,e=0,f=0,g=0;e=x[a+24>>1];c=v[a+4>>2];d=!w[a+77|0]<<1;b=(e<<2)+(x[c+28>>1]>>>d|0)|0;v[a+40>>2]=((b&3)<<4)+34128;f=b>>>2|0;b=b>>>0<48;g=b?12-f|0:0;u[a+32>>1]=g;u[a+36>>1]=b?1:1<<f-12;u[a+34>>1]=-1<<g^-1;if((e|0)==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+52>>2]=((b&3)<<4)+34128;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+44>>1]=f;u[a+48>>1]=b?1:1<<e-12;u[a+46>>1]=-1<<f^-1;c=(x[a+30>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+64>>2]=((c&3)<<4)+34128;d=c>>>2|0;c=c>>>0<48;b=c?12-d|0:0;u[a+56>>1]=b;u[a+60>>1]=c?1:1<<d-12;u[a+58>>1]=-1<<b^-1}function V9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;a:{b:{c:{if((d|0)==1){break c}v[22708]=0;_(1961,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22708]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(1999,d|0,c|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3055,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}gb=c+16|0;return+e}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(pk(a)>>>0>=b>>>0){h=e,i=Tf(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Fb(e+12|0,e+8|0)>>2];if(f){while(1){GN(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){kz(a,b-d|0,c);break a}xN(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){Tf(d);AO(d);uN(d);_z(wb(d),v[d>>2],pk(d));h=wb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=wN(a,b);if(tN()>>>0<f>>>0){Sc();L()}wb(d);g=sN(f);v[d>>2]=g;v[d+4>>2]=g;h=wb(d),i=B(f,52)+g|0,v[h>>2]=i;rN(d,0);kz(a,b,c)}gb=e+16|0}function mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46162>>1])+B(u[e-2>>1],u[f+46160>>1])|0)+B(u[e+2>>1],u[f+46164>>1])|0)+B(u[e+4>>1],u[f+46166>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function O4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;c=Ie(b,-1);e=w[a+52|0];f=a;a:{b:{if(c){c=b;if(e){break a}b=v[a+48>>2];a=Ie(b,-1)^1;break b}if(e){v[d+16>>2]=v[a+48>>2];c:{d:{e:{f:{c=d+20|0;switch(Ws(v[a+36>>2],v[a+40>>2],d+16|0,c,d+12|0,d+24|0,d+32|0,c)-1|0){case 0:case 1:break d;case 2:break f;default:break e}}c=v[a+48>>2];v[d+20>>2]=d+25;t[d+24|0]=c}while(1){c=v[d+20>>2];e=1;if(c>>>0<=d+24>>>0){break c}c=c-1|0;v[d+20>>2]=c;if((Ts(t[c|0],v[a+32>>2])|0)!=-1){continue}break}}c=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;c=b}gb=d+32|0;return c|0}function Cpa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{d=gb+-64|0;gb=d;k=d;g=d+16|0;h=gb-16|0;gb=h;l=fU(h+8|0);while(1){e=gb-48|0;gb=e;b=l;c=v[b+4>>2]-v[b>>2]|0;b:{if(!c){b=v[b>>2];break b}c=c+1|0;if(!c){b=RT(TT(e+8|0,32));break b}f=E(c);f=TT(e+8|0,(c&-1>>>f+1?32:31)-f|0);while(1){j=RT(f);if(c>>>0<=j>>>0){continue}break}b=v[b>>2]+j|0}gb=e+48|0;m=yf(g,i),n=b,v[m>>2]=n;i=i+1|0;if((i|0)!=12){continue}break}gb=h+16|0;b=oU(k,g,tU(g));v[22708]=0;OB(a,b,0);a=v[22708];v[22708]=0;if((a|0)!=1){Lc(b);gb=d- -64|0;break a}a=P()|0;O()|0;Lc(b);S(a|0);L()}}function Cna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,16);a=v[d>>2];v[22708]=0;d=Sd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,3,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(684,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function mq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;Ai(e+16|0,b);c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;d=gb-32|0;gb=d;c=v[e+4>>2];f=v[e>>2];v[d+8>>2]=f;v[d+12>>2]=c;v[d+16>>2]=f;v[d+20>>2]=c;f=gb-16|0;gb=f;g=v[d+12>>2];c=f;h=v[d+8>>2];v[c>>2]=h;v[c+4>>2]=g;v[c+8>>2]=h;v[c+12>>2]=g;g=gb-16|0;gb=g;h=v[c>>2];i=v[c>>2];c=yb(c);v[22708]=0;jo(d+24|0,h,c+i|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){gb=g+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=f+16|0;c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;c=e+24|0;qy(c,a,d);gb=d+32|0;yb(c);a=e+8|0;Ai(a,b);yb(a);gb=e+32|0}function aZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,44);a=v[d>>2];v[22708]=0;d=Sd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,2,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(450,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function W9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)==1){break c}v[22708]=0;_(1961,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}c=v[a+24>>2];b=uc(d+8|0,b);v[22708]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(1997,c|0,d|0,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,7306,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function rQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function pQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Fb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Fb(c,f+4|0)>>2];c=zb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(zb(w[c|0])+h|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(zb(w[c|0])+d|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=f+16|0;return h+i<<1}function nQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function mQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Fb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Fb(c,f+4|0)>>2];c=zb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(zb(w[c+1|0])+h|0)+(zb(w[c|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(zb(w[c+1|0])+d|0)+(zb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=f+16|0;return h+i<<1}function L4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{b:{c:{if(Ie(b,-1)){break c}i=c,j=xh(b),t[i+23|0]=j;if(w[a+44|0]){if((Kk(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Ws(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Kk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((Kk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Xs(b);break a}a=-1}gb=c+32|0;return a|0}function vka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb+-64|0;gb=f;g=f+24|0;Lh(g,c);v[22708]=0;R(777,f+36|0,d|0);c=v[22708];v[22708]=0;a:{b:{c:{if((c|0)!=1){v[22708]=0;R(777,f+48|0,e|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=2}else{a=1}a=B(a,12)+g|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}c=f+24|0;v[f+16>>2]=c;v[f+20>>2]=c+36;v[22708]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(453,a|0,b|0,f+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;cl(f+24|0)}S(b|0);L()}cl(f+24|0);gb=f- -64|0}function tM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=Gi(a,b,c,d);t[a+4260|0]=e;v[a>>2]=50952;c=mc(a+4264|0);d=mc(a+4276|0);v[a+4232>>2]=1061997773;e=a+4224|0;v[e>>2]=1061158912;v[e+4>>2]=1059082943;e=a+4216|0;v[e>>2]=1038174126;v[e+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[a+4328>>2]=0;e=a+4320|0;v[e>>2]=0;v[e+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;v[22708]=0;W(1533,a+44|0,2,2)|0;e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}v[22708]=0;Uh(b);e=v[22708];v[22708]=0;if((e|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);Lc(c);jf(b);S(a|0);L()}function XE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=w[a+8|0];f=v[a>>2];a=v[a+4>>2];d=Jb(b);b=Ab(b);c=gb-16|0;gb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Fb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=f;break b}b=e;a=f;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{d:{e:{switch(g-1|0){case 0:case 1:d=v[c+12>>2];t[c+7|0]=0;Jo(a,((a+d|0)-e|0)+b|0,c+7|0);break d;case 2:case 3:break e;default:break c}}d=v[c+12>>2];t[c+6|0]=32;Jo(a,((a+d|0)-e|0)+b|0,c+6|0)}f:{switch(g-1|0){case 0:case 3:break f;default:break c}}t[(v[c+12>>2]+f|0)-1|0]=0}gb=c+16|0}function X7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-32|0;gb=b;e=mc(a);Ld(b+24|0);a=0;c=v[b+28>>2];d=v[b+24>>2];v[22708]=0;R(1421,e|0,Hy(d,c)|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){b:{c:{c=v[b+24>>2];if((Hy(c,v[b+28>>2])|0)>0){while(1){c=v[(a<<3)+c>>2];v[22708]=0;c=Q(70,b+8|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;R(1423,e|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(c);c=v[b+24>>2];a=a+1|0;if((Hy(c,v[b+28>>2])|0)>(a|0)){continue}break}}gb=b+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0}yd(e);S(a|0);L()}function Dk(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;o(+e);j(1)|0;c=(j(0)|0)+128|0;b=c<<4&4080;d=A[b+29040>>3];a=a-(e+-26388279066624)-A[b+29048>>3];return ji(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function yla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;ud(b,0);XC(d,a+1|0);c=d+16|0;Bc(c,d);v[22708]=0;Q(303,b+43|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;qc(b+8|0,v[b>>2]);qc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function dD(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=c;e=w[d+74|0];t[d+74|0]=e-1|e;e=v[d>>2];b:{if(e&8){v[d>>2]=e|32;d=-1;break b}v[d+4>>2]=0;v[d+8>>2]=0;e=v[d+44>>2];v[d+28>>2]=e;v[d+20>>2]=e;v[d+16>>2]=e+v[d+48>>2];d=0}if(d){break a}d=v[c+16>>2]}f=g;g=v[c+20>>2];if(f>>>0>d-g>>>0){return kb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]<0){d=0;break c}f=b;while(1){d=f;if(!d){d=0;break c}f=d-1|0;if(w[f+a|0]!=10){continue}break}f=kb[v[c+36>>2]](c,a,d)|0;if(f>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;g=v[c+20>>2]}hc(g,a,b);v[c+20>>2]=v[c+20>>2]+b;f=b+d|0}return f}function nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=f>>>21&2040;e=(((B(t[e|0],u[f+46162>>1])+B(t[e-1|0],u[f+46160>>1])|0)+B(t[e+1|0],u[f+46164>>1])|0)+B(t[e+2|0],u[f+46166>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function WH(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!_f(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(vH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22708]=0;b=T(2316,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22708]=0;_(2317,a+b|0);a=v[22708];v[22708]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function g8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=mc(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[22708]=0;R(2100,c|0,(d+(a<<5)|0)+480289|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;U(2093,c+16|0,b|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}v[22708]=0;R(1423,f|0,c+16|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}vb(c+16|0);vb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+16|0)}vb(c)}yd(f);S(a|0);L()}function it(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=gb-240|0;gb=h;g=v[c>>2];v[h+232>>2]=g;c=v[c+4>>2];v[h>>2]=a;v[h+236>>2]=c;a:{b:{c:{d:{if((g|0)!=1){g=a;i=1;break d}g=a;i=1;if(c){break d}c=a;break c}while(1){c=g-v[(d<<2)+f>>2]|0;if((kb[b|0](c,a)|0)<1){c=g;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=g-4|0;if((kb[b|0](j,c)|0)>-1){break e}if((kb[b|0](j-e|0,c)|0)>-1){break e}}v[(i<<2)+h>>2]=c;g=h+232|0;e=HI(g);jt(g,e);i=i+1|0;d=d+e|0;e=0;g=c;if(v[h+236>>2]|v[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}GI(h,i);_x(c,b,d,f)}gb=h+240|0}function gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Eg(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;lq(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=en(c+8|0,fh(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22708]=0;lq(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22708]=0;R(1502,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}eh(a);gb=c+32|0;break b}b=P()|0;O()|0;eh(a);S(b|0);L()}}function Pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function yna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-80|0;gb=d;e=Rf(d+48|0);v[22708]=0;c=Q(687,b|0,e|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(688,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}c=e+2|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22708]=0;U(288,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=jc(d+24|0,d);Vc(e+8|0,b);xb(b);xb(d);pW(a,e)}ed(e);gb=d+80|0;return}a=P()|0;O()|0;ed(e);S(a|0);L()}function KU(a,b){var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,4);a=v[d>>2];v[22708]=0;d=Sd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,3,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(874,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(401,c|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function Zna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Np(c,a,1);wb(a);a=v[d+4>>2];v[22708]=0;R(657,a|0,b|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=ts(c+8|0,Zw(a,Ec(a)+1|0),Ec(a),e);e=v[a+8>>2];v[22708]=0;R(657,e|0,b|0);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[22708]=0;Mn(d,a);b=v[22708];v[22708]=0;if((b|0)==1){break c}ss(a);gb=c+32|0;break b}b=P()|0;O()|0;ss(a);S(b|0);L()}}function Ww(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[wb(a)>>2]){b=gb-16|0;gb=b;c=Jw(b,a,1);d=wb(a);e=v[c+4>>2];v[22708]=0;R(208,d|0,e|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+36;$b(c);gb=b+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}d=gb-32|0;gb=d;c=a;e=wb(a);b=NF(d+8|0,OF(a,al(a)+1|0),al(a),e);f=v[b+8>>2];v[22708]=0;R(208,e|0,f|0);e=v[22708];v[22708]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+36;v[22708]=0;R(209,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}ls(b);gb=d+32|0;break b}a=P()|0;O()|0;ls(b);S(a|0);L()}}lj(a)}function SD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=mi(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;wn(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=En(c+8|0,Uk(a,tc(a)+1|0),tc(a),e);f=v[a+8>>2];v[22708]=0;wn(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[22708]=0;R(313,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}Ih(a);gb=c+32|0;break b}b=P()|0;O()|0;Ih(a);S(b|0);L()}}function Dt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+12>>2]=b;u[f+10>>1]=0;u[f+8>>1]=65535;a:{b:{if(Et(f+12|0,f+10|0,f+8|0)){a=a+24|0;if(!me(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0){break a}if(x[v[a>>2]+480188>>1]>(d|0)){break b}}break a}if(e>>>0>5){break a}a=Xc(b,c,d&65535);c:{switch(e-1|0){default:g=w[a|0];break a;case 0:g=w[a+1|0];break a;case 1:g=w[a+2|0];break a;case 2:g=w[a+3|0];break a;case 3:g=w[a+4|0];break a;case 4:break c}}g=w[a+5|0]}gb=f+16|0;return g|0}function Qja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function _C(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Eg(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;cp(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=en(c+8|0,fh(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22708]=0;cp(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22708]=0;R(52,d|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}eh(a);gb=c+32|0;break b}b=P()|0;O()|0;eh(a);S(b|0);L()}}function B0(){var a=0;a:{if(t[465440]&1){break a}if(!Qd(465440)){break a}a=465152;while(1){a=Kb(a)+12|0;if((a|0)!=465440){continue}break}Pd(465440)}ld(465152,88408);ld(465164,88440);ld(465176,88476);ld(465188,88500);ld(465200,88524);ld(465212,88540);ld(465224,88560);ld(465236,88580);ld(465248,88608);ld(465260,88648);ld(465272,88680);ld(465284,88716);ld(465296,88752);ld(465308,88768);ld(465320,88784);ld(465332,88800);ld(465344,88524);ld(465356,88816);ld(465368,88832);ld(465380,88848);ld(465392,88864);ld(465404,88880);ld(465416,88896);ld(465428,88912)}function xP(a,b){var c=0,d=0,e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(!w[b+846|0]|v[a+480180>>2]!=1){break a}c=v[b+104>>2];if(!c){break a}if(!Md(c)){break a}d=x[c+34>>1];if(!(d&10)){break a}e=w[b+847|0]+w[(w[b+846|0]&15)+39680|0]|0;t[b+847|0]=e;if(e<<24>>24>-1){break a}t[b+847|0]=0;e=d&2;d=v[(e?4:12)+c>>2];f=v[b+760>>2]+1|0;v[b+760>>2]=f>>>0<v[(e?8:16)+c>>2]-d>>>0?f:0;e=jj(c);f=g+8|0;bc(f,zb(zb(v[c+20>>2]))+B(e,v[b+760>>2]+d|0)|0,e);b=v[f>>2];d=v[f+4>>2];if((b|0)!=(d|0)){while(1){t[b|0]=w[b|0]^-1;b=b+1|0;if((d|0)!=(b|0)){continue}break}}_h(c,a,0)}gb=g+16|0}function my(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=C(0),l=C(0);e=gb-32|0;gb=e;gJ(C(-z[a>>2]),C(z[a+24>>2]+z[a+12>>2]),C(z[a+48>>2]+z[a+36>>2]),e+20|0);gJ(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){d=a<<2;h=d+c|0;i=z[h>>2];f=z[d+(e+20|0)>>2];g=z[d+68256>>2];j=z[d+68268>>2];k=z[d+(e+8|0)>>2];z[h>>2]=C(f*g)-C(j*k);h=b+d|0;l=z[(0-a<<2)+68264>>2];f=C(C(f*j)+C(k*g));d=5-a<<2;g=z[d+68256>>2];z[h>>2]=C(i*l)-C(f*g);z[b+d>>2]=C(f*l)+C(i*g);a=a+1|0;if((a|0)!=3){continue}break}gb=e+32|0}function jma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,26);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function uj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=gb-16|0;gb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?E(e)+32|0:E(c);Mf(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;gb=f+16|0}function sQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function oQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Fb(c,e+4|0)>>2];c=zb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return g+i<<1}function bpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=cw(c,a,1);a=wb(a);e=v[d+4>>2];v[22708]=0;Av(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+20;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=bD(c+8|0,cD(a,Je(a)+1|0),Je(a),e);f=v[a+8>>2];v[22708]=0;Av(e,f,b);b=v[22708];v[22708]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+20;v[22708]=0;zv(d,a);b=v[22708];v[22708]=0;if((b|0)==1){break c}ip(a);gb=c+32|0;break b}b=P()|0;O()|0;ip(a);S(b|0);L()}}function Hna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-48|0;gb=e;v[22708]=0;c=Q(191,a|0,1)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}v[22708]=0;_(679,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[22708]=0;c=T(374,a|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}if(!c){break c}while(1){v[22708]=0;d=Q(680,a|0,e+8|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=w[e+8|0];if(d>>>0>63){break d}hc(zW(b,d),e+8|0,33)}if(c&255){continue}break}}xb(a);gb=e+48|0;return}}b=P()|0;O()|0;xb(a);S(b|0);L()}function lW(a){var b=0,c=0;a:{if(sd(a,11487,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4294966507){break a}b=a+16|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}}a=a+32|0;c=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return c}function Tz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}c=e+8|0;f=a+1074312|0;Db(c,f,21);d=Cb(c);g=a;a=w[b+821|0];a=Pz(g,w[b+828|0],d?a:a+16>>>2|0);Db(c,f,45);b:{if(!(!Cb(c)|w[b+828|0]!=3)){g=b;d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];c=d+1|0;break c}t[b+832|0]=a;c=1}t[g+821|0]=c;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}c=e+8|0;Db(c,f,47);if(!Cb(c)){break a}t[b+831|0]=a}if(a){h=b,i=Mb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[h+684>>2]=i}gb=e+16|0}function a6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=1073741807){i=d,j=Ab(a),v[i+8>>2]=j;e=xm(v[Mc(d+12|0,d+8|0)>>2]);if((e|0)!=(bq(a)|0)){a:{f=1;g=bq(a);h=Ab(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>g>>>0){b=Ti(b,c);break c}v[22708]=0;b=Q(2298,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}f=Ee(a);c=Jb(a)}yi(b,c,Ab(a)+1|0);if(f){ai(a,c,g+1|0)}d:{if((e|0)!=1){rg(a,e+1|0);de(a,h);cf(a,b);break d}Ze(a,h)}}}gb=d+16|0;return}bg();L()}function Rq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=4294967279){i=d,j=Ab(a),v[i+8>>2]=j;e=Wk(v[Mc(d+12|0,d+8|0)>>2]);if((e|0)!=(Kc(a)|0)){a:{f=Kc(a);g=Ab(a);b:{if((e|0)==10){h=1;b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>f>>>0){b=pi(b,c);break c}v[22708]=0;b=Q(67,b|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}h=Ee(a);c=Jb(a)}Qg(b,c,Ab(a)+1|0);if(h){$k(a,c,f+1|0)}d:{if((e|0)!=10){rg(a,e+1|0);de(a,g);cf(a,b);break d}Ze(a,g)}}}gb=d+16|0;return}bg();L()}function I4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-32|0;gb=c;a:{b:{c:{if(Ie(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((Kk(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Ws(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Kk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((Kk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Xs(b);break a}a=-1}gb=c+32|0;return a|0}function Gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=vh(a);a:{if(b){v[22708]=0;R(941,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}e=gb-16|0;gb=e;d=Jw(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){c=Qb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0}return a|0}a=P()|0;O()|0;HB(c);S(a|0);L()}function Iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){c=v[a+20>>2];a=g;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=c;f=fe(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=e,j=Uc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}gb=d+16|0;return g<<2}function yz(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;j=gb-16|0;gb=j;v[j+12>>2]=d;d=a+12|0;i=d;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}i=a+8|0;v[j+8>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);k=b,l=v[Fb(j+8|0,j+12|0)>>2],v[k>>2]=l;b=Fd(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24),v[b>>2],v[j+12>>2]);v[c>>2]=b;if(!(b>>>0>=y[j+12>>2]|h)){v[c>>2]=b+1}u[e>>1]=x[e>>1]|f;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=x[e>>1]|g}gb=j+16|0}function Bf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Pc(28400,d+14|0)>>1];c=tc(a);a:{if(b>>>0>c>>>0){e=gb-32|0;gb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){tp(a,c,f);break d}b=wb(a);b=En(e+8|0,Uk(a,tc(a)+c|0),tc(a),b);v[22708]=0;U(312,b|0,c|0,f|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;R(313,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ih(b)}gb=e+32|0;break b}a=P()|0;O()|0;Ih(b);S(a|0);L()}break a}if(b>>>0<c>>>0){xn(a,v[a>>2]+(b<<1)|0)}}gb=d+16|0}function t_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=16384;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=bl(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}bs(d+4|0,bl(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}bs(d+4|0,e-c|0);break b}eF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}eF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}gb=d+16|0}function yl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb-16|0;gb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Vh(a,d+15|0);h=w[d+15|0];v[b>>2]=(h&252)>>>2;v[b+4>>2]=0;c=h&3;if(c){c=-1<<c;l=(c>>>0<4294967294?c:-2)^-1;while(1){t[d+15|0]=0;m=Vh(a,d+15|0);c=b;f=v[c>>2];n=v[c+4>>2];j=w[d+15|0];e=g;g=k+1|0;e=g>>>0<1?e+1|0:e;k=g;g=e;h=c;o=c;p=f;c=(k<<3)-2|0;f=c&31;if((c&63)>>>0>=32){e=j<<f;c=0}else{e=(1<<f)-1&j>>>32-f;c=j<<f}v[o>>2]=p|c;v[h+4>>2]=e|n;i=i&m;if((k|0)!=(l|0)|g){continue}break}}gb=d+16|0;return i|0}function o3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=ye();v[a>>2]=e;e=i>>>9&1;g=Hf(f,e+13|0,h,g,a)+f|0;i=Tg(f,g,c);e=f-((e<<3)+107&112)|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2502,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Rn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];h=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Af(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;i=a;f=fe(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Uc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<2}function s_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=32768;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=bl(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}bs(d+4|0,bl(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}bs(d+4|0,e-c|0);break b}dF(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}dF(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}gb=d+16|0}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;$m(d,b);v[22708]=0;Vd(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(931,b|0,d|0,a>>>5|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Ru(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Mka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;$m(d,b);v[22708]=0;Vd(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(932,b|0,d|0,a>>>2|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;ci(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;$m(d,b);v[22708]=0;Vd(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(933,b|0,d|0,a>>>8|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Pu(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;d=c- -64|0;$m(d,b);v[22708]=0;Vd(c+32|0,d);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}b=Ud(c+24|0);v[22708]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(203,c+40|0,c+16|0,c+8|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}d=dd(a);a=oc(c- -64|0);v[22708]=0;U(934,b|0,d|0,a>>>4|0);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Ou(d);xb(b);break a}xb(b);gc(c- -64|0);gb=c+80|0;return}a=P()|0;O()|0}gc(c- -64|0);S(a|0);L()}function KR(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=qq(b);d=a;e=vh(a);v[22708]=0;R(1115,a|0,2048);a=v[22708];v[22708]=0;a:{if((a|0)!=1){v[22708]=0;CR(d);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Nf(e);S(a|0);L()}a=0;b:{while(1){c=1;if((a|0)!=1024){v[22708]=0;c=+(a-1024|0);g=qq(K(c*c*-9.5367431640625e-7+1)*b);e=v[22708];v[22708]=0;if((e|0)==1){break b}c=c*.0372006759294457;c=si(c)*g/(f*c)}h=ze(d,a),i=c*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Nf(d);S(a|0);L()}function qfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-48|0;gb=d;c=d+24|0;Rm(c,b,1819307379);Vc(a+40|0,c);xb(c);Rm(c,b,1953721961);Vc(a+60|0,c);xb(c);Rm(c,b,543520099);Vc(a+120|0,c);xb(c);Rm(c,b,1414744396);v[22708]=0;c=Q(555,c|0,11089)|0;e=v[22708];v[22708]=0;a:{if((e|0)!=1){b:{if(c){v[22708]=0;U(1429,d|0,d+24|0,2);c=v[22708];v[22708]=0;if((c|0)==1){break b}RN(a+140|0,d);tB(d)}v[22708]=0;U(1430,d|0,b|0,1634890872);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;xb(d+24|0);S(a|0);L()}Vc(a+80|0,d);xb(d);xb(d+24|0);gb=d+48|0}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-16|0;gb=c;f=x[fj(a,b)>>1];a:{if(!No(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=Vb(d),v[j+8>>2]=k;j=c,k=Zb(d),v[j>>2]=k;if(!Gb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=Zl(g);if(i){e=0;while(1){if(!(x[sc(g,e)>>1]!=(h|0)|((a|0)==(g|0)?(b|0)==(e|0):0))){d=vN(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=c+8|0;mS(d);if(Gb(d,c)){continue}break a}break}j=fj(a,b),k=d,u[j>>1]=k;f=d}gb=c+16|0;return f&65535}function uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Se(b);e=d+56|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Sd(e);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22708]=0;Xe(d+8|0,2,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;U(13,d+40|0,2,d+24|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=d+40|0;Eb(b,a);vb(a);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Sd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,1,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(301,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Sd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,3,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(303,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function Jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Se(b);e=d+56|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Sd(e);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22708]=0;Xe(d+8|0,3,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;U(13,d+40|0,5,d+24|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}a=d+40|0;Eb(b,a);vb(a);vb(d+24|0);zc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+56|0);S(a|0);L()}}function Foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Sd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,2,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(399,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function CY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Sd(e);f=v[22708];v[22708]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22708]=0;Xe(d+8|0,2,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break d}v[22708]=0;Q(301,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}return a|0}function iF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}d=b+80|0;f=a;c=v[b+84>>2];if(c>>>0<=15){c=v[d>>2]}else{v[e+12>>2]=c-16;c=v[Mc(d,e+12|0)>>2]}v[f+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+794|0]){break a}b:{c:{d:{if(!hF(b)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}g=a,h=v[a>>2]+B(jj(c),b)|0,v[g+4>>2]=h}gb=e+16|0}function E0(){var a=0;a:{if(t[465136]&1){break a}if(!Qd(465136)){break a}a=464848;while(1){a=Kb(a)+12|0;if((a|0)!=465136){continue}break}Pd(465136)}Wc(464848,2130);Wc(464860,2121);Wc(464872,8108);Wc(464884,7877);Wc(464896,2357);Wc(464908,8906);Wc(464920,2214);Wc(464932,2701);Wc(464944,6017);Wc(464956,6e3);Wc(464968,6008);Wc(464980,6027);Wc(464992,7343);Wc(465004,10593);Wc(465016,6090);Wc(465028,4778);Wc(465040,2357);Wc(465052,6904);Wc(465064,7748);Wc(465076,8120);Wc(465088,6406);Wc(465100,3520);Wc(465112,2584);Wc(465124,10502)}function uP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?(b&240?-16:15)&b:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074456|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Rd(d+12|0,0,256);v[c>>2]=v[d+12>>2]}gb=d+16|0}function fx(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Qb(d+24|0,0,39);a=a+f|0;a:{if(Sg(e,c,0)){v[d+56>>2]=1;kb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}kb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}gb=d- -64|0;return b}function c4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;a=iH(a,e+12|0,d,ye());d=jb;f=v[115189];f:{if(f){if(v[e+12>>2]!=(b|0)){break f}if((f|0)==68){break d}break e}v[115189]=g;if(v[e+12>>2]==(b|0)){break e}}}v[c>>2]=4;a=0;break a}if((d|0)<-1?1:(d|0)<=-1?a>>>0<=2147483647:0){v[c>>2]=4;break c}if((d|0)<0?1:(d|0)<=0?a>>>0<=2147483647:0){break a}}v[c>>2]=4;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break b}}a=-2147483648;break a}a=2147483647}gb=e+16|0;return a|0}function bX(a,b){var c=0,d=0;c=(a|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}d=ng(v[b+8>>2]);c=v[b+8>>2];b:{if(d){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!ng(b)){b=v[b+8>>2];vr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;ur(a);return}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(ng(b)){b=v[b+8>>2];ur(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;vr(a);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(a|0)==(b|0);t[c+12|0]=1;if((a|0)!=(b|0)){continue}break}}}function tba(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(!a){a=ie(18720);break b}v[22708]=0;c=Q(70,b|0,a|0)|0;a=v[22708];v[22708]=0;c:{d:{if((a|0)!=1){v[22708]=0;R(1916,b+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}d=b+16|0;a=ie(Jb(d));vb(d);vb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;vb(c)}Z(a|0)|0;a=0;v[22708]=0;Y(1912,8248,0,0,0);c=v[22708];v[22708]=0;if((c|0)==1){break a}$()}gb=b+32|0;return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{e=gb-32|0;gb=e;a=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;f=Q(191,b|0,8)|0;g=v[22708];v[22708]=0;if((g|0)==1){break c}if(f){v[22708]=0;U(1467,e|0,b|0,c|0);f=v[22708];v[22708]=0;if((f|0)==1){break e}v[22708]=0;R(1468,a|0,e|0);f=v[22708];v[22708]=0;if((f|0)==1){break d}ed(e);Zi(e,GU(a));if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}gb=e+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ed(e);break b}b=P()|0;O()|0}ke(a);S(b|0);L()}}function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;h=fg(a,c);te(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{b:{if(!h){d=-1;if(!nd(a,5)){break b}break a}d=v[h+8>>2]}g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 3:aB(g,b);break c;default:break d}}e=gb-32|0;gb=e;v[e+28>>2]=d;u[e+26>>1]=0;v[e+12>>2]=2;d=e+16|0;i=g;g=e+28|0;bo(d,i,e+26|0,v[Fb(g,e+12|0)>>2]);yb(d);v[e+16>>2]=2;Fb(g,d);u[e+16>>1]=x[e+26>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;gb=e+32|0}}Zf(a,h,c,f+24|0);gb=f+32|0}function hk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!Ee(a)){if(!Ee(b)){v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;a:{if(b>>>0<=10){Ze(a,b);Qg(a,e,b);t[d+15|0]=0;Bd(a+b|0,d+15|0);break a}c=w[a+11|0];vp(a,10,b-10|0,c,0,c,b,e)}gb=d+16|0;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;c=fk(a);b:{if(c>>>0>b>>>0){c=v[a>>2];de(a,b);Qg(c,e,b);t[d+15|0]=0;Bd(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=v[a+4>>2];vp(a,f,g,c,0,c,b,e)}gb=d+16|0}return a|0}function A3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=ye();v[a>>2]=e;g=Hf(f,(i>>>9&1)+13|0,h,g,a)+f|0;i=Tg(f,g,c);e=f-32|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2495,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function _9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22708]=0;_(1935,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22708]=0;ja(1993,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1912,7951,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Z9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22708]=0;_(1935,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22708]=0;ja(1994,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1912,7906,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;b=-1;a:{if(!Wf(a,8)){break a}c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;b=vd(c+8|0,c+24|0,8);e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;b=a;e=c+16|0;hd(e,a,c);e=(yb(e)|0)==8&(v[c+24>>2]==1096043343&v[c+28>>2]==1196314451);if(e){bd(b,8)}gb=c+32|0;b=0;if(!e){break a}b=-1;if(!dk(a,d+8|0)){break a}a=d+8|4;b=0;if(!Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}b=!(Yb(w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24))&-2139062144)}gb=d+16|0;return b|0}function x3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=ye();v[a>>2]=e;g=Hf(f,i>>>9&1|12,h,g,a)+f|0;i=Tg(f,g,c);e=f-32|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2495,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function l3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83445]|w[83446]<<8;v[a+24>>2]=w[83441]|w[83442]<<8|(w[83443]<<16|w[83444]<<24);g=a+24|0;hl(g|1,8041,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;gb=f;h=ye();v[a>>2]=e;g=Hf(f,i>>>9&1|12,h,g,a)+f|0;i=Tg(f,g,c);e=f-96|0;gb=e;h=a+8|0;Fc(h,c);v[22708]=0;ja(2502,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Rn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function iB(a,b){var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{if(cd(a)){break a}u[v[a>>2]>>1]=0;zf(v[a>>2]+2|0,b);f=c,g=Vb(a),v[f>>2]=g;f=c,g=Zo(c,1),v[f+8>>2]=g;f=c,g=Zb(a),v[f>>2]=g;if(!Gb(c+8|0,c)){break a}while(1){d=c+8|0;e=v[d>>2];f=c,g=Zo(d,-1),v[f>>2]=g;e=Le(e,v[c>>2]);u[v[c+8>>2]>>1]=x[e>>1];zf(v[c+8>>2]+2|0,b);Qe(d);f=c,g=Zb(a),v[f>>2]=g;if(Gb(d,c)){continue}break}}zf(a+14|0,Nb(a)-1&255);zf(a+13|0,w[a+14|0]);zf(a+16|0,Nb(a)-1&255);zf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){zf(a+17|0,Nb(a)-1&255)}gb=c+16|0}function N$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Sg(a,v[b+8>>2],e)){bx(b,c,d);return}a:{if(Sg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];kb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Rf(c+48|0);v[22708]=0;e=Q(875,b|0,d|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(876,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=bn(d);v[22708]=0;U(288,c|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=jc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);_j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function mm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function gqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Rf(c+48|0);v[22708]=0;e=Q(454,b|0,d|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(455,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=uD(d);v[22708]=0;U(288,c|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=jc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);_j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-80|0;gb=c;d=Rf(c+48|0);v[22708]=0;e=Q(539,b|0,d|0)|0;f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){if(e){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[22708]=0;T(540,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break b}}break a}e=uD(d);v[22708]=0;U(288,c|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=jc(c+24|0,c);Vc(d+8|0,b);xb(b);xb(c);_j(a,d)}ed(d);gb=c+80|0;return}a=P()|0;O()|0;ed(d);S(a|0);L()}function SO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Nb(c);a:{if(d>>>0<b>>>0){f=gb-32|0;gb=f;b:{d=b-d|0;c:{if(d>>>0<=v[wb(c)>>2]-v[c+4>>2]>>2>>>0){qE(c,d,g);break c}b=wb(c);b=en(f+8|0,fh(c,Nb(c)+d|0),Nb(c),b);v[22708]=0;U(1327,b|0,d|0,g|0);d=v[22708];v[22708]=0;if((d|0)==1){break b}v[22708]=0;R(52,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}eh(b)}gb=f+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}if(b>>>0<d>>>0){hj(c,v[c>>2]+(b<<2)|0)}}eA(a);gb=e+16|0}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;a=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;d=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(d){v[22708]=0;R(868,c|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break e}v[22708]=0;R(869,a|0,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break d}ed(c);Zi(c,GU(a));if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}gb=c+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;ed(c);break b}b=P()|0;O()|0}ke(a);S(b|0);L()}}
function uZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;a:{b:{if(!Wf(a,7)){break b}c=0;if(!_D(a,14907)){break a}if(!Wf(a,1)){break b}c=-1;if(!bd(a,aw(a))){break a}d=gb-32|0;gb=d;c=d+24|0;g=f+8|0;sn(c,g);h=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;c=a;e=d+16|0;hd(e,a,d);e=yb(e);if((e|0)==(h|0)){bd(c,yb(d+24|0))}gb=d+32|0;d=(e|0)==(h|0);if(!d){Tv(g)}c=-1;if(!d){break a}c=0;if(!WD(f+8|0)){break a}c=Oe(a,b,VD(f+8|0),jb);break a}c=-1}gb=f+16|0;return c|0}function kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Sd(e);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22708]=0;Xe(d+8|0,1,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;Q(303,b|0,d+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(d+24|0);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(a|0);L()}}function Pz(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;d=e+8|0;Db(d,a+1074312|0,21);a:{if(Cb(d)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+39888|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=kO(Ao(a))+-64|0;break a}d=t[(c>>>1&31)+38384|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+39760|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+39824|0]}a=d;gb=e+16|0;return a}function Nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-4112|0;gb=d;$m(a,b);if(oc(a)>>>0>4095){while(1){f=e<<12;b=0;c=0;while(1){b=zb(w[kc(a,c+f|0)|0])+b|0;g=zb(b&255);i=lc(d+16|0,c<<1|1),j=g,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}g=f|2048;c=0;while(1){b=zb(w[kc(a,c+g|0)|0])+b|0;h=zb(b&255);i=lc(d+16|0,c<<1),j=h,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}i=d,j=Vb(a),v[i+8>>2]=j;b=d+16|0;Qu(b,b+4096|0,xe(d+8|0,f));e=e+1|0;if(e>>>0<oc(a)>>>12>>>0){continue}break}}gb=d+4112|0}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;h=fg(a,c);te(f+8|0,v[a+28>>2]);e=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=e;a:{b:{if(!h){e=-1;if(!nd(a,5)){break b}break a}e=v[h+8>>2]}g=v[a+28>>2];c:{d:{switch(e+1|0){case 0:case 2:Wh(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=e;t[d+24|0]=0;v[d+12>>2]=1;e=d+16|0;i=g;g=d+28|0;bo(e,i,d+24|0,v[Fb(g,d+12|0)>>2]);yb(e);v[d+16>>2]=1;Fb(g,e);t[d+16|0]=w[d+24|0];t[b|0]=w[e|0];gb=d+32|0}}Zf(a,h,c,f+24|0);gb=f+32|0}function zM(a){a=a|0;var b=0,c=0,d=0,e=0;b=v[a>>2];if(b){kb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;zr(a);c=gb-32|0;gb=c;a:{b:{c:{if(dg(a)>>>0<=oc(a)>>>0){break c}b=wb(a);d=oc(a);e=oc(a);v[22708]=0;b=ca(1636,c+8|0,d|0,e|0,b|0)|0;d=v[22708];v[22708]=0;d:{e:{if((d|0)!=1){v[22708]=0;R(396,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ae(b);break c}a=V(0)|0;O()|0;break d}a=V(0)|0;O()|0;ae(b)}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break b}}gb=c+32|0;break a}V(0)|0;O()|0;Bb();L()}}function lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=C(0);e=gb-32|0;gb=e;h=fg(a,c);d=e+8|0;te(d,v[a+28>>2]);f=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=f;a:{if(!h){if(nd(a,5)){break a}}d=gb-32|0;gb=d;f=v[a+28>>2];yl(f,d+24|0);j=d,k=Qc(v[d+24>>2],v[d+28>>2]),v[j+16>>2]=k;v[d+12>>2]=256;Dl(b,v[Fb(d+16|0,d+12|0)>>2]);if(Nb(b)){while(1){v[d+16>>2]=0;mq(f,d+16|0);i=z[d+16>>2];j=Lb(b,g),l=i,z[j>>2]=l;g=g+1|0;if(Nb(b)>>>0>g>>>0){continue}break}}gb=d+32|0}Zf(a,h,c,e+24|0);gb=e+32|0}function xna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=NY(c,a);yC(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=LY(f+8|0,MY(a,_i(a)+1|0),_i(a),c);yC(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;yC(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];KY(d);gb=f+32|0}function Lz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;a:{if((c|0)<2){break a}j=c-2>>>1|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=vq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(vq(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=vq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!vq(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}gb=h+16|0}function uS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;n=c?0:e;f=v[a+12>>2];h=v[a>>2]+B(f,62)|0;d=b?1:-1;o=B(f,d)<<1;c=e;while(1){if((f|0)>0){g=B(c,f);p=v[a+4>>2];b=0;while(1){u[(b<<1)+h>>1]=x[p+(b+g<<1)>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}h=h+o|0;a:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break a}}b=c+d|0;c=!c&(d|0)<0;b=c?n:b;g=c?l:d}d=g;c=b;i=i+1|0;if((j|0)!=(i|0)){continue}break}}function ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;d=c+40|0;Re(d,a,31);a=v[d>>2];v[22708]=0;d=Sd(d);e=v[22708];v[22708]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22708]=0;Xe(c+8|0,2,d,a);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;R(324,c+24|0,c+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}v[22708]=0;Q(303,b|0,c+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}vb(c+24|0);zc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}zc(c+40|0);S(a|0);L()}}function _l(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=NY(c,a);tD(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=LY(f+8|0,MY(a,_i(a)+1|0),_i(a),c);tD(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;tD(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),dc(c));v[c>>2]=v[c+4>>2];KY(d);gb=f+32|0}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];f=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=fe(e);a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=h,j=Uc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return f<<2}function tS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>-1|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function v8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-32|0;gb=b;a:{b:{if(Bj(a)){Ah(b+24|0);break b}c=b+8|0;no(c,a);v[22708]=0;c=T(2085,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break a}v[b+24>>2]=c;Yf(b+8|0)}if(Bj(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=Vb(c),v[f+8>>2]=g;f=b,g=Zb(c),v[f>>2]=g;if(!Gb(b+8|0,b)){break c}while(1){a=b+8|0;d=d+A[v[a>>2]>>3];YK(a);if(Gb(a,b)){continue}break}break c}d=A[Vl(c,a)>>3]}wl(b+24|0);gb=b+32|0;return+d}a=P()|0;O()|0;Yf(b+8|0);S(a|0);L()}function aaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22708]=0;_(1935,a|0);g=v[22708];v[22708]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22708]=0;ka(1991,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1912,9703,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Qo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){b=a;if(d&512){yS(a);d=x[a+34>>1]}u[b+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;Zm(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function Zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;Ke(d,2,a+6|0);e=d+16|0;Bc(e,d);v[22708]=0;Q(301,b+492|0,e|0)|0;e=v[22708];v[22708]=0;if((e|0)!=1){e=b+236|0;c=c+1|0;vb(d+16|0);while(1){g=w[(a+f|0)+38|0];h=wd(e,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if((f|0)!=128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;vz(a+180|0,b+48|0,0);vz(a+228|0,b+88|0,2);vz(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){yB(e)}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function B2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=Ab(a);e=bq(a);g=kr(b,c);a:{if(!g){break a}if(aD(b,Jb(a),Jb(a)+(Ab(a)<<2)|0)){d=gb-16|0;gb=d;hH(f,b,c);gb=d+16|0;b=f;c=Jb(b);d=Ab(b);v[22708]=0;W(2522,a|0,c|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Ic(b);break a}a=P()|0;O()|0;Ic(b);S(a|0);L()}if(e-d>>>0<g>>>0){kI(a,e,(d+g|0)-e|0,d,d)}e=Jb(a)+(d<<2)|0;if((b|0)!=(c|0)){while(1){Ge(e,b);e=e+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f>>2]=0;Ge(e,f);jh(a,d+g|0)}gb=f+16|0}function $9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22708]=0;_(1935,a|0);g=v[22708];v[22708]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22708]=0;ka(1992,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22708]=0;Y(1912,9603,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Jg(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/6>>>0){QC(a,d,c);break c}b=wb(a);b=MW(e+8|0,BC(a,Jg(a)+d|0),Jg(a),b);v[22708]=0;U(643,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}OC(a);c=b+4|0;KW(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];DC(a,Jg(a));pv(b)}gb=e+32|0;break a}a=P()|0;O()|0;pv(b);S(a|0);L()}return}if(b>>>0<d>>>0){PC(a,v[a>>2]+B(b,6)|0)}}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,16);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function W3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115189];v[115189]=0;a=zx(a,e+12|0,d,ye());d=jb;e:{g=v[115189];if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68){break e}break b}v[115189]=h;if(v[e+12>>2]==(b|0)){break b}break c}v[c>>2]=4;a=-1;b=-1;break a}}v[c>>2]=4;a=0;b=0;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}gb=e+16|0;jb=b;return a|0}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22708]=0;Q(1167,f|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22708]=0;R(1168,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;Q(1167,f|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function qP(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}f=e+8|0;Db(f,a+1074312|0,3);if(Cb(f)){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){d=e+8|0;Db(d,a+1074312|0,3);if(!Cb(d)){break a}}c=c<<2}if(!c){break a}d=mu(a,b);if(!d){break a}f=d;a=v[(B(b,872)+a|0)+1075648>>2];if(a){a=w[a+33|0]}else{a=13}kb[v[v[d>>2]+84>>2]](f,c,a<<24>>24,b)}gb=e+16|0}function g3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-208|0;gb=a;u[a+204>>1]=w[83451]|w[83452]<<8;v[a+200>>2]=w[83447]|w[83448]<<8|(w[83449]<<16|w[83450]<<24);f=ye();v[a>>2]=e;g=a+176|0;i=Hf(g,20,f,a+200|0,a);e=i+g|0;g=Tg(g,e,c);f=a+8|0;Fc(f,c);v[22708]=0;f=T(2481,f|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;cH(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Rn(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);gb=a+208|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function Mf(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function KD(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;e=Sd(e);f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)==1){break c}e=zb(e);v[22708]=0;Xe(d+8|0,3,e,a);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;R(324,d+24|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)==1){break c}v[22708]=0;Q(301,b|0,d+24|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function Uz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=bk(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;cm(l+c|0,l,k);break b}Wm(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Ir(f+h|0,c,d);d=b;b=c+g|0;jh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Yn();L()}m=e,n=zd(a),v[m+8>>2]=n;a=xe(e+8|0,j);gb=e+32|0;return a|0}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=Eg(d,a,1);wb(a);ZS(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}f=gb-32|0;gb=f;e=wb(a);d=fh(a,Nb(a)+1|0);i=Nb(a);g=gb-16|0;gb=g;v[g+12>>2]=0;c=f+8|0;hf(c+12|0,e);if(d){h=TW(d)}v[c>>2]=h;e=(i<<2)+h|0;v[c+8>>2]=e;v[c+4>>2]=e;j=dc(c),k=(d<<2)+h|0,v[j>>2]=k;gb=g+16|0;ZS(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;XS(a,c);a=c;WS(c);b=v[c>>2];if(b){GC(v[a+16>>2],b,Bk(a))}gb=f+32|0}function Q$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Ec(b)){a=0;while(1){d:{if(!a){break d}v[22708]=0;Q(113,f|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=Ad(b,a);v[22708]=0;R(175,e|0,d|0);d=v[22708];v[22708]=0;if((d|0)==1){break c}v[22708]=0;Q(113,f|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Ec(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function m3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=ye();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=Hf(g,e+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2502,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Rn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function k3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=ye();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=Hf(g,e+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2502,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=Rn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function $x(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=LI(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<=-1){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}gb=e+16|0;return c}function ZU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!w[b+8|0]){while(1){if(!w[b+d|0]){aa(14534,6236,413,10492);L()}d=d+1|0;if((d|0)!=8){continue}break}v[c+24>>2]=0;v[c+28>>2]=0;d=vd(c+8|0,c+24|0,8);e=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=e;e=c+16|0;cc(e,a,c);d=0;if(!((yb(e)|0)!=8|(v[c+24>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|v[c+28>>2]!=(w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24))))){Rb(a,8);d=1}gb=c+32|0;break a}aa(14513,6236,411,10492);L()}return d|0}function Eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function Rn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((tn(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=iI(i,b,f);h=Jb(f);v[22708]=0;h=W(2504,a|0,h|0,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}Ic(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((tn(a,c,b)|0)!=(b|0)){break b}}PB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;Ic(f);S(a|0);L()}function Qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;_(1946,c|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[a+24>>2];v[22708]=0;b=Q(1947,d|0,b|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,7623,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c);a:{if(!g){break a}qc(f+28|0,65535);Bf(a,x[f+28>>1]);i=f,j=Vb(a),v[i+16>>2]=j;i=f,j=Zb(a),v[i+8>>2]=j;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Mg(b,c)){h=gb-16|0;gb=h;Jf(c);gb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;nf(a);if(Gb(a,f+8|0)){continue}break}}gb=f+32|0;return g|0}function Q4(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=Tb(b,13839);v[22708]=0;U(138,b+16|0,a|0,c|0);a=v[22708];v[22708]=0;a:{b:{c:{if((a|0)!=1){vb(c);if(Ec(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;vb(c);break b}a=0;while(1){d:{c=Ad(b+16|0,d);v[22708]=0;c=T(139,c|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=Ec(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;qm(b+16|0)}S(d|0);L()}qm(b+16|0);gb=b+32|0;return a|0}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function q3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-96|0;gb=a;u[a+92>>1]=w[83451]|w[83452]<<8;v[a+88>>2]=w[83447]|w[83448]<<8|(w[83449]<<16|w[83450]<<24);f=ye();v[a>>2]=e;g=a- -64|0;i=Hf(g,20,f,a+88|0,a);e=i+g|0;g=Tg(g,e,c);f=a+8|0;Fc(f,c);v[22708]=0;f=T(21,f|0)|0;h=v[22708];v[22708]=0;if((h|0)!=1){Wb(a+8|0);h=f;f=a+16|0;eH(h,a- -64|0,e,f);h=b;b=f+i|0;b=un(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);gb=a+96|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115189];v[115189]=0;a=zx(a,e+12|0,d,ye());d=jb;g=v[115189];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115189]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a&65535}function rK(a){var b=0,c=0,d=0,e=0,f=0;if(v[a+16>>2]){while(1){c=Zz(v[a>>2]);d=jb;e=v[a+28>>2];if((d|0)==(e|0)&y[a+24>>2]<=c>>>0|d>>>0>e>>>0){continue}d=b;b=v[a+8>>2];b=(c&v[a+40>>2])+(b>>>0<32?d<<b:0)|0;c=v[a+16>>2];f=f+1|0;if(c>>>0>f>>>0){continue}break}}if(y[a+12>>2]>c>>>0){while(1){d=Zz(v[a>>2]);f=jb;e=v[a+36>>2];if((f|0)==(e|0)&y[a+32>>2]<=d>>>0|f>>>0>e>>>0){continue}e=b;b=v[a+8>>2];b=(d&v[a+48>>2])+(b>>>0<31?e<<b+1:0)|0;c=c+1|0;if(c>>>0<y[a+12>>2]){continue}break}}return b}function y_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=-1;c=gb-32|0;gb=c;f=c+24|0;h=e+8|0;ds(f,h);f=yb(f);d=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=d;v[c>>2]=i;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(f|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){Cw(h)}a:{if(!a){break a}g=0;if(!lF(e+8|0)){break a}if(b){c=v[b>>2];a=e+12|0;if(!v[b+4>>2]&c>>>0<Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))-8>>>0){break a}}g=1}gb=e+48|0;return g|0}function Rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function JD(a,b,c){var d=0,e=0;d=gb+-64|0;gb=d;e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Sd(e);e=v[22708];v[22708]=0;a:{b:{c:{if((e|0)==1){break c}c=zb(c);v[22708]=0;Xe(d+8|0,3,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}v[22708]=0;Q(399,b|0,d+24|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(d+24|0);zc(d+40|0);gb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}zc(d+40|0);S(c|0);L()}function jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=fg(a,c);d=f+8|0;te(d,v[a+28>>2]);e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;a:{b:{if(!g){d=-1;if(!nd(a,5)){break b}break a}d=v[g+8>>2]}h=v[a+28>>2];c:{if(!((d|0)!=-1?(d|0)!=4:0)){d=gb-16|0;gb=d;v[d+8>>2]=0;mq(h,d+8|0);z[b>>2]=z[d+8>>2];gb=d+16|0;break c}e=gb-32|0;gb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;bo(e+8|0,h,e+28|0,v[Fb(e+24|0,e+20|0)>>2]);v[b>>2]=0;gb=e+32|0}}Zf(a,g,c,f+24|0);gb=f+32|0}function Sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){g=g<<8;h=h<<8;while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+B(h,t[e|0]);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function f$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=e;v[d+8>>2]=b;v[d+12>>2]=e;g=gb-16|0;gb=g;h=g+8|0;f=h;i=gb-16|0;gb=i;e=gb-16|0;gb=e;c=gb-16|0;gb=c;b=e;v[b+4>>2]=1;j=b,k=Nc(24,4),v[j+8>>2]=k;gb=c+16|0;c=v[b+8>>2];v[22708]=0;Q(213,c|0,d|0)|0;c=v[22708];v[22708]=0;a:{if((c|0)!=1){c=f;f=Kp(b);Nw(c,dc(f),f);WF(b);gb=e+16|0;break a}a=P()|0;O()|0;WF(b);S(a|0);L()}gb=i+16|0;Xf(a,h);Kd(h);gb=g+16|0;gb=d+16|0}function QE(a,b){a=a|0;b=b|0;var c=0,d=0;Qb(b,0,44);if(w[a+2|0]|w[a+3|0]<<8?1:w[a|0]|w[a+1|0]<<8){v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;c=b,d=Mb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[c+16>>2]=d;c=b,d=Mb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[c+12>>2]=d;c=b,d=Mb((w[a+2|0]|w[a+3|0]<<8)>>>11|0,0,23),v[c+8>>2]=d;c=b,d=Mb((w[a+2|0]|w[a+3|0]<<8)>>>5&63,0,59),v[c+4>>2]=d;c=b,d=Mb((w[a+2|0]|w[a+3|0]<<8)<<1&62,0,59),v[c>>2]=d}v[b+44>>2]=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-32|0;gb=f;d=Ab(a);e=Kc(a);g=Zh(b,c);a:{if(!g){break a}if(aD(b,Jb(a),Jb(a)+Ab(a)|0)){b=Oj(f+16|0,b,c);c=Jb(b);d=Ab(b);v[22708]=0;W(2300,a|0,c|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Wm(a,e,(d+g|0)-e|0,d,d,0,0)}e=Jb(a)+d|0;if((b|0)!=(c|0)){while(1){Bd(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(e,f+15|0);jh(a,d+g|0)}gb=f+32|0}function ZP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b|0]);d=zb(w[b+1|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+2|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+3|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+4|0])|(g|i);j=a,k=Jc(d,zb(w[b+5|0])<<8|g|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function YP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b+7|0]);d=zb(w[b+6|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+5|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+4|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+3|0])|(g|i);j=a,k=Jc(d,zb(w[b+2|0])<<8|g|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function V6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;v[e+40>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=v[qi(e+16|0,e+40|0)>>2];c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;v[22708]=0;c=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=c;ca(1933,a+8|0,e|0,b|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){JJ(a);b=IJ(a+88|0);v[a>>2]=59704;v[b>>2]=59792;eg(e+40|0);gb=e+48|0;return a|0}a=P()|0;O()|0;eg(e+40|0);S(a|0);L()}function y3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=ye();v[a>>2]=e;v[a+4>>2]=f;f=Hf(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-48|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2495,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function w3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;hl(h|1,7874,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;gb=g;j=ye();v[a>>2]=e;v[a+4>>2]=f;f=Hf(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=Tg(g,f,c);e=g-48|0;gb=e;i=a+8|0;Fc(i,c);v[22708]=0;ja(2495,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[22708];v[22708]=0;if((f|0)!=1){Wb(a+8|0);b=un(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Wb(a+8|0);S(b|0);L()}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Fb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(c,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function CQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];c=e+8|0;h=v[Fb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Fb(c,e+4|0)>>2];c=zb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=zb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=zb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=zb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}gb=e+16|0;return h+i|0}function xO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;jb=v[e+4>>2];return v[e>>2]}function xZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c<<1);a:{if(!g){break a}qc(f+28|0,65535);Bf(a,x[f+28>>1]);h=f,i=Vb(a),v[h+16>>2]=i;h=f,i=Zb(a),v[h+8>>2]=i;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;if(!Dp(b,c)){HD(c)}c=w[f+24|0]|w[f+25|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;nf(a);if(Gb(a,f+8|0)){continue}break}}gb=f+32|0;return g|0}function a1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!(!e|(c|0)==(d|0))){while(1){a:{g=1;f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];h=wi(f+8|0,f+12|0);v[22708]=0;i=jH(c,d-c|0,b);l=v[22708];v[22708]=0;b:{if((l|0)!=1){ff(h);gb=f+16|0;break b}a=P()|0;O()|0;ff(h);S(a|0);L()}c:{switch(i+2|0){default:g=i;break;case 0:case 1:break a;case 2:break c}}j=g+j|0;k=k+1|0;if(k>>>0>=e>>>0){break a}c=c+g|0;if((d|0)!=(c|0)){continue}}break}return j|0}return 0}function un(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>=1){if((tn(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=He(i,b,f);g=Jb(f);v[22708]=0;g=W(28,a|0,g|0,b|0)|0;h=v[22708];v[22708]=0;if((h|0)==1){break a}vb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((tn(a,c,b)|0)!=(b|0)){break b}}PB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;vb(f);S(a|0);L()}function bG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;v[f+16>>2]=c;v[f+24>>2]=b;k=f,l=zd(a),v[k+8>>2]=l;b=f+24|0;h=f+8|0;i=bk(b,h);e=i;b=bk(f+16|0,b);a:{if(Ab(a)>>>0>=e>>>0){if((b|0)==-1){sE(a,e);break a}d=gb-16|0;gb=d;v[d+12>>2]=b;if(b){c=Ab(a);j=Jb(a);g=c-e|0;v[d+8>>2]=g;b=v[Fb(d+12|0,d+8|0)>>2];v[d+12>>2]=b;g=g-b|0;if(g){e=e+j|0;cm(e,b+e|0,g);b=v[d+12>>2]}e=a;a=c-b|0;jh(e,a);t[d+7|0]=0;Bd(a+j|0,d+7|0)}gb=d+16|0;break a}Yn();L()}xe(h,i);gb=f+32|0}function mt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Md(e)){break a}g=a+1298224|0;d=a+1074992|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+872|0;if((g|0)!=(d|0)){continue}break}Ol(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Qo(e,0,c)}gb=c+32|0;return f|0}function $6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;vy(b,c,yb(d));e=v[b+16>>2];a:{if(e>>>0<=c>>>0){nk(a,d,0);break a}v[f+28>>2]=e-c;i=f,j=yb(d),v[i+24>>2]=j;g=v[Fb(f+28|0,f+24|0)>>2];KB(f+16|0,d,0,g);e=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=e;e=gb-32|0;gb=e;b=b+4|0;i=e,j=Vb(b),v[i+24>>2]=j;h=xe(e+24|0,c);i=e,j=Vb(b),v[i+8>>2]=j;i=e,j=xe(e+8|0,c),v[i+16>>2]=j;b=f+8|0;Wi(h,xe(e+16|0,yb(b)),v[b>>2]);gb=e+32|0;KB(a,d,0,g)}gb=f+32|0}function Ifa(a,b){a=a|0;b=b|0;var c=0;b=38480;a=dd(a);a:{while(1){b:{if(!cd(a)){if(!wj(v[b+8>>2],v[uo(a)>>2])){break b}}v[22708]=0;R(1413,a|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=39044){continue}break}b=39056;while(1){c:{if(!cd(a)){if(!wj(v[b+8>>2],v[uo(a)>>2])){break c}}v[22708]=0;R(1413,a|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=39104){continue}break}return}b=P()|0;O()|0;Lc(a);S(b|0);L()}function mI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=xm(v[Mc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Ti(l,k);if(e){yi(c,j,e)}if(g){yi(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;yi((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){ai(a,j,b)}cf(a,c);rg(a,k);b=a;a=d+(e+g|0)|0;de(b,a);v[i+4>>2]=0;Ge(c+(a<<2)|0,i+4|0);gb=i+16|0;return}bg();L()}function Si(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;if(!cd(a)){oS(b+32|0,Zb(a));oS(b+24|0,Vb(a));c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!pS(c,e)){break a}while(1){d=gb-16|0;gb=d;v[d+8>>2]=v[c+4>>2];f=gS(d+8|0);gb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}gS(c+4|0);if(pS(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=sD(Vb(a),v[b+44>>2])}gb=b+48|0;return c&65535}function EQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Fb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(c,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=xh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=xh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function Laa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22708]=0;_(1935,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22708]=0;b=sa(1952,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10286,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function JV(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!kf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!kf(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}gb=f+16|0}function Iaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22708]=0;_(1935,a|0);h=v[22708];v[22708]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22708]=0;b=sa(1955,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10218,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=oqa(b,c,h,i);i=jb;j=h;h=oqa(d,e,f,g);e=j+h|0;d=jb+i|0;i=e;h=e>>>0<h>>>0?d+1|0:d;j=g;e=0;g=e;k=i;l=c;d=0;i=oqa(j,e,c,d);e=k+i|0;c=jb+h|0;k=e;e=e>>>0<i>>>0?c+1|0:c;h=f;c=0;i=b;f=oqa(h,c,i,0);b=jb;d=oqa(h,c,l,d);b=b+d|0;c=jb;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+k|0;d=c>>>0<h>>>0?e+1|0:e;h=c;c=d;d=oqa(i,m,j,g)+b|0;e=jb;e=b>>>0>d>>>0?e+1|0:e;b=h;h=e;e=b+e|0;v[a+8>>2]=e;v[a+12>>2]=e>>>0<h>>>0?c+1|0:c;v[a>>2]=f;v[a+4>>2]=d}function pl(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[22614]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115189]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function fH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115189];v[115189]=0;a=zx(a,e+12|0,d,ye());d=jb;g=v[115189];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115189]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a|0}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=vh(a);a:{if(b){v[22708]=0;R(903,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=gb-16|0;gb=d;c=d;v[c>>2]=a;e=v[a+4>>2];v[c+4>>2]=e;v[c+8>>2]=e+B(b,9);e=c;b=v[c+4>>2];c=v[c+8>>2];if((b|0)!=(c|0)){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[e+4>>2]=b;if((b|0)!=(c|0)){continue}break}}$b(e);gb=d+16|0}return a|0}a=P()|0;O()|0;NB(c);S(a|0);L()}function nc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return nc(a,24)+(nc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){d=qt(a);if((d|0)==-1){break b}e=v[a+1396>>2];c=e+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}v[a+1396>>2]=c-b;c=a;a=v[a+1392>>2];v[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}v[a+1396>>2]=-1;return 0}aa(7347,10528,1632,3887);L()}function eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[pc(b,0)|0]==(hg(43)&255)){break b}if(w[pc(b,0)|0]==(hg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=xe(d+8|0,e-c|0),v[i+16>>2]=j;Gd(d+24|0,d+16|0);Uz(b,v[d+24>>2],1,hg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function H9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[22708]=0;_(2008,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[22708]=0;b=Ua(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8588,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function TN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=zd(a),v[m+16>>2]=n;j=bk(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;cm(l+c|0,l,k);break b}Wm(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Ir(f+h|0,c,d);d=b;b=c+g|0;jh(d,b);t[i+15|0]=0;Bd(b+f|0,i+15|0)}gb=i+16|0;break a}Yn();L()}m=e,n=zd(a),v[m+8>>2]=n;xe(e+8|0,j);gb=e+32|0}function xU(a){var b=0,c=0,d=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>32){break a}b=a+32|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>256){break a}b=a+34|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}d=(w[a|0]|w[a+1|0]<<8)>>>0<129}return d}function Sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[Jb(b)|0]==(hg(43)&255)){break b}if(w[Jb(b)|0]==(hg(45)&255)){break b}}i=d,j=zd(b),v[i+8>>2]=j;i=d,j=xe(d+8|0,e-c|0),v[i+16>>2]=j;Gd(d+24|0,d+16|0);TN(b,v[d+24>>2],1,hg(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function wv(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{switch(w[a+3|0]){case 10:case 17:case 18:c=8;break d;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=w[a|0];if(!(c&7)){break d}case 11:c=b+1>>>1|0;b=(w[a+3|0]==11)<<4;break c;case 9:break e;default:break d}}c=16}c=B(c>>>3|0,b);b=(w[a+3|0]==11)<<4}c=b+B(fp(a),c)|0}return c|0}function Ena(a,b){a=a|0;b=b|0;var c=0,d=0;c=Je(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/20>>>0){pE(a,c);break c}b=wb(a);b=bD(d+8|0,cD(a,Je(a)+c|0),Je(a),b);v[22708]=0;R(683,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;zv(a,b);a=v[22708];v[22708]=0;if((a|0)==1){break b}ip(b)}gb=d+32|0;break a}a=P()|0;O()|0;ip(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,20)|0;Je(a);$D(a,b);bm(a);Je(a)}}function h7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-48|0;gb=e;a:{if(w[b+8|0]){b=b+12|0;i=e,j=oc(b)-c|0,v[i+40>>2]=j;i=e,j=yb(d),v[i+32>>2]=j;f=e+40|0;h=e+32|0;g=v[Fb(f,h)>>2];i=e,j=Vb(b),v[i+40>>2]=j;f=xe(f,c);i=e,j=Vb(b),v[i+24>>2]=j;i=e,j=xe(e+24|0,c),v[i+32>>2]=j;Wi(f,xe(h,g),v[d>>2]);nk(a,d,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;kb[f|0](a,b,c,e+8|0)}gb=e+48|0}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Gi(a,b,c,d);v[a>>2]=51824;d=mc(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=wf(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[22708]=0;W(1533,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Uh(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);jf(b);S(a|0);L()}function pY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1064>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1072|0,g=bl(a,7),t[f|0]=g;d=bl(a,1);e=bl(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;pY(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function TB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;e=mc(a);f=d,g=Vb(b),v[f+40>>2]=g;f=d,g=Zb(b),v[f+32>>2]=g;a:{if(Gb(d+40|0,d+32|0)){while(1){a=d+8|0;b=v[d+40>>2];Zi(a,b);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){a=d+8|0;qn(a,b);v[22708]=0;R(535,e|0,a|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}xb(d+8|0)}a=d+40|0;on(a);if(Gb(a,d+32|0)){continue}break}}gb=d+48|0;return}a=P()|0;O()|0;xb(d+8|0);jd(e);S(a|0);L()}function K9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22708]=0;_(2008,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[22708]=0;b=ca(f|0,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8733,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function J9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22708]=0;_(2008,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[22708]=0;b=ca(f|0,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8769,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function cG(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1129474426|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1634291279){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)!=14){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}b=a+14|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<0){break a}a=a+18|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>23}return c}function $K(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=gb-48|0;gb=b;v[b+40>>2]=e;v[b+44>>2]=f;c=vd(b+32|0,c,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a:{a=gA(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;v[22708]=0;b=Q(70,b+16|0,5190)|0;c=v[22708];v[22708]=0;b:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(b);break b}d=P()|0;O()|0;da(a|0)}S(d|0);L()}gb=b+48|0;return a|0}L()}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22708]=0;_(2008,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[22708]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3717,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22708]=0;_(2008,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[22708]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3771,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function lP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}rk(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}c=d+8|0;Db(c,a+1074312|0,7);if(Cb(c)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function GN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=gb-16|0;gb=e;g=v[d+4>>2];d=v[d>>2];f=(g-d|0)/6|0;a:{if(f>>>0<=Xj(c)>>>0){if(Jg(c)>>>0<f>>>0){v[e+12>>2]=d;h=Jg(c);v[e+12>>2]=v[e+12>>2]+B(h,6);h=d;d=v[e+12>>2];oz(h,d,v[c>>2]);mz(c,d,g,f-Jg(c)|0);break a}PC(c,oz(d,g,v[c>>2]));break a}BN(c);kX(c,BC(c,f));mz(c,d,g,f)}gb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];FN(a+24|0,b+24|0);hk(a+36|0,b+36|0)}function E$(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[22708]=0;m=a;a=0;a=oG(1926,m|a,b,c,d,a|e,f);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;ja(1923,5974,g|0,h|0,i|0,j|0,k|0,l|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function zoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;$C(e+24|0,c);v[22708]=0;R(637,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function cpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;$C(e+24|0,c);v[22708]=0;R(538,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function aqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;On(e+24|0,c);v[22708]=0;R(160,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function Yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Lh(e+24|0,c);v[22708]=0;R(777,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(453,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function Boa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;On(e+24|0,c);v[22708]=0;R(144,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function FZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;gw(e+24|0,c);v[22708]=0;R(365,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function $v(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;GD(e+24|0,c);v[22708]=0;R(144,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function $4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-48|0;gb=e;Lh(e+24|0,c);v[22708]=0;R(144,e+36|0,d|0);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(e+16|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(146,a|0,b|0,e+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(e+24|0);gb=e+48|0;break a}a=P()|0;O()|0;vb(e+24|0);break b}a=P()|0;O()|0;Ef(e+24|0)}S(a|0);L()}}function oN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Nb(a);if(c>>>0<=127){e=gb-32|0;gb=e;a:{b:{d=128-c|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){fz(a,d,b);break c}c=wb(a);c=en(e+8|0,fh(a,Nb(a)+d|0),Nb(a),c);v[22708]=0;U(1501,c|0,d|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(1502,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}eh(c)}gb=e+32|0;break a}a=P()|0;O()|0;eh(c);S(a|0);L()}return}if((c|0)!=128){hj(a,v[a>>2]+512|0)}}function mB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=-1;f=d&2147483647;k=f;g=(f|0)==2147418112;h=c;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=f;j=(f|0)==2147418112;if(j?0:j&0|f>>>0>2147418112){break a}if(!(a|h|(g|k|b))){return 0}h=d&e;if((h|0)>0?1:(h|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(d|0)>(e|0)?1:(d|0)>=(e|0)?c:0){break a}i=(a|c)!=0|(d^e|b)!=0}return i}function sP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}rk(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}c=d+8|0;Db(c,a+1074312|0,7);if(Cb(c)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function gf(a,b,c,d){var e=0,f=0;a:{if(!Ab(a)|(c-b|0)<5){break a}e=b;f=c;b:{if((e|0)==(f|0)){break b}f=f-4|0;if(f>>>0<=e>>>0){break b}while(1){xc(e,f);e=e+4|0;f=f-4|0;if(e>>>0<f>>>0){continue}break}}e=Jb(a);f=Ab(a);a=c-4|0;c:{if(a>>>0>b>>>0){c=e+f|0;while(1){f=w[e|0];if((f|0)!=v[b>>2]?(f-1&255)>>>0<=125:0){break c}e=((c-e|0)>1)+e|0;b=b+4|0;if(a>>>0>b>>>0){continue}break}}b=w[e|0];if((b-1&255)>>>0>125|b>>>0>v[a>>2]-1>>>0){break a}}v[d>>2]=4}}function PS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];a:{b:{if(!v[Fb(c+12|0,c+8|0)>>2]){break b}while(1){e=Zq(t[kc(a,d)|0]);f=Zq(t[kc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];d=d+1|0;if(d>>>0>=y[Fb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(v[a+4>>2]==v[b+4>>2]){break a}d=y[a+4>>2]<y[b+4>>2]?-1:1}gb=c+16|0;return d}function yoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=oc(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){Cn(a,d,c);break c}b=wb(a);b=Zg(e+8|0,qh(a,oc(a)+d|0),oc(a),b);v[22708]=0;U(638,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(296,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}ae(b)}gb=e+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<d>>>0){Cm(a,v[a>>2]+b|0)}}function efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gb-32|0;gb=d;e=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}if(!a){break d}v[22708]=0;U(1467,d|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(1468,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(d);break b}gb=d+32|0;break a}a=P()|0;O()|0}ke(e);S(a|0);L()}}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=gb-32|0;gb=d;e=Go(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;f=v[22708];v[22708]=0;if((f|0)==1){break c}if(!a){break d}v[22708]=0;U(1158,d|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(1159,e|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(d);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(d);break b}gb=d+32|0;break a}a=P()|0;O()|0}tB(e);S(a|0);L()}}function Ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=-1;a:{if(!dk(a,d+8|0)){break a}c=d+8|0;b:{if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(zn(6109)|0)){break b}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<256){break b}e=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<260}c=0;if(!e){break a}c=a;a=d+12|0;c=Oe(c,b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<259?80:76,0)}gb=d+16|0;return c|0}function Maa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22708]=0;_(1935,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22708]=0;b=fa(1951,f|0,b|0,c|0,d|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6840,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Jaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22708]=0;_(1935,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22708]=0;b=fa(1954,f|0,b|0,c|0,d|0,e|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6768,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Joa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=c;c=Pb(b,c<<2);a:{if(!c){break a}qc(d+28|0,65535);Bf(a,x[d+28>>1]);g=d,h=Vb(a),v[g+16>>2]=h;g=d,h=Zb(a),v[g+8>>2]=h;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];e=d+24|0;if(!is(b,e)){f=gb-16|0;gb=f;$j(e);gb=f+16|0}e=w[d+24|0]|w[d+25|0]<<8;u[a>>1]=e;if((e|0)==65535){u[a>>1]=65535}a=d+16|0;nf(a);if(Gb(a,d+8|0)){continue}break}}gb=d+32|0;return c|0}function B9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22708]=0;_(2008,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[22708]=0;Wa(f|0,d|0,b|0,+c);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8932,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-48|0;gb=d;EC(d+24|0,c);v[22708]=0;R(637,d+36|0,49068);c=v[22708];v[22708]=0;b:{c:{if((c|0)!=1){v[22708]=0;ri(d+16|0,d+24|0);c=v[22708];v[22708]=0;if((c|0)==1){break c}v[22708]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;U(146,a|0,b|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break c}Ef(d+24|0);gb=d+48|0;break a}a=P()|0;O()|0;vb(d+24|0);break b}a=P()|0;O()|0;Ef(d+24|0)}S(a|0);L()}}function Oe(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=wo(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=wo(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Tk(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}gb=e+16|0;return a}function y7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Xg(b,e,f)>>2];c=Ac(pqa(oqa(c,c>>31,g,h),jb,65536,0),jb);i=Xg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;ZJ(a,d);gb=d+16|0}function Rda(a,b){a=a|0;b=b|0;var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){fN(a,c);break c}b=wb(a);b=en(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22708]=0;R(1543,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(1540,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}eh(b)}gb=d+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}return}if(b>>>0<c>>>0){hj(a,v[a>>2]+(b<<2)|0)}}function H7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Xg(b,e,f)>>2];c=Ac(pqa(oqa(c,c>>31,g,h),jb,65536,0),jb);i=Xg(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;eK(a,d);gb=d+16|0}function ie(a){var b=0,c=0,d=0;d=Wp(Of(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!gt(eb(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}gb=d+32|0;return e|0}function Tr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14534,6236,413,10492);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=vd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);b:{if((yb(e)|0)!=7){break b}if(sd(c+24|0,b,7)){break b}Rb(a,7);d=1}gb=c+32|0;break a}aa(14513,6236,411,10492);L()}return d|0}function tE(a,b){a=a|0;b=b|0;var c=0,d=0;c=tc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){gE(a,c);break c}b=wb(a);b=En(d+8|0,Uk(a,tc(a)+c|0),tc(a),b);v[22708]=0;R(338,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(313,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ih(b)}gb=d+32|0;break a}a=P()|0;O()|0;Ih(b);S(a|0);L()}return}if(b>>>0<c>>>0){xn(a,v[a>>2]+(b<<1)|0)}}function W5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[pd(e+12|0,pd(e+8|0,e+4|0))>>2];Qg(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+d;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=xh(d),t[h|0]=i;d=1}b=b+d|0;f=d+f|0;if((f|0)<(c|0)){continue}break}}gb=e+16|0;return f|0}function S5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;d=v[pd(e+12|0,pd(e+8|0,e+4|0))>>2];yi(b,v[a+12>>2],d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;if((g|0)<(c|0)){continue}break}}gb=e+16|0;return g|0}function D8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22708]=0;b=Q(70,h|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,4);c=Ky(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=h+16|0;return c|0}e=P()|0;O()|0;da(a|0)}S(e|0)}L()}function A8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[22708]=0;b=Q(70,h|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,4);c=Jy(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=h+16|0;return c|0}e=P()|0;O()|0;da(a|0)}S(e|0)}L()}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,15);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function t9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[22708]=0;R(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10088,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function WM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(Cl(a)>>>0<=Vf(a)>>>0){break b}b=wb(a);d=Vf(a);e=Vf(a);v[22708]=0;b=ca(1537,c+8|0,d|0,e|0,b|0)|0;d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){v[22708]=0;R(1538,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}Rt(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Rt(b)}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function VM(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(pe(a)>>>0<=Nb(a)>>>0){break b}b=wb(a);d=Nb(a);e=Nb(a);v[22708]=0;b=ca(1539,c+8|0,d|0,e|0,b|0)|0;d=v[22708];v[22708]=0;c:{d:{if((d|0)!=1){v[22708]=0;R(1540,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break d}eh(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;eh(b)}Z(a|0)|0;v[22708]=0;X(20);a=v[22708];v[22708]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function Gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,14);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function Gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=ca(1957,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10249,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=ca(1959,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10175,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function u9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[22708]=0;R(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6469,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Naa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=ca(1950,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6608,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Kaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=ca(1953,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6577,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function I9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[22708]=0;R(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8598,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Haa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=ca(1956,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6801,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function HZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=-1;a:{if(!Wf(a,7)){break a}d=0;if(!_D(a,9028)){break a}c=gb-32|0;gb=c;d=g;e=c+24|0;PD(e,g);h=yb(e);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;f=c+16|0;e=a;hd(f,e,c);f=yb(f);if((f|0)==(h|0)){bd(e,yb(c+24|0))}gb=c+32|0;e=(f|0)==(h|0);if(!e){OD(d)}d=-1;if(!e){break a}d=0;if(!ZD(g)){break a}d=Oe(a,b,YD(g),jb)}gb=g+16|0;return d|0}function Faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22708]=0;_(1935,a|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22708]=0;b=ca(1958,e|0,b|0,c|0,d|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6723,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function z9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[22708]=0;ta(e|0,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22708]=0;Y(1912,8970,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Jj(C(C(wf(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Jj(C(C(b>>>0)*C(1.1892070770263672)));d=Jj(C(C(c>>>0)*C(1.1892070770263672)));g=Jj(C(C(d>>>0)*C(1.1892070770263672)));e=Jj(C(C(b+d>>>0)*C(.11546666920185089)));f=Jj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;QL(a);OL(a)}function x9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[22708]=0;ta(e|0,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22708]=0;Y(1912,4841,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function v9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[22708]=0;ta(e|0,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22708]=0;Y(1912,4789,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);d=v[22708];v[22708]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function QS(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a=Kb(a);d=Ab(b);v[22708]=0;R(60,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){a:{e=c,f=zd(b),v[e+8>>2]=f;e=c,f=ef(b),v[e>>2]=f;if(Gb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[22708]=0;R(61,a|0,10);break b}v[22708]=0;R(61,a|0,b<<24>>24)}b=v[22708];v[22708]=0;if((b|0)==1){break a}b=c+8|0;Pe(b);if(Gb(b,c)){continue}break}}gb=c+16|0;return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function Kna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){c=gb-16|0;gb=c;f=c+8|0;oW(f,v[d+24>>2]);gb=c+16|0;if(v[d+8>>2]!=(w[f|0]|w[f+1|0]<<8)){c=d+24|0;on(c);if(Gb(c,d+16|0)){continue}}break}f=v[d+24>>2]}gb=d+32|0;v[e+8>>2]=f;h=e,i=Zb(b),v[h>>2]=i;a:{if(Rj(e+8|0,e)){Kh(a);break a}qn(a,v[e+8>>2])}gb=e+16|0}function Fla(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;t[b+15|0]=128;d=Kv(a,127,b+15|0);v[22708]=0;t[b+14|0]=64;e=W(780,a+12|0,127,b+14|0)|0;c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){v[22708]=0;t[b+13|0]=0;W(867,a+24|0,127,b+13|0)|0;c=v[22708];v[22708]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;gb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;gc(e)}gc(d);S(a|0);L()}function p2(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(w[b+16|0]){v[22708]=0;Q(154,a|0,2041)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[22708]=0;Q(154,a|0,9778)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}}if(gd(a)){v[22708]=0;Q(154,a|0,7337)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[22708]=0;Q(154,a|0,8320)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Fc(a,b);v[22708]=0;U(97,d+8|0,b|0,c|0);e=v[22708];v[22708]=0;a:{if((e|0)==1){break a}Wb(d+8|0);v[22708]=0;e=v[b+24>>2];f=v[22708];v[22708]=0;if((f|0)==1){break a}if(e){v[22708]=0;b=v[b+24>>2];e=v[22708];v[22708]=0;if((e|0)==1){break a}v[22708]=0;U(98,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}Wb(d)}gb=d+16|0;return}b=P()|0;O()|0;Wb(a);S(b|0);L()}function lpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(536,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(537,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function gr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[lc(a,0)|0]&15)<<8|w[lc(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=x[(c<<1)+39120>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+39118>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[lc(a,2)|0];g=b,h=w[lc(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[lc(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[lc(a,3)|0],t[g+5|0]=h}function Lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,6)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(681,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(682,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function Gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(868,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(869,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function C9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[22708]=0;d=+Va(e|0,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8951,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function $la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(823,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(824,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function vp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)-17>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Wk(v[Mc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=pi(l,k);if(e){Qg(c,j,e)}if(g){Qg(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){Qg((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){$k(a,j,b)}cf(a,c);rg(a,k);b=a;a=d+(e+g|0)|0;de(b,a);t[i+7|0]=0;Bd(a+c|0,i+7|0);gb=i+16|0;return}bg();L()}function dZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb-32|0;gb=c;d=hh(a);b:{c:{d:{e:{while(1){v[22708]=0;a=Q(191,b|0,8)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}if(!a){break d}v[22708]=0;R(448,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;R(449,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break e}ed(c);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;ed(c);break b}gb=c+32|0;break a}a=P()|0;O()|0}ke(d);S(a|0);L()}}function WO(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a=gb-16|0;gb=a;f=a,g=Vb(c),v[f+8>>2]=g;f=a,g=Zb(c),v[f>>2]=g;if(Gb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[22708]=0;_(b|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Gl(c);Bb();L()}Hb(b+20|0);Hb(b+8|0);Xb(b);b=a+8|0;Qe(b);if(Gb(b,a)){continue}break}}Gl(c);gb=a+16|0;Xb(c)}}}function Py(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){gq(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,oc(a)+c|0),oc(a),b);v[22708]=0;R(123,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(120,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}ae(b)}gb=d+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<c>>>0){Cm(a,v[a>>2]+b|0)}}function Nk(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){gq(a,c);break c}b=wb(a);b=Zg(d+8|0,qh(a,oc(a)+c|0),oc(a),b);v[22708]=0;R(395,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(396,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}ae(b)}gb=d+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<c>>>0){Cm(a,v[a>>2]+b|0)}}function G9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[22708]=0;b=Q(d|0,c|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3744,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function E9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(2008,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[22708]=0;b=Q(d|0,c|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3795,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function baa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22708]=0;_(1935,a|0);f=v[22708];v[22708]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22708]=0;b=Dt(f,b,c,d,e);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,9656,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function U5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+28>>2];g=v[a+24>>2];b:{if(d>>>0<=g>>>0){if(((i=a,j=Lg(t[b|0]),h=v[v[a>>2]+52>>2],kb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0;break b}v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[pd(e+12|0,e+8|0)>>2];Qg(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=d+f|0;b=b+d|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function Dl(a,b){var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){fN(a,c);break c}b=wb(a);b=en(d+8|0,fh(a,Nb(a)+c|0),Nb(a),b);v[22708]=0;R(1503,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;R(1502,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}eh(b)}gb=d+32|0;break a}a=P()|0;O()|0;eh(b);S(a|0);L()}return}if(b>>>0<c>>>0){hj(a,v[a>>2]+(b<<2)|0)}}function _D(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+7|0]){while(1){if(!w[b+d|0]){aa(14534,6236,413,10492);L()}d=d+1|0;if((d|0)!=7){continue}break}d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=vd(c+8|0,c+24|0,7);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;hd(e,a,c);b:{if((yb(e)|0)!=7){break b}if(sd(c+24|0,b,7)){break b}bd(a,7);d=1}gb=c+32|0;break a}aa(14513,6236,411,10492);L()}return d}function LN(a){var b=0,c=0,d=0,e=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if((d|(c|w[b|0]))!=-1095062050?(w[b|0]|c|d)!=-1346458146:0){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;e=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return e}function KT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;f=v[c>>2];v[d+8>>2]=6553600;e=b+4|0;i=d,j=Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[i+4>>2]=j;g=+(f>>>0)/6553600;f=d+8|0;e=d+4|0;h=hr(g*+y[Fb(f,e)>>2]);v[d+12>>2]=h;v[d+4>>2]=6553600;b=b+8|0;i=d,j=Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[i>>2]=j;i=d,j=hr(g*+y[Fb(e,d)>>2]),v[i+8>>2]=j;v[d+4>>2]=v[c>>2]-h;Mu(a,d+12|0,Fb(e,f));gb=d+16|0}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Gi(a,b,c,d);v[a>>2]=51212;c=mc(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[22708]=0;W(1533,a+44|0,2,2)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;Uh(b);d=v[22708];v[22708]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(c);jf(b);S(a|0);L()}function v5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;hk(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Jb(c)+Ab(c)|0,v[d+44>>2]=e;Wn(a,Jb(c),Jb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Ab(c);d=a,e=b+Jb(c)|0,v[d+44>>2]=e;uu(c,Kc(c));Mx(a,Jb(c),Jb(c)+Ab(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;Zs(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}Zs(a,b)}}function tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;QW(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;gb=c+16|0}return a|0}function _P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+3|0]);g=a,h=id(f|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+7|0]);g=a,h=id(f|zb(w[b+6|0])<<8|zb(w[b+5|0])<<16|zb(w[b+4|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function Ez(a,b,c,d){var e=0,f=0,g=0;f=gb-48|0;gb=f;a:{if(!c){c=Tc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;Ez(a,b,g,e+16|0);Mi(e+32|0,d,Tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Ez(a,b|c,g,e)}gb=f+48|0}function $P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(f|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[g>>1]=h;f=zb(w[b+4|0]);g=a,h=id(f|zb(w[b+5|0])<<8|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22708]=0;U(1949,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,7591,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Nr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;e=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=e;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){c=gb-16|0;gb=c;e=c+8|0;Zi(e,v[d+24>>2]);e=IY(e);gb=c+16|0;if(v[d+8>>2]!=(e|0)){c=d+24|0;on(c);if(Gb(c,d+16|0)){continue}}break}e=v[d+24>>2]}gb=d+32|0;v[f+8>>2]=e;h=f,i=Zb(b),v[h>>2]=i;a:{if(Rj(f+8|0,f)){Kh(a);break a}qn(a,v[f+8>>2])}gb=f+16|0}function XI(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;u[e+12>>1]=c;u[e+14>>1]=b;yg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=gb-16|0;gb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Og(a)>>>0>=d>>>0){g=b,h=tc(a),v[g+8>>2]=h;lv(v[a>>2],v[Fb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){tp(a,d-f|0,c);break a}xn(a,v[a>>2]+(d<<1)|0);break a}qS(a);VB(a,Uk(a,d));tp(a,d,c)}gb=b+16|0;gb=e+16|0}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22708]=0;e=+oa(1945,d|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2442,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ud(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Ol(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Tb(d,18720);v[22708]=0;Q(303,a+43|0,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(b);yS(a);gb=d+16|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=b;d=gb-16|0;gb=d;v[d>>2]=c;v[d+8>>2]=b;b=mv(d,d+8|0);gb=d+16|0;a:{b=Sk(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[22708]=0;gn(c,d,f);c=v[22708];v[22708]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;Qe(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}_c(b);gb=e+32|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function vy(a,b,c){var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{if(w[a+20|0]){break a}e=b;b=-1-b|0;b=e+(b>>>0<c>>>0?b:c)|0;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=uy(b,4096);KJ(a,b-c|0);b=vd(d+16|0,kc(a+4|0,v[a+16>>2]),b-v[a+16>>2]|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;b=d+24|0;kb[c|0](b,a,d+8|0);f=a,g=yb(b)+v[a+16>>2]|0,v[f+16>>2]=g;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}gb=d+32|0}function Tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function SC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=gb-16|0;gb=c;if(Pb(a,b)){while(1){t[c+11|0]=0;b:{if(b>>>0>d>>>0){Mg(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;c=d;break a}c=sg(a);Rb(a,b-4|0)}t[f|0]=c}function D$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[22708]=0;a=La(1927,a|0,b|0,c|0,d|0)|0;b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;ja(1923,8355,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function y9(a){a=a|0;var b=0,c=0,d=0;v[22708]=0;_(2008,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[22708]=0;c=+pa(d|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4858,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w9(a){a=a|0;var b=0,c=0,d=0;v[22708]=0;_(2008,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[22708]=0;c=+pa(d|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4806,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function A9(a){a=a|0;var b=0,c=0,d=0;v[22708]=0;_(2008,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[22708]=0;c=+pa(d|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8988,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Hh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14534,6236,413,10492);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=vd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);if(!((yb(e)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){Rb(a,4);d=1}gb=c+32|0;break a}aa(14513,6236,411,10492);L()}return d|0}function pna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b>>2];f=eD(b);d=gb-16|0;gb=d;e=kr(c,f);a:{if(e>>>0<=pe(a)>>>0){if(Nb(a)>>>0<e>>>0){v[d+12>>2]=c;ZV(d+12|0,Nb(a));b=v[d+12>>2];Rg(c,b,v[a>>2]);YV(a,b,f,e-Nb(a)|0);break a}hj(a,Rg(c,f,v[a>>2]));break a}XV(a);b=a;g=fh(a,e);if(g>>>0>hC(a)>>>0){Sc();L()}h=PE(wb(b),g);v[b>>2]=h;v[b+4>>2]=h;i=wb(b),j=(g<<2)+h|0,v[i>>2]=j;cn(b,0);YV(a,c,f,e)}gb=d+16|0}function fpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;a=mc(a);f=d,g=Vb(b),v[f+40>>2]=g;f=d,g=Zb(b),v[f+32>>2]=g;a:{if(Gb(d+40|0,d+32|0)){while(1){b=d+8|0;e=v[d+40>>2];Zi(b,e);if((IY(b)|0)==(c|0)){b=d+8|0;qn(b,e);v[22708]=0;R(535,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}xb(d+8|0)}b=d+40|0;on(b);if(Gb(b,d+32|0)){continue}break}}gb=d+48|0;return}b=P()|0;O()|0;xb(d+8|0);jd(a);S(b|0);L()}function bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=gb-32|0;gb=d;e=gb-16|0;gb=e;f=e,g=Ib(w[c|0]|w[c+1|0]<<8),u[f+14>>1]=g;c=d+16|0;jR(c,e+14|0);gb=e+16|0;v[22708]=0;mj(d+8|0,c);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function Uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function pj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(lk(a,g+8|0)){break b}f=4;h=nl(a);if(!nh(d,2048,h)){break b}b=Qn(d,h);ml(a);b=b-48|0;c:{if(!mk(a,g+8|0)|(e|0)<2){break c}while(1){f=nl(a);if(!nh(d,2048,f)){break a}f=Qn(d,f);ml(a);b=(f+B(b,10)|0)-48|0;if(!mk(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!lk(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function oj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(il(a,g+8|0)){break b}f=4;h=tm(a);if(!jl(d,2048,h)){break b}b=Pn(d,h);sm(a);b=b-48|0;c:{if(!um(a,g+8|0)|(e|0)<2){break c}while(1){f=tm(a);if(!jl(d,2048,f)){break a}f=Pn(d,f);sm(a);b=(f+B(b,10)|0)-48|0;if(!um(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!il(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function hga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=gb-880|0;gb=d;b=Qb(a,0,76);v[b+84>>2]=0;v[b+88>>2]=0;v[b+80>>2]=256;u[b+76>>1]=65535;v[b+92>>2]=0;v[b+96>>2]=0;t[b+100|0]=1;e=b+223848|0;c=b+616|0;a=c;while(1){a=GB(a)+872|0;if((e|0)!=(a|0)){continue}break}a=d+8|0;Qb(a,0,872);e=GB(a);a=c;c=((a+223232|0)-a|0)/872|0;if((c|0)>=1){while(1){nu(a,e);a=a+872|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}gb=d+880|0;return b|0}function a4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;d=iH(a,e+12|0,d,ye());a=jb;f=v[115189];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[115189]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}gb=e+16|0;jb=a;return d|0}function fy(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!pt(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}ec(a,32);return 0}aa(12852,10528,1564,3128);L()}function E8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22708]=0;b=Q(70,f|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,2);c=Ky(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=f+16|0;return c|0}e=P()|0;O()|0;da(a|0)}S(e|0)}L()}function B8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[22708]=0;b=Q(70,f|0,5333)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}e=P()|0;O()|0;vb(b);break b}Cj(a,b,2);c=Jy(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=f+16|0;return c|0}e=P()|0;O()|0;da(a|0)}S(e|0)}L()}function Rz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;t[e+15|0]=!d|y[c+20>>2]<2?0:v[b+480180>>2]==1;d=!v[c+52>>2]|d;t[e+14|0]=d;if(!(!x[b+480188>>1]|((d|0)!=1|v[b+480180>>2]!=2))){d=0;while(1){v[(B(d,872)+c|0)+1380>>2]=0;d=d+1|0;if(d>>>0<x[b+480188>>1]){continue}break}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=v[c+52>>2];u[c+72>>1]=x[c+74>>1];t[a|0]=w[e+15|0];t[a+1|0]=w[e+14|0];gb=e+16|0}function Ku(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=d+16|0;pT(c,a,a+1|0,a+2|0,a+3|0);pT(d,b,b+1|0,b+2|0,b+3|0);gb=d+32|0;a=d;b=1;a:{if(w[v[c>>2]]<w[v[a>>2]]){break a}b=0;if(w[v[a>>2]]<w[v[c>>2]]){break a}b=1;b:{if(t[v[c+4>>2]]<t[v[a+4>>2]]){break b}b=0;if(t[v[a+4>>2]]<t[v[c+4>>2]]){break b}b=1;c:{if(w[v[c+8>>2]]<w[v[a+8>>2]]){break c}b=0;if(w[v[a+8>>2]]<w[v[c+8>>2]]){break c}b=w[v[c+12>>2]]<w[v[a+12>>2]]}}}return b}function ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;Se(b);e=d+40|0;Re(e,a,c);a=v[e>>2];v[22708]=0;c=Sd(e);e=v[22708];v[22708]=0;b:{if((e|0)==1){break b}c=zb(c);v[22708]=0;Xe(d+8|0,1,c,a);a=v[22708];v[22708]=0;if((a|0)==1){break b}v[22708]=0;R(324,d+24|0,d+8|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}a=d+24|0;Eb(b,a);vb(a);zc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;zc(d+40|0);S(a|0);L()}}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=Gi(a,b,c,d);v[a>>2]=50720;d=mc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[22708]=0;W(1533,a+44|0,2,2)|0;b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}v[22708]=0;Uh(c);b=v[22708];v[22708]=0;if((b|0)==1){break a}Lt(a);return a|0}a=P()|0;O()|0;Lc(d);jf(c);S(a|0);L()}function U3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;ye();d=gb-16|0;gb=d;Tx(d,a,e+12|0,0);f=sI(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115189];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115189]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return C(f)}function rba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;a:{b:{if(!a){break b}a=uc(b+8|0,a);v[22708]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=aL(b);c=v[22708];v[22708]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1912,9785,0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}a=0}gb=b+16|0;return a|0}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;R(1938,c|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8133,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function D2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;d=v[fc(a)>>2];i=v[b>>2];g=v[a>>2];f=(d|0)==2508;j=f?0:g;d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}h=d?d:4;d=Vp(j,h);if(d){if(!f){be(a)}v[e+4>>2]=2457;d=ge(e+8|0,d,e+4|0);Fe(a,be(d));f=v[fc(d)>>2];k=fc(a),l=f,v[k>>2]=l;Hc(d);v[b>>2]=v[a>>2]+(i-g|0);v[c>>2]=v[a>>2]+(h&-4);gb=e+16|0;return}Ss();L()}function Cu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){ER(b,A[ze(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=Vb(c),v[g+8>>2]=h;g=d,h=Zb(c),v[g>>2]=h;if(Gb(d+8|0,d)){while(1){e=d+8|0;f=v[e>>2];g=f,i=ER(b,A[f>>3]),A[g>>3]=i;Bu(e);if(Gb(e,d)){continue}break}}LB(a,c);gb=d+16|0}function goa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;v[e+24>>2]=d;g=fg(a,c);te(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(nd(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=gb-16|0;gb=f;d=Kb(f);v[22708]=0;ca(629,b|0,h|0,d|0,i|0)|0;b=v[22708];v[22708]=0;b:{if((b|0)!=1){vb(d);gb=f+16|0;break b}a=P()|0;O()|0;vb(d);S(a|0);L()}}Zf(a,g,c,e+16|0);gb=e+32|0}function eW(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;v[f+12>>2]=a;a:{b:{if(!(!c|b)){e=+(B(a,d)>>>0)*.25*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}if(!(!b|!a)){qc(f+12|0,10);a=B(w[v[f+12>>2]+29024|0],1e4);break a}e=+(a>>>0);if(a-1>>>0<=9){e=733.8401379310345/e*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}e=e/.264*1e4;if(!(e<4294967296&e>=0)){break b}a=~~e>>>0;break a}a=0}gb=f+16|0;return a}function Tga(a){a=a|0;var b=0;a=Kb(a);v[22708]=0;R(60,a|0,4);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[22708]=0;R(61,a|0,32);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(61,a|0,10);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(61,a|0,13);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(61,a|0,9);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function Cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;d=Rc(c+8|0,16,1,1,0);v[c+4>>2]=0;ud(a,0);vc(b);a:{b:{if(Tr(b,11081)){Zc(b,12);if(!Kr(b)){Ap(d,2)}Zc(b,24);break b}if(Hh(b,10963)){vc(b);v[c+4>>2]=4;e=1;break a}Yi(d,8)}e=0}f=a,g=(mf(b)>>>0)/(B(fp(d),w[d|0])>>>3>>>0)|0,v[f>>2]=g;b=Cg(d,a,b);if(!(!e|!b)){d=v[a+20>>2];f=c,g=aj(a),v[f>>2]=g;Qb(d,0,v[Fb(c+4|0,c)>>2])}gb=c+16|0;return(b|0)!=0|0}function iA(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;eO(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(kb[v[v[b>>2]+136>>2]](b)|0){b=v[b+16>>2];e=b+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[b+480232>>2])/z[e+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function J$(a){a=a|0;var b=0;a=Kb(a);v[22708]=0;R(65,a|0,4);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[22708]=0;R(66,a|0,32);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(66,a|0,10);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(66,a|0,13);b=v[22708];v[22708]=0;if((b|0)==1){break b}v[22708]=0;R(66,a|0,9);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function uaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=LK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6534,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function taa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=KK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3286,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function saa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=JK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3187,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function raa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=IK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3329,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function qaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;d=HK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3231,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function nfa(a){a=a|0;var b=0,c=0,d=0;b=gb-48|0;gb=b;while(1){c=c+1|0;if((c|0)!=15){continue}break}t[b+39|0]=0;t[b+40|0]=0;t[b+41|0]=0;t[b+42|0]=0;t[b+43|0]=0;t[b+44|0]=0;t[b+45|0]=0;t[b+46|0]=0;v[b+32>>2]=0;v[b+36>>2]=0;c=vd(b+16|0,b+32|0,15);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;d=b+24|0;cc(d,a,b+8|0);c=0;a:{if((yb(d)|0)!=15){break a}if(sd(b+32|0,5672,15)){break a}Rb(a,15);c=1}gb=b+48|0;return c|0}function Xq(a,b,c){var d=0,e=0;a=Kb(a);d=Ab(b);v[22708]=0;R(62,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){a:{if(Ab(b)){while(1){d=w[pc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[22708]=0;R(63,a|0,d|0);d=v[22708];v[22708]=0;if((d|0)!=1){break b}break a}v[22708]=0;R(63,a|0,65533);d=v[22708];v[22708]=0;if((d|0)==1){break a}}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Ic(a);S(b|0);L()}function qy(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;e=d+24|0;yc(e,v[v[b>>2]-12>>2]+b|0);v[e+4>>2]=b;b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;v[d+16>>2]=c;v[d+20>>2]=b;b=d+8|0;kl(v[d+28>>2],zb(v[b>>2]),yb(b));c=gb-16|0;gb=c;v[c+12>>2]=v[v[d+28>>2]+4>>2];v[22708]=0;v[c+8>>2]=0;e=If(c+8|0,c+12|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=c+16|0;c=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}nk(a,b,c);gb=d+32|0}function QY(a,b,c){var d=0,e=0,f=0;e=gb+-64|0;gb=e;Se(b);d=e+40|0;Re(d,a,c);a=v[d>>2];v[22708]=0;d=Sd(d);f=v[22708];v[22708]=0;a:{if((f|0)==1){break a}d=zb(d);v[22708]=0;Xe(e+8|0,2,d,a);d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;R(324,e+24|0,e+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=b;b=e+24|0;Eb(d,b);vb(b);zc(e+40|0);gb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(e+40|0);S(a|0);L()}function N9(a){a=a|0;var b=0;v[22708]=0;_(2008,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){kb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2147,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function LD(a,b,c){var d=0,e=0,f=0;e=gb+-64|0;gb=e;Se(b);d=e+40|0;Re(d,a,c);a=v[d>>2];v[22708]=0;d=Sd(d);f=v[22708];v[22708]=0;a:{if((f|0)==1){break a}d=zb(d);v[22708]=0;Xe(e+8|0,3,d,a);d=v[22708];v[22708]=0;if((d|0)==1){break a}v[22708]=0;R(324,e+24|0,e+8|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=b;b=e+24|0;Eb(d,b);vb(b);zc(e+40|0);gb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;zc(e+40|0);S(a|0);L()}function dQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;f=zb(w[b+3|0]);g=a,h=id(zb(w[b+4|0])<<16|f<<8|zb(w[b+5|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function cQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+5|0]);g=a,h=id(zb(w[b+4|0])<<16|f<<8|zb(w[b+3|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function aP(a,b){a=a|0;b=b|0;var c=0;YO(a);YO(a+368680|0);if(b){$N(a,1);return a|0}b=a;a:{if(t[459704]&1){break a}if(!Qd(459704)){break a}v[22708]=0;Q(1415,91e3,1)|0;c=v[22708];v[22708]=0;if((c|0)!=1){Pd(459704);break a}a=P()|0;O()|0;_e(459704);S(a|0);L()}$t(222112,287648,b+131112|0);$t(287648,353184,b+196648|0);$t(353184,418720,b+262184|0);$t(91024,222112,b+24|0);hc(b+327720|0,418720,40960);return a|0}function wJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((go(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;b=Q(70,c|0,7993)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}gb=c+16|0;return+(+v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]*.015625)}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function qU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+4|0]){while(1){if(!w[b+d|0]){aa(14534,6236,413,10492);L()}d=d+1|0;if((d|0)!=4){continue}break}d=0;v[c+28>>2]=0;e=vd(c+8|0,c+28|0,4);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;hd(e,a,c);if(!((yb(e)|0)!=4|v[c+28>>2]!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){bd(a,4);d=1}gb=c+32|0;break a}aa(14513,6236,411,10492);L()}return d}function YI(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){ec(a,21);return-1}if(v[a+1396>>2]<=9){rl(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Am(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>-1)){ec(a,21)}return c}aa(4610,10528,1793,2842);L()}function Waa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;WK(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2876,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function VY(){var a=0,b=0;a=gb-16|0;gb=a;a:{if(cb(a+12|0,a+8|0)|0){break a}b=Cd((v[a+12>>2]<<2)+4|0);v[115992]=b;if(!b){break a}b=Cd(v[a+8>>2]);if(b){v[v[115992]+(v[a+12>>2]<<2)>>2]=0;if(!(bb(v[115992],b|0)|0)){break a}}v[115992]=0}gb=a+16|0;b:{if(t[463952]&1){break b}if(!Qd(463952)){break b}v[22708]=0;X(2402);a=v[22708];v[22708]=0;if((a|0)!=1){Pd(463952);break b}a=P()|0;O()|0;_e(463952);S(a|0);L()}}function Taa(a,b){a=a|0;b=+b;var c=0;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;b=+Ya(1943,c|0,+b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;Z(c|0)|0;v[22708]=0;Y(1912,4650,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function S3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115189];v[115189]=0;ye();d=gb-16|0;gb=d;Tx(d,a,e+12|0,1);f=cy(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115189];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115189]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return+f}function Me(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Rp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(rG(a,b)&3){case 0:c=Rp(A[b>>3],A[b+8>>3]);break a;case 1:c=-Sp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Rp(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Sp(A[b>>3],A[b+8>>3],1)}a=c;gb=b+16|0;return a}function Q5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;a:{if((c|0)<1){break a}while(1){e=v[a+24>>2];g=v[a+28>>2];b:{if(e>>>0>=g>>>0){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}f=f+1|0;b=b+4|0;break b}v[d+12>>2]=g-e>>2;v[d+8>>2]=c-f;e=v[pd(d+12|0,d+8|0)>>2];yi(v[a+24>>2],b,e);g=e<<2;v[a+24>>2]=g+v[a+24>>2];f=f+e|0;b=b+g|0}if((c|0)>(f|0)){continue}break}}gb=d+16|0;return f|0}function uJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((go(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[22708]=0;b=Q(70,c|0,7993)|0;c=v[22708];v[22708]=0;if((c|0)==1){break c}rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}gb=c+16|0;return(w[(v[a+32>>2]+B(b,872)|0)+1075081|0]&4)>>>2|0}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function FQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+8>>2]=c;v[d+4>>2]=v[a>>2];e=v[Fb(d+8|0,d+4|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){j=d,k=xh(w[b|0]),t[j+15|0]=k;t[d+14|0]=192;t[d+13|0]=63;h=d+13|0;i=gb-16|0;gb=i;f=d+15|0;g=d+14|0;if(!Mj(f,g)){g=Mj(h,f)?h:f}gb=i+16|0;t[a|0]=w[g|0]<<1;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function St(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function F8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,1);c=Ky(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,1);c=Jy(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=DU(a,b);v[22708]=0;e=Q(877,a+12|0,b+12|0)|0;d=v[22708];v[22708]=0;b:{c:{if((d|0)!=1){v[22708]=0;Q(878,a+24|0,b+24|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;gc(e)}gc(c);S(a|0);L()}}function paa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=T(1975,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4322,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function ZY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+28>>2]=c;a:{if(!Pb(b,c<<1)){break a}qc(d+28|0,65535);Bf(a,x[d+28>>1]);e=d,f=Vb(a),v[e+16>>2]=f;e=d,f=Zb(a),v[e+8>>2]=f;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];c=d+24|0;if(!Dp(b,c)){HD(c)}c=Ib(w[d+24|0]|w[d+25|0]<<8);u[a>>1]=c;if((c|0)==65535){u[a>>1]=65535}a=d+16|0;nf(a);if(Gb(a,d+8|0)){continue}break}}gb=d+32|0}function Rm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;a:{if(!Gb(d+24|0,d+16|0)){break a}while(1){if(iD(d+8|0,v[d+24>>2])){break a}c=d+24|0;v[c>>2]=v[c>>2]+28;if(Gb(c,d+16|0)){continue}break}}gb=d+32|0;v[e+8>>2]=v[d+24>>2];h=e,i=Zb(b),v[h>>2]=i;b:{if(Rj(e+8|0,e)){Kh(a);break b}qn(a,v[e+8>>2])}gb=e+16|0}function tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=b;d=gb-16|0;gb=d;g=d+8|0;e=b+1074376|0;c=hc(sf(223848),e,614);b=0;while(1){f=B(b,872);nu((c+f|0)+616|0,(e+f|0)+616|0);b=b+1|0;if((b|0)!=256){continue}break}b=v[Xi(g,c)>>2];gb=d+16|0;v[a+4>>2]=b;b=Ik(a+8|0);d=dd(a+20|0);v[22708]=0;_(1254,a|0);c=v[22708];v[22708]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;hP(d);gP(b);fP(a+4|0);S(c|0);L()}function daa(a,b){a=a|0;b=b|0;var c=0;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;b=CK(c,b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6943,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function caa(a,b){a=a|0;b=b|0;var c=0;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22708]=0;b=AK(c,b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3681,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Uaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;c=+pa(1942,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4722,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Ls(a){var b=0,c=0;ko(a,1,10900);v[22708]=0;b=ga(147)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[22708]=0;b=ga(148)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}t[a+16|0]=b;v[22708]=0;b=ga(149)|0;c=v[22708];v[22708]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[22708]=0;_(150,a+20|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function L8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-32|0;gb=b;c=vd(b+24|0,c,d);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;a:{a=gA(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;v[22708]=0;b=Q(70,b+8|0,5190)|0;c=v[22708];v[22708]=0;b:{if((c|0)!=1){rc(a,b);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(b);break b}d=P()|0;O()|0;da(a|0)}S(d|0);L()}gb=b+32|0;return a|0}L()}function z8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,2);c=cL(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function y8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,4);c=cL(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,2);c=bL(a,c,2,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[22708]=0;c=Q(70,e|0,5333)|0;b=v[22708];v[22708]=0;if((b|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}Cj(a,b,4);c=bL(a,c,4,d);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function oda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;b=d+8|0;HM(b,a,0);if(yb(b)){a=v[a+20>>2];v[a+148>>2]=-1;b=gb-16|0;gb=b;c=v[d+8>>2];f=v[d+12>>2];e=Zh(c,f);a=a+4|0;a:{if(e>>>0<=dg(a)>>>0){if(oc(a)>>>0<e>>>0){v[b+12>>2]=c;vO(b+12|0,oc(a));g=c;c=v[b+12>>2];Rg(g,c,v[a>>2]);sr(a,c,f,e-oc(a)|0);break a}Cm(a,Rg(c,f,v[a>>2]));break a}Cv(a);Bn(a,qh(a,e));sr(a,c,f,e)}gb=b+16|0}gb=d+16|0}function jV(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;c=w[b+1|0]<<8;if((w[b|0]|c)>>>0<512|(c|w[b|0])>>>0>767){break a}b=a+112|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;d=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return d}function Xaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=v[b+8>>2];c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,8163,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function uR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a+4>>2]=0;a:{if(b){b:{if($u(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}wb(a);e=av(d+16|0);v[22708]=0;f=Q(832,a|0,b|0)|0;g=v[22708];v[22708]=0;if((g|0)==1){break a}v[22708]=0;R(833,e|0,f|0);f=v[22708];v[22708]=0;if((f|0)==1){break a}v[e+4>>2]=b;SB(a,e);De(e)}Ak(d,a);xp(d,b,w[c|0])}gb=d+32|0;return}a=P()|0;O()|0;De(e);S(a|0);L()}function una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb+-64|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;dW(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){cW(g)}d=-1;a:{if(!c){break a}d=0;if(!lW(f+8|0)){break a}d=Oe(a,b,kW(f+8|0),jb)}gb=f- -64|0;return d|0}function hz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;i=f+8|0;d=gb-16|0;gb=d;c=a;j=b;e=Yd(a);g=fc(a);h=gb-16|0;gb=h;if(e){wb(c);while(1){c=bN(e+16|0,j);g=c?g:e;e=v[(c?4:0)+e>>2];if(e){continue}break}}c=v[yc(h+8|0,g)>>2];gb=h+16|0;v[d+8>>2]=c;k=d,l=Dh(a),v[k>>2]=l;a:{if(Gb(d+8|0,d)){if(!cN(wb(a),b,ve(d+8|0))){break a}}c=Dh(a)}gb=d+16|0;a=v[yc(i,c)>>2];gb=f+16|0;return a}function e1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[e>>2]=c;c=2;a=lx(f+12|0,0,b,v[a+8>>2]);a:{if(a+1>>>0<2){break a}c=1;b=v[e>>2];g=d-b|0;d=a-1|0;if(g>>>0<d>>>0){break a}c=0;if(!d){break a}d=w[f+12|0];v[e>>2]=b+1;t[b|0]=d;a=a-2|0;if(!a){break a}b=f+12|0;while(1){d=w[b+1|0];g=v[e>>2];v[e>>2]=g+1;t[g|0]=d;b=b+1|0;a=a-1|0;if(a){continue}break}}gb=f+16|0;return c|0}function Saa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;c=A[b+16>>3];b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4686,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function si(a){var b=0,c=0;b=gb-16|0;gb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Sp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(rG(a,b)&3){case 0:a=Sp(A[b>>3],A[b+8>>3],1);break a;case 1:a=Rp(A[b>>3],A[b+8>>3]);break a;case 2:a=-Sp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Rp(A[b>>3],A[b+8>>3])}gb=b+16|0;return a}function $oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-112|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;KX(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){JX(g)}d=-1;a:{if(!c){break a}d=0;if(!NX(f+8|0)){break a}d=Oe(a,b,MX(f+8|0),jb)}gb=f+112|0;return d|0}function e_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-512|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;CE(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){BE(g)}d=-1;a:{if(!c){break a}d=0;if(!IE(f+8|0)){break a}d=Oe(a,b,HE(f+8|0),jb)}gb=f+512|0;return d|0}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ae(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>5>>>0){eB(a,d,c);break c}b=wb(a);b=aS(e+8|0,_q(a,Ae(a)+d|0),Ae(a),b);v[22708]=0;U(1100,b|0,d|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}$R(a,b);bB(b)}gb=e+32|0;break a}a=P()|0;O()|0;bB(b);S(a|0);L()}return}if(b>>>0<d>>>0){kS(a,v[a>>2]+(b<<5)|0)}}function B7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;$J(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){j=z[a+24>>2];f=ir(h,d,i);z[f>>2]=j*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function Aaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=SK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10106,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function zaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=RK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6487,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=QK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,5927,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function xaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=OK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6908,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function waa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=NK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2411,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=MK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4167,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function so(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;a:{while(1){g=h&255;if(qz(b,c,g>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;gB(a,f+15|0,f+14|0);break a}gi(b,d);gi(c,e);h=h+1|0;if(g>>>0<3){continue}break}h=f;g=w[b|0];if(to(g)>>>0>to(w[d|0])>>>0){gi(b,d);gi(c,e);g=w[b|0]}t[h+11|0]=g;gB(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}gb=f+16|0}function oaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=go(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4135,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function naa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=GK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3942,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function maa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=FK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4010,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function laa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=vl(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,3844,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=hq(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,4524,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Vaa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;b=VK(b);c=v[22708];v[22708]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2908,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function b_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-48|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;lE(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){kE(g)}d=-1;a:{if(!c){break a}d=0;if(!yE(f+8|0)){break a}d=Oe(a,b,xE(f+8|0),jb)}gb=f+48|0;return d|0}function zV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;a:{if(!w[b+5|0]){while(1){if(!w[b+d|0]){aa(14534,6236,413,10492);L()}d=d+1|0;if((d|0)!=5){continue}break}d=0;t[c+28|0]=0;v[c+24>>2]=0;e=vd(c+8|0,c+24|0,5);f=v[e+4>>2];v[c>>2]=v[e>>2];v[c+4>>2]=f;e=c+16|0;cc(e,a,c);b:{if((yb(e)|0)!=5){break b}if(sd(c+24|0,b,5)){break b}Rb(a,5);d=1}gb=c+32|0;break a}aa(14513,6236,411,10492);L()}return d}function Baa(a){a=a|0;var b=0,c=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22708]=0;c=TK(b);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,7419,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function hZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-1968|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;CD(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){BD(g)}d=-1;a:{if(!c){break a}d=0;if(!FD(f+8|0)){break a}d=Oe(a,b,1024,0)}gb=f+1968|0;return d|0}function rV(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function UB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Gi(a,b,c,d);v[a>>2]=49672;d=mc(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=wf(c),v[e+4232>>2]=f;RY(a+4260|0,80,150,80,255);v[22708]=0;W(1533,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Uh(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);jf(b);S(a|0);L()}function H0(){var a=0;a:{if(t[464840]&1){break a}if(!Qd(464840)){break a}a=464672;while(1){a=Kb(a)+12|0;if((a|0)!=464840){continue}break}Pd(464840)}ld(464672,88068);ld(464684,88096);ld(464696,88124);ld(464708,88156);ld(464720,88196);ld(464732,88232);ld(464744,88260);ld(464756,88296);ld(464768,88312);ld(464780,88328);ld(464792,88344);ld(464804,88360);ld(464816,88376);ld(464828,88392)}function nB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-32|0;gb=f;v[f+8>>2]=c;g=f,h=mf(b),v[g+28>>2]=h;c=f+8|0;Re(c,b,v[Fb(c,f+28|0)>>2]);v[22708]=0;b=Sd(c);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[22708]=0;a=fa(361,a|0,b|0,c|0,d|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}zc(f+8|0);gb=f+32|0;return a|0}a=P()|0;O()|0;zc(f+8|0);S(a|0);L()}function Pda(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[22708]=0;R(440,b+4|0,8);b=v[22708];v[22708]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(89104)|0;if((O()|0)==(ea(89104)|0)){Z(b|0)|0;zr(v[a+20>>2]+4|0);$();return}S(b|0);L()}function iI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;h=c;d=gb-16|0;gb=d;c=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){Ze(c,b);e=c;break b}f=xm(b)+1|0;e=Ti(c,f);cf(c,e);rg(c,f);de(c,b)}c=e;f=b;c:{d:{if(b){v[22708]=0;AI(c,h,f);c=v[22708];v[22708]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Bb();L()}v[d+12>>2]=0;Ge((b<<2)+e|0,d+12|0);gb=d+16|0;break a}bg();L()}gb=g+16|0;return a}function aG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=v[b>>2];g=v[b+8>>2];e=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=e;v[d+24>>2]=c;v[d+28>>2]=e;rh(d+32|0,d+16|0);c=v[v[f>>2]+28>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;kb[c|0](d+40|0,f,g,d+8|0);c=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=c;rh(a,d);h=b,i=yb(a)+v[b+8>>2]|0,v[h+8>>2]=i;gb=d+48|0}function Ks(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}b=c&16384;a:{b:{if((d|0)!=256){if((d|0)!=4){break b}c=b?70:102;break a}c=b?69:101;break a}c=b?65:97;if((d|0)==260){break a}c=b?71:103}t[a|0]=c;return(d|0)!=260}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=b;wb(b);d=a;f=vh(a);b:{c:{e=tc(b);if(e){v[22708]=0;R(814,d|0,e|0);g=v[22708];v[22708]=0;if((g|0)==1){break c}bS(d,v[c>>2],v[c+4>>2],e)}break b}a=P()|0;O()|0;cs(f);S(a|0);L()}v[22708]=0;Q(4,a+12|0,b+12|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;Ye(d);S(a|0);L()}}function tH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;c=Tb(d,c);v[22708]=0;U(2434,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){v[22708]=0;Q(2435,a|0,d+16|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(d+16|0);vb(c);v[a>>2]=79180;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;gb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d+16|0)}vb(c);S(a|0);L()}function Bpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;c=gb-32|0;gb=c;d=c+24|0;g=f+8|0;MD(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){Vv(g)}d=-1;a:{if(!c){break a}d=0;if(!ZX(f+8|0)){break a}d=Oe(a,b,72,0)}gb=f+32|0;return d|0}function s7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;VJ(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){f=Xg(h,d,i);z[f>>2]=z[a+24>>2]*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}
function lF(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>27}return c}function eba(a){a=a|0;var b=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Xb(Ft(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2174,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function DJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>4?1:b<=0){a=ba(8)|0;v[22708]=0;c=Q(70,c|0,4918)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Bh(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;yq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function BJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>4?1:b<=0){a=ba(8)|0;v[22708]=0;c=Q(70,c|0,4939)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Bh(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;yq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;vU(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){uU(f)}f=-1;a:{if(!d){break a}f=0;if(!xU(g)){break a}f=Oe(a,b,wU(g),jb)}gb=g+608|0;return f|0}function qJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[22708]=0;c=Q(70,c|0,7993)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(b,c);v[22708]=0;U(186,b|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function kZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;e=a;if(!Pb(b,c)){c=mf(b)}v[e>>2]=c;c=v[b>>2];a:{if(kb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];f=c,g=(kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[f+4>>2]=g;break a}c=a+8|0;Nk(c,v[a>>2]);if(cd(c)){break a}Vd(d+24|0,c);a=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=a;cc(d+16|0,b,d+8|0)}gb=d+32|0}function Uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-576|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;vX(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){uX(f)}f=-1;a:{if(!d){break a}f=0;if(!yX(g)){break a}f=Oe(a,b,xX(g),jb)}gb=g+576|0;return f|0}function Moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-192|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;Qr(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){VW(f)}f=-1;a:{if(!d){break a}f=0;if(!tX(g)){break a}f=Oe(a,b,sX(g),jb)}gb=g+192|0;return f|0}function KF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;g=gb-16|0;gb=g;e=d+8|0;h=e;f=gb-16|0;gb=f;b=gb-16|0;gb=b;c=f;v[c+4>>2]=1;i=c,j=Nc(16,4),v[i+8>>2]=j;gb=b+16|0;b=v[c+8>>2];v[22708]=0;JF(b);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=Kp(c);Nw(h,dc(b),b);IF(c);gb=f+16|0;break a}a=P()|0;O()|0;IF(c);S(a|0);L()}gb=g+16|0;Xf(a,e);Kd(e);gb=d+16|0;v[a+8>>2]=0;Ud(a+12|0)}function I8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-48|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+16>>2]=b;v[d+20>>2]=e;v[d+32>>2]=b;v[d+36>>2]=e;rh(d+40|0,d+16|0);b=Xf(d+24|0,c);v[22708]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(207,a|0,d+8|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){Kd(c);gb=d+48|0;return}a=P()|0;O()|0;Kd(c);S(a|0);L()}function yX(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function ppa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=Bi(d,a,1);wb(a);lp(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Zg(d+8|0,qh(a,oc(a)+1|0),oc(a),c);lp(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+1;v[22708]=0;R(396,a|0,c|0);a=v[22708];v[22708]=0;a:{if((a|0)!=1){ae(c);gb=d+32|0;break a}a=P()|0;O()|0;ae(c);S(a|0);L()}}function pJ(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+60144>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+60144>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+60144>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+60144>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+60144>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function Xca(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[v[a+20>>2]+148>>2]=-1;v[22708]=0;sn(c+8|0,a+4228|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=v[a+20>>2];d=c+8|0;e=v[d>>2];d=v[d+4>>2];v[22708]=0;U(1668,b+4|0,e|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){break b}}b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;zr(v[a+20>>2]+4|0);$()}gb=c+16|0;return}S(b|0);L()}function jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-80|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;aW(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){rC(f)}f=-1;a:{if(!d){break a}f=0;if(!dT(g)){break a}f=Oe(a,b,cT(g),jb)}gb=g+80|0;return f|0}function tma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-128|0;gb=g;c=gb-32|0;gb=c;f=g;d=c+24|0;gV(d,g);h=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;e=c+16|0;d=a;hd(e,d,c);e=yb(e);if((e|0)==(h|0)){bd(d,yb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){fV(f)}f=-1;a:{if(!d){break a}f=0;if(!jV(g)){break a}f=Oe(a,b,256,0)}gb=g+128|0;return f|0}function lG(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=gb-16|0;gb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=sp(d,g+i|0,f+15|0);if(!d){break a}if(!Uo(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}gb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function _aa(a,b){a=a|0;b=b|0;var c=0;v[22708]=0;_(1935,a|0);c=v[22708];v[22708]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2752,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;c=sf(64);v[22708]=0;e=T(1316,c|0)|0;f=v[22708];v[22708]=0;a:{if((f|0)!=1){c=ns(d,e);e=v[c>>2];v[22708]=0;a=W(1531,e|0,a|0,b|0)|0;b=v[22708];v[22708]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}bA(d+8|0);break b}a=P()|0;O()|0;Ig(c);break a}qi(d+8|0,c)}Ig(c);gb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Xb(c)}S(a|0);L()}function GH(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=gb-16|0;gb=c;b=ba(16)|0;a=gb-16|0;gb=a;a:{if(t[460840]&1){break a}if(!Qd(460840)){break a}Pd(460840)}td(a+8|0,1,90512);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;gb=a+16|0;v[22708]=0;Q(2387,b|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,78492,2388);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;wb(a);v[c+12>>2]=268435455;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}wb(a);c=b;if(c>>>0>268435455){rd(8445);L()}c=Nc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+(b<<4)|0,v[f>>2]=g;aI(a,0)}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Gi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=51448;v[22708]=0;W(1533,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Uh(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function cZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,10);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function Dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;KU(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))==1414807888){KU(a,c+11|0);t[b|0]=1;a=0}else{a=1}b=gb-16|0;gb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Tb(b,a);v[22708]=0;d=T(870,a|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(a)}gb=b+16|0;break a}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=c+16|0;return d|0}function d4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){qG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=ts(c+8|0,Zw(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22708]=0;Nn(d,f,b);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22708]=0;Mn(e,a);b=v[22708];v[22708]=0;if((b|0)==1){break b}ss(a);gb=c+32|0;break a}b=P()|0;O()|0;ss(a);S(b|0);L()}}function RQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){qG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=ts(c+8|0,Zw(a,Ec(a)+1|0),Ec(a),d);f=v[a+8>>2];v[22708]=0;Nn(d,f,b);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22708]=0;Mn(e,a);b=v[22708];v[22708]=0;if((b|0)==1){break b}vu(a);gb=c+32|0;break a}b=P()|0;O()|0;vu(a);S(b|0);L()}}function yda(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function Ula(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=cw(d,a,1);wb(a);UU(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+20;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=bD(d+8|0,cD(a,Je(a)+1|0),Je(a),c);UU(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;v[22708]=0;zv(a,c);a=v[22708];v[22708]=0;a:{if((a|0)!=1){ip(c);gb=d+32|0;break a}a=P()|0;O()|0;ip(c);S(a|0);L()}}function LJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;if(!w[a+20|0]){if(!(kb[v[v[a>>2]+40>>2]](a)|0)){d=a+4|0;while(1){KJ(a,65536);c=vd(b+16|0,kc(d,v[a+16>>2]),65536);e=v[v[a>>2]+44>>2];f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;c=b+24|0;kb[e|0](c,a,b+8|0);g=a,h=yb(c)+v[a+16>>2]|0,v[g+16>>2]=h;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){continue}break}}t[a+20|0]=1}gb=b+32|0}function Pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[22708]=0;CC(f,b,c);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}_c(d);gb=e+16|0;return}a=P()|0;O()|0;_c(d);S(a|0);L()}function K0(){var a=0;a:{if(t[464664]&1){break a}if(!Qd(464664)){break a}a=464496;while(1){a=Kb(a)+12|0;if((a|0)!=464664){continue}break}Pd(464664)}Wc(464496,2336);Wc(464508,2343);Wc(464520,2309);Wc(464532,2317);Wc(464544,2300);Wc(464556,2350);Wc(464568,2327);Wc(464580,6900);Wc(464592,7234);Wc(464604,8584);Wc(464616,10171);Wc(464628,2595);Wc(464640,8051);Wc(464652,3644)}function wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,20);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[22708]=0;R(342,e|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[c>>2]+20|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0;return}a=P()|0;O()|0;_c(c);S(a|0);L()}function gca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Ii(d+12|0);a:{b:{switch(b-1|0){default:c=z[d+12>>2];break a;case 0:c=fe(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4212>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b}}c=C(fe(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Zy(a)}gb=d+16|0}function ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;a:{a=v[a+1298424>>2];b:{if(a){kb[v[v[a>>2]+8>>2]](a,b,c);break b}v[d+8>>2]=0;if(!DF(fu(d+8|0),b)){break b}v[d+8>>2]=0;e=d+8|0;fu(e);v[d+24>>2]=0;a=fu(d+24|0);UO(e,6310,8124,133,42);v[22708]=0;ha(33,a|0,e|0,b|0,10584,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}}gb=d+32|0;return}a=P()|0;O()|0;S(a|0);L()}function Nca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Ii(d+12|0);a:{b:{switch(b-3|0){default:c=z[d+12>>2];break a;case 0:c=fe(z[d+12>>2]);z[d+12>>2]=c;if(z[a+4220>>2]==c){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b}}c=C(fe(C(z[d+12>>2]*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Zy(a)}gb=d+16|0}function qA(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Km(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=a+1298260|0;if(!Dd(a)){break a}Pi(v[a>>2],b,0)}}function pD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=Vb(b);g=Zb(b);d=gb-32|0;gb=d;v[d+16>>2]=g;v[d+24>>2]=f;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){if(!iD(d+8|0,v[d+24>>2])){c=d+24|0;on(c);if(Gb(c,d+16|0)){continue}}break}f=v[d+24>>2]}gb=d+32|0;v[e+8>>2]=f;h=e,i=Zb(b),v[h>>2]=i;a:{if(Rj(e+8|0,e)){Kh(a);break a}qn(a,v[e+8>>2])}gb=e+16|0}function kq(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){iM(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=Zg(c+8|0,qh(a,oc(a)+1|0),oc(a),d);f=v[a+8>>2];v[22708]=0;ql(d,f,b);b=v[22708];v[22708]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+1;v[22708]=0;R(120,e|0,a|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}ae(a);gb=c+32|0;break a}b=P()|0;O()|0;ae(a);S(b|0);L()}}function Zaa(a){a=a|0;var b=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,6047,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Pq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;e=Vb(a);f=Zb(a);b=gb-16|0;gb=b;v[b>>2]=f;v[b+8>>2]=e;if(Gb(b+8|0,b)){while(1){e=b+8|0;d=d+A[v[e>>2]>>3];Bu(e);if(Gb(e,b)){continue}break}}gb=b+16|0;g=c,h=Vb(a),v[g+8>>2]=h;g=c,h=Zb(a),v[g>>2]=h;if(Gb(c+8|0,c)){d=-d;while(1){a=c+8|0;b=v[a>>2];d=d+A[b>>3];A[b>>3]=d;Bu(a);if(Gb(a,c)){continue}break}}gb=c+16|0}function tl(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=gb-32|0;gb=c;f=uc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Gc(c+8|0,c);gb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=e+16|0;return a}function oB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+8>>2]=c;f=e,g=mf(b),v[f+28>>2]=g;c=e+8|0;Re(c,b,v[Fb(c,e+28|0)>>2]);v[22708]=0;b=Sd(c);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[22708]=0;ca(913,a|0,b|0,c|0,d|0)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}zc(e+8|0);gb=e+32|0;return 1}a=P()|0;O()|0;zc(e+8|0);S(a|0);L()}function iN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!_f(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Hk(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}Dl(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;mq(a,c+8|0);f=z[c+8>>2];g=Lb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=_f(v[v[a>>2]-12>>2]+a|0)}d=e;gb=c+16|0;return d}function hN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!_f(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;ag(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}Dl(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;mq(a,c+8|0);f=z[c+8>>2];g=Lb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=_f(v[v[a>>2]-12>>2]+a|0)}a=e;gb=c+16|0;return a}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=gb-1120|0;gb=f;d=gb-32|0;gb=d;c=d+24|0;_U(c,f+8|0);g=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;e=d+16|0;c=a;hd(e,c,d);e=yb(e);if((e|0)==(g|0)){bd(c,yb(d+24|0))}gb=d+32|0;c=-1;a:{if((e|0)!=(g|0)){break a}c=0;if(!bV(f+8|0)){break a}c=Oe(a,b,aV(f+8|0),jb)}gb=f+1120|0;return c|0}function yA(a,b,c,d){var e=0,f=0;e=gb-32|0;gb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e+31|0]=0;u[a>>1]=w[(b&15)+39104|0];t[a+2|0]=w[e+31|0];break a}t[e+30|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+30|0]=1;f=f<<1}c=e+16|0;Db(c,b+1074312|0,66);if(!(!Cb(c)|!d)){u[e+14>>1]=0;tC(a,e+14|0,e+30|0);break a}u[e+12>>1]=f<<4;tC(a,e+12|0,e+30|0)}gb=e+32|0}function Bm(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return t[a+69696|0]}if((a|0)<=511){return t[(a>>>5|0)+69696|0]+5|0}return t[(a>>>10|0)+69696|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return t[(a>>>15|0)+69696|0]+15|0}return t[(a>>>20|0)+69696|0]+20|0}if((a|0)<=536870911){return t[(a>>>25|0)+69696|0]+25|0}a=t[(a>>>30|0)+69696|0]+30|0}else{a=0}return a}function HU(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|(w[a+65|0]!=1?w[a+65|0]!=16:0))){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=gb-16|0;gb=c;d=mE(b,a);gb=c+16|0;a=d?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function $aa(a){a=a|0;var b=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return ie(a)|0}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,9429,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();return 0}return ie(18720)|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+f;a:{a=v[d>>2];if((a|0)!=v[d+4>>2]){while(1){v[22708]=0;R(1489,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}a=v[d>>2]+52|0;v[d>>2]=a;if(v[d+4>>2]!=(a|0)){continue}break}}_c(d);gb=e+16|0;return}a=P()|0;O()|0;_c(d);S(a|0);L()}function Zy(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(wf(v[a+16>>2])>>>0);c=C(C(C(kb[v[v[a>>2]+204>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(kb[v[v[a>>2]+196>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Xh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(kb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(kb[v[v[a>>2]+192>>2]](a)|0)){b=sG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function L2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Vp((f|0)==2508?0:v[a>>2],d);if(g){if((f|0)!=2508){be(a)}v[e+4>>2]=2457;f=ge(e+8|0,g,e+4|0);PG(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);gb=e+16|0;return}Ss();L()}function f7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Jp(a);v[a>>2]=59216;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=dc(a);Ip(c);v[c>>2]=59580;mc(c+4|0);t[c+20|0]=0;v[c+16>>2]=0;v[c>>2]=59380;b=v[d+4>>2];v[c+24>>2]=v[d>>2];v[c+28>>2]=b;b=v[d+12>>2];v[c+32>>2]=v[d+8>>2];v[c+36>>2]=b;t[c+40|0]=0;gb=d+16|0;return a|0}function OF(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=119304647;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=_k(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function zJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>1?1:b<0){a=ba(8)|0;v[22708]=0;c=Q(70,c|0,9006)|0;d=v[22708];v[22708]=0;if((d|0)==1){break c}rc(a,c);v[22708]=0;U(186,a|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=Bh(b*256);v[v[a+32>>2]+1074456>>2]=d;gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=119304647;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=119304648){rd(8445);L()}c=Nc(B(c,36),4);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,36)|0,v[f>>2]=g}function kY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=89478485;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=ln(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Gq(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function rpa(a){a=a|0;var b=0,c=0,d=0,e=0;c=vh(a);v[22708]=0;_(516,a|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=gb-16|0;gb=d;c=d;v[c>>2]=a;b=v[a+4>>2];v[c+4>>2]=b;v[c+8>>2]=b+32768;b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){u[b>>1]=0;u[b+2>>1]=0;b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return a|0}a=P()|0;O()|0;fD(c);S(a|0);L()}function M2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[fc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Vp((f|0)==2508?0:v[a>>2],d);if(g){if((f|0)!=2508){be(a)}v[e+4>>2]=2457;f=ge(e+8|0,g,e+4|0);PG(a,f);Hc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];gb=e+16|0;return}Ss();L()}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=4925421;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=4925422){rd(8445);L()}c=Nc(B(c,872),8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,872)|0,v[f>>2]=g}function lL(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=Of(e);if((f|0)==(Ab(c)|0)){v[22708]=0;c=fa(551,c|0,0,-1,e|0,f|0)|0;e=v[22708];v[22708]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Bb();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=d+16|0;return a}function Vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=477218588;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=477218589){rd(8445);L()}c=Nc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,9)|0,v[f>>2]=g}function Jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=715827882;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=b;if(c>>>0>=715827883){rd(8445);L()}c=Nc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,6)|0,v[f>>2]=g}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Dg(c+24|0,a);$U(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;b=gb-16|0;gb=b;a=1;d=c;e=c+8|0;if(v[e+4>>2]==v[c+4>>2]){f=v[d+4>>2];a=b;d=v[d>>2];v[a>>2]=d;v[a+4>>2]=f;v[a+8>>2]=d;v[a+12>>2]=f;a=(JW(e,a)|0)!=0}gb=b+16|0;gb=c+32|0;return a|0}function NI(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if((b|0)<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}function LE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<5){a:{if(!b){break a}if(!Pb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Mg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;return d}aa(8513,6236,136,11431);L()}function PY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=2147483647;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Og(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function EJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-32>>>0>=481){b=ba(8)|0;v[22708]=0;c=Q(70,c|0,6520)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(b,c);v[22708]=0;U(186,b|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function pO(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075785|0];if((c|0)>=0){iP(a,b,(d|0)==32,((w[(B(b,872)+a|0)+1075836|0]<<5)+a|0)+901692|0,c&255);return}iP(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function MY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=153391689;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=$i(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function MB(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=357913941;v[22708]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22708];v[22708]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=ug(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=gb-224|0;gb=f;d=gb-32|0;gb=d;c=d+24|0;CX(c,f);g=yb(c);c=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=c;v[d>>2]=e;v[d+4>>2]=c;e=d+16|0;c=a;hd(e,c,d);e=yb(e);if((e|0)==(g|0)){bd(c,yb(d+24|0))}gb=d+32|0;c=-1;a:{if((e|0)!=(g|0)){break a}c=0;if(!GX(f)){break a}c=Oe(a,b,FX(f),jb)}gb=f+224|0;return c|0}function YD(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=oqa(w[a+3|0],0,18,0);d=d+c|0;b=jb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}jb=a;return b}function pz(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function ZK(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=kb[a|0](b)|0;d=jb;f=d;if((d|0)<0){break b}if((kb[c|0](b,0,0,0)|0)<=-1){break a}if((kb[c|0](b,0,0,2)|0)<=-1){break a}d=kb[a|0](b)|0;a=jb;kb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=JA(d,a)}return g}kb[c|0](b,e,f,0)|0;return 0}function GJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-1>>>0>=65535){b=ba(8)|0;v[22708]=0;c=Q(70,c|0,2940)|0;a=v[22708];v[22708]=0;if((a|0)==1){break c}rc(b,c);v[22708]=0;U(186,b|0,54936,1937);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074416>>2]=b;gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function Dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<11)+e;a:{if(v[c>>2]!=v[c+4>>2]){while(1){a=v[c>>2];v[22708]=0;bz(a);a=v[22708];v[22708]=0;if((a|0)==1){break a}a=v[c>>2]+2048|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0;return}a=P()|0;O()|0;_c(c);S(a|0);L()}function x7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;YJ(a,c);gb=c+16|0}function vea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;u[a>>1]=0;c=mc(a+4|0);d=mc(a+16|0);v[a+36>>2]=0;e=Kb(a+40|0);f=Ik(a+52|0);Fg(c);u[a+28>>1]=65472;v[22708]=0;v[b+12>>2]=1065353216;R(1499,c|0,b+12|0);g=v[22708];v[22708]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Fg(d);gb=b+16|0;return a|0}a=P()|0;O()|0;ZW(f);vb(e);Lc(d);Lc(c);S(a|0);L()}function r7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;UJ(a,c);gb=c+16|0}function lU(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if(w[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10377,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Sn(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e+8|0;Fc(d,b);v[22708]=0;b=T(2482,d|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;d=T(2491,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}v[c>>2]=d;v[22708]=0;R(2492,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(e+8|0);gb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function G7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;dK(a,c);gb=c+16|0}function A7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Wg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;_J(a,c);gb=c+16|0}function ypa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{e=Be(a);b:{if(e>>>0>1){break b}c:{if(e){v[22708]=0;U(506,d|0,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){np(b,d);gc(d);break c}a=V(27364)|0;if((O()|0)!=(ea(27364)|0)){break a}Z(a|0)|0;$();break b}if(!Pb(a,c)){break b}YX(a,b,c)}f=oc(b)>>>0>=c>>>0}gb=d+16|0;return f|0}S(a|0);L()}function jQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b|0])+g|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+2|0])+d|0)+(zb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function gQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b+1|0])+g|0)+(zb(w[b|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+3|0])+d|0)+(zb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function boa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b>>2];e=v[b>>2]+yb(b)|0;f=Hg(a);v[22708]=0;b=Zh(d,e);c=v[22708];v[22708]=0;a:{b:{if((c|0)==1){break b}if(!b){break a}v[22708]=0;R(517,a|0,b|0);c=v[22708];v[22708]=0;if((c|0)==1){break b}v[22708]=0;Y(665,a|0,d|0,e|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;im(f);S(a|0);L()}}function Wm(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;if(-17-b>>>0>=c>>>0){i=Jb(a);k=a;a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Wk(v[Mc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=pi(k,j);if(e){Qg(c,i,e)}d=d-(e+f|0)|0;if(d){Qg((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){$k(a,i,b)}cf(a,c);rg(a,j);gb=h+16|0;return}bg();L()}function Un(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e+8|0;Fc(d,b);v[22708]=0;b=T(2453,d|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;d=T(2465,b|0)|0;f=v[22708];v[22708]=0;if((f|0)==1){break a}t[c|0]=d;v[22708]=0;R(2466,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Wb(e+8|0);gb=e+16|0;return}a=P()|0;O()|0;Wb(e+8|0);S(a|0);L()}function TA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=A[b+8>>3];d=$g(A[b>>3]);e=A[b>>3];a:{if(d){if(e<0){c=zR(c)?c:1;break a}if(c!=0){if(zR(c)){break a}}d=$g(c);Tm(a,A[b>>3],d?M:c);return}if(!Oi(e)|A[b+8>>3]!=0){break a}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;return}e=_w(A[b>>3]);f=si(c);Tm(a,e*Me(c),f*e)}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Gi(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=52832;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[22708]=0;W(1533,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Uh(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[pc(b,0)|0]!=(hg(43)&255)){if(w[pc(b,0)|0]!=(hg(45)&255)){break b}}c=c+1|0;Pe(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Gd(d,d+8|0);f=Ab(b);Uz(b,v[e>>2],c-f|0,hg(48))}Dc(a,b);gb=d+16|0}function kz(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=f;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){wb(a);v[22708]=0;R(1489,b|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}b=b+52|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=f+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function b6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Ab(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Fb(f+12|0,f)>>2],v[g+4>>2]=h;b=Uo(Jb(a)+b|0,d,v[Fb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}gb=f+16|0;return b|0}Yn();L()}function Q_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;f=gb-16|0;gb=f;e=gb-16|0;gb=e;v[f+4>>2]=1;i=f,j=Nc(32,4),v[i+8>>2]=j;gb=e+16|0;e=f;h=v[e+8>>2];v[22708]=0;ca(223,h|0,b|0,c|0,d|0)|0;b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=a;a=Kp(e);Nw(b,dc(a),a);vF(e);gb=f+16|0;break a}a=P()|0;O()|0;vF(e);S(a|0);L()}gb=g+16|0}function Oda(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((oc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}_y(a,b)}St(a)}function Fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22708]=0;_(779,a|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}a=a+24|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function Fq(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function kI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;if(1073741807-b>>>0>=c>>>0){g=Jb(a);i=a;a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=xm(v[Mc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Ti(i,h);if(e){yi(c,g,e)}d=d-e|0;if(d){e=e<<2;yi(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){ai(a,g,b)}cf(a,c);rg(a,h);gb=f+16|0;return}bg();L()}function gg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;c=a;a:{if(!Ee(b)){v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;break a}g=v[b>>2];b:{c:{d=v[b+4>>2];d:{if(d>>>0<=10){b=c;Ze(c,d);break d}if(d>>>0>4294967279){break c}f=Wk(d)+1|0;b=pi(c,f);cf(c,b);rg(c,f);de(c,d)}Qg(b,g,d+1|0);break b}bg();L()}}gb=e+16|0;return a|0}function tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22708]=0;FT(a);e=v[22708];v[22708]=0;if((e|0)==1){break a}a=a+872|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function kQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+2|0])|zb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function hQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+3|0])|zb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function cx(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if(v[a+48>>2]!=1){break a}if((d|0)==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Sq(a,b){var c=0,d=0;if(a-1>>>0<=268435455){a=a+208|0;oqa(b,0,a,0);a=jb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[22708]=0;b=T(2433,a|0)|0;c=v[22708];v[22708]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;X(20);c=v[22708];v[22708]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}if(!b){break a}d=Qb(b,0,a)- -64|0}return d}function dt(a,b,c,d){var e=0,f=0;e=gb-160|0;gb=e;hc(e+8|0,74296,144);a:{b:{if((b|0)<=0){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=TI(e+8|0,c,d,2289,2290);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[115189]=61;a=-1}gb=e+160|0;return a}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=zd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[Jb(b)|0]!=(hg(43)&255)){if(w[Jb(b)|0]!=(hg(45)&255)){break b}}c=c+1|0;Pe(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Gd(d,d+8|0);f=Ab(b);TN(b,v[e>>2],c-f|0,hg(48))}Dc(a,b);gb=d+16|0}function Ll(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c|0]&32)){break a}g=d,h=zd(b),v[g+8>>2]=h;g=d,h=ef(b),v[g>>2]=h;if(!Gb(d+8|0,d)){break a}while(1){e=v[d+8>>2];c=t[e|0];f=hg(97);b:{if((c|0)<(f|0)){break b}if((hg(122)|0)<(c|0)){break b}g=e,h=hg(65)+(c-f|0)|0,t[g|0]=h}c=d+8|0;Pe(c);if(Gb(c,d)){continue}break}}Dc(a,b);gb=d+16|0}function cV(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=oqa(w[a+30|0],0,37,0);c=jb;d=b;b=a+24|0;b=oqa(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=jb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}jb=a;return b}function T8(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a=mc(a);v[22708]=0;R(2069,c+16|0,0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){b=c+16|0;d=Vb(b);b=Zb(b);e=v[yc(c+8|0,a)>>2];v[22708]=0;U(2070,d|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break b}Lc(c+16|0);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Lc(c+16|0)}yd(a);S(b|0);L()}function Cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Gi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=53064;v[22708]=0;W(1533,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Uh(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22708]=0;_(1935,a|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1920;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,10407,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function X4(a){a=a|0;a:{v[22708]=0;T(2408,463096)|0;a=v[22708];v[22708]=0;b:{if((a|0)==1){break b}v[22708]=0;T(2409,463180)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}v[22708]=0;T(2408,463432)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}v[22708]=0;T(2409,463516)|0;a=v[22708];v[22708]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Bb();L()}}function Rw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+8>>2]=b;v[d+12>>2]=e;v[d+16>>2]=b;v[d+20>>2]=e;rh(d+24|0,d+8|0);v[22708]=0;b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;R(212,a|0,d|0);b=v[22708];v[22708]=0;if((b|0)!=1){v[a+8>>2]=0;Xf(a+12|0,c);Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function M7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a:{b:{if((Gy(a)|0)!=1){break b}if((wK(a)|0)!=(b|0)){break b}d=a+120|0;Ci(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[13842];v[a+8>>2]=v[13841];v[a+12>>2]=e;e=v[13840];v[a>>2]=v[13839];v[a+4>>2]=e;kb[v[Sh(a,Yg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break a}vK(a,1,b)}gb=c+16|0}function qK(a,b,c){var d=0,e=0,f=0;a:{d=v[c>>2];c=a;e=vh(c);b:{if(!d){break b}v[22708]=0;R(2110,c|0,d|0);f=v[22708];v[22708]=0;if((f|0)!=1){v[22708]=0;pK(c,d);d=v[22708];v[22708]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;Gl(e);S(a|0);L()}v[22708]=0;b=nK(b);d=v[22708];v[22708]=0;if((d|0)!=1){v[a+12>>2]=b;break a}a=P()|0;O()|0;Gl(c);S(a|0);L()}}function ji(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function T$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb+-64|0;gb=e;d=1;a:{if(Sg(a,b,0)){break a}d=0;if(!b){break a}b=fx(b,89644,89692);d=0;if(!b){break a}d=e+8|0;Qb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;kb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}gb=e- -64|0;return d|0}function Qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;a:{if($u(a)>>>0<b>>>0){wb(a);d=av(c+32|0);v[22708]=0;R(836,d|0,b|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=c+16|0;Ak(b,a);e=c+8|0;Sl(e,a);v[22708]=0;U(837,d|0,b|0,e|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}SB(a,d);De(d)}gb=c+48|0;return}a=P()|0;O()|0;De(d);S(a|0);L()}function Oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+24>>2]=d;f=fg(a,c);te(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!f){if(nd(a,5)){break a}}g=v[a+28>>2];d=0;tE(b,v[e+24>>2]);if(v[e+24>>2]){while(1){aB(g,sc(b,d));d=d+1|0;if(d>>>0<y[e+24>>2]){continue}break}}}Zf(a,f,c,e+16|0);gb=e+32|0}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;AU(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){yU(g)}if(a){f=HU(b+8|0)}gb=b+160|0;return f|0}function t5(a,b){a=a|0;b=b|0;var c=0;c=v[a+24>>2];if(c>>>0>y[a+44>>2]){v[a+44>>2]=c}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(Ie(b,-1)){Wn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return Xs(b)|0}if(!(w[a+48|0]&16)){if(!Ie(xh(b),t[v[a+12>>2]-1|0])){break a}}Wn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=xh(b);t[v[a+12>>2]]=c;return b|0}return-1}function r2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=gb-16|0;gb=d;b=a;a:{if(!Ee(f)){v[b+8>>2]=v[f+8>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;break a}e=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){Ze(a,c);break d}if(c>>>0>1073741807){break c}f=xm(c)+1|0;b=Ti(a,f);cf(a,b);rg(a,f);de(a,c)}yi(b,e,c+1|0);break b}bg();L()}}gb=d+16|0}function cqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-624|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;BY(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){AY(g)}if(a){f=DY(b+8|0)}gb=b+624|0;return f|0}function VA(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function G_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;a:{if(y[b+16>>2]<=c>>>0){nk(a,d,0);break a}f=v[b+4>>2];g=v[b+12>>2];h=e,i=yb(d),v[h+20>>2]=i;v[e+16>>2]=v[b+16>>2]-c;nk(e+24|0,d,v[Fb(e+20|0,e+16|0)>>2]);b=v[v[f>>2]+28>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kb[b|0](a,f,c+g|0,e+8|0)}gb=e+32|0}function wH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=kb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((Kk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=lt(v[a+32>>2])?-1:0}gb=b+16|0;return d|0}function cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;Ek(a);i=v[b+4>>2];f=b+4|0;Ck(wb(a),v[a>>2],c,f);j=wb(a);g=b+8|0;d=g;h=v[a+4>>2];if((h|0)!=(c|0)){e=v[d>>2];while(1){gn(j,e,c);e=v[d>>2]+4|0;v[d>>2]=e;c=c+4|0;if((h|0)!=(c|0)){continue}break}}xc(a,f);xc(a+4|0,g);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];cn(a,Nb(a));return i|0}function ana(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22708]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(772,a|0,d+8|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function Mo(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;t[d+15|0]=b;a:{b:{c:{d:{if(Ee(a)){c=fk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}Wm(a,c,1,c,c,0,0);b=c;if(Ee(a)){break b}}c=a;Ze(a,b+1|0);break a}c=v[a>>2];de(a,b+1|0)}a=b+c|0;Bd(a,d+15|0);t[d+14|0]=0;Bd(a+1|0,d+14|0);gb=d+16|0}function zu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=d+8|0;b=gb-16|0;gb=b;v[22708]=0;c=a;OQ(c+4|0);f=v[22708];v[22708]=0;a:{b:{c:{if((f|0)!=1){v[22708]=0;v[b+12>>2]=0;df(c+8|0,b+12|0,e);e=v[22708];v[22708]=0;if((e|0)!=1){break c}break b}break b}g=c,h=fc(c),v[g>>2]=h;gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=d+16|0;return a}function os(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22708]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(207,a|0,d+8|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;Bv(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){QX(g)}if(a){f=TX(b+8|0)}gb=b+32|0;return f|0}function Z5(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(Ee(a)){c=fk(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=1;b=w[a+11|0];if((b|0)!=1){break c}}kI(a,c,1,c,c);b=c;if(Ee(a)){break b}}c=a;Ze(a,b+1|0);break a}c=v[a>>2];de(a,b+1|0)}a=(b<<2)+c|0;Ge(a,d+12|0);v[d+8>>2]=0;Ge(a+4|0,d+8|0);gb=d+16|0}function XX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=Xf(d+16|0,c);v[22708]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(515,a|0,d+8|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){Kd(c);gb=d+32|0;return a|0}a=P()|0;O()|0;Kd(c);S(a|0);L()}function Nna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;f=-1;c=gb-32|0;gb=c;e=c+24|0;g=b+8|0;Wv(e,g);e=yb(e);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){rW(g)}if(a){f=CW(b+8|0)}gb=b+16|0;return f|0}function voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;EC(e,c);v[22708]=0;mj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;On(e,c);v[22708]=0;mj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function oma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Mq(e,c);v[22708]=0;mj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function jqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Lh(e,c);v[22708]=0;mj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(453,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function wY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;GD(e,c);v[22708]=0;mj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function vG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;Lh(e,c);v[22708]=0;mj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function ZZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-32|0;gb=d;e=d+16|0;gw(e,c);v[22708]=0;mj(d+8|0,e);c=v[22708];v[22708]=0;b:{if((c|0)==1){break b}v[22708]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(146,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function IE(a){var b=0,c=0,d=0,e=0,f=0;b=w[a|0]|w[a+1|0]<<8;a:{if(w[a+110|0]>64|((b|0)!=20042?(b|0)!=26217:0)|(t[a+112|0]<0|w[a+111|0]>128)){break a}while(1){e=0;d=a+c|0;b=t[d+113|0];f=(b|0)>-1;if(!((b&255)>>>0<254?f:1)){break a}b=w[d+241|0];if(!b&f|b>>>0>15|w[d+369|0]>=64){break a}e=1;c=c+1|0;if((c|0)!=128){continue}break}}return e}function _r(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;d=Jb(b);e=Jb(b);g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;Rg(d,e+v[Fb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Fb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;Jo(b+d|0,e+f|0,c+7|0);gb=c+16|0;return a|0}function KE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;if(b>>>0<3){a:{if(!b){break a}if(!Pb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Mg(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}gb=c+16|0;return d}aa(8513,6236,136,11431);L()}function ema(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=Pb(a,6);a:{if(!e){a=gb-16|0;gb=a;d=gb-16|0;gb=d;f=b+6|0;while(1){Jf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,6);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return e|0}function eK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14076];v[c+8>>2]=v[14075];v[c+12>>2]=g;g=v[14074];v[c>>2]=v[14073];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function dK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14080];v[c+8>>2]=v[14079];v[c+12>>2]=g;g=v[14078];v[c>>2]=v[14077];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function _J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14285];v[c+8>>2]=v[14284];v[c+12>>2]=g;g=v[14283];v[c>>2]=v[14282];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function ZJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14488];v[c+8>>2]=v[14487];v[c+12>>2]=g;g=v[14486];v[c>>2]=v[14485];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function YJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14492];v[c+8>>2]=v[14491];v[c+12>>2]=g;g=v[14490];v[c>>2]=v[14489];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function VJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14695];v[c+8>>2]=v[14694];v[c+12>>2]=g;g=v[14693];v[c>>2]=v[14692];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function UJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14699];v[c+8>>2]=v[14698];v[c+12>>2]=g;g=v[14697];v[c>>2]=v[14696];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function JN(a,b,c,d){var e=0,f=0,g=0;e=gb-32|0;gb=e;g=v[a+20>>2];f=x[a+34>>1];v[22708]=0;f=f&65;v[e+16>>2]=f;v[e+8>>2]=f^65;ka(1474,d|0,a|0,b|0,c|0,e+16|0,e+8|0);d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[a>>2]=c;v[a+20>>2]=b;v[22708]=0;Tq(g);a=v[22708];v[22708]=0;if((a|0)==1){break a}gb=e+32|0;return}a=P()|0;O()|0;S(a|0);L()}function $J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=sl(v[a+8>>2]);Ci(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14281];v[c+8>>2]=v[14280];v[c+12>>2]=g;g=v[14279];v[c>>2]=v[14278];v[c+4>>2]=g;kb[v[Sh(c,Yg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-208|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;bU(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){aU(h)}if(a){f=jU(b)}gb=b+208|0;return f|0}function cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,40);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,40);gb=c+16|0}return a|0}function Xoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;AX(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){zX(h)}if(a){f=BX(b)}gb=b+160|0;return f|0}function Hz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=F(c,.999);h=c*3.141592653589793;i=qq(b);while(1){j=a;k=c;f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=si(g)*qq(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}l=j,m=JT(k*d*32768),u[l>>1]=m;a=a+2|0;e=e+1|0;if((e|0)!=32768){continue}break}}function rX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=gb-16|0;gb=e;d=c+24|0;bc(d,b,80);gb=e+16|0;e=yb(d);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,80);gb=c+16|0}return a|0}function n7(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=ZK(d);Ip(a);t[a+8|0]=0;v[a+4>>2]=c;v[a>>2]=59164;mc(a+12|0);v[a>>2]=58972;c=v[b+4>>2];v[a+24>>2]=v[b>>2];v[a+28>>2]=c;c=v[b+12>>2];v[a+32>>2]=v[b+8>>2];v[a+36>>2]=c;gb=d+16|0;return a|0}function lQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+2|0])|zb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function iQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+3|0])|zb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function RE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=Rc(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){Ap(a,3)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=11;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){Cf(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}Cf(a,b)}}function BX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>9){break a}b=(w[a|0]|w[a+1|0]<<8)!=0}return b}function dM(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function Xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Se(b);v[d+12>>2]=0;a:{if(!Hk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Vh(a,d+11|0)){break b}Mo(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}gb=d+16|0;return e|0}function Ac(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[22708]=0;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=Pr(c+24|0,c+8|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}v[22708]=0;a=Ly(c+16|0,a);b=v[22708];v[22708]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Vna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Se(b);t[d+15|0]=0;a:{if(!Vh(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Vh(a,d+14|0)){break b}Mo(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}gb=d+16|0;return e|0}function $Z(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-48|0;gb=b;f=-1;c=gb-32|0;gb=c;h=b;e=c+24|0;jE(e,b);e=yb(e);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){iE(h)}if(a){f=vE(b)}gb=b+48|0;return f|0}function lM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=(wf(v[a+16>>2])|0)/5|0;b=Ac(b,b>>31);v[a+4272>>2]=b;v[22708]=0;v[c+12>>2]=0;U(1541,a+4256|0,b<<1,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;gb=c+16|0;return}S(b|0);L()}function fQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function eQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=id(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function _x(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((kb[b|0](a,f)|0)>=0){if((kb[b|0](a,e)|0)>-1){break a}}j=f;f=(kb[b|0](f,e)|0)>-1;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}GI(g,h);gb=g+240|0}function Lf(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(y[b+8>>2]<c>>>0){v[22708]=0;Y(2117,14450,6267,394,3438);a=v[22708];v[22708]=0;if((a|0)==1){break a}L()}v[d+8>>2]=v[b+8>>2];e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;gb=d+16|0;return}V(0)|0;O()|0;Bb();L()}function Jla(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!hD(a,b+16|0)){break a}c=0;if(!OU(b+16|0)){break a}c=-1;if(!dk(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;gb=b+32|0;return a|0}function GI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=gb-256|0;gb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;hc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;hc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}gb=e+256|0}function bQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=id(zb(w[b|0])|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function aQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=id(zb(w[b+3|0])|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Wka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Md(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}Ol(b);$o(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Zm(b)){break a}if(v[a>>2]!=(d|0)){Cw(b+68|0)}hc(zb(v[b+20>>2]),zb(v[a+20>>2])+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function eY(){var a=0,b=0;a=gb-240|0;gb=a;a:{b:{if(t[90992]&1){break b}if(!Qd(90992)){break b}v[22708]=0;X(43);b=v[22708];v[22708]=0;if((b|0)==1){break a}v[22708]=0;_(44,a+120|0);b=v[22708];v[22708]=0;if((b|0)==1){break a}hc(90872,hc(a,a+120|0,120),116);Pd(90992)}gb=a+240|0;return 90872}a=P()|0;O()|0;_e(90992);S(a|0);L()}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=gg(d,b);v[22708]=0;U(1164,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){v[22708]=0;U(71,a|0,d+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function p8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Hg(a);a:{c=v[b+4>>2];if(!c){break a}v[22708]=0;R(2088,a|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[22708]=0;Y(2089,a|0,c|0,e+f|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pF(d);S(a|0);L()}return a|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Sk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;lq(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=yy(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;ql(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Sk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;cp(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gu(a+60|0);v[a>>2]=78196;v[d>>2]=78216;v[22708]=0;e=a+8|0;W(106,a|0,78228,e|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){a:{v[a>>2]=78196;v[d>>2]=78216;v[22708]=0;W(107,e|0,b|0,c|8)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;oh(d);S(a|0);L()}function lu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;if(b){e=f+8|0;Db(e,a+1074312|0,73);k=Cb(e)?c- -64|0:c;i=sk(a);l=i^1;c=120;g=1;while(1){e=c>>>1|0;j=e+g|0;h=_g(a,j,k,d);a:{if(!((h|0)!=0&l|b>>>0<=h>>>0?(h>>>0<=b>>>0|i)==1:0)){g=j+1|0;c=(e^-1)+c|0;break a}c=e}if(c){continue}break}}gb=f+16|0;return g}function c_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Dn(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22708]=0;wn(d,f,c);d=v[22708];v[22708]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}_c(b);gb=e+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function _fa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;d=a+1298260|0;if(!Dd(d)){f=b;c=gb-16|0;gb=c;e=sf(532);a=v[a+24620>>2];v[22708]=0;g=Q(1313,e|0,a|0)|0;a=v[22708];v[22708]=0;a:{if((a|0)!=1){a=v[Xi(c+8|0,g)>>2];gb=c+16|0;break a}a=P()|0;O()|0;Xb(e);S(a|0);L()}v[f+8>>2]=a;a=b+8|0;VO(d,be(a));hu(a)}gb=b+16|0}function M$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Sg(a,v[b+8>>2],e)){bx(b,c,d);return}a:{if(!Sg(a,v[b>>2],e)){break a}if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=33;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}e=d+24|0;zC(e,b);f=vd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);zC(e,b);Qb(v[e>>2]+c|0,0,33-c|0);Rb(a,v[d+44>>2]);gb=d+48|0;return c|0}function g7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+28>>2]){break a}if((kb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}c=v[d>>2];f=yb(d);if(!f){break a}while(1){b:{e=kb[v[b+28>>2]](v[b+24>>2],c,f)|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;if(!e){break b}c=c+e|0;f=f-e|0;if(f){continue}}break}e=g}nk(a,d,e)}function F$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=gg(d,b);v[22708]=0;U(176,d+16|0,b|0,c|0);e=v[22708];v[22708]=0;a:{b:{if((e|0)!=1){v[22708]=0;U(5,a|0,d+16|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function $z(a,b){var c=0,d=0,e=0;XV(a);kp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function fO(a,b,c,d,e){var f=0,g=0,h=0;if((e|0)!=10){f=c;while(1){a:{if((b|0)==(f|0)){f=b;g=d;break a}f=f-1|0;g=(d>>>0)/(e>>>0)|0;t[f|0]=w[(d-B(g,e)|0)+1991|0];h=d>>>0>=e>>>0;d=g;if(h){continue}}break}b:{if(!g){d=c-f|0;if(d){break b}}v[a+4>>2]=61;v[a>>2]=c;return}b=zh(b,f,d);v[a+4>>2]=0;v[a>>2]=b+d;return}EA(a,b,c,d)}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+12;VT(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Tu(d+8|0,MB(a,Ec(a)+1|0),Ec(a),c);VT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;eU(a,c);dU(c);gb=d+32|0}function Tx(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;f=e+16|0;Qb(f,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;zi(f,0,0);uI(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+24>>2]|0)+b}v[a>>2]=g;v[a+4>>2]=h;v[a+8>>2]=d;v[a+12>>2]=f;gb=e+160|0}function tp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=mi(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;wn(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+2|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function qE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Eg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;cp(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function ld(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=lI(b);e=gb-16|0;gb=e;c=bq(a);a:{if(c>>>0>=b>>>0){f=Jb(a);g=f;c=b;b:{c:{if(b){v[22708]=0;CI(g,d,c);d=v[22708];v[22708]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}v[e+12>>2]=0;Ge((b<<2)+f|0,e+12|0);jh(a,b);break a}f=a;a=Ab(a);mI(f,c,b-c|0,a,0,a,b,d)}gb=e+16|0}function jU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==50}return c}function dO(a,b,c,d,e){var f=0,g=0;a:{f=a;if((e|0)!=10){a=c;while(1){b:{if((a|0)==(b|0)){a=b;break b}g=d&255;d=(g|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(g-B(d,e)|0)+1991|0];if(d&255){continue}}break}c:{if(!(d&255)){d=c-a|0;if(d){break c}}v[f+4>>2]=61;v[f>>2]=c;break a}a=zh(b,a,d);v[f+4>>2]=0;v[f>>2]=a+d;break a}VP(f,b,c,d)}}function QC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Cr(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;CC(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+6|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function Cn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Bi(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;ql(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function oY(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Cr(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+4|0]=6;t[a+5|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=8;t[a+3|0]=4;a=a+6|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function ika(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{b:{c:{d:{e:{f:{if((b|0)<=28590){if((b|0)==437){break c}if((b|0)==1252){break b}if((b|0)!=20127){break f}e=1;break a}if((b|0)==28591){break e}if((b|0)==28605){break d}e=0;if((b|0)==65001){break a}}e=c;break a}e=2;break a}e=3;break a}e=5;break a}e=8}wT(a,e,d)}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=Yl(a);d=Yl(b);b=gb-32|0;gb=b;v[b+24>>2]=c;b:{if((a|0)!=(d|0)){while(1){c=Tb(b+8|0,v[a>>2]);v[22708]=0;R(2118,b+24|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break b}vb(c);a=a+4|0;if((d|0)!=(a|0)){continue}break}}gb=b+32|0;break a}a=P()|0;O()|0;vb(c);S(a|0);L()}}function pE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=cw(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=wb(a);v[22708]=0;R(342,e|0,b|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}b=b+20|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Qt(a){var b=0,c=0,d=0,e=0;b=Dk(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){d=a;if(b>45e-5){c=Tp(b)/.6931471805599453;b=c-H(c);e=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Dk(e+c)*.5}else{b=0}A[d+4248>>3]=b}Pt(a)}function ZX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=320012546|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=184619540|w[a+8|0]>1){break a}b=a+9|0;if(!w[b|0]|w[b|0]>8){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function $ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=4896;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}e=d+24|0;FC(e,b);f=vd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);FC(e,b);Qb(v[e>>2]+c|0,0,4896-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function vC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;jW(a,b);e=b+8|0;Zc(a,Yb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);iW(a,d);a:{b=b+32|0;if(!Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}if(!Zc(a,Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){break a}xC(a,c);return}Qb(c,0,80)}function $pa(a,b){a=a|0;b=b|0;var c=0;fv(a,b);Pf(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=263;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}e=d+24|0;_S(e,b);f=vd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);_S(e,b);Qb(v[e>>2]+c|0,0,263-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function X6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c>>2];e=yb(c);b:{if(!e){break b}while(1){f=kb[v[b+28>>2]](v[b+24>>2],d,e)|0;if(!f){t[b+40|0]=1;break b}d=d+f|0;g=f+g|0;h=g>>>0<f>>>0?h+1|0:h;e=e-f|0;if(e){continue}break}}d=g}nk(a,c,d)}function Rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=gb-16|0;gb=e;d=gb-16|0;gb=d;Ze(c,1);Ir(c,1,b<<24>>24);t[d+15|0]=0;Bd(c+1|0,d+15|0);gb=d+16|0;gb=e+16|0;b=c;d=Jb(c);e=Ab(c);v[22708]=0;W(117,a|0,d|0,e|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(b);gb=c+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function ES(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=Ik(a);a=b+236|0;b=Ju(a);a:{if((a|0)!=(b|0)){while(1){d=x[a>>1];u[c+14>>1]=d;if(d){v[22708]=0;U(1082,c|0,e|0,c+14|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}gb=c+16|0;return}a=P()|0;O()|0;or(e);S(a|0);L()}function Z2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=v[20911];v[g+24>>2]=v[20910];v[g+28>>2]=h;h=v[20909];v[g+16>>2]=v[20908];v[g+20>>2]=h;h=v[20907];v[g+8>>2]=v[20906];v[g+12>>2]=h;h=v[20905];v[g>>2]=v[20904];v[g+4>>2]=h;h=a;a=g+32|0;b=ik(h,b,c,d,e,f,g,a);gb=a;return b|0}function To(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];if(e|v[d>>2]){if(!b){break a}while(1){e=id((id(0-e|0,31)&255)+e|0,8);f=v[d>>2];f=id((id(0-f|0,31)&255)+f|0,8);v[c>>2]=v[c>>2]-e;v[d>>2]=v[d>>2]-f;e=(g<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}e=v[c>>2];continue}}Qb(a,0,b<<3)}}function Pfa(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Ab(b);v[22708]=0;R(65,a|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){a:{if(Ab(b)){while(1){c=t[pc(b,d)|0];v[22708]=0;R(66,a|0,hg(c)|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}d=d+1|0;if(Ab(b)>>>0>d>>>0){continue}break}}return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function JW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;v[d+12>>2]=v[a+4>>2];c=v[b+4>>2];v[22708]=0;v[d+8>>2]=c;c=Fb(d+12|0,d+8|0);e=v[22708];v[22708]=0;if((e|0)!=1){c=Uo(v[a>>2],v[b>>2],v[c>>2]);a:{if(c){break a}c=0;if(v[a+4>>2]==v[b+4>>2]){break a}c=y[a+4>>2]<y[b+4>>2]?-1:1}gb=d+16|0;return c}V(0)|0;O()|0;Bb();L()}function JA(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[22708]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=Pr(c+24|0,c+8|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){break a}v[22708]=0;a=Ly(c+16|0,a);b=v[22708];v[22708]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=22;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}e=d+24|0;Bv(e,b);f=vd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);Bv(e,b);Qb(v[e>>2]+c|0,0,22-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=40;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}e=d+24|0;oC(e,b);f=vd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);oC(e,b);Qb(v[e>>2]+c|0,0,40-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function aba(a){a=a|0;var b=0;v[22708]=0;_(1935,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,2782,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function OB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=a;d=gb-96|0;gb=d;XU(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=d+e|0;e=v[g+4>>2];v[f>>2]=v[g>>2];v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;gb=d+96|0;v[a+112>>2]=0;return a|0}function FN(a,b){var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){d=gb-16|0;gb=d;c=v[b>>2];e=v[b+4>>2];b=kr(c,e);a:{if(b>>>0<=pe(a)>>>0){if(Nb(a)>>>0<b>>>0){v[d+12>>2]=c;ZV(d+12|0,Nb(a));f=c;c=v[d+12>>2];Rg(f,c,v[a>>2]);nz(a,c,e,b-Nb(a)|0);break a}hj(a,Rg(c,e,v[a>>2]));break a}CN(a);hw(a,fh(a,b));nz(a,c,e,b)}gb=d+16|0}}function jS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{switch(c+1|0){case 0:case 3:aB(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;c=d+16|0;e=a;a=d+28|0;bo(c,e,d+26|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=2;Fb(a,c);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[c|0]|w[c+1|0]<<8;gb=d+32|0}function j8(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(Bj(a)){Ah(b+24|0);break b}c=b+8|0;no(c,a);v[22708]=0;c=T(2085,c|0)|0;d=v[22708];v[22708]=0;if((d|0)==1){break a}v[b+24>>2]=c;Yf(b+8|0)}if(Bj(a)){a=a+36|0}else{a=v[b+24>>2]}a=io(a);wl(b+24|0);gb=b+32|0;return a|0}a=P()|0;O()|0;Yf(b+8|0);S(a|0);L()}function UM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[22708]=0;v[c+12>>2]=0;U(1541,a+4208|0,b<<1,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;gb=c+16|0;return}S(b|0);L()}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=65;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}e=d+24|0;dw(e,b);f=vd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);dw(e,b);Qb(v[e>>2]+c|0,0,65-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function uba(){var a=0,b=0;v[22708]=0;a=v[22708];v[22708]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1912,7167,0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}else{a=19923024}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jw(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(!Pb(a,256)){a=gb-16|0;gb=a;d=gb-16|0;gb=d;e=b+256|0;while(1){Jf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0;break a}d=gb-16|0;gb=d;bc(c+24|0,b,256);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function cC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-1024|0;gb=g;d=gb-32|0;gb=d;f=d+24|0;ZB(f,g);f=yb(f);e=v[d+28>>2];h=v[d+24>>2];v[d+8>>2]=h;v[d+12>>2]=e;v[d>>2]=h;v[d+4>>2]=e;e=d+16|0;cc(e,a,d);e=yb(e);if((e|0)==(f|0)){Rb(a,yb(d+24|0))}gb=d+32|0;if((e|0)==(f|0)){i=aC(g,c)>>>0<=b>>>0}gb=g+1024|0;return i}function T2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=gb-128|0;gb=c;v[c+12>>2]=c+116;d=a+8|0;a=c+16|0;UG(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;if((a|0)!=(e|0)){while(1){QH(d+8|0,t[a|0]);a=a+1|0;if((e|0)!=(a|0)){continue}break}b=v[d+8>>2]}gb=d+16|0;gb=c+128|0;return b|0}function M9(a){a=a|0;var b=0;v[22708]=0;_(2008,a|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22708]=0;Y(1912,9228,a|0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Wca(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{if((oc(v[a+20>>2]+4|0)|0)!=7){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=Vb(v[a+20>>2]+4|0);c=Zb(v[a+20>>2]+4|0);sn(d+8|0,a+4228|0);Wi(b,c,v[d+8>>2]);break a}_y(a,b)}Lt(a);gb=d+16|0}function Vg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);Mf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;gb=d+16|0}function Hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{b=zT(d,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){v[22708]=0;R(1088,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=d+16|0;return}a=P()|0;O()|0;_c(b);S(a|0);L()}function Dma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;b=-1;a:{if(!Wf(a,1084)){break a}Ul(a,1080);e=d+60|0;FV(a,e);c=e;e=EV(d+40|0);b=0;if(!DV(c,e)){break a}Ul(a,20);b=1;while(1){c=d+8|0;CV(a,c);f=eC(c)+f|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}b=y[e+4>>2]>=f>>>0}gb=d- -64|0;return b|0}function wba(){var a=0,b=0;v[22708]=0;a=v[22708];v[22708]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1912,7139,0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}else{a=393216}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function SY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=Pb(a,8);a:{if(!d){a=gb-16|0;gb=a;e=gb-16|0;gb=e;f=b+8|0;while(1){Jf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=e+16|0;gb=a+16|0;break a}EY(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function IM(a){a=a|0;var b=0,c=0,d=0,e=0;c=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(c)<0x8000000000000000){b=c;e=~~b>>>0;d=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}d=-2147483648}A[a+4256>>3]=c-(+(e>>>0)+ +(d|0)*4294967296)}function Goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;FC(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,4896);gb=c+16|0}return a|0}function zQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=zb(w[b|0])+g|0;t[a|0]=g;d=zb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function xl(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;$f(c,b);v[22708]=0;R(2042,c+16|0,c|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){v[22708]=0;U(2043,a|0,0,c+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(c+16|0);vb(c);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ic(c+16|0)}vb(c);S(b|0);L()}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=cq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;yR(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function pP(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+851|0]=w[b+851|0]|32;g=b;d=a?w[b+813|0]:0;h=v[b+852>>2]+((c|0)>-1?0-d|0:d)|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+852>>2]=h+d;c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+813|0]=a^a+c}function kN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(pe(a)>>>0>=b>>>0){f=d,g=Nb(a),v[f+8>>2]=g;jN(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){fz(a,b-e|0,c);break a}hj(a,v[a>>2]+(b<<2)|0);break a}CN(a);hw(a,fh(a,b));fz(a,b,c)}gb=d+16|0}function gK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;v[22708]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22708];v[22708]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Sc();L()}c=Nc(b,1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=b+c|0,v[f>>2]=g}function _K(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=v[a>>2];a:{if(!b){break a}d=v[a+8>>2];if(!d){break a}e=v[a+12>>2];if(!e){break a}f=kb[e|0](b)|0;a=jb;if((a|0)<0){break a}c=0;b:{if((kb[d|0](b,0,0,0)|0)<0){break b}c=0;if((kb[d|0](b,0,0,2)|0)<0){break b}kb[e|0](b)|0;c=(jb|0)>-1}kb[d|0](b,f,a,0)|0}return c|0}function KJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;c=a+4|0;a:{if(oc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!oc(c)){Nk(c,uy(v[a+16>>2]+b|0,65536));break a}f=d,g=oc(c),v[f+12>>2]=g;e=xf(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Nk(c,uy(a,65536));break a}f=d,g=oc(c),v[f+8>>2]=g;Nk(c,xf(d+8|0))}gb=d+16|0}function AQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;f=a,g=zb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function kx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;h=b;c=lI(b);d=gb-16|0;gb=d;b=a;a:{if(c>>>0<=1073741807){b:{if(c>>>0<=1){Ze(b,c);e=b;break b}g=xm(c)+1|0;e=Ti(b,g);cf(b,e);rg(b,g);de(b,c)}yi(e,h,c);v[d+12>>2]=0;Ge((c<<2)+e|0,d+12|0);gb=d+16|0;break a}bg();L()}gb=f+16|0;return a|0}function kba(){var a=0,b=0;v[22708]=0;a=v[22708];v[22708]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;Y(1912,8398,0,0,0);a=v[22708];v[22708]=0;if((a|0)==1){break a}$();a=0}else{a=2048}return a|0}a=P()|0;O()|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function hH(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=kr(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){Ze(a,e);d=a;break a}g=xm(e)+1|0;d=Ti(a,g);cf(a,d);rg(a,g);de(a,e)}if((b|0)!=(c|0)){while(1){Ge(d,b);d=d+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f+12>>2]=0;Ge(d,f+12|0);gb=f+16|0;return}bg();L()}function eB(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=AB(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){wb(a);v[22708]=0;R(1088,b|0,c|0);g=v[22708];v[22708]=0;if((g|0)==1){break a}b=b+32|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function FS(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=Zh(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){Ze(a,e);d=a;break a}g=Wk(e)+1|0;d=pi(a,g);cf(a,d);rg(a,g);de(a,e)}if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Bd(d,f+15|0);gb=f+16|0;return}bg();L()}function gq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Bi(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;Jf(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function gE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=mi(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;ew(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+2|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function ev(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=Vb(a);c=Zb(a);a=gb-16|0;gb=a;v[a>>2]=c;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}b=a+8|0;nf(b);if(Gb(b,a)){continue}break}}gb=a+16|0}gb=d+16|0}function Zf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=gb-48|0;gb=c;a:{if(!b){b=1;if(nd(a,5)){break a}b=HL(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;te(c,v[a+28>>2]);e=c+16|0;TL(e,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[e+8>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}gb=c+48|0;return b|0}function Ur(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;c=f+12|0;qc(c,256);qc(c,65535);h=x[f+12>>1];Bf(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=fj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}gb=f+16|0}function rka(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Pl(a,0,c);return;case 1:Pl(a,1,c);return;case 2:Pl(a,2,c);return;case 3:Pl(a,3,c);return;case 4:Pl(a,4,c);return;case 5:Pl(a,5,c);return;case 6:zS(a,24992,c);return;case 7:zS(a,26016,c);return;case 8:Pl(a,6,c);return;default:break a}}Kb(a)}function qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(dg(a)>>>0>=b>>>0){f=d,g=oc(a),v[f+8>>2]=g;oi(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){Cn(a,b-e|0,c);break a}Cm(a,b+v[a>>2]|0);break a}Cv(a);Bn(a,qh(a,b));Cn(a,b,c)}gb=d+16|0}function qI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=Ab(a);f=Kc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Jb(a);h=e;f=d;if(d){cm(c+e|0,e,f);b=(b>>>0>=e>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}cm(h,b,c);b=c+d|0;jh(a,b);t[g+15|0]=0;Bd(b+e|0,g+15|0);break a}vp(a,f,(c+d|0)-f|0,d,0,0,c,b)}gb=g+16|0;return a}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Ab(b);f=Ab(c);b=Jb(b);v[22708]=0;Y(116,a|0,b|0,e|0,e+f|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=Jb(c);v[22708]=0;W(117,a|0,b|0,f|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function T6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;v[f+8>>2]=d;d=v[qi(f,f+8|0)>>2];v[22708]=0;fa(1934,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){JJ(a);b=IJ(a+88|0);v[a>>2]=59704;v[b>>2]=59792;eg(f+8|0);gb=f+16|0;return a|0}a=P()|0;O()|0;eg(f+8|0);S(a|0);L()}function Aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;b=c+16|0;An(b,d);b=zb(v[b>>2]);e=c+8|0;An(e,d);b=Oj(c+24|0,b,zb(v[e>>2]+2|0));v[22708]=0;Q(1099,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function V_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;GF(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-36|0;FF(h,e-36|0,c);e=v[d>>2]-36|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];al(a);_k(a);_k(a)}function QQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;gT(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;xu(h,e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];_i(a);$i(a);$i(a)}function JQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=zb(w[b|0])+d|0;d=g+zb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;wb(b);e=a;f=vh(a);a:{c=Nb(b);if(!c){break a}v[22708]=0;R(333,e|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22708]=0;Y(1498,e|0,b|0,d|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;qv(f);S(a|0);L()}return a|0}function jf(a){a=a|0;var b=0,c=0;v[a>>2]=50140;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;DM(a+44|0);return a|0}function ip(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-20|0;v[b+8>>2]=d;v[22708]=0;R(348,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){aE(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/20|0)}}
function fz(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Eg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22708]=0;lq(f,b,c);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function cR(a,b,c){var d=0,e=0,f=0;d=Yd(a);e=fc(a);a:{if(d){f=wb(a);b:{while(1){c:{a=d+16|0;d:{if(Ml(f,c,a)){if(!v[d>>2]){break a}a=d;break d}if(!Ml(f,a,c)){break b}a=d+4|0;if(!v[d+4>>2]){break c}d=a;a=d}e=a;d=v[d>>2];continue}break}v[b>>2]=d;return a}v[b>>2]=d;return e}d=fc(a)}v[b>>2]=d;return d}function ls(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-36|0;v[b+8>>2]=d;v[22708]=0;R(214,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){ks(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/36|0)}}function Fr(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);f=x[d+12>>1];Bf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==65535){e=65535;break a}if((e|0)!=65535){break a}e=65534}g=fj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function pN(a){var b=0,c=0,d=0,e=0;c=a;d=v[a+4>>2];a:{while(1){b=v[c+8>>2];if((b|0)==(d|0)){break a}e=v[c+16>>2];b=b-52|0;v[c+8>>2]=b;v[22708]=0;R(1325,e|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}c=v[a>>2];if(c){_z(v[a+16>>2],c,(v[dc(a)>>2]-v[a>>2]|0)/52|0)}}function hM(a,b,c){var d=0,e=0,f=0,g=0;g=(b|0)<1;if(C(D(a))<C(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!(g|(e|0)<0)){while(1){d=b-1|0;e=e<<1;if((b|0)<2){break a}b=d;if((e|0)>-1){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function Fm(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;mc(a+32|0);dd(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function BQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=xh(w[b|0]),t[f|0]=g;f=a,g=xh(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function sd(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(v[a>>2]!=v[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function fe(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>-1?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>-1?a:C(-a)}return a}function MS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){if(c){while(1){h=id((id(0-d|0,31)&255)+d|0,8);i=id((id(0-e|0,31)&255)+e|0,8);f=(g<<3)+b|0;d=d-h|0;v[f>>2]=d+v[f>>2];e=e-i|0;v[f+4>>2]=e+v[f+4>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}v[a+96>>2]=e;v[a+92>>2]=d}}function Jm(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=zP(a,b,d);if(e-251>>>0<5){break d}if(e){break a}}return yP(a,b,d)}e=yP(a,b,d);if(e-251>>>0<5){break b}if(e){break a}}e=zP(a,b,d)}return e}function CP(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}So(b,e,a);c=f+8|0;Db(c,a+1074312|0,10);if(!Cb(c)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}gb=f+16|0}function Zd(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;Jn(a);a=Xi(d+8|0,a);a:{if(Nb(465840)>>>0<=b>>>0){v[22708]=0;_(2561,b+1|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}}c=v[Lb(465840,b)>>2];if(c){Ln(c)}c=be(a);e=Lb(465840,b),f=c,v[e>>2]=f;IG(a);gb=d+16|0;return}b=P()|0;O()|0;IG(a);S(b|0);L()}function TX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<14){break a}if(Yb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>256){break a}a=a+8|0;c=!Ib(w[a|0]|w[a+1|0]<<8)}return c}function zv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;nE(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-20|0;Av(h,e-20|0,c);e=v[d>>2]-20|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];bE(a,Je(a))}function qB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Ab(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=Uo(Jb(a),v[c+8>>2],v[Fb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}gb=c+16|0;return a|0}function jI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Of(b);f=Ab(c);v[22708]=0;Y(2299,a|0,b|0,e|0,e+f|0);b=v[22708];v[22708]=0;a:{if((b|0)!=1){b=Jb(c);v[22708]=0;W(2300,a|0,b|0,f|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function aoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{switch(c+1|0){case 0:case 2:Wh(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;c=d+16|0;e=a;a=d+28|0;bo(c,e,d+24|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=1;Fb(a,c);t[d+16|0]=w[d+24|0];t[b|0]=w[c|0];gb=d+32|0}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Gi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=52312;v[22708]=0;W(1533,a+44|0,2,2)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;Uh(b);c=v[22708];v[22708]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;jf(b);S(a|0);L()}function Mn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;_p(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Nn(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}xc(a,f);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Yw(a,Ec(a))}function LX(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);f=x[d+12>>1];Bf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=fj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function GE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,128);qc(c,65535);f=x[d+12>>1];Bf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=fj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function uL(a,b){var c=0;c=gb-32|0;gb=c;$f(c,b);v[22708]=0;U(2048,c+16|0,0,c|0);b=v[22708];v[22708]=0;a:{b:{if((b|0)!=1){v[22708]=0;R(2049,a|0,c+16|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(c+16|0);vb(c);gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ic(c+16|0)}vb(c);S(b|0);L()}function RD(a,b,c){var d=0,e=0,f=0,g=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=192;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=mf(a)}e=d+24|0;Qr(e,b);f=vd(d+32|0,v[e>>2],c);g=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=g;cc(d+16|0,a,d+8|0);Qr(e,b);Qb(v[e>>2]+c|0,0,192-c|0);Rb(a,v[d+44>>2]);gb=d+48|0}function Lw(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}
function xQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function uQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function mP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}rk(a,b,b+700|0,c<<2,0)}}function cM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[22708]=0;v[c+12>>2]=0;U(1541,a+4208|0,b<<2,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;gb=c+16|0;return}S(b|0);L()}function Qz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[_b(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;c=d+8|0;Db(c,a+1074312|0,63);if(!Cb(c)){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}gb=d+16|0}function QX(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function m4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a:{if((d|0)!=(e|0)){f=d;a=b;while(1){g=-1;if((a|0)==(c|0)){break a}h=t[a|0];i=t[f|0];if((h|0)<(i|0)){break a}if((h|0)>(i|0)){return 1}a=a+1|0;f=f+1|0;if((f|0)!=(e|0)){continue}break}}g=((e-d|0)+b|0)!=(c|0)}return g|0}function fN(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Eg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22708]=0;Xo(b);f=v[22708];v[22708]=0;if((f|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function aw(a){var b=0,c=0,d=0,e=0,f=0;e=gb-16|0;gb=e;b=gb-32|0;gb=b;d=b+24|0;Wr(d,e+15|0);d=yb(d);c=v[b+28>>2];f=v[b+24>>2];v[b+8>>2]=f;v[b+12>>2]=c;v[b>>2]=f;v[b+4>>2]=c;c=b+16|0;hd(c,a,b);c=yb(c);if((c|0)==(d|0)){bd(a,yb(b+24|0))}gb=b+32|0;gb=e+16|0;return((c|0)==(d|0)?w[e+15|0]:0)&255}function Tn(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Fc(d,a);v[22708]=0;a=T(2481,d|0)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)==1){break b}v[22708]=0;Y(2493,a|0,83408,83434,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Wb(c+8|0);gb=c+16|0;break a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}return b}function He(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;e=gb-16|0;gb=e;d=a;a:{if(b>>>0<=4294967279){b:{if(b>>>0<=10){Ze(d,b);f=d;break b}h=Wk(b)+1|0;f=pi(d,h);cf(d,f);rg(d,h);de(d,b)}Ir(f,b,c);t[e+15|0]=0;Bd(b+f|0,e+15|0);gb=e+16|0;break a}bg();L()}gb=g+16|0;return a|0}function wQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b|0])+d|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function tQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b+1|0])+d|0)+(zb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function Sna(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Sk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;$j(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function FH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=ct(a);v[a+32>>2]=b;v[a>>2]=78756;b=d+8|0;Ys(b,e);v[22708]=0;b=T(2406,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Vn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);wm(e);S(a|0);L()}function EH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=dI(a);v[a+32>>2]=b;v[a>>2]=78860;b=d+8|0;Ys(b,e);v[22708]=0;b=T(2407,b|0)|0;f=v[22708];v[22708]=0;if((f|0)!=1){Wb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Vn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Wb(d+8|0);aq(e);S(a|0);L()}function rP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}rk(a,b,b+700|0,c,0)}}function k_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Sk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;Xr(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function eN(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Sk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;Xo(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function Zn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);Mf(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;gb=c+16|0}function NZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Dn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;ew(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function LZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Dn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;Ok(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function Fy(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=yy(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22708]=0;Jf(b);b=v[22708];v[22708]=0;if((b|0)==1){break a}b=v[a>>2]+1|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}_c(a);gb=c+16|0;return}b=P()|0;O()|0;_c(a);S(b|0);L()}function rz(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function Jc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}e=b;d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=e-d|0;jb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function LF(a){a=a|0;var b=0,c=0;b=Kb(a);v[22708]=0;T(215,a+12|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){b=gb-16|0;gb=b;v[b+12>>2]=0;v[22708]=0;df(a+32|0,b+12|0,b+8|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function tv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=fg(a,c);e=f+8|0;te(e,v[a+28>>2]);h=v[e+12>>2];v[f+24>>2]=v[e+8>>2];v[f+28>>2]=h;a:{b:{if(!g){e=-1;if(!nd(a,5)){break b}break a}e=v[g+8>>2]}kb[d|0](v[a+28>>2],b,e)}a=Zf(a,g,c,f+24|0);gb=f+32|0;return a|0}function mD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[pf(d+15|0,d+14|0)|0];e=a>>>0<15|b>>>0<2;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[pf(d+13|0,d+12|0)|0]}gb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,1030);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,1030)}return a|0}function Sha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=AB(d,a,1);wb(a);cB(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=aS(d+8|0,_q(a,Ae(a)+1|0),Ae(a),c);cB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;$R(a,c);bB(c);gb=d+32|0}function qZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,120);a:{if(!d){a=gb-16|0;gb=a;e=b+120|0;while(1){Jf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}bc(c+24|0,b,120);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function yQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function vQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,225);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,225)}return a|0}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,326);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,326)}return a|0}function We(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;DE(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];gb=b+32|0}function Vma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,826);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,826)}return a|0}function Tpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;gY(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function Of(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=Zh(b,c);d=Kc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Ab(a);Wm(a,g,h,d,0,d,0)}d=Jb(a);if((b|0)!=(c|0)){while(1){Bd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;Bd(d,e+15|0);jh(a,f);gb=e+16|0}function $ma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,422);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,422)}return a|0}function y4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[b>>2]){if(!gd(c)){px(c,14858)}e=v[b+4>>2];kb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[22708]=0;Q(1167,c|0,d|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}vb(d)}Dc(a,c);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function wO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=Zh(b,c);a:{if(e>>>0<=dg(a)>>>0){if(oc(a)>>>0<e>>>0){v[d+12>>2]=b;vO(d+12|0,oc(a));Rg(b,v[d+12>>2],v[a>>2]);sr(a,v[d+12>>2],c,e-oc(a)|0);break a}Cm(a,Rg(b,c,v[a>>2]));break a}Cv(a);Bn(a,qh(a,e));sr(a,b,c,e)}gb=d+16|0}function sX(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=vh(a);a:{b=b+4|0;c=uf(b);if(!c){break a}v[22708]=0;R(2044,a|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22708]=0;Y(2045,a|0,b|0,d|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jt(e);S(a|0);L()}}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,8)){u[c+16>>1]=0;b=4;while(1){d=w[c+16|0]|w[c+17|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;a=a+2|0;b=b-1|0;if(b){continue}break}break a}Gp(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function rh(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;d=gb-16|0;gb=d;b=c+8|0;e=v[b>>2];b=v[b>>2]+yb(b)|0;v[22708]=0;jo(a,e,b);a=v[22708];v[22708]=0;a:{if((a|0)!=1){gb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=c+32|0}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,64);a:{if(!d){a=gb-16|0;gb=a;e=b- -64|0;while(1){Ok(b);b=b+2|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0;break a}rD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,73);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,73)}return a|0}function Xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,60);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,60)}return a|0}function Lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,71);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,71)}return a|0}function Jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,91);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,91)}return a|0}function ET(a,b,c){a:{switch(b|0){case 0:zk(a,0,c);return;case 1:zk(a,1,c);return;case 2:zk(a,2,c);return;case 3:zk(a,3,c);return;case 4:zk(a,4,c);return;case 5:zk(a,5,c);return;case 6:xS(a,24992,c);return;case 7:xS(a,26016,c);return;case 8:zk(a,6,c);return;default:break a}}Kb(a)}function ek(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){g=v[a+8>>2];c=v[a>>2];while(1){a:{if(c){d=v[a+4>>2];break a}v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=w[c|0];c=8}c=c-1|0;v[a>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function M4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if(((g=a,h=Lg(t[b|0]),f=v[v[a>>2]+52>>2],kb[f](g|0,h|0)|0)|0)==-1){return d|0}b=b+1|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Kk(b,1,c,v[a+32>>2])|0}function Lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-48|0;gb=c;d=c+40|0;t[d|0]=w[b|0];b=c+16|0;Wr(b,d);b=zb(v[b>>2]);e=c+8|0;Wr(e,d);b=Oj(c+24|0,b,zb(v[e>>2]+1|0));v[22708]=0;Q(1099,a|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function kda(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=4104;d=v[b+8>>2];c=0;a:{if(d>>>0<4096){break a}a=v[b+12>>2];e=a+7&-8;a=e-a|0;c=0;if(a>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-a;c=e}a=c;if(!a){aa(3145,6145,88,4444);L()}gb=b+16|0;return a|0}function Wda(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+8>>2]=b;b=0;a:{if(Nb(a)>>>0>511){break a}if(!Dd(c+8|0)){break a}d=c+8|0;b=v[d>>2];v[22708]=0;R(1529,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Ig(c+8|0);S(a|0);L()}Ig(c+8|0);gb=c+16|0;return b|0}function Uc(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[22708]=0;v[b+4>>2]=32767;a=pd(b+12|0,b+4|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;a=If(b+8|0,a);c=v[22708];v[22708]=0;if((c|0)==1){break a}gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function Ts(a,b){var c=0,d=0;c=-1;a:{if((a|0)==-1){break a}d=v[b+76>>2]>=0;b:{c:{c=v[b+4>>2];d:{if(!c){xI(b);c=v[b+4>>2];if(!c){break d}}if(v[b+44>>2]-8>>>0<c>>>0){break c}}c=-1;if(d){break b}break a}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a;if(!d){break a}}}return c}function $d(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function f9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;v[d+44>>2]=b;b=d+8|0;xl(b,c);c=d+24|0;v[c>>2]=v[d+44>>2];Dc(c+4|0,b);v[22708]=0;R(2047,a+4|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){Fk(d+24|0);vb(d+8|0);gb=d+48|0;return}a=P()|0;O()|0;Fk(d+24|0);vb(d+8|0);S(a|0);L()}function XZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;dw(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,65)}return a|0}function Ska(a,b){a=a|0;b=b|0;var c=0,d=0;b=gb-16|0;gb=b;c=-1;a:{if(!dk(a,b+8|0)){break a}c=0;if(!UT(b+8|0)){break a}c=-1;if(!Wf(a,4)){break a}c=gb-16|0;gb=c;if(DT(a,c+8|0)){a=c+8|0;d=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=c+16|0;c=d>>>31|0}gb=b+16|0;return c|0}function $n(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=rqa(a,b,10,0);e=jb;f=e;e=oqa(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function wM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[v[a+16>>2]+1074404>>2];v[22708]=0;v[c+12>>2]=0;U(1541,a+4208|0,B(b,254)|0,c+12|0);b=v[22708];v[22708]=0;a:{if((b|0)==1){b=V(89104)|0;if((O()|0)!=(ea(89104)|0)){break a}Z(b|0)|0;$()}v[a+4220>>2]=0;gb=c+16|0;return}S(b|0);L()}function o7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Jp(a);v[a>>2]=58808;v[22708]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;Q(2121,dc(a)|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function d1(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[22708]=0;b=T(2575,b|0)|0;c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=v[a+8>>2];if(!a){return 1}v[22708]=0;a=T(2576,a|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}V(0)|0;O()|0;Bb();L()}function Spa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=vh(a);a:{if(!b){break a}v[22708]=0;R(486,c|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;oY(c,b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;kD(d);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function NL(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;ML(a+60|0);ML(a+52|0);Aq(a+49956|0);Aq(a+58148|0);Aq(a+66340|0);Aq(a+74532|0);Qb(a+228|0,0,32768);pB(a+32996|0);Qb(a+33508|0,0,16384)}function tX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function eF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;u[(v[a+1068>>2]<<1)+d>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=fd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function P_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;Jp(a);v[a>>2]=28048;f=dc(a);b=gm(e+16|0,b);c=v[c>>2];d=v[d>>2];g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;Ip(f);v[f>>2]=28184;b=e+8|0;gm(f+4|0,b);v[f+16>>2]=d;v[f+12>>2]=c;Kd(b);gb=e+32|0;return a|0}function Km(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Ij(f)){break a}e=w[f+34|0];if(e-251>>>0<5|!e){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}kb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function vu(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22708]=0;R(279,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){km(v[a+16>>2],v[a>>2],Mp(a))}}function ss(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22708]=0;R(181,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){km(v[a+16>>2],v[a>>2],Mp(a))}}function PQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-28|0;v[b+8>>2]=d;v[22708]=0;R(955,c|0,d|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){sB(v[a+16>>2],v[a>>2],JY(a))}}function HV(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[22708]=0;v[b+4>>2]=127;a=pd(b+12|0,b+4|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;a=If(b+8|0,a);c=v[22708];v[22708]=0;if((c|0)==1){break a}gb=b+16|0;return t[a|0]}V(0)|0;O()|0;Bb();L()}function zna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;zC(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){AC(b)}return a|0}function xf(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;b=gb-16|0;gb=b;d=2;e=v[a>>2];if(e>>>0>=2){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Fb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Fb(b+12|0,b+8|0)>>2]}gb=b+16|0;gb=c+16|0;return d|0}function gR(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-12|0;v[b+8>>2]=c;v[22708]=0;R(1131,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){km(v[a+16>>2],b,Mp(a))}}function bB(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-32|0;v[b+8>>2]=c;v[22708]=0;R(1101,e|0,c|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Xk(v[a+16>>2],b,zB(a))}}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;MR(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){VA(b)}return a|0}function $R(a,b){var c=0,d=0,e=0,f=0,g=0;dv(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;cB(e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}wc(a,f);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];dB(a,Ae(a))}function uE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;jE(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){iE(b)}return a|0}function bw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;PD(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){OD(b)}return a|0}function _u(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;PU(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){QU(b)}return a|0}function _8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;no(c,a);a=b;if(v[a>>2]){Od(a);Dy(v[a>>2],gv(a));d=wb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=wb(c);d=wb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Yf(c);gb=c+16|0}function N8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Nc(52,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22708]=0;Q(2119,e|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){b=a;a=Kp(d);TJ(b,dc(a),a);SJ(d);gb=c+16|0;break a}a=P()|0;O()|0;SJ(d);S(a|0);L()}}function M8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Nc(56,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22708]=0;Q(2120,e|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){b=a;a=Kp(d);TJ(b,dc(a),a);OJ(d);gb=c+16|0;break a}a=P()|0;O()|0;OJ(d);S(a|0);L()}}function DU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;wb(b);d=vh(a);a:{c=oc(b);if(c){v[22708]=0;R(488,a|0,c|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}d=v[b>>2];e=v[b+4>>2];b=gb-16|0;gb=b;c=Bi(b,a,c);wb(a);jv(d,e,c+4|0);$b(c);gb=b+16|0}return a|0}a=P()|0;O()|0;im(d);S(a|0);L()}function ei(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[22708]=0;v[b+4>>2]=255;a=pd(b+12|0,b+4|0);c=v[22708];v[22708]=0;a:{if((c|0)==1){break a}v[22708]=0;a=If(b+8|0,a);c=v[22708];v[22708]=0;if((c|0)==1){break a}gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function ee(a){var b=0,c=0,d=0,e=0;o(+a);b=j(1)|0;j(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){d=a+c+-1;break a}a=a+c;d=a;if(!(c<=-.5)){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function ay(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}kb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;kb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(!Md(b)){break a}if(v[b+20>>2]==(zb(v[a+20>>2])|0)){v[a+20>>2]=0}qc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Zm(a)){break a}hc(zb(v[a+20>>2]),v[b+20>>2],aj(a));d=1}return d|0}function jz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!Tf(a)){break a}while(1){if(!ii(af(a,e))){break a}d=d+1|0;e=d&65535;if(Tf(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=wh(a,d&65535,b)?d:-1}return c&65535}function R_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-32|0;gb=e;v[e+24>>2]=d;v[e+28>>2]=c;v[22708]=0;Y(222,e+8|0,b|0,e+28|0,e+24|0);c=v[22708];v[22708]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;Fw(c,d);Xf(a,c);Kd(c);Kd(d);Kd(b);gb=e+32|0;return}a=P()|0;O()|0;Kd(b);S(a|0);L()}function OT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-16|0;gb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Jb(d);Oj(b,a,Ab(d)+a|0);break c}ET(e,c,d);v[22708]=0;U(57,a|0,b|0,e|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(e)}gb=e+16|0;break a}a=P()|0;O()|0;Ic(e);S(a|0);L()}}function ica(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;tM(a,b,c,d,e^1);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=52052;return a|0}function dF(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=fd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function ah(a,b){var c=0,d=0,e=0,f=0;c=Ab(a);a:{if((c|0)!=(Ab(b)|0)){break a}d=Jb(a);b=Jb(b);b:{if(!Ee(a)){if(c){break b}return 1}return!Uo(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function Sp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(e*.16666666666666632+(d*(b*.5-e*f)-b))}function qm(a){var b=0,c=0,d=0,e=0;_p(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=wb(d);v[22708]=0;b=b-12|0;R(181,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[d+4>>2]=e;km(wb(a),v[a>>2],ug(a))}}function pma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,274);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,274)}}function lma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,106);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,106)}}function iqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,136);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,136)}}function i4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+4|0;d=d+4|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=Fu(a+8|0,d);v[22708]=0;Q(1652,a+20|0,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Lt(a){var b=0,c=C(0),d=0;if(w[a+4232|0]>=5){t[a+4232|0]=0}if(t[a+4233|0]<=-1){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<=-1){t[a+4234|0]=127;b=127}d=a;a:{if((yM(a)|0)==3){c=C(C(1)-oe(C(2),C(-C((b&255)+1|0))));break a}c=oe(C(2),C(-C((b&255)>>>0)))}z[d+4224>>2]=c}function wK(a){var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;b=a+120|0;Ci(b);c=gb-16|0;gb=c;v[c+8>>2]=d+8;a=gb-16|0;gb=a;e=v[13838];v[a+8>>2]=v[13837];v[a+12>>2]=e;e=v[13836];v[a>>2]=v[13835];v[a+4>>2]=e;b=kb[v[Sh(a,Yg(b))>>2]](c+8|0,b)|0;gb=a+16|0;gb=c+16|0;gb=d+16|0;return b}function iW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,284);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,284)}}function YS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=zd(b);f=ef(b);e=zd(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=d;v[c+8>>2]=e;if(Gb(c+24|0,c+16|0)){while(1){d=c+24|0;f=Zq(t[v[d>>2]]);e=c+8|0;t[v[e>>2]]=f;Pe(d);Pe(e);if(Gb(d,c+16|0)){continue}break}}gb=c+32|0;Dc(a,b)}function MF(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Fc(d,a);v[22708]=0;a=T(21,d|0)|0;d=v[22708];v[22708]=0;a:{if((d|0)==1){break a}v[22708]=0;a=Q(22,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}Wb(c+8|0);gb=c+16|0;return a}a=P()|0;O()|0;Wb(c+8|0);S(a|0);L()}function kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,42);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,42)}}function kma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,72);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,72)}}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,34);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,34)}}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=vh(a);a:{d=rf(b);if(d){v[22708]=0;R(1115,a|0,d|0);e=v[22708];v[22708]=0;if((e|0)==1){break a}c=gb-16|0;gb=c;e=v[b>>2];f=v[b+4>>2];b=fs(c,a,d);jv(e,f,b+4|0);$b(b);gb=c+16|0}return a|0}a=P()|0;O()|0;Nf(c);S(a|0);L()}function zD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,50);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,50)}}function hl(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function VZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,59);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,59)}}function RN(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){_i(c);fT(c);$i(c);_i(c);sB(wb(c),v[c>>2],$i(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}kp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function LK(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function HQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function DR(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[e+16>>2]=b;b=LT(c-+(b<<2));v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=b;v[a+12>>2]=jb}function yh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function xka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){t[c+16|0]=0;a=4;while(1){t[b|0]=w[c+16|0];b=b+1|0;a=a-1|0;if(a){continue}break}break a}lC(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function pF(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(e);v[22708]=0;b=b-12|0;R(279,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[e+4>>2]=d;km(wb(a),v[a>>2],ug(a))}}function _pa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,64)){a=gb-16|0;gb=a;d=b- -64|0;while(1){Jf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}rD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function NM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){d=b;if(b>>>0>2097151){rd(8445);L()}f=Nc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<11)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function rl(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=qt(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function IQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=xh(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function GQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=zb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f|0}function Rs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=ba(16)|0;uH();a=td(c+8|0,a,90816);v[22708]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2436,d|0,c|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(d|0,79216,2437);L()}a=P()|0;O()|0;da(d|0);S(a|0);L()}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-32|0;gb=e;f=fg(a,c);d=e+8|0;te(d,v[a+28>>2]);g=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=g;a:{b:{if(!f){d=-1;if(!nd(a,5)){break b}break a}d=v[f+8>>2]}CO(v[a+28>>2],b,d)}Zf(a,f,c,e+24|0);gb=e+32|0}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,27)){a=gb-16|0;gb=a;d=b+27|0;while(1){Jf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}MR(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function iV(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,32)){a=gb-16|0;gb=a;d=b+32|0;while(1){Jf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}eV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function fC(a){var b=0,c=0,d=0;if(v[a>>2]){c=a;b=v[a+4>>2];d=v[a>>2];if((b|0)!=(d|0)){while(1){b=b-24|0;xb(b);if((b|0)!=(d|0)){continue}break}}v[c+4>>2]=d;c=v[a>>2];a=gv(a);v[22708]=0;Oc(c,B(a,24),4);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Tha(a){a=a|0;var b=0,c=0,d=0;c=gb-32|0;gb=c;b=255;a:{if(Qi(a)>>>0<=49){b=fB(c,v[a+12>>2]);v[22708]=0;R(1089,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)==1){break a}Xm(b);Ri(a,Qi(a)-1&255);b=Qi(a)-1|0}gb=c+32|0;return b&255}a=P()|0;O()|0;Xm(b);S(a|0);L()}function TT(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=90840;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function P$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Sg(a,v[b+8>>2],0)){ex(b,c,d);return}e=v[a+12>>2];f=a+16|0;tG(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){tG(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function Fv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-48;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){hY(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/48|0)}}function zY(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;Gv(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){jD(b)}return a}function mU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;HX(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){IX(b)}return a}function jW(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;dW(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){cW(b)}return a}function hna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;RV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Ok(b)}}function hD(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;aY(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){bY(b)}return a}function dk(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;Gp(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){hm(b)}return a}function dG(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;QF(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Lw(b)}return a}function bO(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=c;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=f;v[a+8>>2]=e;v[a+12>>2]=d;v[a>>2]=b;v[a+4>>2]=f;d=!PS(a+8|0,a)}gb=c+32|0;return d}function _5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=bq(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);yi(d+(e<<2)|0,b,c);b=c+e|0;jh(a,b);v[f+12>>2]=0;Ge(d+(b<<2)|0,f+12|0);break a}mI(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function YC(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;HX(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){IX(b)}return a}function Xma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,2)){a=gb-16|0;gb=a;d=b+2|0;while(1){Jf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}RV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function TU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;PU(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){QU(b)}return a}function Oka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;$m(a,b);e=c,f=Vb(a),v[e+8>>2]=f;e=c,f=Zb(a),v[e>>2]=f;if(Gb(c+8|0,c)){b=0;while(1){a=c+8|0;d=v[a>>2];b=zb(w[d|0])+(b&255)|0;e=d,f=zb(b&255),t[e|0]=f;Pe(a);if(Gb(a,c)){continue}break}}gb=c+16|0}function CV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;qV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(e|0)){bd(a,yb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){rV(b)}return a}function pv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-6;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){HC(v[a+16>>2],v[a>>2],(v[dc(a)>>2]-v[a>>2]|0)/6|0)}}function kd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b>>2];g=v[b+8>>2];f=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=f;h=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=f;kb[h|0](a,e,g,d);i=b,j=yb(a)+v[b+8>>2]|0,v[i+8>>2]=j;gb=d+16|0}function cv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;eV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){UB(b)}}function yt(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=12;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){e=yo(a);v[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}}gb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function Zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,1100);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function Rt(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-2048;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){KM(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]>>11)}}function Qq(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=Nl(a,b);if((e|0)==255){break a}if(wk(a)){break a}b=XA(a+314|0,e);e=RR(e);if(f=1,g=t[lc(b,10)|0]&1,h=d,h?f:g){Yh(v[a>>2],e- -64&65535,QR(c,w[lc(b,2)|0]))}if(d){break a}Yh(v[a>>2],e+67&65535,QR(c,w[lc(b,3)|0]))}}function Oz(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=lw(f,c);d=e+8|0;g=a+1074312|0;Db(d,g,31);a=0;if(!Cb(d)){Db(e,g,93);a=Cb(e)^1}if(!(t[jO(b,c)+6|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=cd(f)^1}gb=e+16|0;return d}function Nu(a){var b=0,c=0;a:{if(w[a+4|0]|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1414687062){break a}b=a+6|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function DG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83728;b=v[a+8>>2];v[22708]=0;c=ga(2477)|0;d=v[22708];v[22708]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[22708]=0;Cx(b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Bb();L()}return a|0}function YM(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;c=d+16|0;e=a;a=d+28|0;bo(c,e,d+24|0,v[Fb(a,d+12|0)>>2]);yb(c);v[d+16>>2]=4;Fb(a,c);v[d+16>>2]=v[d+24>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);gb=d+32|0}function X2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(2481,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);XG(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function W2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(2481,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);WG(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function VD(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}jb=a;return b}function MI(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=MI(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function AK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;u[c+10>>1]=0;u[c+8>>1]=65535;a:{if(Et(c+12|0,c+10|0,c+8|0)){a=a+24|0;d=0;if(!me(v[a>>2]+484344|0,b&65535)){break a}d=v[_b(v[a>>2]+484344|0,b)+12>>2];break a}d=0}a=d;gb=c+16|0;return a|0}function yka(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=vd(b+8|0,b+24|0,6);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);a:{if((yb(c)|0)!=6){break a}if(sd(b+24|0,1024,6)){break a}Rb(a,6);e=1}gb=b+32|0;return e|0}function soa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;e=d+8|0;SE(e,a);IW(c+24|0,e);gb=d+16|0;Dg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-2496|0;gb=c;XU(b,c,c+2496|0);b=hc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<=-1){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}gb=c+2496|0;return a|0}function Koa(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;t[b+30|0]=0;u[b+28>>1]=0;c=vd(b+8|0,b+28|0,3);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);a:{if((yb(c)|0)!=3){break a}if(sd(b+28|0,11944,3)){break a}Rb(a,3);e=1}gb=b+32|0;return e|0}function wE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;bc(e,b,37);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,37)}}function nma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(814,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(815,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;cs(d);S(a|0);L()}return a|0}function jx(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[22708]=0;c=ga(2477)|0;d=v[22708];v[22708]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[22708]=0;Cx(b);b=v[22708];v[22708]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Bb();L()}return a|0}function c3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(21,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);_G(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function b3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Fc(g,d);v[22708]=0;b=T(21,g|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(g);ZG(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Wb(g);S(a|0);L()}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,16);a:{if(!d){a=b+16|0;while(1){t[b|0]=0;b=b+1|0;if((a|0)!=(b|0)){continue}break}break a}fw(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function yP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075080>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,872)+a|0)+1075778>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function xW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,33)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){AC(a);a=v[c>>2]+33|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function vT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<8)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){yB(a);a=v[c>>2]+256|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function u5(a){a=a|0;var b=0,c=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<c>>>0){Wn(a,v[a+8>>2],v[a+12>>2],c)}b=v[a+16>>2];a=v[a+12>>2];if(b>>>0<=a>>>0){break a}return Lg(t[a|0])|0}return-1}function oX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(617,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(618,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;uv(d);S(a|0);L()}return a|0}function WZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(333,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(334,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;qv(d);S(a|0);L()}return a|0}function QD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(389,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(390,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;im(d);S(a|0);L()}return a|0}function Kv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Hg(a);a:{if(!b){break a}v[22708]=0;R(488,a|0,b|0);e=v[22708];v[22708]=0;if((e|0)!=1){v[22708]=0;U(489,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;im(d);S(a|0);L()}return a|0}function Az(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;c=uf(a);e=b,f=Vb(a),v[e+8>>2]=f;e=b,f=Zb(a),v[e>>2]=f;if(Gb(b+8|0,b)){d=+(c>>>0);while(1){c=b+8|0;a=v[c>>2];A[a>>3]=A[a>>3]/d;A[a+8>>3]=A[a+8>>3]/d;Yo(c);if(Gb(c,b)){continue}break}}gb=b+16|0}function xI(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){kb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function dn(a){var b=0,c=0,d=0,e=0;dv(a);if(v[a>>2]){c=a;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}wb(c);v[22708]=0;b=b-32|0;e=v[22708];v[22708]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[c+4>>2]=d;nV(wb(a),v[a>>2],bi(a))}}function ag(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;u[c+30>>1]=0;d=c+30|0;v[c+8>>2]=d;v[c+12>>2]=d+2;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;nt(d,a,c);a=yb(d);u[c+16>>1]=x[c+30>>1];u[b>>1]=w[d|0]|w[d+1|0]<<8;gb=c+32|0;return(a|0)==2|0}function ae(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-1;v[22708]=0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){$k(v[a+16>>2],v[a>>2],v[dc(a)>>2]-v[a>>2]|0)}}function _la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;oC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function Oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;EY(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function qW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;PX(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function mT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Oj(b,a,Ab(c)+a|0);break c}hT(d,c);v[22708]=0;U(57,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(d)}gb=d+16|0;break a}a=P()|0;O()|0;Ic(d);S(a|0);L()}}function kj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Gp(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function SW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,48)+e;if(v[c>>2]!=v[c+4>>2]){while(1){RW(v[c>>2]);a=v[c>>2]+48|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}_c(c);gb=d+16|0}function Iw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<3)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){hm(a);a=v[c>>2]+8|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}_c(c);gb=d+16|0}function aC(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[lc(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function Sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;e=ct(a);v[a>>2]=77316;f=Kb(a+32|0);v[a+48>>2]=c;v[a+44>>2]=0;v[22708]=0;R(108,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){gb=d+16|0;return a|0}a=P()|0;O()|0;vb(f);wm(e);S(a|0);L()}function GY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=Dn(d+8|0,a+8|0,sD(b,c));c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){b=d+24|0;Gr(c,v[b>>2]);v[a>>2]=v[a>>2]+2;Pv(b);c=v[a>>2];if((c|0)!=v[a+4>>2]){continue}break}}_c(a);gb=d+32|0}function ED(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(a,512)){a=gb-16|0;gb=a;d=b+512|0;while(1){$j(b);b=b+4|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0;break a}Rv(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0}function wT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Oj(b,a,Ab(c)+a|0);break c}ET(d,b,c);v[22708]=0;R(58,a|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}Ic(d)}gb=d+16|0;break a}a=P()|0;O()|0;Ic(d);S(a|0);L()}}function foa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=fg(a,c);te(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}jX(v[a+28>>2],b,v[e+24>>2],0)}Zf(a,d,c,e+16|0);gb=e+32|0}function mna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=d+12|0;qc(c,256);qc(c,65535);e=x[d+12>>1];Bf(a,e);if(e){c=0;while(1){f=w[b+c|0];g=fj(a,c),h=f,u[g>>1]=h;c=c+1|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0}function iX(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=zb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+18848|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Ft(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[22708]=0;T(1291,c|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){yd(a+68|0);Yf(a+36|0);iq(a+32|0);Ei(b);Di(a+4|0);eg(a);return a}V(0)|0;O()|0;yd(a+68|0);Yf(a+36|0);iq(a+32|0);Ei(b);Di(a+4|0);eg(a);Bb();L()}function Bp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Kc(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Qg(d+e|0,b,c);b=c+e|0;jh(a,b);t[f+15|0]=0;Bd(b+d|0,f+15|0);break a}vp(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=fg(a,c);te(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(nd(a,5)){break a}}gN(v[a+28>>2],b,v[e+24>>2])}Zf(a,d,c,e+16|0);gb=e+32|0}function Hk(a,b){var c=0,d=0;c=gb-32|0;gb=c;v[c+28>>2]=0;dX(c+8|0,c+28|0);d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;nt(d,a,c);a=yb(d);v[c+16>>2]=v[c+28>>2];v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);gb=c+32|0;return(a|0)==4}function HP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a=Uc(Om(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=uk(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Uc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function wV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=c+24|0;qV(e,b);e=yb(e);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(e|0)){Rb(a,yb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){rV(b)}}function oO(a,b){var c=0,d=0,e=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}d=b;c=v[c>>2];b:{if(c){e=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[e+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[d>>2]=a}}function V2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22708]=0;b=T(2481,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(a);VG(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function MC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=mc(a+8|0);v[22708]=0;d=T(467,b|0)|0;e=v[22708];v[22708]=0;b:{if((e|0)==1){break b}v[22708]=0;U(393,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;gc(c);S(a|0);L()}}function J4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}b=b+4|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Kk(b,4,c,v[a+32>>2])|0}function ZA(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(w[a+530|0]){while(1){d=c&65535;Pi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;oi(a+4|0,18,b+15|0);lv(a+22|0,18,35498);t[b+14|0]=255;oi(a+58|0,256,b+14|0);gb=b+16|0}function Iu(a){a=a|0;var b=0,c=0,d=0,e=0;c=TS(a);if((c|0)!=(a|0)){while(1){b=0;e=a;hX(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Qb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function Fpa(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!hD(a,b+16|0)){break a}c=0;if(!dY(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!bd(a,4)){break a}}c=-1;if(!dk(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}gb=b+32|0;return c|0}function i7(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=a;if(!w[c+8|0]){d=c+12|0;Nk(d,v[c+4>>2]);Vd(b+24|0,d);d=v[v[c>>2]+40>>2];e=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=e;kb[d|0](b+16|0,c,0,b+8|0);t[c+8|0]=1}gb=b+32|0;return v[a+12>>2]}function a3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Fc(a,d);v[22708]=0;b=T(21,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){Wb(a);YG(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Wb(a);S(b|0);L()}function Rp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function AF(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function xL(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;v[b>>2]=0;t[c+15|0]=0;Vh(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;d=d&3;if(d){while(1){t[c+15|0]=0;Vh(a,c+15|0);e=e+1|0;v[b>>2]=v[b>>2]|w[c+15|0]<<(e<<3)-2;if((d|0)!=(e|0)){continue}break}}gb=c+16|0}function t3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=wi(e,e+12|0);v[22708]=0;a=W(2498,a|0,c|0,v[e+8>>2])|0;c=v[22708];v[22708]=0;if((c|0)!=1){ff(b);gb=e+16|0;return a|0}a=P()|0;O()|0;ff(b);S(a|0);L()}function _M(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){Ze(a,c);d=a;break a}f=Wk(d)+1|0;d=pi(a,f);cf(a,d);rg(a,f);de(a,c)}Qg(d,b,c);t[e+15|0]=0;Bd(c+d|0,e+15|0);gb=e+16|0;return}bg();L()}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>=1){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){wO(e,v[d+4>>2],v[d+8>>2])}hc(f+16|0,d+16|0,144);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function ye(){var a=0,b=0;a:{b:{if(t[464228]&1){break b}if(!Qd(464228)){break b}v[22708]=0;a=W(2479,2147483647,11503,0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}v[116056]=a;Pd(464228)}return v[116056]}a=P()|0;O()|0;_e(464228);S(a|0);L()}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(517,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(518,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;im(c);S(a|0);L()}return a|0}function Tu(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if(b>>>0>=357913942){rd(8445);L()}f=Nc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Tma(a,b){a=a|0;b=b|0;var c=0,d=0;c=vh(a);a:{if(!b){break a}v[22708]=0;R(775,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(776,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;fC(c);S(a|0);L()}return a|0}function OP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Mc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=DP(c&255),v[e+44>>2]=f}gb=d+16|0}function LY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if(b>>>0>=153391690){rd(8445);L()}f=Nc(B(d,28),4)}v[a>>2]=f;c=B(c,28)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,28)+f|0,v[g>>2]=h;gb=e+16|0;return a}function qX(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(488,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(606,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;im(c);S(a|0);L()}return a|0}function QZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(335,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(336,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;oE(c);S(a|0);L()}return a|0}function NF(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){d=b;if(b>>>0>119304647){rd(8445);L()}f=Nc(B(d,36),4)}v[a>>2]=f;c=B(c,36)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,36)+f|0,v[g>>2]=h;gb=e+16|0;return a}function nW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,18);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=gb-32|0;gb=e;c=b+4|0;b=v[c+48>>2];a:{if(b&16){b=v[c+44>>2];d=v[c+24>>2];if(b>>>0<d>>>0){v[c+44>>2]=d;b=d}Oj(a,v[c+20>>2],b);break a}if(b&8){Oj(a,v[c+8>>2],v[c+16>>2]);break a}Kb(a)}gb=e+32|0}function jY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){d=b;if(b>>>0>89478485){rd(8445);L()}f=Nc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,48)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Vt(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;a:{e=!b|!c;if(!e){b=Tb(d,b);v[22708]=0;U(1477,d+16|0,b|0,c|0);c=v[22708];v[22708]=0;if((c|0)==1){break a}c=a+36|0;a=d+16|0;Eb(c,a);vb(a);vb(b)}gb=d+32|0;return!e}a=P()|0;O()|0;vb(b);S(a|0);L()}function UX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=yy(d+8|0,a+8|0,VX(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){b=d+24|0;lp(v[a>>2],v[b>>2]);v[a>>2]=v[a>>2]+1;Pe(b);if(v[a>>2]!=v[a+4>>2]){continue}break}}_c(a);gb=d+32|0}function Re(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a+8|0);v[22708]=0;U(393,a|0,b|0,c|0);c=v[22708];v[22708]=0;a:{if((c|0)!=1){a=v[a>>2];v[22708]=0;Q(318,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;gc(d);S(a|0);L()}}function KQ(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function BF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,20);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=-1;a:{if(!dG(a,c+8|0)){break a}d=0;if(!LN(c+8|0)){break a}if(b){a=c+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}d=1}gb=c+32|0;return d|0}function VQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if(b>>>0>=613566757){rd(8445);L()}f=Nc(B(d,7),1)}v[a>>2]=f;c=B(c,7)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,7)+f|0,v[g>>2]=h;gb=e+16|0;return a}function O7(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=v[v[b>>2]+(a<<2)>>2]+(c<<3)|0;v[d>>2]=0;v[d+4>>2]=0;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function JE(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;bc(d,b,1);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function CI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function KG(a){var b=0,c=0,d=0;d=gb-16|0;gb=d;b=d;v[b>>2]=465840;c=v[116461];v[b+4>>2]=c;v[b+8>>2]=c+(a<<2);c=b;a=v[b+4>>2];b=v[b+8>>2];if((a|0)!=(b|0)){while(1){Xo(a);a=a+4|0;v[c+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(c);gb=d+16|0}function pV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;oV(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function nY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Gv(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function jF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;ds(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function is(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Ai(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function fY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;fw(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function bW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;aW(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function a$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[b+8>>2];if(f>>>0>c>>>0){v[e+12>>2]=f-c;h=e,i=yb(d),v[h+8>>2]=i;f=Fb(e+12|0,e+8|0);b=v[b+4>>2]+c|0;g=v[f>>2];Rg(b,b+g|0,v[d>>2])}nk(a,d,g);gb=e+16|0}function _X(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;rD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Xv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Wv(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Sv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;sn(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function SV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;lC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function PF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;QF(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function ND(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;MD(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Mg(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Wr(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Dp(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;An(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function DT(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;lC(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;hd(d,a,c);d=yb(d);if((d|0)==(b|0)){bd(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function $X(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;aY(d,b);b=yb(d);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=c+16|0;cc(d,a,c);d=yb(d);if((d|0)==(b|0)){Rb(a,yb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=0;a:{if(!Nb(a)){break a}while(1){gg(d,v[Lb(a,e)>>2]+40|0);c=wr(d,b);vb(d);if(c){c=v[Lb(a,e)>>2];break a}e=e+1|0;if(Nb(a)>>>0>e>>>0){continue}break}c=0}gb=d+16|0;return c|0}function Vh(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;t[c+24|0]=0;d=c+24|0;v[c+8>>2]=d;v[c+12>>2]=d+1;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=c+16|0;nt(d,a,c);a=yb(d);t[c+16|0]=w[c+24|0];t[b|0]=w[d|0];gb=c+32|0;return(a|0)==1|0}function Oq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=131072/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-ee(f*A[ze(a,c)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=yf(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function Gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;iY(a);wb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Yj(a);ln(a);ln(a)}function hO(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ac(pqa(oqa(d,d>>31,g,h),jb,256,0),jb);v[a+4>>2]=f-d;v[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function dka(a,b){a=a|0;b=b|0;var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(333,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;aT(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;qv(c);S(a|0);L()}return a|0}function cna(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22708]=0;R(296,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}
function Wma(a,b){a=a|0;b=b|0;var c=0,d=0;c=vh(a);a:{if(!b){break a}v[22708]=0;R(773,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;mr(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ci(c);S(a|0);L()}return a|0}function II(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-16;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Xn(v[a+16>>2],b,Px(a))}}function wpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22708]=0;R(396,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}function Tg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function PA(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-8;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){OA(v[a+16>>2],b,wF(a))}}function fW(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Og(a)>>>0<b>>>0){d=wb(a);b=En(c+8|0,b,tc(a),d);v[22708]=0;R(313,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}Ih(b)}gb=c+32|0;return}a=P()|0;O()|0;Ih(b);S(a|0);L()}function TE(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=v[a+4>>2];d=e+b|0;v[a+4>>2]=d;a:{b:{if(!e){g=d-1|0;break b}g=d-1|0;if((g^e-1)>>>0<32){break a}}v[v[a>>2]+((d>>>0<33?0:g>>>5|0)<<2)>>2]=0}d=f+8|0;yp(d,a,e);xp(d,b,c);gb=f+16|0}function Id(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){u[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function ig(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[yf(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function en(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){f=Ti(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function $G(){var a=0,b=0,c=0;b=gb-16|0;gb=b;a=Tb(b,12129);a:{if(!Ab(a)){break a}c=1;if((vg(a,11840)|0)!=-1){break a}if((vg(a,13867)|0)!=-1){break a}if((vg(a,11032)|0)!=-1){break a}c=(vg(a,11075)|0)!=-1}vb(a);gb=b+16|0;return c|0}function xD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){d=b;if((b|0)<=-1){rd(8445);L()}f=Nc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function YB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);h=b,i=yb(a)+v[b+12>>2]|0,v[h+12>>2]=i;gb=d+16|0}function Wc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Of(b);e=gb-16|0;gb=e;c=Kc(a);a:{if(c>>>0>=d>>>0){c=Jb(a);cm(c,b,d);t[e+15|0]=0;Bd(d+c|0,e+15|0);jh(a,d);break a}f=c;g=d-c|0;c=Ab(a);vp(a,f,g,c,0,c,d,b)}gb=e+16|0;return a|0}function Qd(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;a=hx(c,a);d=gb-16|0;gb=d;if(!w[v[yc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}gb=d+16|0;gb=c+16|0;return b}function IR(a,b){var c=0,d=0;c=Hg(a);a:{if(!b){break a}v[22708]=0;R(1117,a|0,b|0);d=v[22708];v[22708]=0;if((d|0)!=1){v[22708]=0;R(1118,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;AR(c);S(a|0);L()}return a}function BU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=VU(c+8|0,c);gb=c+32|0;return a}function ws(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;if(b){e=Kc(a);d=Ab(a);g=d+b|0;if(e-d>>>0<b>>>0){Wm(a,e,g-e|0,d,d,0,0)}e=d;d=Jb(a);Ir(e+d|0,b,c);jh(a,g);t[f+15|0]=0;Bd(d+g|0,f+15|0)}gb=f+16|0;return a|0}function uA(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[a+104>>2];if(d){v[a+88>>2]=v[a+88>>2]&-131|128;d=v[d>>2];v[a+76>>2]=d;v[c+12>>2]=b<<8;v[c+8>>2]=d-1;b=d+(v[Fb(c+12|0,c+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}gb=c+16|0}function kO(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){while(1){d=yo(a);v[b+12>>2]=7;v[b+8>>2]=32;c=c+15|0;if(c>>>0<y[Fb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}gb=b+16|0;return c}function Vpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c+24|0;Gp(d,b);d=yb(d);b=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=b;v[c>>2]=e;v[c+4>>2]=b;b=c+16|0;cc(b,a,c);if((yb(b)|0)==(d|0)){Rb(a,yb(c+24|0))}gb=c+32|0}function IK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function HK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(ug(a)>>>0<b>>>0){d=wb(a);b=ts(c+8|0,b,Ec(a),d);v[22708]=0;Mn(a,b);a=v[22708];v[22708]=0;if((a|0)==1){break a}vu(b)}gb=c+32|0;return}a=P()|0;O()|0;vu(b);S(a|0);L()}function nD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=0;a:{if(!a){break a}e=a|-16;if(b>>>0>1?a>>>0<16&c:1){break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[pf(d+15|0,d+14|0)|0]}a=e;gb=d+16|0;return a&255}function n4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=dt(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=Cd(c);v[f>>2]=a;if(!a){break a}e=dt(a,c,b,v[d+12>>2])}gb=d+16|0;return e|0}function eu(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=49516;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=49532;break a;case 2:c=49528;break a;case 1:break b;case 0:break c}}c=49524;break a}c=49520}v[a>>2]=v[c>>2]}function dY(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function IN(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=Vb(a),v[e+8>>2]=f;c=d+24|0;b=b+B(Wt(c,d+8|0),6)|0;if(Gb(c,d+16|0)){PC(a,oz(b+B(Wt(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}Gg(b);gb=d+32|0}function Qfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[a+480180>>2]=b;jA(c,zq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;eu(a+8|0,zq(a));gb=c+16|0}function KK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function JK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function EO(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function vma(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;u[b+30>>1]=0;c=vd(b+8|0,b+30|0,2);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;c=b+16|0;cc(c,a,b);if(!((yb(c)|0)!=2|x[b+30>>1]!=21584)){Rb(a,2);e=1}gb=b+32|0;return e|0}function dP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;b=fs(d,a,b);a=v[b+4>>2];e=v[b+8>>2];if((a|0)!=(e|0)){while(1){f=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=f;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(e|0)){continue}break}}$b(b);gb=d+16|0}function NU(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){OY(c);vD(v[c>>2],$i(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);d=wb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function ys(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){Ze(a,c);e=a;break a}f=Wk(c)+1|0;e=pi(a,f);cf(a,e);rg(a,f);de(a,c)}Qg(e,b,c);t[d+15|0]=0;Bd(c+e|0,d+15|0);gb=d+16|0;return}bg();L()}function qt(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!fy(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Ne(a)}return b}aa(12800,10528,1578,2521);L()}function nU(a,b,c){var d=0;d=gb-16|0;gb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|b>>>0>=c>>>0|b>>>0>=109|c>>>0>=109)){t[d+14|0]=(x[(b<<1)+39070>>1]-x[(c<<1)+39070>>1]|0)/5;a=w[ac(d+15|0,d+14|0)|0]}gb=d+16|0;return a&255}function mu(a,b){var c=0,d=0;c=B(b,872)+a|0;a:{if(v[c+1075080>>2]&134218752){break a}if(!tk(c+1074992|0)){break a}b=w[v[(B(b,872)+a|0)+1075648>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function cT(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function Zg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){f=pi(v[a+16>>2],b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=b+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function Mt(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(dg(a)>>>0<b>>>0){d=wb(a);b=Zg(c+8|0,b,oc(a),d);v[22708]=0;R(120,a|0,b|0);a=v[22708];v[22708]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}function Mca(a){a=a|0;var b=0;kb[v[v[a>>2]+128>>2]](a);Zy(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=kb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function AA(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=v[a+480208>>2];d=c,e=(Tp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;UP(c+8|0,127);a=fn(A[c+8>>3]);gb=c+16|0;return a|0}function mW(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function So(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=d+8|0;Db(e,c+1074312|0,102);a:{if(!Cb(e)){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;gb=d+16|0}function QV(a){var b=0,c=0;a:{if(sd(a,12213,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function JG(){var a=0;a:{b:{if(t[464240]&1){break b}if(!Qd(464240)){break b}v[22708]=0;X(2563);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116059]=464232;Pd(464240)}return v[116059]}a=P()|0;O()|0;_e(464240);S(a|0);L()}function G1(){var a=0;a:{b:{if(t[464252]&1){break b}if(!Qd(464252)){break b}v[22708]=0;X(2564);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116062]=464244;Pd(464252)}return v[116062]}a=P()|0;O()|0;_e(464252);S(a|0);L()}function z0(a){a=a|0;a:{b:{if(t[464352]&1){break b}if(!Qd(464352)){break b}v[22708]=0;X(2588);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116087]=465456;Pd(464352)}return v[116087]}a=P()|0;O()|0;_e(464352);S(a|0);L()}function v0(a){a=a|0;a:{b:{if(t[464360]&1){break b}if(!Qd(464360)){break b}v[22708]=0;X(2590);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116089]=465488;Pd(464360)}return v[116089]}a=P()|0;O()|0;_e(464360);S(a|0);L()}function rU(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function TR(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function L0(a){a=a|0;a:{b:{if(t[464320]&1){break b}if(!Qd(464320)){break b}v[22708]=0;X(2580);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116079]=464496;Pd(464320)}return v[116079]}a=P()|0;O()|0;_e(464320);S(a|0);L()}function I0(a){a=a|0;a:{b:{if(t[464328]&1){break b}if(!Qd(464328)){break b}v[22708]=0;X(2582);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116081]=464672;Pd(464328)}return v[116081]}a=P()|0;O()|0;_e(464328);S(a|0);L()}function F0(a){a=a|0;a:{b:{if(t[464336]&1){break b}if(!Qd(464336)){break b}v[22708]=0;X(2584);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116083]=464848;Pd(464336)}return v[116083]}a=P()|0;O()|0;_e(464336);S(a|0);L()}function C0(a){a=a|0;a:{b:{if(t[464344]&1){break b}if(!Qd(464344)){break b}v[22708]=0;X(2586);a=v[22708];v[22708]=0;if((a|0)==1){break a}v[116085]=465152;Pd(464344)}return v[116085]}a=P()|0;O()|0;_e(464344);S(a|0);L()}function xk(a){a=a|0;qc(a+16|0,v[a>>2]);qc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=dd(a);e=Ik(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[22708]=0;R(1122,a|0,1);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;rR(e);wR(d);S(a|0);L()}function oqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;jb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function fT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22708]=0;b=b-28|0;R(955,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function e6(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{if(yr(b,7535)){jI(c,14672,b);a=Jb(c);v[22708]=0;R(2293,44,a|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);S(a|0);L()}gb=c+16|0;return a|0}L()}function aA(a,b,c){var d=0;a:{if(x[a+480192>>1]){if(!we(b)|x[a+480192>>1]<c>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[wd(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function $F(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22708]=0;b=b-36|0;R(214,c|0,b|0);c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=Te(b);c=kT(d+8|0,c);v[22708]=0;Y(954,a|0,b|0,e-1&65535,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){De(c);gb=d+32|0;return}a=P()|0;O()|0;De(c);S(a|0);L()}function gy(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!pt(a)){break a}if(!(t[a+1375|0]&1)){continue}break}ec(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Uca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){v[d+8>>2]=0;v[d+4>>2]=1065353216;e=(a+b|0)+4232|0,f=ch(C(z[Af(d+12|0,d+8|0,d+4|0)>>2]*C(127))),t[e|0]=f;Lt(a)}gb=d+16|0}function LT(a){a=+a;a=a*4294967296;if(D(a)<0x8000000000000000){jb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0|0}jb=-2147483648;return 0}function DL(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=sf(12);b=v[b>>2];a=v[a>>2];v[22708]=0;a=CL(d,a,b);b=v[22708];v[22708]=0;if((b|0)!=1){a=v[Xi(c+8|0,a)>>2];gb=c+16|0;return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function _n(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Gb(d+16|0,d+24|0)){while(1){b=d+16|0;v[d+12>>2]=v[v[b>>2]>>2];_C(a,d+12|0);Qe(b);if(Gb(b,d+24|0)){continue}break}}gb=d+32|0}function RX(a){var b=0,c=0,d=0;b=v[a>>2];c=eD(a);d=gb-16|0;gb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=yn(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}gb=d+16|0;return v[b>>2]}function Pba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=12){Ii(d+12|0);c=z[d+12>>2];if((b|0)==12){c=C(fe(C(c*C(3)))/C(3));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}gb=d+16|0}function P7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=ir(b,a,c),e=0,v[d>>2]=e;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,12);a:{if(!d){t[c+16|0]=0;oi(b,12,c+16|0);break a}QW(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function qG(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Np(d,a,1);a=wb(a);e=v[c+4>>2];v[22708]=0;Nn(a,e,b);a=v[22708];v[22708]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function q0(a){a=a|0;a:{b:{if(t[464392]&1){break b}if(!Qd(464392)){break b}v[22708]=0;Q(2593,464380,83892)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464392)}return 464380}a=P()|0;O()|0;_e(464392);S(a|0);L()}function l0(a){a=a|0;a:{b:{if(t[464424]&1){break b}if(!Qd(464424)){break b}v[22708]=0;Q(2593,464412,83928)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464424)}return 464412}a=P()|0;O()|0;_e(464424);S(a|0);L()}function h0(a){a=a|0;a:{b:{if(t[464456]&1){break b}if(!Qd(464456)){break b}v[22708]=0;Q(2593,464444,83964)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464456)}return 464444}a=P()|0;O()|0;_e(464456);S(a|0);L()}function d0(a){a=a|0;a:{b:{if(t[464488]&1){break b}if(!Qd(464488)){break b}v[22708]=0;Q(2593,464476,84048)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464488)}return 464476}a=P()|0;O()|0;_e(464488);S(a|0);L()}function _v(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function XQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=Dn(d,a+8|0,$q(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){Ro(v[a>>2],b);c=v[a>>2]+2|0;v[a>>2]=c;b=b+2|0;if(v[a+4>>2]!=(c|0)){continue}break}}_c(a);gb=d+16|0}function OH(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=kb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!Ie(b,-1)){break a}v[a>>2]=0}return a|0}function NP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;c=d+8|0;Db(c,a+1074312|0,80);if(!(!Cb(c)|!e)){t[b+824|0]=w[b+824|0]<<2}gb=d+16|0}function ER(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=A[a>>3]*b+c*A[a+8>>3]+e*A[a+16>>3]-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function sW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Eg(d,a,1);a=wb(a);e=v[c+4>>2];v[22708]=0;gn(a,e,b);a=v[22708];v[22708]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function pqa(a,b,c,d){var e=0,f=0,g=0;f=(b^d)>>31;e=b>>31;a=a^e;g=a-e|0;a=(b^e)-((a>>>0<e>>>0)+e|0)|0;e=d>>31;b=c^e;a=rqa(g,a,b-e|0,(e^d)-((e>>>0>b>>>0)+e|0)|0)^f;b=a-f|0;jb=(f^jb)-((a>>>0<f>>>0)+f|0)|0;return b}function iM(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Bi(d,a,1);a=wb(a);e=v[c+4>>2];v[22708]=0;ql(a,e,b);a=v[22708];v[22708]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Wz(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}hc(a+24604|0,b,40);rO(a,c)}function NC(a,b){var c=0,d=0,e=0,f=0;c=a<<8&16711680|a<<24;d=b<<24|a>>>8;e=d&65280;d=b<<8|a>>>24;c=d&255|e|c;a=((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|f;jb=c;return a}function uk(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=v[a+24>>2];d=v[a+40>>2];v[22708]=0;v[b+12>>2]=1;a=Mc(a+20|0,b+12|0);e=v[22708];v[22708]=0;if((e|0)!=1){gb=b+16|0;return B(v[a>>2],c+d|0)}V(0)|0;O()|0;Bb();L()}function q2(){var a=0;a=gb-16|0;gb=a;v[116460]=0;v[116461]=0;v[a+12>>2]=0;Xo(465848);t[465976]=0;gb=a+16|0;v[22708]=0;X(2559);a=v[22708];v[22708]=0;if((a|0)!=1){KG(30);return}a=P()|0;O()|0;ox(465840);S(a|0);L()}function o0(a){a=a|0;a:{b:{if(t[464408]&1){break b}if(!Qd(464408)){break b}v[22708]=0;Q(70,464396,11025)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464408)}return 464396}a=P()|0;O()|0;_e(464408);S(a|0);L()}function j0(a){a=a|0;a:{b:{if(t[464440]&1){break b}if(!Qd(464440)){break b}v[22708]=0;Q(70,464428,10819)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464440)}return 464428}a=P()|0;O()|0;_e(464440);S(a|0);L()}function Ew(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(!Pb(b,3)){t[c+16|0]=0;oi(a,3,c+16|0);break a}d=gb-16|0;gb=d;bc(c+24|0,a,3);gb=d+16|0;a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=ok(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=kb[e|0](a,c)|0}else{a=1}gb=c+16|0;return a|0}function s0(a){a=a|0;a:{b:{if(t[464376]&1){break b}if(!Qd(464376)){break b}v[22708]=0;Q(70,464364,2361)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464376)}return 464364}a=P()|0;O()|0;_e(464376);S(a|0);L()}function f0(a){a=a|0;a:{b:{if(t[464472]&1){break b}if(!Qd(464472)){break b}v[22708]=0;Q(70,464460,6410)|0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(464472)}return 464460}a=P()|0;O()|0;_e(464472);S(a|0);L()}function Vz(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;qO(a+24648|0);JO(a)}function lt(a){var b=0;if(a){if(v[a+76>>2]<=-1){return ay(a)}return ay(a)}if(v[22702]){b=lt(v[22702])}a=v[115188];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=ay(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function ko(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{if(c){Tb(d,c);break a}Kb(d)}v[22708]=0;U(13,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function ex(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function EU(a){var b=0,c=0,d=0;c=a;b=v[a+8>>2];d=v[a+4>>2];if((b|0)!=(d|0)){while(1){b=b-56|0;v[c+8>>2]=b;Yu(b);b=v[c+8>>2];if((d|0)!=(b|0)){continue}break}}c=v[a>>2];if(c){Wu(c,(v[dc(a)>>2]-v[a>>2]|0)/56|0)}}function xd(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Mg(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}gb=c+16|0;break a}aa(8513,6236,136,11431);L()}return d}function wg(a){var b=0;v[22708]=0;a=T(1290,a|0)|0;b=v[22708];v[22708]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;X(20);b=v[22708];v[22708]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Bb();L()}function n8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Np(e,a,d);wb(a);v[22708]=0;U(2090,b|0,c|0,d+4|0);a=v[22708];v[22708]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function ME(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Pb(a,1)){break b}t[c+15|0]=0;Mg(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}gb=c+16|0;break a}aa(8513,6236,136,11431);L()}return d}function I6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;kb[g|0](a,b,e,d);gb=e+16|0}function CR(a){a=a|0;var b=0,c=0,d=0;c=gb-16|0;gb=c;b=fs(c,a,2048);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;v[a+4>>2]=0;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function hS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e>>2]=c;v[e+8>>2]=b;if(Gb(e+8|0,e)){while(1){b=e+8|0;wn(a,v[d>>2],v[b>>2]);nf(b);v[d>>2]=v[d>>2]+2;if(Gb(b,e)){continue}break}}gb=e+16|0}function cP(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function bC(a,b,c){var d=0;d=gb-16|0;gb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Gb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}a=d+8|0;nf(a);if(Gb(a,d)){continue}break}}gb=d+16|0;return v[d+8>>2]}function Vv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Kx(a){a=a|0;var b=0;v[a>>2]=78428;v[22708]=0;R(2386,a|0,0);b=v[22708];v[22708]=0;if((b|0)!=1){Wb(a+28|0);Xb(v[a+32>>2]);Xb(v[a+36>>2]);Xb(v[a+48>>2]);Xb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Bb();L()}function JO(a){var b=0,c=0;b=gb-544|0;gb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){DR(b,wf(a));c=a+1298224|0;a=a+1074992|0;while(1){hc(a+112|0,b,538);a=a+872|0;if((c|0)!=(a|0)){continue}break}}gb=b+544|0}function zO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-52|0;R(1325,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function ts(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){f=eG(v[a+16>>2],b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function kR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-12|0;R(1131,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function eS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-32|0;R(1101,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function bD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){f=cE(v[a+16>>2],b)}v[a>>2]=f;c=B(c,20)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,20)+f|0,v[g>>2]=h;gb=e+16|0;return a}function UG(a,b,c,d,e,f){var g=0,h=0,i=0;g=gb-16|0;gb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){gi(g+13|0,g+14|0)}h=c,i=(ab(b|0,nS(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;gb=g+16|0}function Iv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Mb(128/(B(v[If(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[pf(c+7|0,c+6|0)|0];gb=c+16|0;return a|b<<4&240}function wfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){cO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=vo(d+8|0,lr(a,Nb(a)+1|0),Nb(a),c);xq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;SN(a,c);Gz(c);gb=d+32|0}function nu(a,b){a=hc(a,b,88);v[a+88>>2]=v[b+88>>2];hc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];hc(a+672|0,b+672|0,52);xo(a+724|0,b+724|0);xo(a+732|0,b+732|0);xo(a+740|0,b+740|0);hc(a+748|0,b+748|0,123)}function gla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;$U(c+24|0,a);Dg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Gc(c+8|0,c);gb=c+32|0;return a|0}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){cO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=vo(d+8|0,lr(a,Nb(a)+1|0),Nb(a),c);xq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;XS(a,c);Gz(c);gb=d+32|0}function B1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){while(1){a=d;if(y[b>>2]<=127){e=x[Yp()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function $D(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22708]=0;c=c-20|0;R(348,d|0,c|0);d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function $A(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){Lo(d);UR(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function zp(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){f=PE(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function zi(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?((c|0)<(f|0)?1:(c|0)<=(f|0)?b>>>0<e>>>0:0)?b+g|0:d:d}function cg(a,b,c,d,e){var f=0;f=gb-256|0;gb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Qb(f,b&255,d?c:256);if(!d){while(1){tf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}tf(a,f,c)}gb=f+256|0}function Uba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;b=Ac(pqa(oqa(d,d>>31,b,0),jb,1e3,0),jb);v[a+16>>2]=0;v[a+12>>2]=b+c;ZL(a,e);b=v[a+12>>2];v[f+12>>2]=0;kN(a,b,f+12|0);gb=f+16|0}function OS(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;Dg(c+24|0,a);Dg(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=PS(c+8|0,c);gb=c+32|0;return a|0}function MW(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){f=NW(v[a+16>>2],b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=B(b,6)+f|0,v[g>>2]=h;gb=e+16|0;return a}function JS(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=ei(w[a+797|0]-u[a+770>>1]|0);if(!b|!v[a+656>>2]){break a}if(!c){c=0;break a}if(c>>>0>=129){break a}c=w[lc(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function En(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;Ch(a+12|0,d);if(b){f=aF(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function zN(a){var b=0,c=0,d=0;if(Tf(a)){while(1){b=a;d=c&65535;if(Tf(b)>>>0>d>>>0){b=af(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;HN(b);Se(b+36|0)}c=c+1|0;if(Tf(a)>>>0>(c&65535)>>>0){continue}break}}}function xX(a){var b=0,c=0;b=a+36|0;c=oqa(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}jb=a;return b}function pK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Eg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;Vi(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function jP(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22708]=0;v[c>>2]=2147483647;v[c+4>>2]=0;a=Tk(c+8|0,c);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function hC(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=1073741823;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function bF(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=2147483647;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function aT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Eg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);Xo(b);b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function _d(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Cd(b)}return c}function DN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Cr(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);hi(b);b=b+6|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function z1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]>127){break a}if(!(x[Yp()+(v[c>>2]<<1)>>1]&b)){break a}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function g9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=cq(e,a,d);v[22708]=0;U(2046,b|0,c|0,a+4|0);b=v[22708];v[22708]=0;if((b|0)!=1){$b(a);gb=e+16|0;return}b=P()|0;O()|0;$b(a);S(b|0);L()}function fG(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=357913941;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function dE(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=214748364;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function OW(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=715827882;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function sU(a){var b=0,c=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;b=w[a+1|0]<<8;if((b|w[a|0])!=2?(w[a|0]|b)!=1:0){break a}c=1}return c}function nt(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;v[d+16>>2]=c;v[d+20>>2]=e;rh(d+24|0,d+8|0);c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;qy(a,b,d);gb=d+32|0}function mp(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=1073741823;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=v[a+24>>2];uL(d,c);v[22708]=0;U(560,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function c1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=wi(b+8|0,b+12|0);v[22708]=0;c=rI(0,0,4);d=v[22708];v[22708]=0;if((d|0)!=1){ff(a);gb=b+16|0;return c|0}b=P()|0;O()|0;ff(a);S(b|0);L()}function Roa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=sf(2500);v[22708]=0;a=Q(48,c|0,a|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){a=v[Xi(b+8|0,a)>>2];gb=b+16|0;return a|0}a=P()|0;O()|0;Xb(c);S(a|0);L()}function Rla(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=OE(a);if(d>>>0>=b>>>0){a=$u(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Mc(c+12|0,c+8|0)>>2]}gb=c+16|0;return d|0}Sc();L()}function RU(a){var b=0,c=0,d=0,e=0;jb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function yI(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=268435455;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function dR(a){var b=0,c=0,d=0;c=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;b=b-8|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=c}function aN(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break b}Fk(b+16|0)}if(b){Xk(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function NA(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=fc(a);if(w[a+4|0]){v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break b}iR(b+16|0)}if(b){ks(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function LL(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(Dk(b-+(a|0)))}else{d=C(0)}return d}function KO(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break a}kb[v[v[b>>2]+96>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function Hw(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=536870911;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function GV(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=178956970;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function AT(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=134217727;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function tN(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=82595524;v[22708]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function CO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-16|0;gb=c;ag(a,c+14|0);SO(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Hk(a,Lb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}eA(b);gb=c+16|0}function rL(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=sf(1298432);v[22708]=0;c=T(2052,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){b=v[Xi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function Jd(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function FR(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function zj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function zP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075648>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,872)+a|0)+1075096>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function Us(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Vx(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Vx(a)}return a}function sF(a){var b=0;if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>6))){b=(w[a+7|0]-9&255)>>>0<7}return b}function lh(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[22708]=0;T(283,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ia(a|0,28304,206);L()}function lS(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[a+16|0]=0;c=fB(b,v[a+12>>2]);v[22708]=0;R(1087,a|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){Xm(c);gb=b+32|0;return}a=P()|0;O()|0;Xm(c);S(a|0);L()}function b1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=wi(b+8|0,b+12|0);v[22708]=0;c=kH();d=v[22708];v[22708]=0;if((d|0)!=1){ff(a);gb=b+16|0;return c|0}b=P()|0;O()|0;ff(a);S(b|0);L()}function aK(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=-1;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Qc(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22708]=0;v[c>>2]=-1;v[c+4>>2]=0;a=Tk(c+8|0,c);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Ev(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function e$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Jp(a);v[a>>2]=27480;e=dc(a);d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;VF(e,c+8|0);gb=c+32|0;return a|0}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<oc(a)>>>0){a=oo(d,kc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=Ty(c,a);Hb(a);e=b^1}gb=d+16|0;return e|0}function OK(a){a=a|0;var b=0;a=a+24|0;b=PK(v[a>>2]);if(Si(Sb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074446>>1]}b=x[sc(Sb(v[a>>2]+484360|0),b)>>1];return(am(v[a>>2]+484344|0,b)?b:-1)|0}function CG(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=e;e=wi(f+8|0,f+12|0);v[22708]=0;a=$p(a,b,c,d);b=v[22708];v[22708]=0;if((b|0)!=1){ff(e);gb=f+16|0;return a}a=P()|0;O()|0;ff(e);S(a|0);L()}function zg(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb+-64|0;gb=c;d=lz(c+8|0,a);v[22708]=0;U(1490,a|0,b|0,d|0);a=v[22708];v[22708]=0;if((a|0)!=1){Im(d);gb=c- -64|0;return}a=P()|0;O()|0;Im(d);S(a|0);L()}function vo(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=Xz(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function oha(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=XT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){fR(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function mr(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Eg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){$j(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function epa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,6)){t[c+16|0]=0;oi(a,6,c+16|0);break a}PX(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function az(a){var b=0,c=0,d=0,e=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=yo(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}A[c+4280>>3]=C(C(a|0)*C(-4.656612873077393e-10))}function aS(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=cS(b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<5)+f|0,v[g>>2]=h;gb=e+16|0;return a}function RA(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=BR(b)}v[a>>2]=f;c=(c<<3)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<3)+f|0,v[g>>2]=h;gb=e+16|0;return a}function QI(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;hf(a+12|0,d);if(b){f=PH(b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=dc(a),h=(b<<4)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Kla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,5)){t[c+16|0]=0;oi(a,5,c+16|0);break a}Wv(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function A1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]<=127){if(x[Yp()+(v[c>>2]<<1)>>1]&b){break a}}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function yT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=oI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Ev(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function yO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];if((b|0)>=11){e=a;b=378;while(1){xO(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}b=0}v[d+112>>2]=b+1;a=xO(a);return a|0}function vn(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,4)){t[c+16|0]=0;oi(a,4,c+16|0);break a}Ai(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22708]=0;a=fa(1802,d|0,a|0,b|0,c|0,0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22708]=0;a=fa(1802,d|0,a|0,b|0,c|0,1)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function eU(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function ZT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=XT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){WT(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4332);if(!d){return 0}v[22708]=0;a=fa(1697,d|0,a|0,b|0,c|0,0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Oh(a,b){var c=0,d=0;a=v[a>>2];b=Wd(b);c=b;d=a+8|0;if(Nb(d)>>>0>b>>>0){c=v[Lb(d,c)>>2]!=0}else{c=0}if(!c){a=ba(4)|0;Dm(a);v[a>>2]=89548;ia(a|0,89596,2321);L()}return v[Lb(a+8|0,b)>>2]}function OI(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=oI(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){XH(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function Li(a){var b=0,c=0,d=0,e=0;e=Be(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=Be(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function CT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=zT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){UB(a);a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function yD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function kv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Sk(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){$j(a);a=v[b>>2]+4|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function cc(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;g=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=b;kb[g|0](a,e,f,d);gb=d+16|0}function TV(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Dn(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Ok(a);a=v[b>>2]+2|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}_c(b);gb=c+16|0}function Dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(86224);if(!d){return 0}v[22708]=0;a=ca(1888,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function CC(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4276);if(!d){return 0}v[22708]=0;a=ca(1755,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function vR(a,b){var c=0,d=0;c=v[a+24>>2];v[22708]=0;c=me(c+484344|0,b);d=v[22708];v[22708]=0;if((d|0)!=1){if(c){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}V(0)|0;O()|0;Bb();L()}function qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4268);if(!d){return 0}v[22708]=0;a=ca(1778,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function lx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=wi(e+8|0,e+12|0);v[22708]=0;a=pl(a,b,c);b=v[22708];v[22708]=0;if((b|0)!=1){ff(d);gb=e+16|0;return a}a=P()|0;O()|0;ff(d);S(a|0);L()}function iw(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(!Pb(b,2)){t[c+16|0]=0;hE(a,c+16|0);break a}An(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;kd(c+16|0,b,c+8|0)}gb=c+32|0}function gp(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(!d){FW(b);break a}Ai(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;kd(c+16|0,a,c+8|0)}gb=c+32|0;return d|0}function d9(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=v[a+24>>2];uL(c,b);v[22708]=0;U(560,a|0,1,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4228);if(!d){return 0}v[22708]=0;a=ca(1815,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4236);if(!d){return 0}v[22708]=0;a=ca(1666,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Zz(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;yc(b+8|0,a+116|0);v[22708]=0;c=Na(1328,a|0)|0;a=O()|0;c=c|0;d=v[22708];v[22708]=0;if((d|0)!=1){gb=b+16|0;jb=a;return c}a=P()|0;O()|0;S(a|0);L()}function Vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4268);if(!d){return 0}v[22708]=0;a=ca(1532,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function UQ(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function Tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(5048);if(!d){return 0}v[22708]=0;a=ca(1838,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Rpa(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=sf(1);v[22708]=0;c=T(39,b|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){b=v[Xi(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function MM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-2048|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4276);if(!d){return 0}v[22708]=0;a=ca(1865,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4280);if(!d){return 0}v[22708]=0;a=ca(1731,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function Bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=wg(4304);if(!d){return 0}v[22708]=0;a=ca(1595,d|0,a|0,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function rH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function hfa(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!dk(a,b+8|0)){break a}c=0;if(!NN(b+8|0)){break a}c=b;a=DT(a,b);if(!a){$j(c)}c=-1;if(!a){break a}c=MN(b)}gb=b+16|0;return c|0}function TL(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function Rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4228|0,c,yb(b));Lt(a)}}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((yb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4260|0,c,yb(b));St(a)}}function GX(a){var b=0,c=0;a:{if(sd(a,18709,11)){break a}b=a+215|0;a=a+63|0;while(1){if(w[a+16|0]>3|w[a+17|0]>3|w[a+18|0]>=16){break a}a=a+19|0;if((b|0)!=(a|0)){continue}break}c=1}return c}function xpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=Tb(b,7535);v[22708]=0;a=Q(46,a|0,c|0)|0;d=v[22708];v[22708]=0;if((d|0)!=1){vb(c);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(c);S(a|0);L()}function x1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Es()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function v1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Ds()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function mca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Ii(d+12|0);c=z[d+12>>2];if((b|0)==4){c=fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;dM(a)}gb=d+16|0}function mY(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-48|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function iz(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Zba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=1){Ii(d+12|0);c=z[d+12>>2];if((b|0)==1){c=fe(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;_L(a)}gb=d+16|0}function Ux(a,b,c,d,e,f,g,h,i){var j=0;j=gb-16|0;gb=j;xg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;gb=j+16|0}function Ui(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function FI(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-16|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;ST(b,c);if(Pb(a,c<<8)){bc(d+24|0,v[b>>2],dh(b)<<8);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0}function zU(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-4|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function oK(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-1|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function k$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;zF(b,c);c=Pb(a,c<<3);if(c){yF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function eqa(){var a=0;a:{b:{if(t[90868]&1){break b}if(!Qd(90868)){break b}v[22708]=0;X(34);a=v[22708];v[22708]=0;if((a|0)==1){break a}Pd(90868)}return}a=P()|0;O()|0;_e(90868);S(a|0);L()}function dH(a){var b=0;a:{b:{a=v[a>>2];if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a|0)!=(a&-256)}return b}function cF(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-2|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function av(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22708]=0;df(a+8|0,b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function XW(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22708]=0;c=c-6|0;d=v[22708];v[22708]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function VS(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function Hg(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22708]=0;Qf(a+8|0,b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function Ct(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=gb-16|0;gb=a;if(Nb(b)){while(1){v[a+8>>2]=0;Vi(a+8|0);d=Lb(b,c),e=v[a+8>>2],v[d>>2]=e;c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}gb=a+16|0}function wj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function t4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=mt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;hc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function iba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=AL(f,b,c,d,0,0,0,0,e);gb=f+16|0;return a|0}function YT(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-12|0;v[b+8>>2]=c;_T(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){Su(b,Mp(a))}}function WS(a){var b=0,c=0;c=v[a+4>>2];a:{while(1){b=v[a+8>>2];if((b|0)==(c|0)){break a}v[a+8>>2]=b-4;v[22708]=0;b=v[22708];v[22708]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function KY(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-28|0;v[b+8>>2]=c;ed(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){vD(b,JY(a))}}function Gm(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Nb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Nb(c)<<16)-65536>>16<(b|0)){break a}d=z[Lb(c,b-u[a+28>>1]|0)>>2]}return d}function $E(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-2;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function $B(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-4;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function qe(a,b){var c=0;a:{c=Of(b);if((c|0)==(Ab(a)|0)){v[22708]=0;a=fa(551,a|0,0,-1,b|0,c|0)|0;b=v[22708];v[22708]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Bb();L()}function e3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=jk(h,b,c,d,e,f,g+8|0,a);gb=a;return b|0}function YX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;Nk(b,c);c=Pb(a,c);if(c){ID(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function YQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Rc(a,8,1,0,11);return}d=a;a=b+31|0;Rc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function Ida(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=gb-16|0;gb=d;e=d,f=C(C(kb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;Ii(d+12|0);kb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);gb=d+16|0}function o1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Es()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function nN(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=32767;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function m1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Ds()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Xh(a){var b=0;a=fe(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Lv(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=65535;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return x[a>>1]}V(0)|0;O()|0;Bb();L()}function B_(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a=In(c+8|0,a);v[22708]=0;a=W(272,a|0,b|0,10435)|0;b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function y0(){var a=0;a:{if(t[465480]&1){break a}if(!Qd(465480)){break a}a=465456;while(1){a=Kb(a)+12|0;if((a|0)!=465480){continue}break}Pd(465480)}Wc(465456,11156);Wc(465468,11135)}function u0(){var a=0;a:{if(t[465512]&1){break a}if(!Qd(465512)){break a}a=465488;while(1){a=Kb(a)+12|0;if((a|0)!=465512){continue}break}Pd(465512)}ld(465488,88928);ld(465500,88940)}function qh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=aK(a);if(d>>>0<=b>>>0){a=dg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function hd(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);gb=d+16|0}function fh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=hC(a);if(d>>>0<=b>>>0){a=pe(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function cD(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=dE(a);if(d>>>0<=b>>>0){a=bm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Zw(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=fG(a);if(d>>>0<=b>>>0){a=ug(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Uk(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=bF(a);if(d>>>0<=b>>>0){a=Og(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function RO(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;NO(c,b+80|0);v[22708]=0;U(13,a|0,0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}
function Gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(GV()>>>0<b>>>0){Sc();L()}c=b;if(c>>>0>=178956971){rd(8445);L()}c=Nc(B(c,24),4);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+B(b,24)|0,v[d>>2]=e}function FL(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=EL(f,b,c,d,e,0,0,0,0);gb=f+16|0;return+c}function Dv(a){var b=0,c=0;b=gb-16|0;gb=b;u[b+14>>1]=a;v[22708]=0;u[b+12>>1]=255;a=Pc(b+14|0,b+12|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function BC(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=OW(a);if(d>>>0<=b>>>0){a=Xj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function wN(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=tN();if(d>>>0<=b>>>0){a=pk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function uoa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;mX(b,c,32);lX(a,c);gb=c+32|0}function lr(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=mp();if(d>>>0<=b>>>0){a=pe(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function gs(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=Hw();if(d>>>0<=b>>>0){a=tg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function fo(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(mK(a)){break a}v[22708]=0;R(2112,b+8|0,a|0);c=v[22708];v[22708]=0;if((c|0)!=1){break a}V(0)|0;O()|0;Bb();L()}t[a+20|0]=255;gb=b+16|0}function dy(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=yI();if(d>>>0<=b>>>0){a=xi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function _q(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=AT();if(d>>>0<=b>>>0){a=bi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Mc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Sc();L()}function Y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=kb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function Os(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=Ab(b);if(d>>>0<c>>>0){Yn();L()}b=Jb(b);v[e+4>>2]=d-c;ys(a,b+c|0,v[Fb(e+12|0,e+4|0)>>2]);gb=e+16|0}function NQ(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{if(w[fc(a)+4|0]){v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break b}Qm(b+16|0)}if(b){HA(b)}break a}V(0)|0;O()|0;Bb();L()}}}function N7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){v[d>>2]=v[a>>2];gg(d+4|0,a+4|0);d=v[c>>2]+16|0;v[c>>2]=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}}function MN(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function KL(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=Me(31415.926535897932/+b);d=Po(32768/(1-e)*(1-(c*e+K((1-c)*+C(a+a)-(1-c*c)*+C(a*a)))))}return d}function HO(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function yL(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22708]=0;T(1936,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return}ia(a|0,54720,1937);L()}function rS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=mi(e,a,d);a=wb(a);v[22708]=0;hS(a,b,c,d+4|0);a=v[22708];v[22708]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function dm(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22708]=0;v[b+8>>2]=255;a=Fb(b+12|0,b+8|0);c=v[22708];v[22708]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function Sy(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[22708]=0;T(1948,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return}ia(a|0,54776,1937);L()}function oW(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function jJ(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;h=a+2304|0;while(1){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;if((d|0)!=(b|0)){continue}break}}function HG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83656;b=a+8|0;if(Nb(b)){while(1){d=v[Lb(b,c)>>2];if(d){Ln(d)}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}vb(a+152|0);ox(b);return a|0}function nj(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(Ee(a)){ai(a,v[a>>2],fk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Ze(b,0);v[c+12>>2]=0;Ge(b,c+12|0);gb=c+16|0}function mz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Cr(e,a,d);wb(a);a=c-b|0;if((a|0)>=1){hc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}$b(d);gb=e+16|0}function vE(a){var b=0,c=0;a:{if(sd(a,11420,3)){break a}b=a+3|0;if((w[b|0]!=1?w[b|0]<=7:0)|w[b|0]>14){break a}a=a+40|0;if(!(w[b|0]>8?w[a|0]<33?w[a|0]:0:1)){break a}c=1}return c}function s4(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;mT(b,0,a);v[22708]=0;a=T(143,b|0)|0;c=v[22708];v[22708]=0;if((c|0)!=1){vb(b);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function SU(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}c=w[a+4|0]>95}return c}function Ry(a,b){var c=0,d=0;c=gb-16|0;gb=c;u[b>>1]=0;t[c+15|0]=0;Vh(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Vh(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}gb=c+16|0}function NX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(sd(a+44|0,14915,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function F4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=d+8|0;kb[v[v[a>>2]+12>>2]](e,a,b);if(Ie(v[e+4>>2],v[c+4>>2])){a=v[e>>2]==v[c>>2]}else{a=0}gb=d+16|0;return a|0}function Eb(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(Ee(a)){$k(a,v[a>>2],fk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Ze(b,0);t[c+15|0]=0;Bd(b,c+15|0);gb=c+16|0}function vN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!me(a,b)){break a}c=jz(a,v[af(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=af(a,b);GN(af(a,c),b);d=c}return d|0}function tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Nb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=mN(a,b,c,d+8|0);gb=d+16|0;return a|0}function jpa(a,b){a=a|0;b=b|0;if(!$X(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function g4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return a|0}function Z6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;vy(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+8|0,d+12|0)>>2]}gb=d+16|0;return c|0}function Kq(a,b){var c=0;a:{if(b){Kq(a,v[b>>2]);Kq(a,v[b+4>>2]);a=fc(a);v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break a}iR(b+16|0);ks(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function JC(a,b){var c=0;a:{if(b){JC(a,v[b>>2]);JC(a,v[b+4>>2]);a=fc(a);v[22708]=0;c=v[22708];v[22708]=0;if((c|0)==1){break a}Fk(b+16|0);Xk(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function J7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[13846];v[c+8>>2]=v[13845];v[c+12>>2]=d;d=v[13844];v[c>>2]=v[13843];v[c+4>>2]=d;kb[v[Sh(c,Yg(b))>>2]](a,b);gb=c+16|0}function qi(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=be(b),v[d+12>>2]=e;v[22708]=0;df(a,c+12|0,b);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function j4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;if((b|0)!=(c|0)){while(1){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function eR(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;if(c){a=wb(a);while(1){f=Ml(a,c+16|0,b);d=f?d:c;c=v[(f?4:0)+c>>2];if(c){continue}break}}a=v[yc(e+8|0,d)>>2];gb=e+16|0;return a}function KA(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Dg(d,b);v[22708]=0;a=qB(a,d);b=v[22708];v[22708]=0;a:{if((b|0)!=1){gb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}return a>>>31|0}function Up(a){var b=0,c=0;b=v[22706];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if($w()>>>0<a>>>0){if(!(va(a|0)|0)){break a}}v[22706]=a;return b}v[115189]=48;return-1}function Jt(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-16|0;Fk(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;uK(v[a>>2],xi(a))}}function JU(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-56|0;Yu(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;Wu(v[a>>2],FU(a))}}function ima(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;zF(b,c);if(Pb(a,c<<3)){yF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;kd(d+16|0,a,d+8|0)}gb=d+32|0}function g5(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;tH(a,c,6074);v[a>>2]=78408;gb=c+16|0;return a|0}function vr(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){ep(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ng(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;ep(a,c)}function ur(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){ep(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ng(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;ep(a,c)}function ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+8>>2]=b;d=c,e=Vb(a),v[d>>2]=e;b=mv(c+8|0,c);b=v[a>>2]+(b<<2)|0;hj(a,Rg(b+4|0,v[a+4>>2],b));Gg(b);gb=c+16|0}function Wp(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=oqa(a,0,b,0);e=jb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=Cd(b);if(!(!a|!(w[a-4|0]&3))){Qb(a,0,b)}return a}function Vha(a,b){a=a|0;b=b|0;var c=0;c=dd(a);t[a+16|0]=0;v[a+12>>2]=b;v[22708]=0;_(1086,a|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Gu(c);S(a|0);L()}function zm(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function r1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Z_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=kb[v[v[a>>2]+24>>2]](a)|0;a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function GT(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/872|0;v[22708]=0;Oc(b,B(a,872),8);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function zl(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;d=e+8|0;Al(d,a+24|0,b);a=v[d+4>>2];a:{if(c){b=v[d>>2];v[b>>2]=a|v[b>>2];break a}b=v[d>>2];v[b>>2]=v[b>>2]&(a^-1)}gb=e+16|0}function xA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[b+56>>2]=0;d=b,e=Om(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(v[a+480180>>2]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function wW(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-33>>>0)/33^-1,33)+c}b=v[a>>2];if(b){vW(b,(v[dc(a)>>2]-v[a>>2]|0)/33|0)}}function bv(a){var b=0,c=0,d=0;d=a+32|0;a:{while(1){c=w[a|0];if(!((c-1&255)>>>0<31|((b^1)&1?0:c))){b=!c|b;a=a+1|0;if((d|0)!=(a|0)){continue}break a}break}b=0}return b&1}function GW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];_C(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}gb=d+16|0}function pt(a){var b=0,c=0;b=a;a:{if((Ne(b)|0)!=79){break a}if((Ne(b)|0)!=103){break a}if((Ne(b)|0)!=103){break a}c=(Ne(b)|0)==83}if(!c){ec(a,30);return 0}return $I(a)}function pea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Ui(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[dj(c+12|0,c+8|0,49656)>>2],v[d+36>>2]=e;nq(a);gb=c+16|0}function n_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;df(a+8|0,d+12|0,d+8|0);if(b){Yr(a,b);TE(a,b,w[c|0])}gb=d+16|0;return a|0}function mma(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=sg(b);sg(b);break a}a=Ng(b);Ng(b)}if(a){while(1){if(a&1){Rb(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function kJ(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function j1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=t[b|0];t[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function c5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Zp(d,a);GG(a,c);v[22708]=0;R(2386,b|0,1);a=v[22708];v[22708]=0;if((a|0)==1){a=P()|0;O()|0;Wb(d);S(a|0);L()}}function Gc(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;d=!JW(a,c)}gb=c+16|0;return d}function CK(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((Si(Sb(v[a>>2]+484360|0))|0)<=(b|0)){break a}c=x[sc(Sb(v[a>>2]+484360|0),b)>>1]}return c|0}function vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}IL(a,i,h,g,e,f,b,c,d)}function tG(a,b,c,d){var e=0,f=0,g=0;f=v[a+4>>2];e=0;a:{if(!c){break a}g=f>>8;e=g;if(!(f&1)){break a}e=dx(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function Fj(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function sf(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Cd(a);if(!b){b=v[116502];if(!b){break a}kb[b|0]();continue}break}return b|0}a=ba(4)|0;lm(a);ia(a|0,89104,1929);L()}function XD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=LD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function UT(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1299020115){a=a+4|0;a=(Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}else{a=0}return a}function NB(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/9|0;v[22708]=0;Oc(b,B(a,9),1);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Mma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=mc(a+8|0);v[22708]=0;U(393,a|0,b|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;gc(d);S(a|0);L()}}function E_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function CZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=KD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function m6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=gt(Qa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);gb=e+16|0;jb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function __(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function _6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;vy(a,b,c);a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Zi(a,b){var c=0;c=v[b+4>>2];b=v[b>>2];t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=c;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24}function Ufa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[22708]=0;a=Q(1314,a|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function TQ(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-7>>>0)/7^-1,7)+c}b=v[a>>2];if(b){LQ(b,(v[dc(a)>>2]-v[a>>2]|0)/7|0)}}function SS(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function OU(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function Jx(a,b){var c=0;c=gu(a+4|0);v[a>>2]=77232;v[c>>2]=77252;v[22708]=0;R(2404,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){return}a=P()|0;O()|0;oh(c);S(a|0);L()}function Ix(a,b){var c=0;c=BH(a+4|0);v[a>>2]=77280;v[c>>2]=77300;v[22708]=0;R(2405,c|0,b|0);a=v[22708];v[22708]=0;if((a|0)!=1){return}a=P()|0;O()|0;oh(c);S(a|0);L()}function Fe(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[fc(a)>>2];v[22708]=0;_(a|0,c|0);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function FX(a){var b=0,c=0;c=oqa(w[a+217|0],0,9,0);b=w[a+216|0];a=b>>>31|0;b=b<<1;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;if(b>>>0<11){a=a+1|0}jb=a;return b}function vA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=4){if((DA(d)|0)>(e|0)){break b}}g=a,h=CA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function ZH(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Lg(b),d=v[v[a>>2]+52>>2],kb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Lg(b)}function VP(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=2){if((DA(d)|0)>(e|0)){break b}}g=a,h=CA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function EA(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=9){if((DA(d)|0)>(e|0)){break b}}g=a,h=CA(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function np(a,b){var c=0,d=0,e=0;Cv(a);kp(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function cu(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Qb(a+32|0,0,40);nx(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function Vu(a,b){var c=0,d=0,e=0;wb(b);c=vh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[wb(b)>>2];d=wb(c),e=a,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Rb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Pb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function GB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;DR(a+112|0,48e3);v[a+668>>2]=0;FB(a+724|0);FB(a+732|0);FB(a+740|0);bj(a+788|0);return a}function Fha(a,b){a=a|0;b=b|0;var c=0;c=Ah(a);t[a+530|0]=0;v[22708]=0;R(1102,a|0,b|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;kn(c);S(a|0);L()}function BS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=nn(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Wq(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function IA(a,b){a:{if(b){IA(a,v[b>>2]);IA(a,v[b+4>>2]);fc(a);v[22708]=0;a=v[22708];v[22708]=0;if((a|0)==1){break a}Qm(b+16|0);HA(b)}return}V(0)|0;O()|0;Bb();L()}function H$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=v[c>>2];a=kb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}gb=d+16|0;return a|0}function j2(){var a=0,b=0;a:{Xd(465568);v[116392]=83728;v[22708]=0;a=ga(2477)|0;b=v[22708];v[22708]=0;if((b|0)!=1){v[116394]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function dma(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-80|0;gb=d;c=-1;a:{if(!zY(a,d+8|0)){break a}c=0;if(!dV(d+8|0)){break a}c=Oe(a,b,cV(d+8|0),jb)}gb=d+80|0;return c|0}function z4(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){uH();c=90816;break a}b:{if(t[463956]&1){break b}if(!Qd(463956)){break b}Pd(463956)}c=90812}td(a,b,c)}function uT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-256>>>8^-1)<<8)+c}b=v[a>>2];if(b){BB(b,v[dc(a)>>2]-v[a>>2]>>8)}}function Voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=mc(a);v[22708]=0;U(47,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Lc(d);S(a|0);L()}function Tj(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!ng(a)){while(1){a=v[a+8>>2];if(!ng(a)){continue}break}}a=v[a+8>>2];break a}a=UV(b)}v[c>>2]=a}function Ce(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function u4(a,b){a=a|0;b=b|0;Dm(a);v[a>>2]=89144;b=Jb(b);v[22708]=0;Q(2448,a+4|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function tK(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function sE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(Ee(a)){d=v[a>>2];t[c+15|0]=0;Bd(b+d|0,c+15|0);de(a,b);break a}t[c+14|0]=0;Bd(a+b|0,c+14|0);Ze(a,b)}gb=c+16|0}function rF(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=zb((kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0);a=v[b>>2];vd(c,d,(kb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function ns(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[22708]=0;df(a,c+12|0,c+8|0);b=v[22708];v[22708]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function FV(a,b){var c=0;c=gb-32|0;gb=c;a:{if(!Wf(a,4)){FW(b);break a}Ai(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;YB(c+16|0,a,c+8|0)}gb=c+32|0}function CA(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=Yx(b,a);break a}c=(a>>>0)/1e8|0;d=a-B(c,1e8)|0;a=(d>>>0)/1e4|0;a=vj(vj(EI(b,c),a),d-B(a,1e4)|0)}return a}function RL(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function LB(a,b){var c=0,d=0,e=0,f=0;d=vh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);e=wb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Js(a){a=a|0;var b=0;b=ba(8)|0;v[22708]=0;Q(1982,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,89452,206);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function Eda(a,b){a=a|0;b=b|0;var c=0;LM(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];Vf(a);Cl(a);Cl(a)}function vv(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;td(c,a,0);v[22708]=0;xp(c,114,0);a=v[22708];v[22708]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function Y2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return ik(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0)|0}function W6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){$f(d,a);d=v[c>>2]+12|0;v[c>>2]=d;a=a+12|0;if((b|0)!=(a|0)){continue}break}}}function lB(a,b,c,d,e){var f=0;if(d){while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function fm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;gb=d+16|0}function em(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;gb=d+16|0}function wA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=Om(a,x[b+70>>1],v[b+48>>2],c,0)}return d|0}function ui(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function bA(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;v[22708]=0;df(a,b+12|0,b+8|0);a=v[22708];v[22708]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function _7(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=gg(a,b);v[22708]=0;Q(69,a+12|0,c|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);S(a|0);L()}}function F_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function AS(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}bX(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function xt(a){var b=0,c=0,d=0;c=v[a+4>>2];b=((c<<2)+(sw(v[a>>2],1)^270549120)|0)+2019860093|0;d=sw(b,16);v[a>>2]=b;b=a;a=B(d,5)+c|0;v[b+4>>2]=a;return a}function ny(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+62816>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function jg(a,b,c){a:{switch(b-1|0){case 0:if(c){return Hj(a,1)}return Hj(a,0);case 1:if(c){return Hj(a,3)}return Hj(a,2);default:break a}}return Hj(a,4)}function d5(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];if(c){while(1){c=c-1|0;d=c<<2;kb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);if(c){continue}break}}}function ch(a){a=C(a);var b=0;a=fe(a);b=255;a:{if(a>=C(255)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b|0}function Kk(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<=-1){a=dD(a,e,d);break a}a=dD(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function $_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ao(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Cd(b)}return c}function SI(a){var b=0,c=0,d=0;if(Rh(t[v[a>>2]])){while(1){b=v[a>>2];d=t[b|0];v[a>>2]=b+1;c=(B(c,10)+d|0)-48|0;if(Rh(t[b+1|0])){continue}break}}return c}function gU(a,b){a=a|0;b=b|0;var c=0,d=0;u[a+34>>1]=0;c=gb-16|0;gb=c;t[c+15|0]=0;d=a+43|0;Jo(d,d+22|0,c+15|0);gb=c+16|0;v[a+20>>2]=0;ud(a,b);return a|0}function d3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return jk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0)|0}function Zc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(kb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function W4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Lx(b);v[a+36>>2]=b;c=a,d=wo(b),v[c+44>>2]=d;c=a,d=Vn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Js(2655);L()}}function S4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Hx(b);v[a+36>>2]=b;c=a,d=wo(b),v[c+44>>2]=d;c=a,d=Vn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Js(2655);L()}}function PR(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function $0(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[22708]=0;a=T(2576,a|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Bb();L()}function sH(a,b){a=a|0;b=b|0;Dm(a);v[a>>2]=89144;v[22708]=0;Q(2448,a+4|0,b|0)|0;b=v[22708];v[22708]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function jr(a,b){a=a|0;b=b|0;var c=0;Ek(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];cn(a,Nb(a))}function Y7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-32|0;gb=h;i=h+8|0;yK(i,b,c,d,e,f,g);Dc(a,h+20|0);Qm(i);gb=h+32|0}function Wy(a,b){a=a|0;b=b|0;var c=0;ut(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];tt(a,oc(a))}function Pd(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;a=hx(b,a);c=gb-16|0;gb=c;d=v[yc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;gb=c+16|0;gb=b+16|0}function Jj(a){var b=0;a=fe(a);b=-1;a:{if(a>=C(4294967296)){break a}b=0;if(a<=C(0)){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function JT(a){var b=0;a=ee(a);b=32767;a:{if(a>=32767){break a}b=-32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b}function Gk(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=a;d=v[v[a>>2]>>2];if(d){v[b>>2]=d}bX(v[fc(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function AE(a,b){a=a|0;b=b|0;var c=0;Ep(a);c=b+4|0;Ck(wb(a),v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];$r(a,tc(a))}function zba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=3){Ii(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];QL(a)}gb=d+16|0}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Of(b);d=sf(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=hc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function tca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Ii(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];gM(a)}gb=d+16|0}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fG(a)>>>0<b>>>0){Sc();L()}c=eG(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,12)+c|0,v[d>>2]=e;Yw(a,0)}function ho(a){var b=0;b=ba(8)|0;v[22708]=0;Q(126,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,89384,24);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function cj(a,b){var c=0;c=v[v[b>>2]-12>>2];v[22708]=0;b=v[(b+c|0)+24>>2];c=v[22708];v[22708]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Bb();L()}function Yr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(OE(a)>>>0<b>>>0){Sc();L()}b=(b-1>>>5|0)+1|0;c=Ti(wb(a),b);v[a+4>>2]=0;v[a>>2]=c;d=wb(a),e=b,v[d>>2]=e}function OZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dE(a)>>>0<b>>>0){Sc();L()}c=cE(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,20)+c|0,v[d>>2]=e;bE(a,0)}function OO(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=wb(a);c=vo(d+8|0,lr(a,Nb(a)+1|0),Nb(a),c);xq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Yk(a,c);sO(c);gb=d+32|0}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=d;b=wi(c,c+12|0);a=qH(a,6419,v[c+8>>2]);ff(b);gb=c+16|0;return a|0}function Gba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){Ii(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];SL(a)}gb=d+16|0}function Fba(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Fo(C(C(C(C(wf(v[a+16>>2])>>>0)/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;SL(a);RL(a)}function Bca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=5){Ii(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];mM(a)}gb=d+16|0}function sV(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878?(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165:0}function rd(a){var b=0;b=ba(8)|0;v[22708]=0;Q(23,b|0,a|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){ia(b|0,89332,24);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function qka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!mU(a,d)){break a}c=0;if(!oT(d)){break a}c=Oe(a,b,nT(d),jb)}gb=d+48|0;return c|0}function mla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!TU(a,d)){break a}c=0;if(!sU(d)){break a}c=Oe(a,b,rU(d),jb)}gb=d+96|0;return c|0}function kX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(OW(a)>>>0<b>>>0){Sc();L()}c=NW(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,6)+c|0,v[d>>2]=e;DC(a,0)}function hw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hC(a)>>>0<b>>>0){Sc();L()}c=Ti(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e;cn(a,0)}function fla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!mU(a,d)){break a}c=0;if(!lU(d)){break a}c=Oe(a,b,kU(d),jb)}gb=d+48|0;return c|0}function eC(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;a=a+22|0;return c+(Ib(w[b|0]|w[b+1|0]<<8)>>>0>Ib(w[a|0]|w[a+1|0]<<8)<<1>>>0)|0}function WY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(JE(a,d+8|0)){v[d+4>>2]=w[d+8|0];QY(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function VB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(bF(a)>>>0<b>>>0){Sc();L()}c=aF(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<1)+c|0,v[d>>2]=e;$r(a,0)}function Se(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(Ee(a)){c=v[a>>2];t[b+15|0]=0;Bd(c,b+15|0);de(a,0);break a}t[b+14|0]=0;Bd(a,b+14|0);Ze(a,0)}gb=b+16|0}function R1(){var a=0;a:{Xd(465784);v[22708]=0;T(2562,465792)|0;a=v[22708];v[22708]=0;if((a|0)!=1){v[116446]=86432;break a}a=P()|0;O()|0;S(a|0);L()}}function P1(){var a=0;a:{Xd(465800);v[22708]=0;T(2562,465808)|0;a=v[22708];v[22708]=0;if((a|0)!=1){v[116450]=86588;break a}a=P()|0;O()|0;S(a|0);L()}}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!TU(a,d)){break a}c=0;if(!SU(d)){break a}c=Oe(a,b,RU(d),jb)}gb=d+96|0;return c|0}function BZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Mg(a,d+8|0)){v[d+4>>2]=w[d+8|0];JD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function MO(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function K$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Sg(a,v[b+8>>2],f)){cx(b,c,d,e);return}a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function In(a,b){var c=0;v[a>>2]=27764;v[a>>2]=27616;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function AR(a){var b=0;if(v[a>>2]){gX(a);wb(a);b=v[a>>2];a=xi(a);v[22708]=0;Oc(b,a<<4,8);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function qqa(a,b,c){var d=0;d=b>>31;a=a^d;mqa(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);jb=ib;a=d^hb;b=a-d|0;jb=(d^jb)-((a>>>0<d>>>0)+d|0)|0;return b}function bY(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function YA(a,b,c){var d=0,e=0,f=0;d=Nl(a,b);if((d|0)!=255){e=wd(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=lc(a,b),f=255,t[e|0]=f;e=lc(a,c),f=d,t[e|0]=f}}function R7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;ys(a,v[c+8>>2],v[c+12>>2]);gb=c+32|0;return a|0}function t1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function rx(a,b,c){a:{if((a|0)==(b|0)){break a}c=v[c>>2];while(1){if((c|0)==v[a>>2]){break a}a=a+4|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function dU(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-12>>>0)/12^-1,12)+c}b=v[a>>2];if(b){Su(b,Mp(a))}}function _L(a){var b=0;b=(wf(v[a+16>>2])>>>0)/(Jj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;qc(a+4224|0,b)}function Z7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=gb-32|0;gb=h;i=h+8|0;yK(i,b,c,d,e,f,g);Dc(a,i);Qm(i);gb=h+32|0}function ON(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Rc(a,8,1,0,11);return}c=a;a=b+14|0;Rc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function OD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function nx(a){var b=0,c=0;v[22708]=0;c=ga(2565)|0;b=v[22708];v[22708]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Jn(a);return}V(0)|0;O()|0;Bb();L()}function l1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function fq(a,b){var c=0;a:{if(!kJ(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;cu(v[v[a>>2]-12>>2]+a|0,c);return a|0}function Vx(a){var b=0,c=0;b=gb-16|0;gb=b;c=-1;a:{if(xI(a)){break a}if((kb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}gb=b+16|0;return c}function QA(a,b){var c=0;pR(a);wb(a);c=b+4|0;ol(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];rf(a);tg(a);tg(a)}function P5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(_f(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){$s(b)}t[a|0]=1}return a|0}function HB(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=_k(a);v[22708]=0;Oc(b,B(a,36),4);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function A5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(_f(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){YH(b)}t[a|0]=1}return a|0}function vk(a,b){var c=0,d=0;a:{b=Nl(a,b);if((b|0)==255){break a}if(wk(a)){break a}c=lc(a+4|0,b);d=w[c|0]&223;t[c|0]=d;Yh(v[a>>2],Eu(b)|176,d)}}function qx(a,b){a:{if((a|0)==(b|0)){break a}b=b-4|0;if(b>>>0<=a>>>0){break a}while(1){wc(a,b);a=a+4|0;b=b-4|0;if(a>>>0<b>>>0){continue}break}}}function nm(a,b){a:{if((a|0)==(b|0)){break a}b=b-1|0;if(b>>>0<=a>>>0){break a}while(1){gi(a,b);a=a+1|0;b=b-1|0;if(a>>>0<b>>>0){continue}break}}}function kD(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=Xj(a);v[22708]=0;Oc(b,B(a,6),1);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Vm(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function Upa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;u[b+14>>1]=1;c=b,d=Zl(a),u[c+12>>1]=d;a=x[Le(b+14|0,b+12|0)>>1];gb=b+16|0;return a-1&65535}function SA(a){var b=0,c=0,d=0;c=w[a+32|0];d=Qi(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Sb(b)}return Sj(b,w[a+32|0])}function FW(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+4|0;while(1){Jf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function CM(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Fb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])/C(-127))+C(1);gb=c+16|0}function Bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aK(a)>>>0<b>>>0){Sc();L()}c=pi(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=b+c|0,v[d>>2]=e;tt(a,0)}function dV(a){var b=0;a:{if(sd(a,11124,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}b=w[a|0]!=0}return b}function WI(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function xT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-16>>>4^-1)<<4)+c}b=v[a>>2];if(b){DB(b,Px(a))}}function fD(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=pe(a);v[22708]=0;Oc(b,a<<2,2);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function c6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;hc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function VL(a){a=a|0;var b=0,c=0;v[a>>2]=52544;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Lc(b);if((b|0)!=(c|0)){continue}break}jf(a);return a|0}function Nf(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=tg(a);v[22708]=0;Oc(b,a<<3,8);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Kr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(is(a,b+8|0)){c=Yb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}gb=b+16|0;return c|0}function BT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-32>>>5^-1)<<5)+c}b=v[a>>2];if(b){EB(b,zB(a))}}function xF(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-8>>>3^-1)<<3)+c}b=v[a>>2];if(b){CF(b,wF(a))}}function qp(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-2>>>1^-1)<<1)+c}b=v[a>>2];if(b){HY(b,xw(a))}}function bP(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function Zr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Vm(d,d+e|0,c+15|0);Oj(a,v[b>>2],d);gb=c+16|0}function RB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function Ml(a,b,c){var d=0,e=0;a=x[b>>1];e=x[c>>1];d=1;a:{if(a>>>0<e>>>0){break a}d=0;if(a>>>0>e>>>0){break a}d=y[b+4>>2]<y[c+4>>2]}return d}function IW(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Vm(d,d+e|0,c+15|0);e=a;a=v[b>>2];td(e,a,d-a|0);gb=c+16|0}function HE(a){var b=0,c=0;c=oqa(w[a+111|0],0,1536,0);b=jb;a=oqa(w[a+110|0],0,25,0);c=c+a|0;b=jb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;jb=b;return a}function $7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=g+8|0;zK(h,b,c,d,e,f);Dc(a,g+20|0);Qm(h);gb=g+32|0}function fn(a){a=+a;var b=0;a=ee(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function cea(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Qy(a)}c=b,d=Vb(a+44|0),v[c>>2]=d;a=v[Gd(b+8|0,b)>>2];gb=b+16|0;return a|0}function bea(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!nd(a,4)){Qy(a)}c=b,d=Zb(a+44|0),v[c>>2]=d;a=v[Gd(b+8|0,b)>>2];gb=b+16|0;return a|0}function Bb(){var a=0;a=v[22705];v[22708]=0;X(a|0);a=v[22708];v[22708]=0;if((a|0)!=1){v[22708]=0;L()}a=V(0)|0;O()|0;Z(a|0)|0;v[22708]=0;L()}function xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(pe(a)>>>0<b>>>0){d=wb(a);e=a;a=vo(c+8|0,b,Nb(a),d);SN(e,a);Gz(a)}gb=c+32|0}function sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(tg(a)>>>0<b>>>0){d=wb(a);e=a;a=RA(c+8|0,b,rf(a),d);QA(e,a);PA(a)}gb=c+32|0}function oU(a,b,c){var d=0;d=mc(a);v[22708]=0;U(55,a|0,b|0,c|0);b=v[22708];v[22708]=0;if((b|0)!=1){return a}a=P()|0;O()|0;Lc(d);S(a|0);L()}function i1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=gb-16|0;gb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Fb(a+12|0,a+8|0);gb=a+16|0;return v[b>>2]}function dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(GA(a)>>>0<b>>>0){d=wb(a);e=a;a=VQ(c+8|0,b,LA(a),d);UQ(e,a);TQ(a)}gb=c+32|0}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(ug(a)>>>0<b>>>0){d=wb(a);e=a;a=Tu(c+8|0,b,Ec(a),d);eU(e,a);dU(a)}gb=c+32|0}function XS(a,b){var c=0;Ek(a);wb(a);c=b+4|0;ol(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2];cn(a,Nb(a))}function SN(a,b){var c=0;Ek(a);wb(a);c=b+4|0;ol(v[a>>2],v[a+4>>2],c);xc(a,c);xc(a+4|0,b+8|0);xc(wb(a),dc(b));v[b>>2]=v[b+4>>2];cn(a,Nb(a))}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;if(b>>>0>=114){ho(9396);L()}e=d+8|0;Db(e,a,b);Df(e,c);gb=d+16|0;return a|0}function OY(a){var b=0,c=0;c=a;b=v[a+4>>2];a=v[a>>2];if((b|0)!=(a|0)){while(1){b=b-28|0;ed(b);if((a|0)!=(b|0)){continue}break}}v[c+4>>2]=a}function Cy(a){var b=0;if(v[a>>2]){Od(a);b=v[a>>2];a=dg(a);v[22708]=0;Oc(b,a,1);a=v[22708];v[22708]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function ti(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function du(a,b){a=a|0;b=b|0;var c=0;c=b>>>0>126;if(!c){We(((b<<5)+a|0)+480280|0);_m((B(b,872)+a|0)+1074992|0,7,a,b,134217728)}return c|0}function Pi(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((Nl(a,b)|0)==255){break a}vk(a,b);Qq(a,b,0,0);if(!c){break a}a=lc(a+58|0,b);t[a|0]=w[a|0]|128}}function PT(a){var b=0,c=0;b=gb-16|0;gb=b;if(SV(a,b+8|0)){a=b+8|0;c=Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=b+16|0;return c}function DP(a){a=50-(B(w[(a>>>4|0)+37792|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ac((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function $ga(a){a=a|0;var b=0;b=v[a>>2];if(kb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=kb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function xea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;Tt(a,b,c);gb=c+32|0}function sea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;Tt(a,b,c);gb=c+32|0}function qoa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Tt(a,b,c);gb=c+32|0}function qea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Tt(a,b,c);gb=c+32|0}function ola(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Yv(a,b,c);gb=c+32|0}function Zja(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;MV(a,b,c);gb=c+32|0}function WX(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;b=c+8|0;Ew(b,a);a=w[lc(b,0)|0];d=w[lc(b,1)|0];b=w[lc(b,2)|0];gb=c+16|0;return a|d<<8|b<<16}function E1(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}kb[a|0](d)}function BI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function rZ(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Yv(a,b,c);gb=c+32|0}function k6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=cy(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function iC(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;MV(a,b,c);gb=c+32|0}function f5(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Mw(a,b,c);gb=c+32|0}function bd(a,b){var c=0,d=0,e=0;c=Wf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function a8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=g+8|0;zK(h,b,c,d,e,f);Dc(a,h);Qm(h);gb=g+32|0}function Ym(a){if(a>=2147483647){return 2147483647}if(a<=-2147483648){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function Xx(a,b){var c=0;if(b>>>0<=99){return EI(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return et(DI(c,a),b-B(a,100)|0)}return vj(a,b)}function Vk(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Hw()>>>0<b>>>0){Sc();L()}c=BR(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<3)+c|0,v[d>>2]=e}function sw(a,b){var c=0,d=0;if((b|0)<=-1){b=0-b|0;c=0-b&31;d=(a&-1>>>c)<<c;c=a;a=b&31;return d|(c&-1<<a)>>>a}return sqa(a,(b|0)%32|0)}function rda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!we(c&255)|!d)){JM(a,8,C(0))}a=ok(a);if(a){kb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function p6(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;Mw(a,b,c);gb=c+32|0}function l5(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;Mw(a,b,c);gb=c+32|0}function jt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function iD(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=d+8|0;Zi(c,b);gb=d+16|0;return v[a>>2]==(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}function bZ(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;Yv(a,b,c);gb=c+32|0}function VI(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}aa(11450,10528,1180,2826);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Qs(a,b){Dm(a);v[a>>2]=89124;v[22708]=0;Q(2448,a+4|0,b|0)|0;a=v[22708];v[22708]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function Kb(a){var b=0,c=0;b=gb-16|0;gb=b;v[22708]=0;c=v[22708];v[22708]=0;if((c|0)!=1){MA(a);gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function sg(a){var b=0,c=0;b=gb-16|0;gb=b;if(is(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=b+16|0;return c}function pI(a){var b=0,c=0,d=0;c=Jb(a);b=Ab(a);a=gb-16|0;gb=a;t[a+15|0]=0;d=-1;if(b){b=sp(c,b,a+15|0);d=b?b-c|0:-1}gb=a+16|0;return d}function h9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(yI()>>>0<b>>>0){Sc();L()}c=PH(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<4)+c|0,v[d>>2]=e}function cA(a,b){a=a|0;b=b|0;var c=0;c=18720;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c|0}function ax(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=dx(v[d>>2],h)}a=v[a>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function LV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(mp()>>>0<b>>>0){Sc();L()}c=_V(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function K7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(mp()>>>0<b>>>0){Sc();L()}c=Xz(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function BG(a){a=a|0;var b=0;a=Kb(a);v[22708]=0;Q(157,a|0,10983)|0;b=v[22708];v[22708]=0;if((b|0)==1){b=P()|0;O()|0;vb(a);S(b|0);L()}}function dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];cu(v[v[a>>2]-12>>2]+a|0,c);return a|0}function cha(a,b){a=a|0;b=b|0;a=Sv(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function Sr(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function Hf(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=wi(f,f+12|0);a=dt(a,b,d,v[f+8>>2]);ff(c);gb=f+16|0;return a}function yb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22708]=0;a=Zh(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function vs(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22708]=0;a=Pp(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function u1(){var a=0,b=0;a=gb-16|0;gb=a;v[a+8>>2]=19923024;a:{if(dH(a+8|0)){break a}if(aH()){break a}b=$G()^1}gb=a+16|0;return b|0}function opa(a){a=a|0;var b=0,c=0,d=0;if(mp()>>>0<=8191){Sc();L()}b=Nc(32768,2);v[a>>2]=b;v[a+4>>2]=b;c=wb(a),d=b+32768|0,v[c>>2]=d}function ht(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function Qx(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Lg(t[b|0])|0}function IB(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22708]=0;a=$q(a,b);b=v[22708];v[22708]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function gda(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;b=c+12|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;AM(a,b);gb=c+16|0}function Sf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;if(b>>>0>=114){ho(9361);L()}d=c+8|0;Db(d,a,b);Df(d,0);gb=c+16|0;return a|0}function RM(a){a=a|0;a=gb-16|0;gb=a;v[a+12>>2]=1869112133;gb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function cda(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;if(pe(a)>>>0<=12){c=wb(a);d=a;a=vo(b+8|0,13,Nb(a),c);Yk(d,a);sO(a)}gb=b+32|0}function Bs(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=dx(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function qL(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=sf(8);fL(b);v[b+4>>2]=a;v[b>>2]=55396;a=v[Xi(c+8|0,b)>>2];gb=c+16|0;return a|0}function Uj(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;Ge(a,d+12|0);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;gb=d+16|0;return a}function QB(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=wb(b),d=0,v[c>>2]=d}function Q6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Dt(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+49584|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function P6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Dt(a+8|0,b,c,d,3);if(a>>>0<=44){a=w[a+49536|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function ok(a){var b=0,c=0;b=Vk(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function iy(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}hc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function ZG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ns(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function WG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ms(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function LS(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=oqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(pqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function Kd(a){var b=0;a=v[a+4>>2];if(a){if(Ln(a)){a:{b=a+8|0;if(v[b>>2]){if((Pw(b)|0)!=-1){break a}}kb[v[v[a>>2]+16>>2]](a)}}}}function KS(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=oqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return Ac(pqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function aH(){var a=0,b=0,c=0;a=gb-16|0;gb=a;b=Tb(a,12129);if(Ab(b)){c=(vg(b,11157)|0)!=-1}else{c=0}vb(b);gb=a+16|0;return c|0}function _R(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){de(b,a)}if(c){de(c,a)}if(d){de(d,a)}if(e){de(e,a)}}function Ik(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;xr(a+4|0);v[b+12>>2]=0;Ge(a+8|0,b+12|0);c=a,d=fc(a),v[c>>2]=d;gb=b+16|0;return a}function V5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Lg(t[a|0])|0}function Ul(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(kb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function R$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Sg(a,v[b+8>>2],0)){ex(b,c,d);return}a=v[a+8>>2];kb[v[v[a>>2]+28>>2]](a,b,c,d)}function Jl(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];td(a,c,v[Fb(d+12|0,d+8|0)>>2]);gb=d+16|0}function u6(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}kb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function qg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=lh(d,a);return((lh(d,a+1|0)<<8|e<<16|lh(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function kU(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;jb=c;return a}function dI(a){v[a>>2]=77076;nx(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function ct(a){v[a>>2]=77012;nx(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function bo(a,b,c,d){var e=0;e=gb-16|0;gb=e;bc(e+8|0,zb(c),d);c=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=c;qy(a,b,e);gb=e+16|0}function _G(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ns(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function XG(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ms(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Ub(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function Pt(a){var b=0;b=A[a+4248>>3]/+(wf(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function NN(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){a=bn(a)>>>0>80}else{a=0}return a}function At(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=Bi(c,a,b);b=v[a+8>>2];if((b|0)!=v[a+4>>2]){v[a+4>>2]=b}$b(a);gb=c+16|0}function wp(a,b){var c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=LE(a,b);break a}c=sg(a);Rb(a,b-4|0)}return c}function qq(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return+b}function oq(a){a=a|0;var b=0,c=0;b=Te(a);while(1){c=b;if(c&65535){b=c-1|0;if(!me(a,b&65535)){continue}}break}return c&65535}function mw(a,b){var c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=1){c=KE(a,1);break a}c=Ng(a);Rb(a,b-2|0)}return c}function ff(a){a:{a=v[a>>2];if(a){v[22708]=0;Bx(a);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function sk(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=b+8|0;Db(c,a+1074312|0,7);if(Cb(c)){d=v[a+480180>>2]!=4}gb=b+16|0;return d}function kB(a){a=a|0;v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function _N(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function WB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Jfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=qQ(d);b=b+1|0}fO(a,b,c,d,e)}function AI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function $T(a,b){var c=0;c=v[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-12|0;_T(c);if((b|0)!=(c|0)){continue}break}}v[a+4>>2]=b}function yi(a,b,c){a:{if(c){v[22708]=0;BI(a,b,c);a=v[22708];v[22708]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function we(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=a;t[b+14|0]=1;t[b+13|0]=120;a=Hv(b+15|0,b+14|0,b+13|0);gb=b+16|0;return a}function je(a,b){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function ZS(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function Rd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Fp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function wS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){uS(a,1);uS(a,0)}}function vZ(a){a=a|0;var b=0;a:{if(!Ie(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=MF(a,32);v[b+76>>2]=a}return a<<24>>24}function vS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){tS(a,1);tS(a,0)}}function gw(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=gb-16|0;gb=c;t[c+15|0]=w[b|0];qR(a,c+15|0);gb=c+16|0;gb=d+16|0}function TH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function R5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function Fl(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;Cz(a,c)}function WQ(a){var b=0;a:{if(w[a|0]<24){break a}b:{if(!w[a+3|0]){b=16;break b}b=15;if(w[a+3|0]!=3){break a}}t[a+3|0]=b}}function Jo(a,b,c){var d=0;b=b-a|0;if((b|0)>=1){while(1){t[a|0]=w[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function x$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return kb[a|0](h|b,c,d,e,b|f,g)|0}function oga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;if(b>>>0>=250){ho(9396);L()}d=c+8|0;Db(d,a,b);er(d);gb=c+16|0}function dT(a){var b=0,c=0,d=0;b=a+68|0;c=w[b+1|0]<<8;if(!(!(w[b|0]|c)|(c|w[b|0])>>>0>127)){d=!sd(a,14772,17)}return d}function Rma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}gb=b+16|0;return c|0}function Ne(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function DY(a){var b=0,c=0;a:{if(sd(a,28564,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}c=t[a+47|0]>-1}return c}function rc(a,b){var c=0;Dm(a);v[a+4>>2]=0;v[a>>2]=54900;c=a;a=Cd(Ab(b)+1|0);v[c+4>>2]=a;if(a){hc(a,Jb(b),Ab(b)+1|0)}}function iga(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=Zz(a),v[d>>2]=e;yo(c);gb=b+16|0;return v[c>>2]}function Uv(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){bc(a,c,v[b>>2]);return}b=b+8|0;if(!cd(b)){Vd(a,b);return}Ud(a)}function to(a){var b=0;a:{while(1){if(w[b+49600|0]==(a|0)){break a}b=b+1|0;if((b|0)!=45){continue}break}b=0}return b}function kV(a){var b=0,c=0;b=gb-16|0;gb=b;c=a+512|0;while(1){Jf(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}gb=b+16|0}function aV(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;jb=b;return a}function JF(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;Jp(a);v[a>>2]=27812;c=dc(a);Ip(c);v[c>>2]=27944;gb=b+16|0;return a|0}function wI(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function sr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Bi(e,a,d);HW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function nz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Eg(e,a,d);HW(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function sB(a,b,c){a:{v[22708]=0;Oc(b,B(c,28),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ks(a,b,c){a:{v[22708]=0;Oc(b,B(c,36),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function km(a,b,c){a:{v[22708]=0;Oc(b,B(c,12),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function hY(a,b,c){a:{v[22708]=0;Oc(b,B(c,48),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fr(a,b,c){if(v[b>>2]<=(Ib(w[a|0]|w[a+1|0]<<8)|0)){a=(Ib(w[a|0]|w[a+1|0]<<8)|0)<=v[c>>2]}else{a=0}return a}function aE(a,b,c){a:{v[22708]=0;Oc(b,B(c,20),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function _z(a,b,c){a:{v[22708]=0;Oc(b,B(c,52),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Yk(a,b){var c=0;c=b+4|0;ol(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),dc(b));v[b>>2]=v[b+4>>2]}function Uh(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function RY(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Mda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=ch(C(c*C(255))),t[d|0]=e;St(a)}}function qS(a){var b=0,c=0;if(v[a>>2]){$l(a);yw(wb(a),v[a>>2],Og(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function fM(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function cO(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=Yz(d,a);wb(a);xq(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0}function XV(a){var b=0,c=0;if(v[a>>2]){Fg(a);ow(wb(a),v[a>>2],pe(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function QH(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!Ie(ZH(c,b),-1)){break a}v[a>>2]=0}return a|0}function MP(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function Hl(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function HC(a,b,c){a:{v[22708]=0;Oc(b,B(c,6),1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Cv(a){var b=0,c=0;if(v[a>>2]){zr(a);$k(wb(a),v[a>>2],dg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function CN(a){var b=0,c=0;if(v[a>>2]){Fg(a);ai(wb(a),v[a>>2],pe(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function BN(a){var b=0,c=0;if(v[a>>2]){HN(a);HC(wb(a),v[a>>2],Xj(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function vW(a,b){a:{v[22708]=0;Oc(a,B(b,33),1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function vD(a,b){a:{v[22708]=0;Oc(a,B(b,28),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ce(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=1;t[b+14|0]=120;a=Hv(a,b+15|0,b+14|0);gb=b+16|0;return a|0}function Wu(a,b){a:{v[22708]=0;Oc(a,B(b,56),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function UF(a,b){a:{v[22708]=0;Oc(a,B(b,24),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Su(a,b){a:{v[22708]=0;Oc(a,B(b,12),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function RJ(a,b){a:{v[22708]=0;Oc(a,B(b,52),4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function PN(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function PI(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function KM(a,b,c){a:{v[22708]=0;Oc(b,c<<11,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Dy(a,b){a:{v[22708]=0;Oc(a,B(b,24),8);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function zn(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function yw(a,b,c){a:{v[22708]=0;Oc(b,c<<1,2);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function wu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=qQ(d);b=b+1|0}EA(a,b,c,d)}function tu(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function ow(a,b,c){a:{v[22708]=0;Oc(b,c<<2,2);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function nV(a,b,c){a:{v[22708]=0;Oc(b,c<<5,8);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fE(a,b,c){a:{v[22708]=0;Oc(b,c<<1,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ai(a,b,c){a:{v[22708]=0;Oc(b,c<<2,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Xn(a,b,c){a:{v[22708]=0;Oc(b,c<<4,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Xk(a,b,c){a:{v[22708]=0;Oc(b,c<<5,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function OA(a,b,c){a:{v[22708]=0;Oc(b,c<<3,8);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Nh(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function N4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Lx(b);v[a+36>>2]=b;c=a,d=Vn(b),t[c+44|0]=d}function Mr(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){c=Ib(w[b+8|0]|w[b+9|0]<<8)}gb=b+16|0;return c|0}function LQ(a,b){a:{v[22708]=0;Oc(a,B(b,7),1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function K4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Hx(b);v[a+36>>2]=b;c=a,d=Vn(b),t[c+44|0]=d}function GC(a,b,c){a:{v[22708]=0;Oc(b,c<<2,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function pS(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Gb(c+8|0,c);gb=c+16|0;return a}function nK(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=yO(a),v[d>>2]=e;yo(c);gb=b+16|0;return v[c>>2]}function dba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,9759);rc(a,c);vb(c);v[a>>2]=54860;gb=b+16|0;return a|0}function Sg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!wj(v[a+4>>2],v[b+4>>2])}function Paa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,5324);rc(a,c);vb(c);v[a>>2]=54880;gb=b+16|0;return a|0}function Jv(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Rd(c+12|0,0,15);gb=c+16|0;return w[c+12|0]}function Df(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function yS(a){var b=0,c=0;b=a+68|0;a=0;while(1){c=yf(b,a);a=a+1|0;v[c>>2]=a<<11;if((a|0)!=9){continue}break}}function vf(a){a=a|0;var b=0;b=v[19556];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19559];bu(a+8|0);oh(a+60|0);return a|0}function uK(a,b){a:{v[22708]=0;Oc(a,b<<4,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function r9(a,b){a=a|0;b=b|0;if(a){b=kb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=ie(b);break a}b=ie(18720)}v[a>>2]=b}}function qC(a,b){a:{v[22708]=0;Oc(a,b<<2,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function jO(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function eP(a,b){a:{v[22708]=0;Oc(a,b<<3,4);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function HY(a,b){a:{v[22708]=0;Oc(a,b<<1,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function EB(a,b){a:{v[22708]=0;Oc(a,b<<5,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function DB(a,b){a:{v[22708]=0;Oc(a,b<<4,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Cq(a){a=a|0;var b=0;b=v[19511];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19514];bu(a+4|0);oh(a+56|0);return a|0}function CF(a,b){a:{v[22708]=0;Oc(a,b<<3,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function BB(a,b){a:{v[22708]=0;Oc(a,b<<8,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function $S(a,b){var c=0;c=v[a+4>>2]+b|0;v[a+4>>2]=c&31;v[a>>2]=v[a>>2]+(((b|0)>=0?c>>>5|0:(c-31|0)/32|0)<<2)}function pC(a){var b=0,c=0;c=a;b=v[a+8>>2];a=v[a+4>>2];if((b|0)!=(a|0)){v[c+8>>2]=(((b-a|0)-4>>>2^-1)<<2)+b}}function gW(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;if((Zl(a)|0)!=65535){SD(a,c+14|0)}gb=c+16|0}function _H(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return Lg(t[b|0])}function YG(a,b,c,d,e){b=pj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function VG(a,b,c,d,e){b=oj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function UR(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+22>>1]<<4|x[b+20>>1]>>>6)&65535)+35360|0]>>>x[a+68>>1]}function No(a,b){a=a|0;b=b|0;if(tc(a)>>>0>b>>>0){a=me(v[a+24>>2]+484344|0,x[fj(a,b)>>1])}else{a=0}return a|0}function EN(a){a=a|0;var b=0;b=v[v[a>>2]-12>>2]+a|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;return a|0}function $k(a,b,c){a:{v[22708]=0;Oc(b,c,1);a=v[22708];v[22708]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function xV(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function rna(a,b){a=a|0;b=b|0;if(!qW(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function gJ(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function fX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){ZW(c+52|0);vb(c+40|0);Lc(c+16|0);Lc(c+4|0);Xb(c)}}}function dj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!ot(a,b)){b=ot(c,a)?c:a}gb=d+16|0;return b|0}function Yx(a,b){var c=0;if(b>>>0<=9999){return Xx(a,b)}c=a;a=(b>>>0)/1e4|0;return vj(Xx(c,a),b-B(a,1e4)|0)}function Th(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Cc(c,(b>>31&a)+b|0)>>2]}function L1(){var a=0;if(mp()>>>0<=29){Sc();L()}a=xG(ix(465840),30);v[116460]=a;v[116461]=a;v[116462]=a+120}function Af(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!sv(a,b)){b=sv(c,a)?c:a}gb=d+16|0;return b|0}function yo(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=zb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function ry(a,b){var c=0;c=(B(B(oy(a),py(a)),125)>>>0)/(nJ(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function nJ(a){var b=0;b=v[(w[a+2|0]&12)+61712>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function lw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function ena(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(dk(a,b+8|0)){c=QV(b+8|0)}gb=b+16|0;return c|0}function Ypa(a,b){a=a|0;b=b|0;var c=0;b=gb-80|0;gb=b;c=-1;if(zY(a,b+8|0)){c=yY(b+8|0)}gb=b+80|0;return c|0}function Xt(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=251;t[b+14|0]=255;a=Hv(a,b+15|0,b+14|0);gb=b+16|0;return a}function yY(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179468868&(w[a+4|0]-1&255)>>>0<10}function tw(a,b){a=a|0;b=b|0;if((a&4088)>>>0>=520){b=sw(0-sqa(b^1230262859,25)|0,4)^1247037516}return b|0}function n$(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;if(dG(a,b+8|0)){c=cG(b+8|0)}gb=b+32|0;return c|0}function lz(a,b){mc(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Go(a+24|0);Kb(a+36|0);v[a+48>>2]=b;return a}function fv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;vn(c+8|0,a);v[c+4>>2]=v[c+8>>2];gr(c+4|0,b);gb=c+16|0}function fZ(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(dk(a,b+8|0)){c=AD(b+8|0)}gb=b+16|0;return c|0}function eL(a){var b=0;while(1){if(!v[(b<<2)+a>>2]){return b}b=b+1|0;if((b|0)!=4){continue}break}return 4}function d6(a){a=a|0;a=gb-16|0;gb=a;if(fb(a+12|0,4)|0){Rs(v[115189],9951);L()}gb=a+16|0;return v[a+12>>2]}function Yp(){var a=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)!=1){return v[19882]}V(0)|0;O()|0;Bb();L()}function UH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function PP(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=0-(d&65535)&65535;b=b+1|0}vA(a,b,c,d&65535)}function Ng(a){var b=0,c=0;b=gb-16|0;gb=b;if(Dp(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}gb=b+16|0;return c}function Es(){var a=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)!=1){return v[20464]}V(0)|0;O()|0;Bb();L()}function EG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function Ds(){var a=0;v[22708]=0;a=v[22708];v[22708]=0;if((a|0)!=1){return v[20076]}V(0)|0;O()|0;Bb();L()}function D_(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(dk(a,b+8|0)){c=sF(b+8|0)}gb=b+16|0;return c|0}function tO(a,b){v[22708]=0;Oc(a,b<<2,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function jq(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=be(b),v[d+12>>2]=e;Ge(a,c+12|0);gb=c+16|0;return a}function hr(a){if(a>=4294967295){return-1}if(a<=0){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function Pg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];jb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function xc(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];gb=c+16|0}function l_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Rk(d,a,22);_r(d,b);gb=c+16|0;return a|0}function jZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Rk(d,a,20);_r(d,b);gb=c+16|0;return a|0}function UP(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function PO(a,b){var c=0;c=gb-16|0;gb=c;a=Yz(c,a);xq(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;$b(a);gb=c+16|0}function Nw(a,b,c){var d=0;d=gb-16|0;gb=d;a=Ud(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;gb=d+16|0}function Mz(a,b){var c=0;c=gb-16|0;gb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];gb=c+16|0}function BK(a,b){var c=0;c=y[b>>2]>y[a>>2];a=v[a+4>>2];b=v[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function KB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=v[b>>2]+c|0;if((d|0)==-1){d=yb(b)-c|0}vd(a,e,d)}function Dq(a,b,c){a=uk(a+1074376|0)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function Bx(a){a=a|0;var b=0;b=v[22614];if(a){v[22614]=(a|0)==-1?460800:a}return((b|0)==460800?-1:b)|0}function vh(a){var b=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Xo(a+8|0);gb=b+16|0;return a}function py(a){var b=0;b=w[a+1|0];return w[(B(b>>>3&1,45)+B(b>>>1&3,15)+(w[a+2|0]>>>4)|0)+61713|0]<<1}function tT(a){v[22708]=0;Oc(a,48,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function q_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;YE(d,a);_r(d,b);gb=c+16|0;return a|0}function iv(a){v[22708]=0;Oc(a,20,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function iT(a){tB(a+140|0);xb(a+120|0);xb(a+100|0);xb(a+80|0);xb(a+60|0);xb(a+40|0);xb(a+20|0);xb(a)}function hm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function ZN(a){v[22708]=0;Oc(a,28,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function Tv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function Ii(a){var b=C(0),c=C(0);a:{b=z[a>>2];if(!(b<C(0))){c=C(1);if(!(b>C(1))){break a}}z[a>>2]=c}}function HA(a){v[22708]=0;Oc(a,40,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function $W(a){v[22708]=0;Oc(a,32,4);a=v[22708];v[22708]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function xE(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}jb=a;return b}function rw(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function pda(a,b,c){a=a|0;b=b|0;c=c|0;a=ok(a);if(!a){return 0}return kb[v[v[a>>2]+100>>2]](a,b,c)|0}function NR(a,b,c){if((b|0)!=(c|0)){while(1){LR(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Ld(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=54976;v[b+8>>2]=55080;Mu(a,b+12|0,b+8|0);gb=b+16|0}function xma(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(hD(a,b)){c=sV(b)}gb=b+16|0;return c|0}function p9(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Jb(b);if(c){kb[c|0](b,v[a+8>>2]);return}Kt(b,a)}function lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;kb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Zp(d,a);GG(a,c)}function h_(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=JE(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Zm(a){a=a|0;var b=0;Ol(a);b=Sq(v[a>>2],jj(a));v[a+20>>2]=b;if(!b){return 0}return aj(a)|0}function D1(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[Yp()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function qr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;lv(a+236|0,128,c+14|0);gb=c+16|0}function nI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ab(a);if(d>>>0<b>>>0){ws(a,b-d|0,c);return}sE(a,b)}function gi(a,b){var c=0;c=gb-16|0;gb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];gb=c+16|0}function bga(a,b){a=a|0;b=b|0;ct(a);v[a>>2]=77316;Kb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function MQ(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function Ag(a){a=a|0;var b=0,c=0;while(1){c=b&65535;du(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function xe(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];kw(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function tR(a,b){var c=0;c=gb-16|0;gb=c;a=v[yc(c+8|0,eR(a,b,Yd(a),fc(a)))>>2];gb=c+16|0;return a}function nT(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}jb=a;return b}function hV(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}v[a>>2]=b}}function Zo(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];VV(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function Uq(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=0;Jo(a,a+32|0,b+15|0);gb=b+16|0;return a|0}function M5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function K5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function I5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function G5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function EX(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];DX(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function E5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function C5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function zfa(a,b){a=a|0;b=b|0;Li(a);Li(a);a:{if(b>>>0>=60){Rb(a,4);break a}Li(a)}return Li(a)|0}function vq(a,b,c){a=v[a>>2]+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function u8(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[Xi(b+8|0,LB(sf(12),a))>>2];gb=b+16|0;return a|0}function qN(a,b){b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Xo(a+8|0);gb=b+16|0;return a}function p5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function oZ(a,b){a=a|0;b=b|0;if(!Xv(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function nda(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;Vd(b,v[a+20>>2]+4|0);GM(a,ne(b+8|0,b),0);gb=b+16|0}function lca(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=wf(v[a+16>>2]),v[b+4256>>2]=c;dM(a);cM(a)}function i_(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Mg(a,b+8|0)){c=w[b+8|0]}gb=b+16|0;return c|0}function cJ(a){var b=0;b=+((a&2097151)>>>0);return C(ji(+C((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function Yna(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=is(a,b+8|0);gb=b+16|0;return C(a?z[b+8>>2]:C(0))}function Lda(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=wf(v[a+16>>2]),v[b+4232>>2]=c;St(a);UM(a)}function I$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Sg(a,v[b+8>>2],f)){cx(b,c,d,e)}}function sY(a,b){return(Mb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Mb((B(a&15,b)>>>0)/15|0,1,15))&255}function sD(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=rp(c,c+8|0);gb=c+16|0;return a}function VX(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=bk(c,c+8|0);gb=c+16|0;return a}function U6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function Oo(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Bh(Dk(b)*+(c>>>0)),v[d+24>>2]=e}function DA(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+27040>>2]>a>>>0)|0)+1|0}function vi(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+(Ab(a)<<2)|0)>>2];gb=b+16|0;return a}function q$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb[a|0](b,c,d,e)|0;ma(jb|0);return a|0}function nd(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Al(d,a+24|0,b);a=Cb(d);gb=c+16|0;return a}function XT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Ff(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=a;a=Tb(c,b);Dc(d,a);vb(a);gb=c+16|0}function E4(a,b,c){a=a|0;b=b|0;c=c|0;if(Ie(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function CW(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1279544644&w[a+4|0]<32}function zT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function x5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return kb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function rE(a){var b=0;b=gb-16|0;gb=b;a=Mg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function oI(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function lI(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function f8(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;qw(d,b,20);Zr(a,d);gb=c+16|0}function Sk(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function FG(a){a=a|0;var b=0;v[a>>2]=83676;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Xb(b)}return a|0}function Ema(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;c=a;a=Kh(b+8|0);PV(c,a,0,0);xb(a);gb=b+32|0}function Dn(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function wr(a,b){var c=0;c=Ab(a);if((c|0)==(Ab(b)|0)){a=Uo(Jb(a),Jb(b),c)}else{a=1}return!a}function tA(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function pf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=hL(a,b);gb=c+16|0;return(d?b:a)|0}function pd(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=ot(b,a);gb=c+16|0;return(d?b:a)|0}function lba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;IL(a,b,c,d,e,0,0,f,g)}function hma(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=kj(a,b+8|0);gb=b+16|0;return+(a?A[b+8>>3]:0)}function bS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=mi(e,a,d);wb(a);jv(b,c,d+4|0);$b(d);gb=e+16|0}function ac(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=hL(b,a);gb=c+16|0;return(d?b:a)|0}function ZL(a,b){var c=0;c=v[a+12>>2];if((c|0)>=1){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function YV(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=Eg(e,a,d);wb(a);jv(b,c,d+4|0);$b(d);gb=e+16|0}function YO(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function Tk(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=rw(b,a);gb=c+16|0;return(d?b:a)|0}function Pr(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=BK(b,a);gb=c+16|0;return(d?b:a)|0}function Pc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Fn(b,a);gb=c+16|0;return(d?b:a)|0}function Pb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return kb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function Mc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=yn(a,b);gb=c+16|0;return(d?b:a)|0}function Ly(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=BK(a,b);gb=c+16|0;return(d?b:a)|0}function Le(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Fn(a,b);gb=c+16|0;return(d?b:a)|0}function If(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=ot(a,b);gb=c+16|0;return(d?b:a)|0}function Fb(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=yn(b,a);gb=c+16|0;return(d?b:a)|0}function CL(a,b,c){a=a|0;b=b|0;c=c|0;Ny(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=54796;return a|0}function AD(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==810369604&w[a+4|0]<4}function xz(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+18824>>2]}else{b=6884}Tb(a,b)}function woa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1580);Dc(c,a);vb(a);gb=b+16|0}
function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ok(a);if(a){kb[v[v[a>>2]+76>>2]](a,b,c,d)}}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ok(a);if(a){kb[v[v[a>>2]+84>>2]](a,b,c,d)}}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ok(a);if(a){kb[v[v[a>>2]+88>>2]](a,b,c,d)}}function gh(a){var b=0;b=a+44|0;Sx(b);if(v[b>>2]){gX(b);Xn(wb(b),v[b>>2],xi(b))}gc(a+32|0)}function YN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[fc(a)+4|0]){Hb(b+16|0)}if(b){ZN(b)}}}function Wk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function VF(a,b){var c=0,d=0;Ip(a);v[a>>2]=27616;v[a+4>>2]=v[b>>2];c=a,d=yb(b),v[c+8>>2]=d}function Oj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;FS(a,b,c);gb=d+16|0;return a|0}function Nv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Ke(c,1,a);XE(c,b);gb=c+16|0;return a|0}function KW(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function Jr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Hr(c,1,a);XE(c,b);gb=c+16|0;return a|0}function JH(a){var b=0;b=v[a>>2];if(b){if(!Ie(_H(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function IH(a){var b=0;b=v[a>>2];if(b){if(!Ie(UH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function Hma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13887);Dc(c,a);vb(a);gb=b+16|0}function Fea(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){Hk(a,b);return}YM(a,b,c)}function Dc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];MA(b)}function Aoa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13284);Dc(c,a);vb(a);gb=b+16|0}function sqa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function spa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1040);Dc(c,a);vb(a);gb=b+16|0}function sZ(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1467);Dc(c,a);vb(a);gb=b+16|0}
function r$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;kb[a|0](b,c,d,e,f,g)}function o_(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;vw(d,b);Zr(a,d);gb=c+16|0}function kt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function kla(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1274);Dc(c,a);vb(a);gb=b+16|0}function iU(a){var b=0;b=443250/+(a>>>0)*1e4;if(b<4294967296&b>=0){return~~b>>>0}return 0}function _ma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1983);Dc(c,a);vb(a);gb=b+16|0}function Zma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1031);Dc(c,a);vb(a);gb=b+16|0}function Wx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;a=dt(a,b,c,d);gb=e+16|0;return a}function W$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13914);Dc(c,a);vb(a);gb=b+16|0}function Oy(a){a=a|0;var b=0;v[a>>2]=54900;b=v[a+4>>2];if(b){Xb(b);v[a+4>>2]=0}return a|0}function Ima(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1116);Dc(c,a);vb(a);gb=b+16|0}function wda(a,b){a=a|0;b=b|0;a=ok(a);if(!a){return 1}return kb[v[v[a>>2]+68>>2]](a,b)|0}function oP(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|32;v[a+852>>2]=v[a+852>>2]+b}}function lv(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function jN(a,b,c){if(b){while(1){z[a>>2]=z[c>>2];a=a+4|0;b=b-1|0;if(b){continue}break}}}function h5(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){Gx(a,c);return}Tb(a,5018)}function ge(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;bH(a,d+12|0,c);gb=d+16|0;return a}function ef(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+Ab(a)|0)>>2];gb=b+16|0;return a}function b0(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1628);Dc(c,a);vb(a);gb=b+16|0}function Vw(){var a=0,b=0;a=gb-16|0;gb=a;b=ns(a+8|0,mc(sf(12)));gb=a+16|0;return v[b>>2]}function Sd(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;Or(c,a);gb=b+16|0;return v[c>>2]}function Ci(a){if(mK(a)){a=ba(4)|0;v[a>>2]=0;Dm(a);v[a>>2]=79404;ia(a|0,79440,1929);L()}}function Be(a){var b=0;b=gb-16|0;gb=b;a=Mg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)&255}function yy(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function gn(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function bj(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function bh(a,b,c){var d=0;d=gb-16|0;gb=d;if(!eT(a,b)){b=eT(c,a)?c:a}gb=d+16|0;return b}function au(a,b){if(!(v[a+480180>>2]==8?t[b+851|0]&1:0)){Nz(a,b,0);Nz(a,b,1);Nz(a,b,2)}}function NT(a,b,c){var d=0;d=v[b>>2];if((c|0)==-1){c=br(b)}v[a>>2]=d;v[a+4>>2]=(c<<2)+d}function Ln(a){var b=0;b=Pw(a+4|0);if((b|0)==-1){kb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function I_(a){a=a|0;var b=0;b=v[a+4>>2];return(kb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function HI(a){var b=0;b=nqa(v[a>>2]-1|0);if(!b){a=nqa(v[a+4>>2]);b=a?a+32|0:0}return b}function pH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a=qH(a,8351,b);gb=c+16|0;return a}function ol(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>=1){hc(c,a,b)}}function oi(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function hG(a){var b=0;b=a+48|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function gH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;bH(a,c+12|0,b);gb=c+16|0;return a}function cl(a){var b=0;b=a+36|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function cB(a,b){Vu(a,b);Dc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function _e(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=v[hx(b,a)+8>>2],d=0,t[c|0]=d;gb=b+16|0}function ZO(a){Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);v[a+60>>2]=0;return a}function Tb(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;ys(a,b,Of(b));gb=c+16|0;return a|0}function QR(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Ef(a){var b=0;b=a+24|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function DE(a){var b=0,c=0;b=gb-16|0;gb=b;c=Xp(a);t[b+15|0]=0;Jo(a,c,b+15|0);gb=b+16|0}function DD(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+28512|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function xm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function w0(a){a=a|0;a=465480;while(1){a=vb(a-12|0);if((a|0)!=465456){continue}break}}function t0(a){a=a|0;a=465512;while(1){a=Ic(a-12|0);if((a|0)!=465488){continue}break}}function q6(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function o6(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function Xu(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function N2(a,b){a=a|0;b=b|0;var c=0;c=Qx(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function Kt(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;v[b>>2]=a;UI(14923,b);lt(90144);gb=b+16|0}function J0(a){a=a|0;a=464664;while(1){a=vb(a-12|0);if((a|0)!=464496){continue}break}}function G0(a){a=a|0;a=464840;while(1){a=Ic(a-12|0);if((a|0)!=464672){continue}break}}function D0(a){a=a|0;a=465136;while(1){a=vb(a-12|0);if((a|0)!=464848){continue}break}}function A0(a){a=a|0;a=465440;while(1){a=Ic(a-12|0);if((a|0)!=465152){continue}break}}function xG(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=Xz(b)}return a}function p1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Es()+((b&255)<<2)>>2]}return b<<24>>24}function n1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Ds()+((b&255)<<2)>>2]}return b<<24>>24}function mf(a){a=a|0;var b=0;b=v[a>>2];return(kb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function hi(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;bj(a)}function fba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zL(a,b,c,d,0,0,0,0,e)|0}function _ja(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;ys(a,b,12);gb=c+16|0;return a|0}function Xi(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;xq(a,c+12|0);gb=c+16|0;return a}function Vca(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function VT(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Nda(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function Gg(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,a)>>2];gb=b+16|0;return a|0}function u$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kb[a|0](b,c,d)|0;ma(jb|0);return a|0}function Xf(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function sT(a,b,c,d,e,f){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e);yc(a+16|0,f)}function sC(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,v[a>>2])>>2];gb=b+16|0;return a}function fj(a,b){a=a|0;b=b|0;if(tc(a)>>>0<=b>>>0){Zx();L()}return v[a>>2]+(b<<1)|0}function dJ(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function cX(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;_W(c,a);gb=b+16|0;return v[c>>2]}function Ti(a,b){a=a|0;b=b|0;if(b>>>0>1073741823){rd(8445);L()}return Nc(b<<2,4)|0}function LP(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function Ah(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;xq(a,b+12|0);gb=b+16|0;return a}function lY(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function cw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function Np(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function Jw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,36);return a}function Fw(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){Jn(a)}}function $o(a,b){a=hc(a,b,34);u[a+34>>1]=x[b+34>>1];hc(a+36|0,b+36|0,68);return a}function zd(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a))>>2];gb=b+16|0;return a}function uD(a){a=a+4|0;return Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function pr(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,sC(a))>>2];gb=b+16|0;return a}function mi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function fs(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function cq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function _j(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;js(a+8|0,b+8|0)}function UI(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;TI(90144,a,b,0,0);gb=c+16|0}function FF(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c);js(b+12|0,c+12|0);qi(b+32|0,c+32|0)}function Eh(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Dh(a))>>2];gb=b+16|0;return a}function Eg(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function Dh(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,fc(a))>>2];gb=b+16|0;return a}function Cr(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function AB(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function $O(a){a=a|0;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;DE(a+9|0);return a|0}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[a|0](b,c,d,e,f)}function oT(a){if((w[a+14|0]-49&255)>>>0<=3){a=sd(a,12661,14)}else{a=1}return!a}function h4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-16|0;gb=b;hH(a,c,d);gb=b+16|0}function eg(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){kb[v[v[b>>2]+4>>2]](b)}}}function LR(a,b){var c=0;c=a;a=v[a>>2];v[c>>2]=a<<8^v[((a>>>24^b)<<2)+35500>>2]}function FJ(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function $ca(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[wb(a)>>2]){PO(a,b);return}OO(a,b)}function z6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return rJ(a-88|0,b,c,d,e)|0}function w$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kb[a|0](b,c,d,e)|0}function kP(a,b){a=a|0;b=b|0;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[b>>2];return a|0}function _o(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function Yfa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[wb(a)>>2]){PO(a,b);return}OO(a,b)}function Qba(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function Hu(a,b){return Bh(Dk((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function zA(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function xj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Xb(b)}function uca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function qo(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function oF(a,b){var c=0;c=gb-16|0;gb=c;b=gm(c+8|0,b);XF(b,a);Kd(b);gb=c+16|0}function nca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function gz(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function gm(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){Jn(b)}return a}function _ba(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function YF(a,b){var c=0;c=gb-16|0;gb=c;b=Xf(c+8|0,b);XF(b,a);Kd(b);gb=c+16|0}function Xy(a){a=a|0;v[a>>2]=50952;Lc(a+4276|0);Lc(a+4264|0);jf(a);return a|0}function S$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Sg(a,v[b+8>>2],0)){ex(b,c,d)}}function RP(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Al(d,a,b);er(d);gb=c+16|0}function Oca(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function JB(a){return(+y[a>>2]+ +v[a+4>>2]*4294967296)*2.3283064365386963e-10}function Il(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;Db(d,a,b);er(d);gb=c+16|0}function Hba(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function Cca(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function C4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,5054);return}Gx(a,c)}function Aba(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function A4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,4984);return}Gx(a,c)}function $U(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=c+8|0;vw(d,b);IW(a,d);gb=c+16|0}function $Q(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function vj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return et(et(c,a),b-B(a,100)|0)}function uH(){a:{if(t[463960]&1){break a}if(!Qd(463960)){break a}Pd(463960)}}function oL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){fo(c+120|0);Xb(c)}}}function eH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function dA(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:18720)|0}function cH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function bn(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function ar(a){var b=0;b=gb-16|0;gb=b;a=v[rT(b+8|0,a)>>2];gb=b+16|0;return a}function Yl(a){var b=0;b=gb-16|0;gb=b;v[b+8>>2]=a;gb=b+16|0;return v[b+8>>2]}function Td(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Rb(b,c);Sw(a,b,d,c)}function PG(a,b){var c=0,d=0;Fe(a,be(b));b=v[fc(b)>>2];c=fc(a),d=b,v[c>>2]=d}function HW(a,b,c,d){a=c-b|0;if((a|0)>=1){hc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function Em(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=sv(b,a);gb=c+16|0;return d?b:a}function Ck(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function $y(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=sv(a,b);gb=c+16|0;return d?b:a}function tz(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function sz(a,b){a=a|0;b=b|0;return(b>>>0<=44?t[v[a+84>>2]+b|0]:63)<<24>>24}function qw(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12820,6210,85,7806);L()}}function qs(a,b){a=a|0;b=b|0;a=v[a>>2];return kb[v[v[a>>2]+32>>2]](a,0,b)|0}function kT(a,b){CU(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Ws(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function UV(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Rk(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){aa(12820,6210,48,7806);L()}}function Qu(a,b,c){var d=0;d=gb-16|0;gb=d;yc(d+8|0,Kn(a,b,Yl(c)));gb=d+16|0}function MH(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function JR(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);FR(a,b,0,0,b+-1,0)}function Bi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function y1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Es()+(b<<2)>>2]}return b|0}function w1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Ds()+(b<<2)>>2]}return b|0}function sh(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function po(a,b){a=v[a+4316>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function pg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function me(a,b){a=a|0;b=b|0;if(am(a,b)){a=ii(af(a,b))}else{a=0}return a|0}function jv(a,b,c){b=b-a|0;if((b|0)>=1){hc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function hx(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function et(a,b){b=x[(b<<1)+74096>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function ZQ(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;$S(a,c)}function NY(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function yV(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function tn(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+48>>2]](a,b,c)|0}function noa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=wp(a,b),v[d>>2]=e}function koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=mw(a,b),u[d>>1]=e}function jl(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+12>>2]](a,b,c)|0}function jda(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function hF(a){return(v[a+88>>2]&2050)==2?(w[v[a+104>>2]+34|0]&8)>>>3|0:0}function aR(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function Yz(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function Xl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function T_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);Xn(b+8|0,a,1);gb=b+16|0}function Rc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function N_(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);Xk(b+8|0,a,1);gb=b+16|0}function Lea(a,b,c){a=a|0;b=b|0;c=c|0;if(Ab(b)>>>0>c>>>0){uu(b,c)}Dc(a,b)}function B5(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+32>>2]](a,b,c)|0}function uz(a,b){a=a|0;b=b|0;return(b>>>0<=15?w[v[a+88>>2]+b|0]!=63:0)|0}function pq(a,b){a=a|0;b=b|0;return(b>>>0<=44?w[v[a+84>>2]+b|0]!=63:0)|0}function mE(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function gI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;sh(a,-1,-1)}function IY(a){return Yb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function uc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Of(b),v[c+4>>2]=d;return a}function nh(a,b,c){return(c|0)>=0?(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function mx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function le(a,b){gm(a,b);v[a+8>>2]=v[b+8>>2];gm(a+12|0,b+12|0);return a}function ey(a){return((ph(a)+(ph(a)<<8)|0)+(ph(a)<<16)|0)+(ph(a)<<24)|0}function ZR(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Yf(a){var b=0;b=a;if(v[b>>2]){Od(b);Dy(v[b>>2],gv(b))}return a}function Vc(a,b){YF(a,b);v[a+8>>2]=v[b+8>>2];YF(a+12|0,b+12|0);return a}function RR(a){if(a>>>0<=8){return w[a+35488|0]}return w[a+35479|0]|256}function HL(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function EV(a){v[a+8>>2]=0;v[a>>2]=0;v[a+4>>2]=40;u[a+12>>1]=0;return a}function AJ(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function xo(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function qF(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function gl(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function eG(a,b){if(b>>>0>357913941){rd(8445);L()}return Nc(B(b,12),4)}function cE(a,b){if(b>>>0>214748364){rd(8445);L()}return Nc(B(b,20),4)}function bx(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function a5(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){ua();L()}}function VO(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){kn(c);Xb(c)}}}function IC(a,b){if(b){IC(a,v[b>>2]);IC(a,v[b+4>>2]);Fk(b+16|0);$W(b)}}function Fz(a,b){if(b){Fz(a,v[b>>2]);Fz(a,v[b+4>>2]);Hb(b+16|0);ZN(b)}}function Cz(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function Cc(a,b){if(Nb(a)>>>0<=b>>>0){Zx();L()}return v[a>>2]+(b<<2)|0}function $h(a){a=a|0;a=uB(a)?a+172|0:a+156|0;return w[a|0]|w[a+1|0]<<8}function UO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function Qj(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function NW(a,b){if(b>>>0>715827882){rd(8445);L()}return Nc(B(b,6),1)}function Lh(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;$f(a,b);gb=c+16|0}function ID(a,b){var c=0;c=gb-16|0;gb=c;bc(a,v[b>>2],oc(b));gb=c+16|0}function G$(a){a=a|0;if(!a){return 0}return(fx(a,89644,89788)|0)!=0|0}function EC(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;jR(a,b);gb=c+16|0}function C1(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;NH(a,b);gb=c+16|0}function zs(a,b,c,d,e){b=Fa(a|0,b|0,c|0,d|0,e|0)|0;jb=O()|0;return b}function wG(a,b,c){a:{if((a|0)==(b|0)){t[a+120|0]=0;break a}tO(b,c)}}function v$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kb[a|0](b,c,d)|0}function sN(a){if(a>>>0>=82595525){rd(8445);L()}return Nc(B(a,52),4)}function s2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gg(a,f)}function rm(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function pW(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];js(a+8|0,b+8|0)}function oz(a,b,c){b=b-a|0;if(b){zh(c,a,b)}return B((b|0)/6|0,6)+c|0}function kC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fc(a);if(b){iv(b)}}}function fB(a,b){mc(a);Kb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function aF(a,b){if(b>>>0>2147483647){rd(8445);L()}return Nc(b<<1,2)}function _F(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(gc(c))}}}function SB(a,b){xc(a,b);xc(a+4|0,b+4|0);xc(wb(a),wb(b));wb(a);wb(b)}function PE(a,b){if(b>>>0>1073741823){rd(8445);L()}return Nc(b<<2,2)}function Gz(a){var b=0;WS(a);b=v[a>>2];if(b){ai(v[a+16>>2],b,Bk(a))}}function F1(a){a=a|0;var b=0;b=v[116064]+1|0;v[116064]=b;v[a+4>>2]=b}function rW(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function pT(a,b,c,d,e){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e)}function oG(a,b,c,d,e,f,g){return Ma(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function nP(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|32}function nC(a,b){if(b){nC(a,v[b>>2]);nC(a,v[b+4>>2]);Xn(fc(a),b,1)}}function loa(a,b){a=a|0;b=b|0;Oj(a,zb(v[b>>2]),zb(v[b>>2])+oc(b)|0)}function ky(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function c$(a){a=a|0;var b=0;b=gb-16|0;gb=b;dc(a);UF(a,1);gb=b+16|0}function _V(a){if(a>>>0>=1073741824){rd(8445);L()}return Nc(a<<2,1)}function Xz(a){if(a>>>0>=1073741824){rd(8445);L()}return Nc(a<<2,4)}function NO(a,b){var c=0;c=gb-16|0;gb=c;Hr(c,1,b);Bc(a,c);gb=c+16|0}function Ffa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fO(a,b,c,d,e)}function wl(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Xb(Yf(b))}}}function s1(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function qja(a,b){a=a|0;b=b|0;if(!v[22708]){v[22709]=b;v[22708]=a}}function jT(a,b){QB(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function jH(a,b,c){a=a|0;b=b|0;c=c|0;return $p(0,a,b,c?c:463984)|0}function eo(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function cS(a){if(a>>>0>=134217728){rd(8445);L()}return Nc(a<<5,4)}function Xc(a,b,c){a=a|0;b=b|0;c=c|0;return ad(a,B(Ki(a),b)+c|0)|0}function TW(a){if(a>>>0>1073741823){rd(8445);L()}return Nc(a<<2,1)}function PH(a){if(a>>>0>=268435456){rd(8445);L()}return Nc(a<<4,4)}function BR(a){if(a>>>0>=536870912){rd(8445);L()}return Nc(a<<3,8)}function yJ(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function wi(a,b){var c=0,d=0;c=a,d=Bx(v[b>>2]),v[c>>2]=d;return a}function wU(a){a=a+34|0;a=oqa(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function oy(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function oE(a){if(v[a>>2]){$D(a,v[a>>2]);aE(wb(a),v[a>>2],bm(a))}}function mn(a){a=a|0;return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function Oc(a,b,c){a=a|0;b=b|0;c=c|0;if(ZE(c)){Xb(a);return}Xb(a)}function MX(a){jb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function Lp(a,b){a=a|0;b=b|0;jc(a,b);Qb(a+20|0,0,1040);return a|0}function Kj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function K_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+12>>2]](a)|0}function J_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+16>>2]](a)|0}function vM(a){a=a|0;v[a>>2]=50720;Lc(a+4208|0);jf(a);return a|0}function mba(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function kM(a){a=a|0;v[a>>2]=51212;Lc(a+4256|0);jf(a);return a|0}function ju(a){vb(a+48|0);vb(a+36|0);vb(a+24|0);vb(a+12|0);vb(a)}function id(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function bM(a){a=a|0;v[a>>2]=51824;Lc(a+4208|0);jf(a);return a|0}function a0(a){a=a|0;var b=0,c=0;b=a,c=ye(),v[b>>2]=c;return a|0}function _Q(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function TM(a){a=a|0;v[a>>2]=49672;Lc(a+4208|0);jf(a);return a|0}function SX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(c)}}}function L_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function FM(a){a=a|0;v[a>>2]=49908;gc(a+4208|0);jf(a);return a|0}function Et(a,b,c){a=v[a>>2];return(a|0)>=x[b>>1]&(a|0)<=x[c>>1]}function y$(a,b){a=a|0;b=b|0;a=kb[a|0](b)|0;ma(jb|0);return a|0}function xx(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+12>>2]](a,b)|0}function wR(a){_p(a);if(v[a>>2]){lR(a);km(wb(a),v[a>>2],ug(a))}}function tB(a){gT(a);if(v[a>>2]){fT(a);sB(wb(a),v[a>>2],$i(a))}}function pn(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+28>>2]](a,b)|0}function pM(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function mg(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function mA(a){iY(a);if(v[a>>2]){uY(a);hY(wb(a),v[a>>2],ln(a))}}function lfa(a,b){a=a|0;b=b|0;a=fY(a,b);if(!a){Ev(b)}return a|0}function kA(a){BO(a);if(v[a>>2]){AO(a);_z(wb(a),v[a>>2],pk(a))}}function jm(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+24>>2]](a)|0}function fha(a,b){a=a|0;b=b|0;a=nW(a,b);if(!a){mW(b)}return a|0}function fA(a){GF(a);if(v[a>>2]){$F(a);ks(wb(a),v[a>>2],_k(a))}}function di(a){Ek(a);if(v[a>>2]){cr(a);GC(wb(a),v[a>>2],pe(a))}}function bp(a){Ek(a);if(v[a>>2]){cr(a);ow(wb(a),v[a>>2],pe(a))}}function Wi(a,b,c){a=a|0;b=b|0;c=c|0;return Kn(Yl(a),Yl(b),c)|0}function Vs(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+44>>2]](a,b)|0}function Pk(a){Ep(a);if(v[a>>2]){zw(a);fE(wb(a),v[a>>2],Og(a))}}function PV(a,b,c,d){le(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Nt(a){LM(a);if(v[a>>2]){PM(a);KM(wb(a),v[a>>2],Cl(a))}}function Lq(a){pR(a);if(v[a>>2]){dR(a);OA(wb(a),v[a>>2],tg(a))}}function Gw(a,b,c){Xf(a,b);v[a+8>>2]=0;Xf(a+12|0,c);Kd(c);Kd(b)}function Gu(a){dv(a);if(v[a>>2]){fS(a);Xk(wb(a),v[a>>2],bi(a))}}function Ex(a,b){a=a|0;b=b|0;return(Rh(a)|0)!=0|(a|32)-97>>>0<6}function z$(a,b){a=a|0;b=+b;a=kb[a|0](b)|0;ma(jb|0);return a|0}function yv(a){a=a|0;a=w[a|0];return we(a)^1|(a-49&255)>>>0<36}function uC(a,b){a=a|0;b=b|0;a=SV(a,b);if(!a){$j(b)}return a|0}function sL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function kF(a,b){a=a|0;b=b|0;a=jF(a,b);if(!a){Cw(b)}return a|0}function gj(a){$B(a);if(v[a>>2]){ow(v[a+16>>2],v[a>>2],Bk(a))}}function es(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function eh(a){$B(a);if(v[a>>2]){ai(v[a+16>>2],v[a>>2],Bk(a))}}function eE(a){$E(a);if(v[a>>2]){fE(v[a+16>>2],v[a>>2],xw(a))}}function bu(a){a=a|0;v[a>>2]=77316;vb(a+32|0);wm(a);return a|0}function bs(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function _B(a,b){a=a|0;b=b|0;a=_X(a,b);if(!a){gD(b)}return a|0}function Yb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Xw(a,b){a=a|0;b=b|0;a=PF(a,b);if(!a){Lw(b)}return a|0}function Wf(a,b){return kb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function UW(a){$B(a);if(v[a>>2]){GC(v[a+16>>2],v[a>>2],Bk(a))}}function UD(a,b){a=a|0;b=b|0;a=Sv(a,b);if(!a){Tv(b)}return a|0}function Tw(a,b){a=a|0;b=b|0;a=BF(a,b);if(!a){AF(b)}return a|0}function Qw(a,b){Xf(a,b);v[a+8>>2]=v[b+8>>2];Xf(a+12|0,b+12|0)}function Nl(a,b){a=t[lc(a+58|0,b)|0];return((a|0)>-1?a:-1)&255}function Jh(a,b){a=a|0;b=b|0;a=kj(a,b);if(!a){hm(b)}return a|0}function Ih(a){$E(a);if(v[a>>2]){yw(v[a+16>>2],v[a>>2],xw(a))}}function Hv(a,b,c){a=w[a|0];return a>>>0>=w[b|0]&a>>>0<=w[c|0]}function FC(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4896);gb=c+16|0}function Dw(a,b){oF(a,b);v[a+8>>2]=v[b+8>>2];oF(a+12|0,b+12|0)}function uy(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function r_(a,b){a=a|0;b=b|0;Qs(a,b);v[a>>2]=89300;return a|0}function ne(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function nG(a,b,c){b=Ja(1998,a|0,b|0,c|0)|0;jb=O()|0;return b}function mR(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function ina(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,qI(c,Jb(b),Ab(b)))}function i8(a,b){a=a|0;b=b|0;Qs(a,b);v[a>>2]=89352;return a|0}function gO(a){a=a|0;v[a+12>>2]=1065353216;eO(a,4);return a|0}function ft(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function b9(a,b,c){a=a|0;b=b|0;c=c|0;OT(a,0,Jk(v[b+24>>2]),c)}function Sm(a,b,c){u[a>>1]=x[b>>1];v[a+4>>2]=v[c>>2];return a}function Ri(a,b){a=a|0;b=b|0;if(Ae(a)>>>0>b>>>0){t[a+16|0]=b}}function Pha(a,b,c){a=a|0;b=b|0;c=c|0;return tv(a,b,c,1094)|0}function NS(a,b){a=a|0;b=b|0;Qs(a,b);v[a>>2]=89164;return a|0}function Mu(a,b,c){v[a>>2]=v[b>>2];v[a+4>>2]=v[c>>2];return a}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;return tv(a,b,c,1486)|0}function Gr(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function wc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function sp(a,b,c){if(!b){return 0}return mt(a,Lg(t[c|0]),b)}function qda(a){a=a|0;a=ok(a);if(a){kb[v[v[a>>2]+96>>2]](a)}}function mF(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,36);gb=c+16|0}function ioa(a,b,c){a=a|0;b=b|0;c=c|0;return tv(a,b,c,644)|0}function cz(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function _O(a){v[a>>2]=0;mc(a+4|0);Qb(a+16|0,0,144);return a}function Ss(){var a=0;a=ba(4)|0;lm(a);ia(a|0,89104,1929);L()}function QW(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,12);gb=c+16|0}function CJ(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function xB(a,b){if(b){xB(a,v[b>>2]);xB(a,v[b+4>>2]);tT(b)}}function wB(a,b){if(b){wB(a,v[b>>2]);wB(a,v[b+4>>2]);iv(b)}}function vF(a){var b=0;b=v[a+8>>2];if(b){Xk(a,b,v[a+4>>2])}}function mC(a,b){if(b){mC(a,v[b>>2]);mC(a,v[b+4>>2]);iv(b)}}function ku(a,b){if(b){ku(a,v[b>>2]);ku(a,v[b+4>>2]);iv(b)}}function k1(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function hB(a){dd(a);v[a+12>>2]=0;u[a+16>>1]=65280;return a}function cU(a){if(v[a>>2]){$T(a,v[a>>2]);Su(v[a>>2],ug(a))}}function Wr(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,1);gb=c+16|0}function Pw(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function IF(a){var b=0;b=v[a+8>>2];if(b){Xn(a,b,v[a+4>>2])}}function EY(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,8);gb=c+16|0}function EI(a,b){if(b>>>0<=9){return DI(a,b)}return et(a,b)}function An(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,2);gb=c+16|0}function Ai(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4);gb=c+16|0}function uG(a){a=v[a>>2]-12|0;if((Pw(a+8|0)|0)<=-1){Xb(a)}}function uB(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function nF(a){var b=0;b=gb-16|0;gb=b;Qb(a,0,36);gb=b+16|0}function lg(a,b){a=pqa(v[a>>2],v[a+4>>2],b,b>>31);return a}function er(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function cga(a){a=a|0;Qs(a,18720);v[a>>2]=89244;return a|0}function a9(a){a=a|0;tL(a,2,100);Ri(v[a+24>>2]+484360|0,0)}function _4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb=0;return 0}function Wn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function Vd(a,b){a=a|0;b=b|0;td(a,v[b>>2],v[b>>2]+oc(b)|0)}function RK(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function Ab(a){if(Ee(a)){return v[a+4>>2]}return w[a+11|0]}function yp(a,b,c){td(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function v_(a){a=a|0;ZF(a,10665);v[a>>2]=28324;return a|0}function uv(a){if(v[a>>2]){YW(a);HC(wb(a),v[a>>2],Xj(a))}}function tk(a){a=v[a+656>>2];if(!a){return 0}return Ij(a)}function sO(a){var b=0;pC(a);b=v[a>>2];if(b){uO(b,Bk(a))}}function re(a,b,c){td(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function qv(a){if(v[a>>2]){cr(a);ai(wb(a),v[a>>2],pe(a))}}function pX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){IU(c)}}function ox(a){if(v[a>>2]){Od(a);wG(ix(a),v[a>>2],pe(a))}}function nL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){wL(c)}}function jy(a,b){return v[((a>>>24^b)<<2)+459712>>2]^a<<8}function im(a){if(v[a>>2]){EF(a);$k(wb(a),v[a>>2],dg(a))}}function cs(a){if(v[a>>2]){zw(a);yw(wb(a),v[a>>2],Og(a))}}function bJ(a){while(1){if((qt(a)|0)!=-1){continue}break}}function Zq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Xg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function Wg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function WF(a){var b=0;b=v[a+8>>2];if(b){UF(b,v[a+4>>2])}}function SJ(a){var b=0;b=v[a+8>>2];if(b){RJ(b,v[a+4>>2])}}function OJ(a){var b=0;b=v[a+8>>2];if(b){Wu(b,v[a+4>>2])}}function Mx(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function IV(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function GK(a){a=a|0;return Si(Sb(v[a+24>>2]+484360|0))|0}function GD(a,b){var c=0;c=gb-16|0;gb=c;qR(a,b);gb=c+16|0}function De(a){if(v[a>>2]){ai(wb(a),v[a>>2],v[wb(a)>>2])}}function $V(a){var b=0;pC(a);b=v[a>>2];if(b){qC(b,Bk(a))}}function zb(a){var b=0;b=gb-16|0;gb=b;gb=b+16|0;return a}function zG(a){a=a|0;v[a>>2]=83816;vb(a+16|0);return a|0}function yj(a){return Ne(a)|Ne(a)<<8|Ne(a)<<16|Ne(a)<<24}function x6(a,b,c){a=a|0;b=b|0;c=c|0;return Cd(B(b,c))|0}function sA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;EA(a,b,c,d)}function o$(a){a=a|0;NS(a,5089);v[a>>2]=27324;return a|0}function nv(a){bp(a+88|0);bp(a+68|0);bp(a+48|0);return a}function joa(a,b){a=a|0;b=b|0;Tb(a,b?b:18720);return a|0}function j9(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,qI(c,b,Of(b)))}function i$(a,b,c){a=a|0;b=b|0;c=c|0;Sw(a,b,v[b+8>>2],c)}function g$(a){a=a|0;ZF(a,5835);v[a>>2]=27432;return a|0}function fI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;sh(a,-1,-1)}function Xe(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;of(a,c,d,b)}function Xba(a){a=a|0;_L(a);t[a+4202|0]=1;v[a+4224>>2]=0}function VC(a){a=a|0;if(!w[a|0]){return 1}return ce(a)|0}function UA(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function Ppa(a,b,c){a=a|0;b=b|0;c=c|0;return KD(a,b,c)|0}function PJ(a){a=a|0;v[a>>2]=59164;gc(a+12|0);return a|0}function Hn(a,b,c){a=pqa(v[a>>2],v[a+4>>2],b,c);return a}function GG(a,b){Jn(v[b>>2]);Ln(v[a>>2]);v[a>>2]=v[b>>2]}function AG(a){a=a|0;v[a>>2]=83776;vb(a+12|0);return a|0}function $j(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function xv(a,b,c){a=a|0;b=b|0;c=c|0;return mt(a,b,c)|0}function wm(a){a=a|0;v[a>>2]=77012;Wb(a+4|0);return a|0}function tF(a){a=a|0;v[a>>2]=28184;Kd(a+4|0);return a|0}function nH(a){return(a|0)!=0&(a|0)!=74848&(a|0)!=74872}function mJ(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function m5(a,b){a=a|0;b=b|0;return RF(a,Jb(b),Ab(b))|0}function ir(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(c<<2)|0}function iH(a,b,c,d){a=zI(a,b,c,0,-2147483648);return a}function iG(a,b,c){a=a|0;b=b|0;c=c|0;return ws(a,b,c)|0}function gx(a){a=a|0;v[a>>2]=89124;uG(a+4|0);return a|0}function fP(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){IU(b)}}function df(a,b,c){a=a|0;b=b|0;c=c|0;Ge(a,b);return a|0}function aq(a){a=a|0;v[a>>2]=77076;Wb(a+4|0);return a|0}function XL(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function WL(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function RC(a,b,c){a=a|0;b=b|0;c=c|0;return LD(a,b,c)|0}function Qv(a,b,c){a=a|0;b=b|0;c=c|0;return QY(a,b,c)|0}function Ps(a,b,c){return lG(Jb(a),Ab(a),Jb(b),c,Ab(b))}function MJ(a){a=a|0;v[a>>2]=59580;gc(a+4|0);return a|0}function Kp(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Kn(a,b,c){b=b-a|0;if(b){zh(c,a,b)}return b+c|0}function Kc(a){if(Ee(a)){a=fk(a)-1|0}else{a=10}return a}function IG(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Ln(b)}}function Ht(a){a=a|0;v[a>>2]=55124;Jt(a+4|0);return a|0}function Fd(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function Dj(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){wL(b)}}function Cs(a){a=a|0;v[a>>2]=89144;uG(a+4|0);return a|0}function sj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function s$(a){a=a|0;a=kb[a|0]()|0;ma(jb|0);return a|0}function ph(a){var b=0;b=qt(a);v[a+1396>>2]=0;return b}function o5(a){a=a|0;return Cq(v[v[a>>2]-12>>2]+a|0)|0}function nM(a){a=a|0;return Jj(C(z[a+4224>>2]*C(4)))|0}function l4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Oj(a,c,d)}function k5(a){a=a|0;return vf(v[v[a>>2]-12>>2]+a|0)|0}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function eq(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function cI(a){a=a|0;return at(v[v[a>>2]-12>>2]+a|0)|0}function bq(a){if(Ee(a)){a=fk(a)-1|0}else{a=1}return a}function WK(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function VR(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;_A(a)}function Ug(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+20>>2]](a,b)}function Sca(a,b,c){a=a|0;b=b|0;c=c|0;vd(a,b+4228|0,7)}function S_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nk(a,d,0)}function SH(a){a=a|0;return _s(v[v[a>>2]-12>>2]+a|0)|0}function Qh(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+24>>2]](a,b)}function QP(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function Ph(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+28>>2]](a,b)}function Mb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function Kda(a,b,c){a=a|0;b=b|0;c=c|0;vd(a,b+4260|0,8)}function Iq(a,b){v[a>>2]=b;v[a+4>>2]=b+223232;return a}function E2(a,b){a=a|0;b=b|0;td(a,TH(v[b>>2]),v[b>>2])}function Bw(a,b){a=oqa(v[a>>2],v[a+4>>2],b,0);return a}function xda(a){a=a|0;t[a+4202|0]=1;Pt(a);az(a);IM(a)}function wo(a){a=a|0;return kb[v[v[a>>2]+24>>2]](a)|0}function vb(a){if(Ee(a)){$k(a,v[a>>2],fk(a))}return a}function us(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function rj(a){a=a|0;return kb[v[v[a>>2]+12>>2]](a)|0}function ri(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function qj(a){a=a|0;return kb[v[v[a>>2]+16>>2]](a)|0}function of(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function mj(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function gma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function am(a,b){a=a|0;b=b|0;return Te(a)>>>0>b>>>0|0}function Qn(a,b){return kb[v[v[a>>2]+36>>2]](a,b,0)|0}function Qf(a,b,c){a=a|0;b=b|0;c=c|0;Xo(a);return a|0}function Pn(a,b){return kb[v[v[a>>2]+52>>2]](a,b,0)|0}function Ic(a){if(Ee(a)){ai(a,v[a>>2],fk(a))}return a}function HD(a){var b=0;b=gb-16|0;gb=b;Ok(a);gb=b+16|0}function Gca(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function FK(a){a=a|0;return oq(v[a+24>>2]+484344|0)|0}function DM(a){Lc(a+36|0);Lc(a+24|0);Nt(a+12|0);Nt(a)}function wn(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function oka(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,Gs(b,c))}
function oM(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function nqa(a){if(a){return 31-E(a-1^a)|0}return 32}function lq(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function cp(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function cca(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function SK(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function NK(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function Gea(a,b){a=a|0;b=b|0;a=a+24|0;FN(a,b);eA(a)}function wX(a){a=a|0;return rz(w[a+3|0],w[a+5|0])|0}function vl(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function vd(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function n9(a){a=a|0;a=v[a+4>>2];return(a?a:2107)|0}function ms(a){if(v[a>>2]){Od(a);CF(v[a>>2],tg(a))}}function lD(a,b){le(a,b);Qb(a+20|0,0,1040);return a}function ke(a){if(v[a>>2]){OY(a);vD(v[a>>2],$i(a))}}function hq(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function hP(a){if(v[a>>2]){Od(a);eP(v[a>>2],tg(a))}}function gt(a){if(!a){return 0}v[115189]=a;return-1}function go(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function fu(a){v[a>>2]=38364;v[a>>2]=18732;return a}function dp(a){if(v[a>>2]){Od(a);vW(v[a>>2],tW(a))}}function ci(a){if(v[a>>2]){Od(a);qC(v[a>>2],pe(a))}}function be(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function _T(a){if(v[a>>2]){Od(a);Su(v[a>>2],ug(a))}}function Zp(a,b){b=v[b>>2];v[a>>2]=b;Jn(b);return a}function Wpa(a){a=a|0;kn(90864);oD(90856);vb(90844)}function VK(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function Uo(a,b,c){if(!c){return 0}return sd(a,b,c)}function SQ(a){if(v[a>>2]){Od(a);LQ(v[a>>2],GA(a))}}function Ru(a){if(v[a>>2]){Od(a);EB(v[a>>2],bi(a))}}function Pu(a){if(v[a>>2]){Od(a);BB(v[a>>2],CB(a))}}function Ou(a){if(v[a>>2]){Od(a);DB(v[a>>2],xi(a))}}function Mv(a){if(v[a>>2]){Od(a);HY(v[a>>2],Og(a))}}function Mea(a,b){a=a|0;b=b|0;hk(a+36|0,b);return 1}function MK(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function Hq(a){a=a|0;return pu(w[a+2|0],w[a+4|0])|0}function Hp(a){a=a|0;a=dc(a);kb[v[v[a>>2]>>2]](a)|0}function HR(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function Gs(a,b){a=a|0;b=b|0;return Bp(a,b,Of(b))|0}function Gl(a){if(v[a>>2]){Od(a);uO(v[a>>2],pe(a))}}function FB(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function Eo(a){a=a|0;return pu(w[a+3|0],w[a+5|0])|0}function Db(a,b,c){td(a,(c>>>3&536870908)+b|0,1<<c)}function D6(a,b,c){a=a|0;b=b|0;c=c|0;vJ(a-88|0,b,c)}function B6(a,b,c){a=a|0;b=b|0;c=c|0;tJ(a-88|0,b,c)}function $5(a,b){a=a|0;b=b|0;return RF(a,b,Of(b))|0}function tC(a,b,c){u[a>>1]=x[b>>1];t[a+2|0]=w[c|0]}function ql(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function nn(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function hp(a){return(v[a+480180>>2]&740327453)!=0}function aD(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function _t(a){a=a|0;Kh(a);v[a+20>>2]=0;return a|0}function Wj(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function Ql(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function Ot(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,LG(b,c))}function Lm(a){Gj(a+724|0);Gj(a+732|0);Gj(a+740|0)}function Lj(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function KP(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function KI(a,b){if(!a){return 0}return pl(a,b,0)}
function Ho(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function F6(a,b,c){a=a|0;b=b|0;c=+c;xJ(a-88|0,b,c)}function C6(a,b){a=a|0;b=b|0;return uJ(a-88|0,b)|0}function A6(a,b){a=a|0;b=b|0;return sJ(a-88|0,b)|0}function yN(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function yE(a){return!sd(a,28402,25)&w[a+34|0]<65}function vg(a,b){return lG(Jb(a),Ab(a),b,0,Of(b))}function ug(a){return(v[wb(a)>>2]-v[a>>2]|0)/12|0}function td(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function tW(a){return(v[wb(a)>>2]-v[a>>2]|0)/33|0}function qma(a,b){a=a|0;b=b|0;if(!Sv(a,b)){Tv(b)}}function pk(a){return(v[wb(a)>>2]-v[a>>2]|0)/52|0}function mfa(a,b){a=a|0;b=b|0;if(!PF(a,b)){Lw(b)}}function ln(a){return(v[wb(a)>>2]-v[a>>2]|0)/48|0}function jh(a,b){if(Ee(a)){de(a,b);return}Ze(a,b)}function gv(a){return(v[wb(a)>>2]-v[a>>2]|0)/24|0}function gna(a,b){a=a|0;b=b|0;if(!jF(a,b)){Cw(b)}}function bm(a){return(v[wb(a)>>2]-v[a>>2]|0)/20|0}function _k(a){return(v[wb(a)>>2]-v[a>>2]|0)/36|0}function Zj(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,20,b)}function ZC(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,40,b)}function Tm(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function Qk(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,22,b)}function Opa(a,b){a=a|0;b=b|0;if(!fY(a,b)){Ev(b)}}function Mp(a){return(v[dc(a)>>2]-v[a>>2]|0)/12|0}function Mk(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,28,b)}function Lr(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,30,b)}function Lk(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,12,b)}function Ke(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,32,b)}function JY(a){return(v[dc(a)>>2]-v[a>>2]|0)/28|0}function Ie(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function Hr(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,64,b)}function FU(a){return(v[wb(a)>>2]-v[a>>2]|0)/56|0}function Dna(a,b){a=a|0;b=b|0;if(!nW(a,b)){mW(b)}}function Cp(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,26,b)}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function BW(a,b,c){a=a|0;b=b|0;c=c|0;of(a,c,16,b)}function $i(a){return(v[wb(a)>>2]-v[a>>2]|0)/28|0}function zz(a){return B(Lj(a),Ql(a))+7>>>3&65535}function xy(a,b,c){return Xg(a,b,v[a+12>>2]+c|0)}function xY(a,b){a=nY(a,b);if(!a){jD(b)}return a}function xR(a){return(v[a+4>>2]-v[a>>2]|0)/872|0}function xC(a,b){a=a|0;b=b|0;if(!bW(a,b)){rC(b)}}function rr(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function ni(a){return(Vf(a)|0)!=(0-Vf(a+12|0)|0)}function lX(a,b){a=a|0;b=b|0;return Vt(a,b,32)|0}function k4(a,b){a=a|0;b=b|0;return kb[b|0](a)|0}function gB(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function eca(a){a=a|0;return z[a+4212>>2]<C(1)|0}function co(a,b,c){return IV(a,b,v[a+12>>2]+c|0)}function cY(a,b){a=a|0;b=b|0;if(!_X(a,b)){gD(b)}}function _A(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function Yg(a){a=w[a+20|0];return(a|0)==255?-1:a}function Xj(a){return(v[wb(a)>>2]-v[a>>2]|0)/6|0}function TJ(a,b,c){a=Ud(a);v[a+4>>2]=c;v[a>>2]=b}function TD(a,b){a=a|0;b=b|0;if(!BF(a,b)){AF(b)}}function Ol(a){a=a|0;Tq(v[a+20>>2]);v[a+20>>2]=0}function Ni(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function MA(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Jb(a){if(Ee(a)){return v[a>>2]}return a}function Ica(a){a=a|0;return z[a+4220>>2]<C(1)|0}function Hpa(a,b,c){a=a|0;b=b|0;c=c|0;hc(b,c,48)}function GA(a){return(v[wb(a)>>2]-v[a>>2]|0)/7|0}function FY(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function Ey(a,b){v[a>>2]=v[b>>2];Dc(a+4|0,b+4|0)}function EZ(a,b){a=a|0;b=b|0;if(!ND(a,b)){Vv(b)}}function E6(a,b){a=a|0;b=b|0;return+wJ(a-88|0,b)}function Dr(a,b){a=a|0;b=b|0;if(!kj(a,b)){hm(b)}}function DS(a,b){yc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function Br(a,b){a=$X(a,b);if(!a){bY(b)}return a}function Ay(a,b,c){return ir(a,b,v[a+12>>2]+c|0)}function zx(a,b,c,d){a=zI(a,b,c,-1,-1);return a}function sca(a){a=a|0;t[a+4202|0]=1;gM(a);fM(a)}function ov(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function nl(a){a=a|0;return _H(v[a>>2])<<24>>24}function jn(a,b,c){v[a>>2]=b;v[a+4>>2]=(c<<1)+b}function io(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function dr(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function dl(a){return kb[v[v[a>>2]+36>>2]](a)|0}function al(a){return(v[a+4>>2]-v[a>>2]|0)/36|0}function _i(a){return(v[a+4>>2]-v[a>>2]|0)/28|0}function Yj(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function Vn(a){return kb[v[v[a>>2]+28>>2]](a)|0}function Um(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Uf(a,b){a=a|0;b=b|0;return Xc(a,b,0)|0}function Tf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function Pp(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Oba(a){a=a|0;YL(a);Uy(a);t[a+4202|0]=1}function NV(a){var b=0;b=v[a>>2];Pe(a);return b}function Je(a){return(v[a+4>>2]-v[a>>2]|0)/20|0}function Fu(a,b){a=a|0;b=b|0;gg(a,b);return a|0}function Ec(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function Ar(a,b,c){b=b-a|0;if(b){zh(c-b|0,a,b)}}function Aca(a){a=a|0;t[a+4202|0]=1;lM(a);mM(a)}function ul(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function tf(a,b,c){if(!(w[a|0]&32)){dD(b,c,a)}}function jo(a,b,c){a=a|0;b=b|0;c=c|0;td(a,b,c)}function fp(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function eD(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function bc(a,b,c){a=a|0;b=b|0;c=c|0;vd(a,b,c)}function YR(a,b){TR(v[a>>2],b);TR(v[a+4>>2],b)}function Wt(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function Vj(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function V8(a,b){a=a|0;b=b|0;Dc(a,Gs(b,14732))}function Tl(a,b){return(B(b,104)+a|0)+484380|0}function OR(a){VA(a);Qb(a+27|0,0,255);return a}function Md(a){return v[a+20>>2]!=0&v[a>>2]!=0}function LA(a){return(v[a+4>>2]-v[a>>2]|0)/7|0}function Ki(a){a=a|0;return x[ro(a)+480188>>1]}function Jp(a){TF(a);v[a+8>>2]=0;v[a>>2]=79020}function Jg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function G4(a,b,c){a=a|0;b=b|0;c=c|0;td(a,c,b)}function Eu(a){return(a>>>0<9?a:a-9|256)&65535}function yg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function um(a,b){a=a|0;b=b|0;return VH(a,b)^1}function uF(a){a=a|0;v[a>>2]=28048;return a|0}function rqa(a,b,c,d){a=mqa(a,b,c,d);return a}function qc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function qY(a){t[a+12|0]=w[a+12|0]|2;return a}function px(a,b){a=a|0;b=b|0;return Gs(a,b)|0}function pi(a,b){a=a|0;b=b|0;return Nc(b,1)|0}function og(a,b){a=a|0;b=b|0;return Gb(a,b)|0}function n5(a){a=a|0;LH(v[v[a>>2]-12>>2]+a|0)}function mk(a,b){a=a|0;b=b|0;return $H(a,b)^1}function lk(a,b){a=a|0;b=b|0;return $H(a,b)|0}function ki(a,b){a=a|0;b=b|0;return lw(a,b)|0}function j5(a){a=a|0;KH(v[v[a>>2]-12>>2]+a|0)}function il(a,b){a=a|0;b=b|0;return VH(a,b)|0}function ck(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function bI(a){a=a|0;Rx(v[v[a>>2]-12>>2]+a|0)}function Zh(a,b){a=a|0;b=b|0;return nS(a,b)|0}function Ut(a,b){a=a|0;b=b|0;return LG(a,b)|0}function Ud(a){v[a>>2]=0;v[a+4>>2]=0;return a}function SF(a){a=a|0;v[a>>2]=27480;return a|0}function RH(a){a=a|0;Nx(v[v[a>>2]-12>>2]+a|0)}function QJ(a){a=a|0;v[a>>2]=58808;return a|0}function Ny(a){a=a|0;v[a>>2]=54956;return a|0}function NJ(a){a=a|0;v[a>>2]=59216;return a|0}function MG(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Ij(a){return(w[a+31|0]-1&255)>>>0<17}function HF(a){a=a|0;v[a>>2]=27812;return a|0}function Gb(a,b){a=a|0;b=b|0;return Rj(a,b)^1}function FP(a){hP(a+20|0);gP(a+8|0);fP(a+4|0)}function DW(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Cl(a){return v[wb(a)>>2]-v[a>>2]>>11}function zB(a){return v[dc(a)>>2]-v[a>>2]>>5}function xw(a){return v[dc(a)>>2]-v[a>>2]>>1}function xu(a,b,c){a=a|0;b=b|0;c=c|0;_j(b,c)}function xi(a){return v[wb(a)>>2]-v[a>>2]>>4}function wL(a){if(a){kb[v[v[a>>2]+4>>2]](a)}}function wF(a){return v[dc(a)>>2]-v[a>>2]>>3}function tg(a){return v[wb(a)>>2]-v[a>>2]>>3}function pe(a){return v[wb(a)>>2]-v[a>>2]>>2}function ng(a){return v[v[a+8>>2]>>2]==(a|0)}function mG(a){a=Ha(a|0)|0;jb=O()|0;return a}function j6(a){a=a|0;return Ea(v[a+60>>2])|0}function dz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function dca(a){a=a|0;return C(z[a+4220>>2])}function bi(a){return v[wb(a)>>2]-v[a>>2]>>5}function a7(a){a=a|0;LJ(a);return v[a+16>>2]}function WD(a){return w[a+1|0]==2?w[a|0]<3:0}function Vy(a){return C(C(a*C(7900))+C(100))}function Vo(a){a=a|0;pB(a+288|0);Wo(a+800|0)}function QK(a){a=a|0;return PK(v[a+24>>2])|0}function Px(a){return v[dc(a)>>2]-v[a>>2]>>4}function Og(a){return v[wb(a)>>2]-v[a>>2]>>1}function Nn(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c)}function Kf(a){return v[a+8>>2]-v[a+12>>2]|0}function Hca(a){a=a|0;return C(z[a+4212>>2])}function DF(a,b){a=a|0;b=b|0;return(b|0)<6|0}function CB(a){return v[wb(a)>>2]-v[a>>2]>>8}function Bk(a){return v[dc(a)>>2]-v[a>>2]>>2}function Av(a,b,c){a=a|0;b=b|0;c=c|0;js(b,c)}function zf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function sm(a){a=a|0;TH(v[a>>2]);return a|0}function sM(a){a=a|0;kb[v[v[a>>2]+4>>2]](a)}function qM(a){a=a|0;return C(z[a+4208>>2])}function ml(a){a=a|0;Qx(v[a>>2]);return a|0}function lK(a,b){a=a|0;b=b|0;return oc(b)|0}function kK(a,b){a=a|0;b=b|0;return Nb(b)|0}function i6(a,b){a=a|0;b=b|0;return Rh(a)|0}function gu(a){QO(a);v[a>>2]=77380;return a}function fda(a,b,c){a=a|0;b=b|0;c=c|0;Ud(a)}function dg(a){return v[wb(a)>>2]-v[a>>2]|0}function dL(a){t[a+4|0]=0;t[a|0]=0;return a}function br(a){return kr(v[a>>2],v[a+4>>2])}function b7(a){a=a|0;LJ(a);return v[a+4>>2]}function ap(a,b){return v[a>>2]<v[b>>2]?b:a}function XR(a,b){u[a+22>>1]=b&7;_A(a);$A(a)}function W_(a,b){a=a|0;b=b|0;LF(Qb(b,0,36))}function Vf(a){return v[a+4>>2]-v[a>>2]>>11}function Ji(a,b){a=a|0;b=b|0;return C(C(0))}function JL(a){return Xh(C(LL(a)*C(32768)))}function Hda(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function BH(a){QO(a);v[a>>2]=77452;return a}function $t(a,b,c){b=b-a|0;if(b){zh(c,a,b)}}function yx(a){a=a|0;return Oh(a,464300)|0}function y5(a){a=a|0;return Oh(a,464096)|0}function ux(a){a=a|0;return Oh(a,464308)|0}function uf(a){return v[a+4>>2]-v[a>>2]>>4}function tc(a){return v[a+4>>2]-v[a>>2]>>1}function rp(a,b){return v[a>>2]-v[b>>2]>>1}function rf(a){return v[a+4>>2]-v[a>>2]>>3}function p7(a,b){a=a|0;b=b|0;RQ(v[a>>2],b)}function mv(a,b){return v[a>>2]-v[b>>2]>>2}function kH(){return(v[v[22614]>>2]?4:1)|0}function fl(a,b){kb[v[v[b>>2]+44>>2]](a,b)}function fk(a){return v[a+8>>2]&2147483647}function el(a,b){kb[v[v[b>>2]+32>>2]](a,b)}function dh(a){return v[a+4>>2]-v[a>>2]>>8}function b$(a){a=a|0;return v[a+4>>2]!=0|0}function Yu(a){De(a+24|0);gc(a+12|0);gc(a)}function WR(a,b){t[a+21|0]=b&3;_A(a);$A(a)}function TK(a){a=a|0;return+MO(v[a+24>>2])}function Sfa(a,b){a=a|0;b=b|0;hk(a+40|0,b)}function PL(a){return C(C(a*C(96))+C(-96))}function Ox(a){a=a|0;return Oh(a,464260)|0}function Nb(a){return v[a+4>>2]-v[a>>2]>>2}function N5(a){a=a|0;return Oh(a,464080)|0}function MT(a,b){return v[a>>2]+B(b,872)|0}function Lx(a){a=a|0;return Oh(a,464268)|0}function Kw(a){ps(a+32|0);xb(a+12|0);vb(a)}function Im(a){vb(a+36|0);Lc(a+24|0);hn(a)}function Hx(a){a=a|0;return Oh(a,464276)|0}function Hs(a,b){kb[v[v[b>>2]+40>>2]](a,b)}function Bea(a,b){a=a|0;b=b|0;gg(a,b+36|0)}function Ae(a){return v[a+4>>2]-v[a>>2]>>5}function $q(a,b){a=a|0;b=b|0;return b-a>>1}function zW(a,b){return v[a>>2]+B(b,33)|0}function y6(a,b){a=a|0;b=b|0;qJ(a-88|0,b)}function wD(a){a=a|0;return Oh(a,466e3)|0}function tm(a){a=a|0;return UH(v[a>>2])|0}function sy(a){a=a|0;Ft(a+8|0);return a|0}function ro(a){return v[v[a+48>>2]+12>>2]}function oo(a,b,c){Oj(a,b,b+c|0);return a}function oc(a){return v[a+4>>2]-v[a>>2]|0}function nf(a){v[a>>2]=v[a>>2]+2;return a}function ly(a){a=a|0;if(a){fJ(a);he(a,a)}}function lka(a){a=a|0;return es(a+20|0)|0}function gS(a){v[a>>2]=v[a>>2]-2;return a}function gF(a){return(w[a+24|0]&16)>>>4|0}function fi(a){return x[a+480190>>1]<3999}function bk(a,b){return v[a>>2]-v[b>>2]|0}function at(a){a=a|0;oh(a+8|0);return a|0}function an(a,b){return v[a>>2]+B(b,56)|0}function af(a,b){return v[a>>2]+B(b,52)|0}function _s(a){a=a|0;oh(a+4|0);return a|0}function _Y(a,b){a=a|0;b=b|0;hk(a+12|0,b)}function Zt(a,b){return v[a>>2]+B(b,28)|0}function WN(a,b){Tm(a,A[b>>3],-A[b+8>>3])}function Vl(a,b){return v[a>>2]+B(b,24)|0}function Tca(a){a=a|0;t[a+4202|0]=1;wM(a)}function TP(a,b){if(z[a>>2]>b){z[a>>2]=b}}function Rf(a){a=a|0;Kh(a+8|0);return a|0}function Q0(a,b){a=a|0;b=b|0;gg(a,b+16|0)}function Pj(a,b){return v[a>>2]+B(b,36)|0}function OL(a){a=a|0;Qb(a+4296|0,0,81928)}function O6(a,b){a=a|0;b=b|0;GJ(a-88|0,b)}function N6(a,b){a=a|0;b=b|0;EJ(a-88|0,b)}function Mba(a){a=a|0;return v[a+4260>>2]}function LG(a,b){return Bp(a,Jb(b),Ab(b))}function Kg(a,b){return v[a>>2]+B(b,20)|0}function Gn(a,b){return v[a>>2]+(b<<11)|0}function Gd(a,b){v[a>>2]=v[b>>2];return a}function Fc(a,b){a=a|0;b=b|0;Zp(a,b+28|0)}function EK(a,b){a=a|0;b=b|0;gg(a,b+12|0)}function DI(a,b){t[a|0]=b+48;return a+1|0}function Ad(a,b){return v[a>>2]+B(b,12)|0}function ze(a,b){return v[a>>2]+(b<<3)|0}function ym(a){return(a|0)==32|a-9>>>0<5}function vna(a,b){a=a|0;b=b|0;Rk(a,b,17)}function sc(a,b){return v[a>>2]+(b<<1)|0}function rg(a,b){v[a+8>>2]=b|-2147483648}function qba(a){a=a|0;return(a|0)==277|0}function mL(a){return(Jb(a)+Ab(a)|0)-1|0}function jj(a){return B(ij(a),fd(a))&255}function fqa(a,b){a=a|0;b=b|0;Rk(a,b,44)}function dX(a,b){v[a>>2]=b;v[a+4>>2]=b+4}function cd(a){return v[a>>2]==v[a+4>>2]}function ad(a,b){return v[a>>2]+B(b,6)|0}function _f(a){a=a|0;return!v[a+16>>2]|0}function Zs(a,b){v[a+24>>2]=v[a+24>>2]+b}function XF(a,b){xc(a,b);xc(a+4|0,b+4|0)}function Wl(a){a=a|0;return v[a>>2]+14|0}function Tc(a,b){return v[a>>2]+(b<<4)|0}function TF(a){v[a+4>>2]=0;v[a>>2]=78964}function S6(a){a=a|0;return sy(a-88|0)|0}function Rl(a,b){return v[a>>2]+(b<<8)|0}function Rj(a,b){return v[a>>2]==v[b>>2]}function O0(a,b){a=a|0;b=b|0;kx(a,83848)}function M6(a,b){a=a|0;b=+b;DJ(a-88|0,b)}function M0(a,b){a=a|0;b=b|0;kx(a,83868)}function Lb(a,b){return v[a>>2]+(b<<2)|0}function K6(a,b){a=a|0;b=+b;BJ(a-88|0,b)}function H6(a,b){a=a|0;b=+b;zJ(a-88|0,b)}function Gj(a){u[a+4>>1]=65535;v[a>>2]=0}function Gda(a){a=a|0;return w[a+4201|0]}function Fda(a){a=a|0;return w[a+4202|0]}function Ela(a,b){a=a|0;b=b|0;Rk(a,b,10)}function EE(a,b){return v[a>>2]+(b<<5)|0}function Bna(a,b){a=a|0;b=b|0;Vt(a,b,17)}function Bg(a){a=a|0;return EP(w[a|0])|0}function BM(a){return(w[a+24|0]&8)>>>3|0}function $b(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function zZ(a,b){a=a|0;b=b|0;Vt(a,b,11)}function yn(a,b){return y[a>>2]<y[b>>2]}function yF(a,b){bc(a,v[b>>2],rf(b)<<3)}function xba(a){a=a|0;return-2013527448}function vw(a,b){a=a|0;b=b|0;qw(a,b,32)}function uW(a,b){a=a|0;b=b|0;return b|0}function tla(a,b){a=a|0;b=b|0;Rk(a,b,5)}function sv(a,b){return z[a>>2]<z[b>>2]}function ot(a,b){return v[a>>2]<v[b>>2]}function iZ(a,b){a=a|0;b=b|0;Rk(a,b,11)}function iS(a,b){v[a>>2]=v[a>>2]+(b<<1)}function he(a,b){if(!v[a+80>>2]){Xb(b)}}function eT(a,b){return A[a>>3]<A[b>>3]}function YE(a,b){a=a|0;b=b|0;Rk(a,b,32)}function XN(a){v[a+4>>2]=v[a+4>>2]|8192}function VV(a,b){v[a>>2]=v[a>>2]+(b<<2)}function Tq(a){a=a|0;if(a){Xb(a+-64|0)}}function TG(a,b){a=a|0;b=b|0;He(a,1,45)}function SG(a,b){a=a|0;b=b|0;iI(a,1,45)}function P0(a,b){a=a|0;b=b|0;Tb(a,8570)}function Nj(a,b){return u[a>>1]<u[b>>1]}function N0(a,b){a=a|0;b=b|0;Tb(a,8687)}function Ir(a,b,c){if(b){Qb(a,Lg(c),b)}}function Ina(a,b){a=a|0;b=b|0;JD(a,b,8)}function Ib(a){return(a<<8|a>>>8)&65535}function Fo(a,b,c){return a<b?b:a>c?c:a}function Fn(a,b){return x[a>>1]<x[b>>1]}function DX(a,b){v[a>>2]=v[a>>2]+B(b,6)}function BP(a,b){return(Nl(a,b)|0)!=255}function BA(a,b,c){return a<b?b:a>c?c:a}function Aj(a,b,c){Dc(a,b);Dc(a+12|0,c)}function zca(a){a=a|0;return-285139079}function yk(a,b){return Jb(a)+(b<<2)|0}function xK(a){return a?(a|0)==2?3:2:1}function uu(a,b){a=a|0;b=b|0;nI(a,b,0)}function sn(a,b){a=a|0;b=b|0;bc(a,b,7)}function s8(a){a=a|0;return+A[a+16>>3]}function rs(a){al(a);$F(a);_k(a);al(a)}function rca(a){a=a|0;return-284078960}function oba(a,b){a=a|0;b=b|0;return 3}function oS(a,b){v[a+4>>2]=b;v[a>>2]=b}function nba(a,b){a=a|0;b=b|0;return 2}function lda(a){a=a|0;return 542066252}function lZ(a){a=a|0;return v[a+12>>2]}function kca(a){a=a|0;return-281111764}function hT(a,b){a=a|0;b=b|0;zk(a,0,b)}function fd(a){return w[a+34|0]&64?2:1}function fca(a){a=a|0;return-271958638}function bH(a,b,c){Ge(a,b);Ge(a+4|0,c)}function as(a){a=a|0;return 2147483647}function aj(a){return B(v[a>>2],jj(a))}function _c(a){v[v[a+8>>2]>>2]=v[a>>2]}function ZF(a,b){sH(a,b);v[a>>2]=89404}function Yy(a,b){a=a|0;b=b|0;jN(a,3,b)}function Yja(a){a=a|0;US(a);return a|0}function Wba(a){a=a|0;return-620920304}function OE(a){wb(a);return 2147483647}function Nba(a){a=a|0;return-275227023}function L6(a){a=a|0;return+CJ(a-88|0)}function Jca(a){a=a|0;return-270114148}function J6(a){a=a|0;return+AJ(a-88|0)}function H_(a){a=a|0;return v[a+16>>2]}function G6(a){a=a|0;return+yJ(a-88|0)}function Eba(a){a=a|0;return 302837129}function Bh(a){a=+a;return hr(ee(a))|0}function $Y(a){a=a|0;return v[a+24>>2]}function uw(a){return w[a+21|0]>>>7|0}function ty(a){a=a|0;return v[a+8>>2]}function rv(a){a=a|0;return Pb(a,1)^1}function op(a,b){u[a+8>>1]=b;return a}function oh(a){a=a|0;Kx(a);return a|0}function ij(a){return t[a+34|0]&1?2:1}function hs(a,b){a=a|0;b=b|0;return 1}function hL(a,b){return w[a|0]<w[b|0]}function bt(a,b){a=a|0;b=b|0;return-1}function bda(a,b){a=a|0;b=b|0;Fu(a,b)}function Y6(a){a=a|0;return w[a+40|0]}function VH(a,b){return IH(a)^IH(b)^1}function V4(a){a=a|0;return zH(a,0)|0}function Ue(a,b){v[a+4>>2]=b;return a}function UE(a){return w[a+22|0]>>>7|0}function U4(a){a=a|0;return zH(a,1)|0}function Sb(a){return EE(a,w[a+16|0])}function R4(a){a=a|0;return xH(a,0)|0}function PK(a){return x[a+1074448>>1]}function P4(a){a=a|0;return xH(a,1)|0}function OQ(a){a=a|0;xr(a);return a|0}function Mj(a,b){return t[a|0]<t[b|0]}function Kh(a){a=a|0;KF(a);return a|0}function Jk(a){return v[a+1298364>>2]}function IJ(a){v[a>>2]=60068;return a}function HH(a){a=a|0;Fx(a);return a|0}function GL(a,b){a=a|0;b=b|0;return 0}function Fx(a){a=a|0;Cs(a);return a|0}function El(a){return(w[a+16|0]&5)!=0}function Ee(a){return w[a+11|0]>>>7|0}function Cx(a){a=a|0;if(nH(a)){Xb(a)}}function Bt(a){a=a|0;return v[a+4>>2]}function $H(a,b){return JH(a)^JH(b)^1}function zpa(a){a=a|0;return WX(a)|0}function xn(a,b){tc(a);cF(a,b);zE(a)}function xN(a,b){Tf(a);zO(a,b);uN(a)}function od(a,b){return Gn(a+12|0,b)}function lj(a){return v[a+4>>2]-36|0}function kS(a,b){Ae(a);eS(a,b);dS(a)}function jG(a,b){a=a|0;b=b|0;Rq(a,b)}function j7(a){a=a|0;return w[a+8|0]}function ih(a,b){a=a|0;b=b|0;UY(a,b)}function hoa(a){a=a|0;return Jk(a)|0}function hj(a,b){Nb(a);zU(a,b);pw(a)}function g_(a,b){a=a|0;b=b|0;Mo(a,b)}function Vr(a,b){a=a|0;b=b|0;Ew(a,b)}function Vba(a){a=a|0;v[a+4224>>2]=0}function UK(a){return v[a+4>>2]-48|0}function S0(a){a=a|0;return t[a+8|0]}function R0(a){a=a|0;return t[a+9|0]}function Qka(a){a=a|0;return PT(a)|0}function QM(a,b,c){a=a|0;b=b|0;c=c|0}function PC(a,b){Jg(a);XW(a,b);LW(a)}function Or(a,b){a=a|0;b=b|0;Uv(a,b)}function MU(a){return v[a+4>>2]-56|0}function ML(a){v[a>>2]=0;v[a+4>>2]=0}function Kga(a){a=a|0;return jm(a)|0}function Jn(a){v[a+4>>2]=v[a+4>>2]+1}function GU(a){return v[a+4>>2]-28|0}function GR(a,b){a=a|0;b=b|0;$f(a,b)}function GO(a){return v[a+4>>2]-32|0}function EP(a){return(a+5&255)>>>0<2}function DK(a){return v[a+4>>2]-12|0}function Cm(a,b){oc(a);oK(a,b);jK(a)}function Cfa(a){a=a|0;return Li(a)|0}function BV(a,b){if(!pV(a,b)){XB(b)}}function $u(a){return v[wb(a)>>2]<<5}function $f(a,b){a=a|0;b=b|0;gg(a,b)}function yc(a,b){v[a>>2]=b;return a}function wz(a){a=a|0;return El(a)|0}function wf(a){return v[a+24620>>2]}function vha(a,b){a=a|0;b=b|0;yR(b)}function uo(a){return v[a+4>>2]-4|0}function pha(a,b){a=a|0;b=b|0;De(b)}function p_(a){a=a|0;return sf(a)|0}function ou(a){return yo(a)<<24>>24}function o2(){Zd(465520,Wd(464064))}function n2(){Zd(465528,Wd(464072))}function l2(){Zd(465552,Wd(464260))}function l$(a){a=a|0;return sg(a)|0}function kka(a,b){a=a|0;b=b|0;ed(b)}function kc(a,b){return v[a>>2]+b|0}function k2(){Zd(465560,Wd(464268))}function i2(){Zd(465568,Wd(464276))}function hy(a){return!sd(a,90132,6)}function h2(){Zd(465584,Wd(464284))}function h$(a){a=a|0;return v[a>>2]}function gc(a){ut(a);im(a);return a}function g2(){Zd(465592,Wd(464292))}function fF(a){a=a|0;return Ng(a)|0}function f2(){Zd(465600,Wd(464300))}function e2(){Zd(465624,Wd(464308))}function d2(){Zd(465656,Wd(464080))}function cm(a,b,c){if(c){zh(a,b,c)}}function c2(){Zd(465664,Wd(464088))}function b2(){Zd(465672,Wd(464096))}function a2(){Zd(465680,Wd(464104))}function _1(){Zd(465696,Wd(464152))}function Zb(a){return Gg(v[a+4>>2])}function Z1(){Zd(465704,Wd(464160))}function YZ(a){a=a|0;return rE(a)|0}function YY(a){a=a|0;return es(a)|0}function Y8(a){a=a|0;return ve(a)|0}function Y1(){Zd(465712,Wd(464168))}function Xr(a){t[a+2|0]=0;u[a>>1]=0}function XA(a,b){return B(b,12)+a|0}function X1(){Zd(465720,Wd(464176))}function WE(a){return w[a+21|0]&127}function WC(a,b){return EX(a,0-b|0)}function W1(){Zd(465728,Wd(464184))}function VE(a){return w[a+22|0]&127}function V1(){Zd(465736,Wd(464192))}function UY(a,b){GH(a,v[a+16>>2]|b)}function U1(){Zd(465744,Wd(464200))}function T1(){Zd(465752,Wd(464112))}function S1(){Zd(465768,Wd(464120))}function Rr(a){a=a|0;return Be(a)|0}function Rna(a,b){a=a|0;b=b|0;$j(b)}function Rg(a,b,c){return Kn(a,b,c)}function Qg(a,b,c){if(c){hc(a,b,c)}}function Q1(){Zd(465784,Wd(464128))}function OV(a,b){return xe(a,0-b|0)}function O1(){Zd(465800,Wd(464136))}function Nfa(a,b){a=a|0;b=b|0;Im(b)}function N1(){Zd(465816,Wd(464208))}function Mfa(a,b){a=a|0;b=b|0;Ig(b)}function M1(){Zd(465824,Wd(464216))}function L7(a){a=a|0;return nK(a)|0}function Jha(a,b){a=a|0;b=b|0;Xm(b)}function Cea(a){a=a|0;Vt(a,18720,1)}function Cda(a,b){a=a|0;b=b|0;bz(b)}function $1(){Zd(465688,Wd(464144))}function w6(a,b){a=a|0;b=b|0;Xb(b)}function ve(a){return v[a>>2]+16|0}function uh(a,b){v[a>>2]=v[a>>2]|b}function st(a){a=a|0;t[a+6152|0]=0}function sS(a,b){t[v[a>>2]]=w[b|0]}function nk(a,b,c){vd(a,v[b>>2],c)}function mK(a){return(Yg(a)|0)==-1}function m2(){Zd(465536,Wd(466e3))}function lo(a,b){v[a+1298424>>2]=b}function lm(a){Dm(a);v[a>>2]=89032}function kw(a,b){v[a>>2]=v[a>>2]+b}function kG(a,b){a=a|0;b=b|0;vb(b)}function j_(a,b){a=a|0;b=b|0;Xr(b)}function iK(a,b){a=a|0;b=b|0;Cy(b)}function hf(a,b){Xo(a);yc(a+4|0,b)}function hK(a,b){a=a|0;b=b|0;Gl(b)}function fU(a){td(a,0,-1);return a}function dN(a,b){a=a|0;b=b|0;Xo(b)}function Xs(a){return Ie(a,-1)?0:a}function Xd(a){TF(a);v[a>>2]=84104}function X_(a,b){a=a|0;b=b|0;Kw(b)}function Sl(a,b){yp(a,b,v[b+4>>2])}function RG(a){return Oh(a,464152)}function QG(a){return Oh(a,464144)}function Ok(a){t[a|0]=0;t[a+1|0]=0}function OG(a){return Oh(a,464168)}function NG(a){return Oh(a,464160)}function Mh(a,b){a=a|0;b=b|0;Kb(a)}function MZ(a,b){a=a|0;b=b|0;ew(b)}function KZ(a,b){a=a|0;b=b|0;Ok(b)}function JZ(a,b){a=a|0;b=b|0;Kh(b)}function IZ(a,b){a=a|0;b=b|0;xb(b)}function Hj(a,b){return(b<<13)+a|0}function Hi(a){a=a|0;t[a+4202|0]=0}function Dg(a,b){td(a,Jb(b),Ab(b))}function Ch(a,b){Xo(a);cf(a+4|0,b)}function By(a,b){a=a|0;b=b|0;Jf(b)}function Bj(a){return cd(a+36|0)^1}function $2(a){a=a|0;ko(a,1,10778)}function yu(a,b,c){return KA(b,c)}function yr(a,b){return qe(a,b)^1}function yf(a,b){return(b<<2)+a|0}function yM(a){return w[a+4232|0]}function wd(a,b){return(b<<1)+a|0}function tr(a){v[a>>2]=v[a>>2]+12}function tV(a,b){return(b<<4)+a|0}function rT(a,b){vB(a,b);return a}function pp(a){v[a>>2]=2;return a}function pc(a,b){return Jb(a)+b|0}function on(a){v[a>>2]=v[a>>2]+28}function mS(a){v[a>>2]=v[a>>2]+32}function jc(a,b){Qw(a,b);return a}function dx(a,b){return v[a+b>>2]}function cN(a,b,c){return Nj(b,c)}function Zfa(a){a=a|0;Bf(a,Si(a))}function ZD(a){return w[a+1|0]==1}function Yo(a){v[a>>2]=v[a>>2]+16}function Yd(a){return v[fc(a)>>2]}function YK(a){v[a>>2]=v[a>>2]+24}function Y$(a){a=a|0;return 10362}function Vi(a){v[a>>2]=0;return a}function Vb(a){return Gg(v[a>>2])}function Te(a){return Tf(a)&65535}function TO(a){v[a>>2]=v[a>>2]+52}function Rh(a){return a-48>>>0<10}function QT(a){return v[wb(a)>>2]}function Pm(a){u[a>>1]=0;return a}function My(a,b){return _N(a,b)^1}function LC(a,b,c){return Fn(b,c)}function Iy(a){return a+1298368|0}function Gy(a){return Yg(a+120|0)}function Gh(a){v[a>>2]=1;return a}function Fh(a){v[a>>2]=v[a>>2]+20}function D4(a){a=a|0;return 10476}function Bq(a){gc(a+4|0);return a}function Bla(a){a=a|0;gW(a,65535)}function Aw(a){return t[a+24|0]&1}function Ao(a){return a+1074328|0}function zr(a){oc(a);EF(a);jK(a)}function yH(a){a=a|0;aq(a);Xb(a)}function w4(a){a=a|0;return 3923}function vL(a){a=a|0;Oy(a);Xb(a)}function ut(a){dg(a);oc(a);dg(a)}function rB(a,b,c){$S(ne(a,b),c)}function qD(a){Yj(a);uY(a);tY(a)}function q9(a){a=a|0;Ny(a);Xb(a)}function pU(a){return w[a|0]<129}function pR(a){tg(a);rf(a);tg(a)}function nE(a){bm(a);Je(a);bm(a)}function k7(a){a=a|0;PJ(a);Xb(a)}function iY(a){ln(a);Yj(a);ln(a)}function i5(a){a=a|0;return 7676}function hW(a,b){hc(a,b+4|0,256)}function gT(a){$i(a);_i(a);$i(a)}function dv(a){bi(a);Ae(a);bi(a)}function c7(a){a=a|0;MJ(a);Xb(a)}function ak(a){v[a>>2]=v[a>>2]+6}function _p(a){ug(a);Ec(a);ug(a)}function Z$(a){a=a|0;return 6987}function XM(a){Vf(a);PM(a);OM(a)}function U$(a){a=a|0;return 2812}function Sx(a){xi(a);uf(a);xi(a)}function SP(a,b,c,d){VP(a,b,c,d)}function Ro(a,b){u[a>>1]=x[b>>1]}function Qe(a){v[a>>2]=v[a>>2]+4}function Pv(a){v[a>>2]=v[a>>2]+2}function Pe(a){v[a>>2]=v[a>>2]+1}function Ow(a){a=a|0;Cs(a);Xb(a)}function Op(a){a=a|0;gx(a);Xb(a)}function OC(a){Xj(a);Jg(a);Xj(a)}function LM(a){Cl(a);Vf(a);Cl(a)}function IP(a,b,c,d){vA(a,b,c,d)}function HN(a){Jg(a);YW(a);LW(a)}function Ge(a,b){v[a>>2]=v[b>>2]}function GF(a){_k(a);al(a);_k(a)}function Fg(a){Nb(a);cr(a);pw(a)}function FA(a){t[a|0]=0;return a}function Er(a){return Qb(a,0,48)}function Ep(a){Og(a);tc(a);Og(a)}function Ek(a){pe(a);Nb(a);pe(a)}function Dd(a){return v[a>>2]!=0}function DH(a){v[a+72>>2]=463096}function CH(a){v[a+72>>2]=463180}function Bu(a){v[a>>2]=v[a>>2]+8}function Bl(a){a=a|0;jf(a);Xb(a)}function BO(a){pk(a);Tf(a);pk(a)}function B4(a){a=a|0;return 7556}function AH(a){a=a|0;wm(a);Xb(a)}function $l(a){tc(a);zw(a);zE(a)}function $L(a){a=a|0;Xy(a);Xb(a)}function $$(a,b){a=a|0;b=b|0;L()}function xh(a){return a<<24>>24}function xb(a){Kd(a+12|0);Kd(a)}function wq(a){u[a+480214>>1]=0}function r0(a){a=a|0;vb(464364)}function qk(a){return!v[a+4>>2]}function p0(a){a=a|0;Ic(464380)}function nw(a,b){return LE(a,b)}function n0(a){a=a|0;vb(464396)}function li(a,b,c){of(a,c,13,b)}function lO(a,b){return jO(a,b)}function kr(a,b){return WV(a,b)}function kf(a,b){return Mg(a,b)}function k0(a){a=a|0;Ic(464412)}function ix(a){return wb(a+8|0)}function i0(a){a=a|0;vb(464428)}function hg(a){return xh(Lg(a))}function g0(a){a=a|0;Ic(464444)}function e0(a){a=a|0;vb(464460)}function c0(a){a=a|0;Ic(464476)}function bN(a,b){return Nj(a,b)}function _b(a,b){return af(a,b)}function Zl(a){return Lv(tc(a))}function Xm(a){vb(a+12|0);Ye(a)}function VU(a,b){return Qj(b,a)}function Ty(a,b){return ah(a,b)}function Sj(a,b){return EE(a,b)}function Sh(a,b){return yf(a,b)}function R6(a){a=a|0;HJ(a-88|0)}function Qm(a){vb(a+12|0);vb(a)}function Qi(a){return Ae(a)&255}function Po(a){return Ym(ee(a))}function PW(a,b){td(a,b,b+16|0)}function Nd(a,b){return Gn(a,b)}function NE(a,b){return KE(a,b)}function Lba(a){a=a|0;return 13}function Kca(a){a=a|0;Xb(Xy(a))}function KC(a,b){return Fn(a,b)}function Is(a){a=a|0;return 127}function Gf(a){vb(a+20|0);vb(a)}function Eq(a){rR(a+12|0);wR(a)}function Ej(a,b){return a>>>b&1}function Al(a,b,c){td(a,b,1<<c)}function $e(a){a=a|0;return a|0}function yca(a){a=a|0;return 6}function yG(a){a=a|0;Xb(jx(a))}function x4(a){a=a|0;Xb(Fx(a))}function vH(){return(db()|0)>0}function uM(a){a=a|0;Xb(vM(a))}function q5(a){a=a|0;Xb(bu(a))}function q1(a){a=a|0;Xb(FG(a))}function pu(a,b){return a<<8|b}function o9(a){a=a|0;Xb(Oy(a))}function m7(a){a=a|0;Xb(QJ(a))}function jM(a){a=a|0;Xb(kM(a))}function hI(a){a=a|0;Xb(oh(a))}function h1(a){a=a|0;Xb(DG(a))}function ec(a,b){v[a+100>>2]=b}function e7(a){a=a|0;Xb(NJ(a))}function e5(a){a=a|0;Xb(HH(a))}function d$(a){a=a|0;Xb(SF(a))}function b5(a){a=a|0;Xb(Kx(a))}function aM(a){a=a|0;Xb(bM(a))}function Zu(a){return a>>>27^a}function X5(a){a=a|0;Xb(wm(a))}function X$(a){a=a|0;Xb(gx(a))}function WV(a,b){return b-a>>2}function V$(a){a=a|0;Xb(Cs(a))}function Uka(a){a=a|0;return 9}function U_(a){a=a|0;Xb(HF(a))}function UL(a){a=a|0;Xb(VL(a))}function U0(a){a=a|0;Xb(AG(a))}function TS(a){return a+4896|0}function T5(a){a=a|0;Xb(aq(a))}function T0(a){a=a|0;Xb(zG(a))}function SM(a){a=a|0;Xb(TM(a))}function Rx(a){a=a|0;Xb(at(a))}function Q7(a){a=a|0;Xb(Ht(a))}function O_(a){a=a|0;Xb(uF(a))}function Nx(a){a=a|0;Xb(_s(a))}function M_(a){a=a|0;Xb(tF(a))}function LH(a){a=a|0;Xb(Cq(a))}function KH(a){a=a|0;Xb(vf(a))}function I1(a){a=a|0;Xb(HG(a))}function Hy(a,b){return b-a>>3}function HJ(a){a=a|0;Xb(sy(a))}function FT(a){GB(Qb(a,0,872))}function EM(a){a=a|0;Xb(FM(a))}function Bd(a,b){t[a|0]=w[b|0]}function xr(a){Vi(a);return a}function wk(a){return Dd(a)^1}function up(a){return a>>>0<5}function ue(a){a=a|0;return 1}function sl(a){return a+120|0}function se(a){a=a|0;return 2}function sR(a){Tj(a);return a}function rM(a){a=a|0;return 7}function nS(a,b){return b-a|0}function nA(a){qF(a);return a}function mc(a){Hg(a);return a}function lc(a,b){return a+b|0}function l9(){return 19923024}function jC(){return Nc(20,4)}function ii(a){return cd(a)^1}function ic(a){a=a|0;return 0}function hh(a){dd(a);return a}function gG(a){a=a|0;return 3}function eM(a){a=a|0;return 5}function eI(a){a=a|0;return-1}function dd(a){vh(a);return a}function bf(a,b){u[a+28>>1]=b}function bR(){return Nc(36,4)}function aX(){return Nc(32,4)}function _U(a,b){bc(a,b,1108)}function Zv(a){return!v[a>>2]}function ZE(a){return a>>>0>8}function ZB(a,b){bc(a,b,1024)}function RW(a){Er(Qb(a,0,48))}function Ov(a){a=a|0;return 4}function LU(a,b){of(a,b,33,1)}function Ko(a,b){v[a+36>>2]=b}function Ju(a){return a+256|0}function It(a,b){v[a+32>>2]=b}function H1(){Zp(464244,JG())}function Go(a){mc(a);return a}function CD(a,b){bc(a,b,1954)}function $w(){return lb()<<16}function $g(a){return D(a)==N}function zw(a){cF(a,v[a>>2])}function zt(a){v[a>>2]=56276}function zS(a,b,c){Yq(a,c,b)}function zR(a){return D(a)<N}function z5(a){a=a|0;UY(a,1)}function xS(a,b,c){Xq(a,c,b)}function xM(a,b,c){Kn(a,b,c)}function vX(a,b){bc(a,b,576)}function vU(a,b){bc(a,b,608)}function uq(a,b){z[a+8>>2]=b}function uY(a){mY(a,v[a>>2])}function tt(a,b){dg(a);dg(a)}function tU(a){return a+48|0}function sq(a,b){z[a+4>>2]=b}function rq(a,b){t[a+33|0]=b}function rN(a,b){pk(a);pk(a)}function qn(a,b){le(a,b+8|0)}function oV(a,b){bc(a,b,130)}function nX(a){return a+36|0}function mV(a,b){bc(a,b,600)}function lR(a){kR(a,v[a>>2])}function l7(a){a=a|0;RJ(a,1)}function kp(a,b){wb(b);wb(a)}function gX(a){FI(a,v[a>>2])}function gV(a,b){bc(a,b,126)}function fS(a){eS(a,v[a>>2])}function fL(a){v[a>>2]=55204}function fK(a,b,c){qK(a,b,c)}function ep(a,b){v[a+8>>2]=b}function de(a,b){v[a+4>>2]=b}function dc(a){return a+12|0}function dB(a,b){bi(a);bi(a)}function d7(a){a=a|0;Wu(a,1)}function cr(a){zU(a,v[a>>2])}function cn(a,b){pe(a);pe(a)}function bU(a,b){bc(a,b,204)}function bE(a,b){bm(a);bm(a)}function aI(a,b){xi(a);xi(a)}function _S(a,b){bc(a,b,263)}function Ze(a,b){t[a+11|0]=b}function Yw(a,b){ug(a);ug(a)}function Ys(a,b){Zp(a,b+4|0)}function YW(a){XW(a,v[a>>2])}function Xp(a){return a+20|0}function XC(a,b){of(a,b,8,2)}function WW(a,b){bc(a,b,674)}function Uw(a,b){_F(a,be(b))}function TC(a,b){pX(a,be(b))}function Rv(a,b){bc(a,b,512)}function Qr(a,b){bc(a,b,192)}function QO(a){v[a>>2]=78428}function PM(a){MM(a,v[a>>2])}function Od(a){de(a,v[a>>2])}function Kz(a,b){t[a+34|0]=b}function Jz(a,b){t[a+32|0]=b}function JJ(a){v[a>>2]=60044}function Iz(a,b){t[a+35|0]=b}function Ip(a){v[a>>2]=27764}function EW(a,b){bc(a,b,128)}function EF(a){oK(a,v[a>>2])}function Dm(a){v[a>>2]=89052}function DC(a,b){Xj(a);Xj(a)}function CX(a,b){bc(a,b,218)}function CE(a,b){bc(a,b,497)}function BY(a,b){bc(a,b,610)}function AX(a,b){bc(a,b,157)}function AU(a,b){bc(a,b,146)}function AO(a){zO(a,v[a>>2])}function $r(a,b){Og(a);Og(a)}function $c(a,b){a=a|0;b=b|0}function zC(a,b){bc(a,b,33)}function wb(a){return a+8|0}function ska(a){a=a|0;FT(a)}function rD(a,b){bc(a,b,64)}function qd(a){return a+1|0}function qV(a,b){bc(a,b,30)}function qQ(a){return 0-a|0}function oC(a,b){bc(a,b,40)}function m9(){return 393216}function lE(a,b){bc(a,b,38)}function jE(a,b){bc(a,b,41)}function h6(){return 460756}function gga(a){a=a|0;lA(a)}function gd(a){return!Ab(a)}function fw(a,b){bc(a,b,16)}function fc(a){return a+4|0}function ej(a){return a+3|0}function eV(a,b){bc(a,b,32)}function dw(a,b){bc(a,b,65)}function ds(a,b){bc(a,b,36)}function dW(a,b){bc(a,b,52)}function bz(a){Qb(a,0,2048)}function aY(a,b){bc(a,b,12)}function aW(a,b){bc(a,b,80)}function Yba(){return 65535}function Xja(a){a=a|0;Wo(a)}function XO(a){Qb(a,0,1024)}function Wo(a){Qb(a,0,4096)}function Ve(a){return a+2|0}function SE(a,b){qw(a,b,22)}function QF(a,b){bc(a,b,24)}function PU(a,b){bc(a,b,96)}function PD(a,b){bc(a,b,11)}function PB(a){v[a+12>>2]=0}function MR(a,b){bc(a,b,27)}function MD(a,b){bc(a,b,17)}function Lg(a){return a&255}function KX(a,b){bc(a,b,98)}function IU(a){if(a){Xb(a)}}function HX(a,b){bc(a,b,48)}function Gv(a,b){bc(a,b,66)}function Cla(){return 65534}function Cf(a,b){t[a+3|0]=b}function Bv(a,b){bc(a,b,22)}function BD(a){Qb(a,0,1954)}function Aq(a){Qb(a,0,8192)}function Ap(a,b){t[a+1|0]=b}function zX(a){Qb(a,0,157)}function zE(a){Og(a);tc(a)}function yd(a){_p(a);pF(a)}function yU(a){Qb(a,0,146)}function yB(a){Qb(a,0,256)}function vc(a){v[a+8>>2]=0}function uX(a){Qb(a,0,576)}function uU(a){Qb(a,0,608)}function uN(a){pk(a);Tf(a)}function tq(a,b){z[a>>2]=b}function tY(a){ln(a);Yj(a)}function rR(a){Kq(a,Yd(a))}function q4(){return 79528}function pw(a){pe(a);Nb(a)}function pB(a){Qb(a,0,512)}function p4(){return 80304}function or(a){nC(a,Yd(a))}function o4(){return 81856}function nr(a){mC(a,Yd(a))}function lV(a){Qb(a,0,600)}function lC(a,b){bc(a,b,4)}function jd(a){nE(a);oE(a)}function jK(a){dg(a);oc(a)}function hn(a){OC(a);uv(a)}function hX(a){t[a+31|0]=0}function hR(a){ug(a);Ec(a)}function hE(a,b){oi(a,2,b)}function gY(a,b){bc(a,b,3)}function gP(a){ku(a,Yd(a))}function fV(a){Qb(a,0,126)}function eX(a){IC(a,Yd(a))}function dS(a){bi(a);Ae(a)}function cf(a,b){v[a>>2]=b}function bg(){rd(8267);L()}function aU(a){Qb(a,0,204)}function aO(a){Fz(a,Yd(a))}function Zx(){ho(4782);L()}function ZW(a){JC(a,Yd(a))}function Yn(){ho(8267);L()}function Ye(a){Ep(a);cs(a)}function Yc(a){a=a|0;Xb(a)}function XB(a){Qb(a,0,130)}function Wv(a,b){bc(a,b,5)}function Wb(a){Ln(v[a>>2])}function VW(a){Qb(a,0,192)}function Tka(a){a=a|0;gb=a}function Sc(){rd(4782);L()}function RV(a,b){bc(a,b,2)}function PX(a,b){bc(a,b,6)}function Oi(a){return a!=a}function OM(a){Cl(a);Vf(a)}function Nq(a){Sx(a);AR(a)}function Nla(){return gb|0}function Lc(a){Ek(a);qv(a)}function LW(a){Xj(a);Jg(a)}function Kl(a){IA(a,Yd(a))}function IT(a){wB(a,Yd(a))}function HT(a){xB(a,Yd(a))}function Gp(a,b){bc(a,b,8)}function Fs(a){a=a|0;Ls(a)}function BE(a){Qb(a,0,497)}function Ak(a,b){yp(a,b,0)}function AY(a){Qb(a,0,610)}function rC(a){Qb(a,0,80)}function kE(a){Qb(a,0,38)}function jD(a){Qb(a,0,66)}function iE(a){Qb(a,0,41)}function gD(a){Qb(a,0,64)}function cW(a){Qb(a,0,52)}function Yi(a,b){t[a|0]=b}function QU(a){Qb(a,0,96)}function Q8(){return 2048}function JX(a){Qb(a,0,98)}function IX(a){Qb(a,0,48)}function Cw(a){Qb(a,0,36)}function AC(a){Qb(a,0,33)}function zc(a){gc(a+8|0)}function yR(a){Tm(a,0,0)}function yC(a,b){pW(a,b)}function xq(a,b){Ge(a,b)}function vO(a,b){kw(a,b)}function vB(a,b){yc(a,b)}function uO(a,b){tO(a,b)}function tD(a,b){_j(a,b)}function mo(a,b){GH(a,b)}function mh(a){a=a|0;L()}function lp(a,b){Bd(a,b)}function js(a,b){Qw(a,b)}function iR(a){Lq(a+8|0)}function ez(a,b){qi(a,b)}function ew(a){u[a>>1]=0}function ed(a){xb(a+8|0)}function aB(a,b){ag(a,b)}function _W(a,b){cf(a,b)}function Zk(a,b){de(a,b)}function ZV(a,b){VV(a,b)}function Xo(a){v[a>>2]=0}function Wh(a,b){Vh(a,b)}function UU(a,b){le(a,b)}function Lpa(){ua();L()}
function Fk(a){vb(a+4|0)}function AN(a,b){oW(a,b)}function Jf(a){t[a|0]=0}function qO(a){$N(a,0)}function ps(a){_F(a,0)}function oD(a){SX(a,0)}function kn(a){pX(a,0)}function iu(a){WO(a,0)}function iq(a){oL(a,0)}function hu(a){VO(a,0)}function Ig(a){fX(a,0)}function Hc(a){Fe(a,0)}function Ei(a){pL(a,0)}function Di(a){nL(a,0)}function lf(a){a=a|0}function fR(a){av(a)}function XH(a){HL(a)}function WT(a){dd(a)}function Hb(a){vb(a)}function _$(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var kb=c([null,Um,Tb,Ot,gg,BL,ko,p6,$5,mT,m5,k4,f3,wT,Um,P5,vZ,un,ih,a5,$,wD,pn,r_,gx,Oc,Ie,$Y,tn,$e,Yc,DF,hs,Lfa,Zpa,Wpa,Rpa,Lpa,Ipa,xpa,_C,Voa,Roa,eqa,Cpa,OB,e6,Una,Tna,GW,Qf,cp,jr,Fb,$c,GW,d6,rka,qT,NS,Rq,Mo,a6,Z5,Um,Rq,Mo,pi,Gha,gg,Tb,BL,GR,wu,xf,nI,uu,$f,nga,JG,mga,Gg,kP,w5,kga,GR,Pfa,sA,sA,mha,eha,Jfa,Ffa,Vga,Sga,dga,bga,c5,lga,$f,sfa,L5,wz,J5,EN,H5,Yea,Sea,v5,Um,F5,D5,xea,Ut,qea,hea,_M,Bp,Um,Qf,Wy,ql,OI,Fy,jo,Zh,i8,By,$c,Zh,If,jo,Zh,$c,l5,f5,$4,Y4,H4,s4,Os,$f,d4,O3,Lh,ri,p$,u3,aH,$G,$2,Os,R2,On,px,Fs,hk,Wc,Ff,x0,On,us,C1,u1,m0,I2,b0,vG,W$,vG,p2,BG,Q$,J$,F$,Lh,pG,Qf,Nn,Mn,mj,kG,jG,iG,Ut,o$,ia,Pp,Op,Bt,Zc,Pb,l$,Tw,k$,jm,j$,aG,i$,Lp,bl,aG,Vd,os,Zh,g$,Cs,Rw,W_,V_,df,h$,f$,e$,X_,Kh,df,JF,df,Iw,jo,R_,Q_,P_,jo,Ow,Bt,SF,d$,Hp,GL,c$,$e,Yc,b$,ue,ue,Bt,ty,a$,$_,__,mh,_$,Z_,Y_,HF,U_,Hp,T_,Yc,ic,ue,ue,ic,ic,S_,uF,O_,Hp,N_,tF,M_,L_,K_,J_,I_,H_,G_,F_,E_,Py,Dfa,yfa,vfa,es,LF,z_,FF,kG,$c,rF,w_,v_,Ow,Qf,Qf,fF,Td,t_,s_,Qf,$c,$c,$c,Fy,Wy,By,ql,k_,jr,q_,Fb,l_,Tk,j_,$c,fF,ki,i_,h_,g_,c_,AE,wn,$c,ZZ,tE,Rb,XZ,WZ,VZ,UZ,Ke,Bc,TZ,SZ,RZ,QZ,Cg,zg,wh,PZ,hw,qE,OZ,pE,Qf,NZ,cp,Qf,Qf,JZ,MZ,$c,LZ,AE,KZ,IZ,FZ,EZ,DZ,XD,CZ,We,BZ,AZ,zZ,yZ,Uz,OT,RS,xZ,me,wZ,gw,UD,Hd,hk,yh,sZ,rZ,$v,Le,Rr,pf,DO,qZ,pZ,oZ,ac,TD,nZ,SD,pd,bw,Zm,Pr,Ly,Bn,Cn,Sd,Xe,kZ,Qf,Fy,Wy,By,$c,jZ,iZ,_r,Xc,iw,dZ,Nr,cZ,Ag,Pc,Ob,Sf,Ff,bZ,Qv,aZ,Wc,Mr,Tha,_Y,ZY,Ri,YY,zD,Lr,ud,XY,Kr,WY,Mea,Uf,Ce,Hm,so,rz,lqa,SY,zM,yD,Nv,Jr,Nk,Ff,kqa,jqa,YE,iqa,kh,hqa,gqa,_l,fqa,GY,mj,dqa,kj,Rf,jG,iG,Ut,Pp,aqa,$pa,_pa,wY,Vpa,_l,pD,mf,Upa,Tpa,Spa,Qpa,No,nB,Ppa,Opa,Npa,Mpa,If,ce,kt,nD,Iv,mD,Hpa,Gpa,Jpa,oY,Bn,Cn,pY,mn,ql,$c,Pf,cY,Dpa,Mk,ypa,wpa,vpa,Vd,Bf,CY,zpa,YX,upa,XX,tpa,oB,spa,UX,rpa,qpa,ppa,Rw,opa,Bn,gq,lpa,Nr,jp,kpa,jpa,zD,ipa,Qk,hpa,gpa,fpa,epa,vn,gr,dpa,cpa,bpa,apa,_l,$C,kj,Rf,Av,zv,OX,jz,Wha,Zj,yv,uz,pq,Yt,b6,VC,Soa,wX,Hh,Ooa,Noa,Qfa,Koa,ega,xv,Cp,Joa,Ioa,Hoa,Dr,QE,Goa,Iu,Vo,Foa,Eoa,Qoa,rX,m_,Doa,Qo,RE,wv,Coa,Ff,Boa,Mc,Aoa,zoa,qX,yoa,f_,xoa,woa,voa,uoa,oX,toa,Uu,soa,Ff,roa,qoa,tw,vY,Poa,Ff,poa,ooa,gq,xp,noa,moa,loa,CO,SC,koa,SC,SC,RC,kX,QC,Fm,joa,jba,ioa,hoa,goa,foa,eoa,doa,coa,dea,jX,Qf,SW,kd,gp,Yna,Af,EC,Qna,Or,boa,Qf,CC,Pna,aoa,$na,_na,ag,eea,Tfa,Wda,Zna,Ot,Xna,Wna,Vna,df,$f,$e,$c,$c,$c,Sna,jr,Rna,sr,Lna,Kna,Jna,Ina,Hna,Gna,Fna,Ena,Dna,BW,AW,Cna,Bna,Ana,zna,yna,xna,wna,vna,xW,gn,qW,Rf,iW,xC,sna,wC,rna,qr,BS,Dr,qna,pna,ona,nna,ZC,ES,Gb,Wl,vC,mna,YZ,lna,kna,gW,fW,vw,Zr,uC,jna,He,ina,Ot,Dr,hna,Dr,gna,Vr,fna,Ff,wY,kv,TV,cna,bna,Vd,ana,$ma,_ma,iC,Zma,hv,Yma,Xma,Wma,Vma,Uma,Tma,uE,Sma,Rma,_ha,Qma,Pma,Oma,Nma,Wja,lha,jha,Mma,r6,MC,s6,Lma,Kma,ky,ly,Ofa,Jma,Ff,mX,lX,HS,Ima,Hma,$v,Rw,LV,mr,Gma,Fma,Lh,ri,Ema,Kv,fv,Oj,Jh,_B,vma,uma,Cma,rv,$c,rma,qma,QD,pma,EO,oma,nma,vN,gp,mma,iV,lma,kma,fm,em,cv,AA,jma,ima,Oo,hma,am,fma,ema,VB,tp,Iw,$la,TB,_la,Zla,Yla,Ol,Xla,_l,kj,Rf,Jh,Ula,Tla,Sla,df,Rla,Qla,WU,df,Yr,Pla,wC,Lla,Lk,xk,cv,Mc,Kla,Pea,LV,mr,kv,Hla,Gla,pD,ZU,TB,bw,Fla,Ela,Dla,Yba,Cla,Bla,Ala,_u,zla,_u,yla,qs,n_,sla,_l,ula,rla,_B,vla,tla,kj,Rf,DU,CU,ola,xC,nla,kla,jla,US,iV,rX,nha,YQ,gla,$v,bla,ala,TD,hU,$ka,_ka,Zka,Yka,fn,gU,Xka,Wka,Vka,ZT,Qka,Pka,Oka,Nka,Mka,Lka,Kka,$m,Vja,ST,Jka,Ika,Hka,Gka,Fka,Eka,Dka,ch,Xha,du,aha,iha,gha,Cka,Qea,Vd,Bka,wC,Aka,zka,yka,rv,KB,xka,LT,Bh,wka,vka,vT,uka,tka,$q,ska,CT,kv,yT,oka,nka,YU,mka,kka,Yha,gka,fka,jfa,eka,dka,cka,ON,bka,ifa,PN,aka,$ja,_ja,Q4,NH,Zha,ev,Ff,Xfa,Wfa,bT,aT,Qf,$c,qB,Uja,Tja,Sja,Rja,Qja,Pja,Oja,Nja,Mja,Lja,Kja,Jja,Ija,Hja,Gja,Fja,Eja,Dja,Cja,Bja,Aja,zja,yja,xja,wja,vja,uja,tja,sja,rja,pja,oja,nja,mja,lja,kja,jja,ija,hja,gja,fja,eja,dja,cja,bja,aja,$ia,_ia,Zia,Yia,Xia,Wia,Via,Uia,Tia,Sia,Ria,Qia,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Fia,Eia,Dia,Cia,Bia,Aia,zia,yia,xia,wia,via,uia,tia,sia,ria,qia,pia,oia,nia,mia,lia,kia,jia,iia,hia,gia,fia,eia,dia,cia,aia,Uq,bia,hS,fj,gE,lS,Uha,Iha,Sha,Rha,Qha,Pha,Oha,jS,Nha,Mha,Lha,Kha,Fu,Hha,Jha,SR,Eha,Dha,Uv,KR,Efa,Bha,Aha,qq,Dz,Bz,Az,TA,zha,CR,yha,xha,Qf,vha,$c,Io,oq,uR,sha,rha,Ki,qha,Uf,oha,pha,$e,$c,st,t6,dj,kha,Ufa,Wi,$ha,_h,XQ,lka,$h,pfa,hha,Nr,fha,Jh,Tw,dha,cha,bha,Nr,$ga,_ga,Tw,Qga,Pga,OQ,df,Nga,_l,pG,Nn,Mn,Ut,Lh,Mga,_l,Oga,Rf,xu,QQ,Qf,$e,MQ,kj,Rf,Qf,kj,Rf,fp,Lga,u_,Re,mZ,JQ,Kga,Kpa,IQ,HQ,GQ,FQ,EQ,DQ,CQ,BQ,AQ,zQ,yQ,xQ,wQ,vQ,uQ,tQ,sQ,rQ,pQ,oQ,nQ,mQ,lQ,kQ,jQ,iQ,hQ,gQ,fQ,eQ,dQ,cQ,bQ,aQ,$P,_P,ZP,YP,XP,WP,Jga,Iga,Hga,Gga,Fga,Ega,Dga,Cga,Bga,Aga,zga,yga,xga,wga,vga,uga,tga,uha,QP,Rz,Au,nR,sga,rga,Qz,Bg,Eo,Hq,qga,OP,So,xA,wA,Om,Tz,FO,Sz,Do,qu,JP,pga,uA,Mm,jB,HP,kB,ZA,Du,Pi,oga,$O,Vha,Yja,eY,iga,gO,hga,Xja,gga,sf,fga,cga,n$,D_,y_,B_,$fa,x_,C_,m$,A_,_m,_fa,CS,SO,yq,Zfa,ufa,eda,Yfa,RO,iA,Fha,Vfa,rea,vea,Sfa,tea,pea,df,df,Gs,Rfa,GS,Nfa,Mfa,Kfa,yO,jka,hka,Moa,Loa,mla,lla,fla,ela,una,tna,dma,cma,Nna,Mna,fZ,eZ,$oa,_oa,HZ,GZ,uZ,tZ,Wla,Vla,qla,pla,qka,pka,Ypa,Xpa,Fpa,Epa,b_,a_,$Z,_Z,Jla,Ila,xla,wla,tma,sma,Ona,DW,Xoa,Woa,Uoa,Toa,cqa,bqa,npa,mpa,Ola,Mla,hfa,gfa,Vea,Uea,xma,wma,Ska,Rka,bma,ama,Zoa,Yoa,ila,hla,dla,cla,Bpa,Apa,Dma,zma,yma,e_,d_,hZ,gZ,ena,dna,Bma,Ama,mh,Hfa,Gfa,aP,$c,$f,qB,Cfa,ws,Afa,Bfa,RQ,xfa,zfa,wfa,_t,tfa,Xga,Rm,Zga,Yga,rfa,qfa,Tr,Tga,Uga,ofa,ika,o_,nfa,kF,Xw,yz,UD,mfa,RB,lfa,Wga,kfa,ffa,efa,pD,dfa,Hr,TB,cfa,bfa,afa,_B,$ea,Jh,_ea,Zea,Xea,Wea,Tea,_l,pJ,v6,u6,kj,Rf,Rea,Tq,Oea,Lea,tv,Jea,Iea,Hea,Gea,_f,Vh,vm,Fea,DN,Eea,zea,Dea,Nea,Cea,wea,Aea,Kea,yea,mz,nz,oN,Qf,fea,jr,eN,sea,YS,lq,nea,mea,lea,kea,jea,mN,uea,nq,ag,lN,gea,yl,Vh,dN,cea,bea,aea,$da,_da,Zda,Zf,Yda,Xda,iea,oea,Uda,Tda,Uh,Sda,Rda,NM,Eda,en,jr,kN,Dda,eN,Cda,$c,dN,$c,TM,SM,SM,RM,ic,lf,ic,ic,ic,$c,Ov,Mda,Nda,Pda,Oda,Qda,Ji,hs,hs,dz,QM,dz,dz,gma,lf,DW,Ida,Hda,Gda,Fda,Lda,Hi,UM,jda,ic,ic,ue,cz,se,se,ue,Kda,Jda,$c,lf,$c,lf,Ada,mda,FM,EM,EM,lda,ic,lf,ic,ic,ic,$c,Uka,JM,yda,oda,nda,zda,Ji,wda,vda,uda,tda,sda,rda,qda,pda,xda,Hi,IM,ic,ic,ue,se,se,ue,HM,GM,kda,gda,AM,Zg,jf,mh,hda,_y,ida,ic,fda,QM,dda,$f,OS,cda,bda,ada,$ca,Fu,Qca,Fca,xca,qca,jca,bca,Tba,Kba,Dba,hca,Vda,Bda,_ca,Zca,sn,wO,vM,uM,uM,RM,ic,lf,ic,ic,ic,$c,gG,Uca,Vca,Xca,Wca,Yca,Ji,Tca,Hi,wM,ic,ic,ue,se,se,ue,Sca,Rca,tM,Yy,Xy,Kca,sM,Jca,ic,lf,ic,ic,ic,$c,rM,Nca,Oca,Pca,Ji,Mca,Hi,Lca,ic,ic,ue,se,se,$c,lf,qM,Ica,Hca,pM,Gca,oM,nM,Eca,kM,jM,jM,zca,ic,lf,ic,ic,ic,$c,yca,Bca,Cca,Dca,Ji,Aca,Hi,lM,ic,ic,ue,se,se,wca,Bl,Bl,rca,ic,lf,ic,ic,ic,$c,eM,tca,uca,vca,Ji,sca,Hi,fM,ic,ic,ue,se,se,pca,bM,aM,aM,kca,ic,lf,ic,ic,ic,$c,eM,mca,nca,oca,Ji,lca,Hi,cM,ic,ic,ue,se,se,ica,$L,$L,fca,rM,gca,qM,eca,dca,pM,cca,oM,nM,aca,Bl,Bl,Wba,ic,lf,ic,ic,ic,$c,se,Zba,_ba,$ba,Ji,Xba,Hi,Vba,ic,ic,ue,se,se,Sba,Uba,VL,UL,UL,Nba,ic,lf,ic,ic,Mba,$c,Lba,Pba,Qba,Rba,Ji,Oba,Hi,Uy,ic,ic,ue,se,se,$c,lf,Jba,Bl,Bl,Eba,ic,lf,ic,ic,ic,$c,gG,Gba,Hba,Iba,Ji,Fba,Hi,RL,ic,ic,ue,se,se,Cba,Bl,Bl,xba,ic,lf,ic,ic,ic,$c,Ov,zba,Aba,Bba,Ji,yba,Hi,OL,ic,ic,ue,se,se,m9,vba,s9,d9,l9,k9,T8,px,aL,Kt,DL,P8,lba,CL,Q8,$K,L8,K8,$e,hba,gba,DL,J8,H8,yL,dba,Oy,XK,ty,WK,VK,v8,r8,s8,t8,Sy,G8,Paa,tL,F8,E8,D8,C8,B8,A8,z8,y8,x8,w8,q8,Sy,k8,TK,SK,RK,QK,OK,NK,MK,LK,KK,JK,IK,HK,j8,go,GK,FK,vl,hq,h8,sH,g8,e8,d8,c8,b8,CK,AK,Dt,a8,$7,Z7,Y7,X7,W7,V7,U7,T7,S7,X8,kL,jL,iL,gL,V6,T6,yL,Sy,K9,J9,I9,H9,G9,F9,E9,D9,C9,B9,A9,z9,y9,x9,w9,v9,u9,t9,ua,r9,Ny,q9,p9,vL,n9,vL,o9,Mq,j9,Rga,xl,xs,hT,Pl,h9,g9,N7,e9,zk,qT,su,$8,jga,W8,jI,V8,O5,Cha,R7,Ot,wha,tha,aga,_8,i9,c9,xz,og,Y8,Ifa,S8,rL,qL,$K,O8,R8,_K,N8,M8,df,Z8,U8,a9,bc,I8,u8,LO,p8,o8,n8,W6,cA,dA,b9,HO,m8,l8,no,EK,Bea,f8,Si,_7,Xc,IO,tz,Zja,sz,M7,L7,K7,pK,J7,gK,At,gK,At,aa,p7,o7,f7,n7,mh,Ht,Q7,f9,$e,mh,$e,Yc,P7,O7,mh,lK,kK,lK,kK,$c,Ct,$c,Ct,iK,hK,iK,hK,Yc,I7,$e,Yc,H7,G7,Yc,eK,dK,mh,F7,cK,E7,cK,D7,bK,C7,bK,Yc,B7,A7,Yc,$J,_J,wt,wt,wt,wt,z7,zy,zy,zy,Yc,y7,x7,Yc,ZJ,YJ,w7,XJ,v7,XJ,u7,WJ,t7,WJ,Yc,s7,r7,Yc,VJ,UJ,vt,vt,vt,vt,q7,wy,wy,wy,QJ,m7,Hp,l7,PJ,k7,ue,ue,j7,i7,Bt,h7,g7,mh,NJ,e7,Hp,d7,MJ,c7,ue,ic,ue,b7,a7,$6,_6,Z6,Y6,X6,mh,$c,Ct,$c,Ct,sy,HJ,Q6,P6,GJ,EJ,DJ,CJ,BJ,AJ,zJ,yJ,xJ,wJ,vJ,uJ,tJ,sJ,rJ,qJ,S6,R6,O6,N6,M6,L6,K6,J6,H6,G6,F6,E6,D6,C6,B6,A6,z6,y6,$e,mh,$e,mh,x6,w6,q6,o6,j6,n6,m6,l6,k6,g6,f6,Rs,c6,CI,BI,AI,Ti,_M,Bp,wo,Fc,N5,M5,K5,I5,G5,E5,C5,Qx,B5,U6,I6,FJ,A5,wo,z5,y5,x5,QH,$e,wm,X5,$c,Um,gI,fI,ic,ic,W5,eI,V5,bt,U5,bt,aq,T5,$c,Um,gI,fI,ic,ic,S5,eI,R5,bt,Q5,bt,at,Rx,cI,bI,at,Rx,cI,bI,_s,Nx,SH,RH,_s,Nx,SH,RH,bu,q5,r5,p5,u5,t5,s5,oh,hI,oh,hI,Cq,LH,o5,n5,vf,KH,k5,j5,lf,d5,g5,HH,$e,Yc,i5,G4,F4,E4,h5,e5,Kx,b5,Y5,ic,_4,Z4,X4,cu,cu,Lx,Hx,$s,YH,AH,W4,V4,U4,T4,yH,S4,R4,P4,O4,AH,N4,wH,M4,L4,yH,K4,wH,J4,I4,$e,mh,mh,p_,y4,u4,tH,Fx,Yc,D4,C4,Yc,B4,z4,A4,x4,Yc,w4,v4,t4,ic,ic,ic,yx,Qh,Ph,Ns,Xb,Ss,mk,lk,nl,xx,ml,c4,qj,Ug,a4,_3,fH,fH,W3,U3,eH,rj,S3,Q3,ye,N3,r4,Bx,Ox,ux,Qh,Ph,Ms,um,il,tm,pn,sm,qj,Ug,cH,rj,z3,t3,s3,n4,Ex,i6,OH,n3,Vs,tn,i3,Rn,Ax,lf,P2,Js,O2,N2,M2,L2,J2,G2,F2,jl,E2,D2,B2,_5,z2,y2,v2,u2,q2,o2,n2,m2,l2,k2,j2,i2,h2,g2,f2,e2,d2,c2,b2,a2,$1,_1,Z1,Y1,X1,W1,V1,U1,T1,S1,R1,Q1,P1,O1,N1,M1,L1,F1,J1,a0,K1,H1,G1,E1,q4,o4,p4,Cx,mH,pl,lH,$p,c1,b1,rI,kH,jH,K0,J0,H0,G0,E0,D0,B0,A0,y0,w0,u0,t0,r0,kx,p0,n0,k0,i0,g0,e0,c0,HG,I1,sM,FG,q1,p1,o1,n1,m1,uW,l1,k1,j1,DG,h1,g1,f1,e1,d1,ic,a1,$0,AG,U0,S0,R0,EK,P0,N0,zG,T0,ty,lZ,Q0,O0,M0,$e,Yc,Yc,D1,B1,A1,z1,y1,x1,w1,v1,uW,t1,s1,r1,Yc,EG,EG,mx,ue,ue,i1,ue,Yc,_0,Z0,mx,ic,ic,Y0,Ov,Yc,X0,W0,mx,ic,ic,V0,Ov,$e,Yc,m4,l4,j4,$e,Yc,i4,h4,g4,Yc,f4,e4,b4,$3,Z3,Y3,X3,V3,T3,R3,P3,Yc,M3,L3,K3,J3,I3,H3,G3,F3,E3,D3,C3,Yc,B3,A3,y3,x3,w3,v3,r3,q3,Yc,p3,o3,m3,l3,k3,j3,h3,g3,$e,Yc,se,e3,d3,c3,b3,a3,_2,L0,F0,z0,j0,f0,s0,o0,$e,Yc,se,Z2,Y2,X2,W2,V2,U2,I0,C0,v0,h0,d0,q0,l0,jx,yG,T2,jx,yG,S2,Yc,Is,Is,Mh,Mh,Mh,TG,ic,gl,gl,Yc,Is,Is,Mh,Mh,Mh,TG,ic,gl,gl,Yc,as,as,Mh,Mh,Mh,SG,ic,gl,gl,Yc,as,as,Mh,Mh,Mh,SG,ic,gl,gl,Yc,Q2,K2,Yc,H2,C2,Yc,A2,x2,Yc,w2,t2,Yc,MG,s2,$c,Yc,MG,r2,$c,Da,$$,Yc,Y$,Yc,Z$,X$,V$,Op,Op,Op,Op,Ow,Yc,U$,$e,Yc,lf,lf,T$,I$,M$,S$,Yc,K$,N$,R$,Yc,L$,O$,P$]);function lb(){return s.byteLength/65536|0}function qb(rb){rb=rb|0;var mb=lb()|0;var nb=mb+rb|0;if(mb<nb&&nb<65536){var ob=new ArrayBuffer(B(nb,65536));var pb=new Int8Array(ob);pb.set(t);t=new Int8Array(ob);u=new Int16Array(ob);v=new Int32Array(ob);w=new Uint8Array(ob);x=new Uint16Array(ob);y=new Uint32Array(ob);z=new Float32Array(ob);A=new Float64Array(ob);s=ob;r.buffer=s;e=w}return mb}return{"va":VY,"wa":wba,"xa":uba,"ya":Yc,"za":Xb,"Aa":tba,"Ba":sba,"Ca":rba,"Da":Kt,"Ea":$c,"Fa":qba,"Ga":pba,"Ha":oba,"Ia":hs,"Ja":nba,"Ka":GL,"La":mba,"Ma":$e,"Na":FL,"Oa":EL,"Pa":FL,"Qa":kba,"Ra":E$,"Sa":D$,"Ta":C$,"Ua":iba,"Va":AL,"Wa":fba,"Xa":zL,"Ya":eba,"Za":cba,"_a":bba,"$a":aba,"ab":$aa,"bb":_aa,"cb":Zaa,"db":Yaa,"eb":Xaa,"fb":Waa,"gb":Vaa,"hb":Uaa,"ib":Taa,"jb":Saa,"kb":Raa,"lb":Qaa,"mb":Oaa,"nb":Naa,"ob":Maa,"pb":Laa,"qb":Kaa,"rb":Jaa,"sb":Iaa,"tb":Haa,"ub":Gaa,"vb":Faa,"wb":Eaa,"xb":Daa,"yb":Caa,"zb":Baa,"Ab":Aaa,"Bb":zaa,"Cb":yaa,"Db":xaa,"Eb":waa,"Fb":vaa,"Gb":uaa,"Hb":taa,"Ib":saa,"Jb":raa,"Kb":qaa,"Lb":paa,"Mb":oaa,"Nb":naa,"Ob":maa,"Pb":laa,"Qb":kaa,"Rb":jaa,"Sb":iaa,"Tb":haa,"Ub":gaa,"Vb":faa,"Wb":eaa,"Xb":daa,"Yb":caa,"Zb":baa,"_b":aaa,"$b":$9,"ac":_9,"bc":Z9,"cc":Y9,"dc":X9,"ec":W9,"fc":B$,"gc":V9,"hc":U9,"ic":T9,"jc":S9,"kc":A$,"lc":R9,"mc":Q9,"nc":P9,"oc":O9,"pc":N9,"qc":M9,"rc":L9,"sc":Cd,"tc":h6,"uc":Nla,"vc":Tka,"wc":qja,"xc":H$,"yc":G$,"zc":kb,"Ac":t$,"Bc":z$,"Cc":y$,"Dc":x$,"Ec":w$,"Fc":v$,"Gc":u$,"Hc":t$,"Ic":s$,"Jc":r$,"Kc":q$}}return sb(ub)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


